@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: CreateDOMDocument.cpp,v 1.20 2004/09/08 13:55:30 peiyongz Exp $
+ * $Id: CreateDOMDocument.cpp 176288 2005-01-12 20:43:22Z cargilld $
  */
 
 /*
@@ -86,7 +86,7 @@ private :
 //  main
 // ---------------------------------------------------------------------------
 
-int main(int argC, char* argV[])
+int main(int argC, char* /* argV[] */)
 {
     // Initialize the XML4C2 system.
     try
