@@ -1,96 +1,56 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DOMPrint.cpp,v 1.48 2002/07/15 15:44:18 peiyongz Exp $
+ * $Id: DOMPrint.cpp 176026 2004-09-08 13:57:07Z peiyongz $
  */
 
 // ---------------------------------------------------------------------------
 //  This sample program invokes the XercesDOMParser to build a DOM tree for
-//  the specified input file. It then invokes DOMWriter::writeNode() to 
+//  the specified input file. It then invokes DOMWriter::writeNode() to
 //  serialize the resultant DOM tree back to XML stream.
 //
 //  Note:
-//  Application needs to provide its own implementation of 
-//		   DOMErrorHandler (in this sample, the DOMPrintErrorHandler), 
-//		   if it would like to receive notification from the serializer 
+//  Application needs to provide its own implementation of
+//		   DOMErrorHandler (in this sample, the DOMPrintErrorHandler),
+//		   if it would like to receive notification from the serializer
 //		   in the case any error occurs during the serialization.
 //
-//  Application needs to provide its own implementation of 
-//		   DOMWriterFilter (in this sample, the DOMPrintFilter), 
-//		   if it would like to filter out certain part of the DOM 
-//		   representation, but must be aware that thus may render the 
+//  Application needs to provide its own implementation of
+//		   DOMWriterFilter (in this sample, the DOMPrintFilter),
+//		   if it would like to filter out certain part of the DOM
+//		   representation, but must be aware that thus may render the
 //		   resultant XML stream invalid.
 //
-//  Application may choose any combination of characters as the 
-//		   end of line sequence to be used in the resultant XML stream, 
-//		   but must be aware that thus may render the resultant XML 
+//  Application may choose any combination of characters as the
+//		   end of line sequence to be used in the resultant XML stream,
+//		   but must be aware that thus may render the resultant XML
 //		   stream ill formed.
 //
-//  Application may choose a particular encoding name in which 
-//		   the output XML stream would be, but must be aware that if 
-//		   characters, unrepresentable in the encoding specified, appearing 
-//		   in markups, may force the serializer to terminate serialization 
+//  Application may choose a particular encoding name in which
+//		   the output XML stream would be, but must be aware that if
+//		   characters, unrepresentable in the encoding specified, appearing
+//		   in markups, may force the serializer to terminate serialization
 //		   prematurely, and thus no complete serialization would be done.
 //
-//  Application shall query the serializer first, before set any 
+//  Application shall query the serializer first, before set any
 //           feature/mode(true, false), or be ready to catch exception if this
 //           feature/mode is not supported by the serializer.
 //
-//  Application needs to clean up the filter, error handler and 
+//  Application needs to clean up the filter, error handler and
 //		   format target objects created for the serialization.
 //
 //   Limitations:
@@ -113,12 +73,14 @@
 #include <xercesc/dom/DOMWriter.hpp>
 
 #include <xercesc/framework/StdOutFormatTarget.hpp>
+#include <xercesc/framework/LocalFileFormatTarget.hpp>
 #include <xercesc/parsers/XercesDOMParser.hpp>
 #include <xercesc/util/XMLUni.hpp>
 
 #include "DOMTreeErrorReporter.hpp"
 #include "DOMPrintFilter.hpp"
 #include "DOMPrintErrorHandler.hpp"
+#include <xercesc/util/OutOfMemoryException.hpp>
 
 #include <string.h>
 #include <stdlib.h>
@@ -146,9 +108,6 @@
 //      The encoding we are to output in. If not set on the command line,
 //      then it is defaults to the encoding of the input XML file.
 //
-//  gMyEOLSequence
-//      The end of line sequence we are to output.
-//
 //  gSplitCdataSections
 //      Indicates whether split-cdata-sections is to be enabled or not.
 //
@@ -167,19 +126,25 @@ static char*                    gXmlFile               = 0;
 static bool                     gDoNamespaces          = false;
 static bool                     gDoSchema              = false;
 static bool                     gSchemaFullChecking    = false;
-static bool                     gDoCreate              = true;
+static bool                     gDoCreate              = false;
 
+static char*                    goutputfile            = 0;
 // options for DOMWriter's features
-static const XMLCh*             gOutputEncoding        = 0;
-static const XMLCh*             gMyEOLSequence         = 0;
+static XMLCh*                   gOutputEncoding        = 0;
 
 static bool                     gSplitCdataSections    = true;
 static bool                     gDiscardDefaultContent = true;
 static bool                     gUseFilter             = false;
 static bool                     gFormatPrettyPrint     = false;
+static bool                     gWriteBOM              = false;
 
 static XercesDOMParser::ValSchemes    gValScheme       = XercesDOMParser::Val_Auto;
 
+
+//	Prototypes for internally used functions
+void usage();
+
+
 // ---------------------------------------------------------------------------
 //
 //  Usage()
@@ -187,10 +152,10 @@ static XercesDOMParser::ValSchemes    gValScheme       = XercesDOMParser::Val_Au
 // ---------------------------------------------------------------------------
 void usage()
 {
-    cout << "\nUsage:\n"
+    XERCES_STD_QUALIFIER cout << "\nUsage:\n"
             "    DOMPrint [options] <XML file>\n\n"
             "This program invokes the DOM parser, and builds the DOM tree.\n"
-            "It then asks the DOMWriter to serialize the DOM tree \n"
+            "It then asks the DOMWriter to serialize the DOM tree.\n"
             "Options:\n"
             "    -e          create entity reference nodes. Default is no expansion.\n"
             "    -v=xxx      Validation scheme [always | never | auto*].\n"
@@ -200,17 +165,18 @@ void usage()
             "    -wenc=XXX   Use a particular encoding for output. Default is\n"
             "                the same encoding as the input XML file. UTF-8 if\n"
             "                input XML file has not XML declaration.\n"
-            "    -weol=xxx   Set the end of line sequence. Default set by DOMWriter\n"
-            "    -wscs=xxx   Enable/Disable split-cdata-sections.      Default on  \n"
-            "    -wddc=xxx   Enable/Disable discard-default-content.   Default on  \n"
-            "    -wflt=xxx   Enable/Disable filtering.                 Default off \n"
-            "    -wfpp=xxx   Enable/Disable format-pretty-print.       Default off \n"
+            "    -wfile=xxx  Write to a file instead of stdout.\n"
+            "    -wscs=xxx   Enable/Disable split-cdata-sections.      Default on\n"
+            "    -wddc=xxx   Enable/Disable discard-default-content.   Default on\n"
+            "    -wflt=xxx   Enable/Disable filtering.                 Default off\n"
+            "    -wfpp=xxx   Enable/Disable format-pretty-print.       Default off\n"
+            "    -wbom=xxx   Enable/Disable write Byte-Order-Mark      Default off\n"
             "    -?          Show this help.\n\n"
             "  * = Default if not provided explicitly.\n\n"
             "The parser has intrinsic support for the following encodings:\n"
             "    UTF-8, USASCII, ISO8859-1, UTF-16[BL]E, UCS-4[BL]E,\n"
-            "    WINDOWS-1252, IBM1140, IBM037.\n"
-          <<  endl;
+            "    WINDOWS-1252, IBM1140, IBM037, IBM1047.\n"
+          <<  XERCES_STD_QUALIFIER endl;
 }
 
 // ---------------------------------------------------------------------------
@@ -230,9 +196,9 @@ int main(int argC, char* argV[])
 
     catch(const XMLException &toCatch)
     {
-        cerr << "Error during Xerces-c Initialization.\n"
+        XERCES_STD_QUALIFIER cerr << "Error during Xerces-c Initialization.\n"
              << "  Exception message:"
-             << StrX(toCatch.getMessage()) << endl;
+             << StrX(toCatch.getMessage()) << XERCES_STD_QUALIFIER endl;
         return 1;
     }
 
@@ -272,7 +238,7 @@ int main(int argC, char* argV[])
                 gValScheme = XercesDOMParser::Val_Always;
             else
             {
-                cerr << "Unknown -v= value: " << parm << endl;
+                XERCES_STD_QUALIFIER cerr << "Unknown -v= value: " << parm << XERCES_STD_QUALIFIER endl;
                 XMLPlatformUtils::Terminate();
                 return 2;
             }
@@ -301,12 +267,11 @@ int main(int argC, char* argV[])
         {
              // Get out the encoding name
              gOutputEncoding = XMLString::transcode( &(argV[parmInd][6]) );
-        }			
-         else if (!strncmp(argV[parmInd], "-weol=", 6))
+        }
+         else if (!strncmp(argV[parmInd], "-wfile=", 7))
         {
-             // Get out the end of line
-             gMyEOLSequence = XMLString::transcode( &(argV[parmInd][6]) );
-        }			
+             goutputfile =  &(argV[parmInd][7]);
+        }
          else if (!strncmp(argV[parmInd], "-wddc=", 6))
         {
             const char* const parm = &argV[parmInd][6];
@@ -317,13 +282,13 @@ int main(int argC, char* argV[])
 				gDiscardDefaultContent = false;
             else
             {
-                cerr << "Unknown -wddc= value: " << parm << endl;
+                XERCES_STD_QUALIFIER cerr << "Unknown -wddc= value: " << parm << XERCES_STD_QUALIFIER endl;
                 XMLPlatformUtils::Terminate();
                 return 2;
             }
 
         }
-         else if (!strncmp(argV[parmInd], "-wcsc=", 6))
+         else if (!strncmp(argV[parmInd], "-wscs=", 6))
         {
             const char* const parm = &argV[parmInd][6];
 
@@ -333,7 +298,7 @@ int main(int argC, char* argV[])
 				gSplitCdataSections = false;
             else
             {
-                cerr << "Unknown -wcsc= value: " << parm << endl;
+                XERCES_STD_QUALIFIER cerr << "Unknown -wscs= value: " << parm << XERCES_STD_QUALIFIER endl;
                 XMLPlatformUtils::Terminate();
                 return 2;
             }
@@ -348,7 +313,7 @@ int main(int argC, char* argV[])
 				gUseFilter = false;
             else
             {
-                cerr << "Unknown -wflt= value: " << parm << endl;
+                XERCES_STD_QUALIFIER cerr << "Unknown -wflt= value: " << parm << XERCES_STD_QUALIFIER endl;
                 XMLPlatformUtils::Terminate();
                 return 2;
             }
@@ -363,15 +328,30 @@ int main(int argC, char* argV[])
 				gFormatPrettyPrint = false;
             else
             {
-                cerr << "Unknown -wfpp= value: " << parm << endl;
+                XERCES_STD_QUALIFIER cerr << "Unknown -wfpp= value: " << parm << XERCES_STD_QUALIFIER endl;
+                XMLPlatformUtils::Terminate();
+                return 2;
+            }
+        }
+         else if (!strncmp(argV[parmInd], "-wbom=", 6))
+        {
+            const char* const parm = &argV[parmInd][6];
+
+            if (!strcmp(parm, "on"))
+                gWriteBOM = true;
+            else if (!strcmp(parm, "off"))
+                gWriteBOM = false;
+            else
+            {
+                XERCES_STD_QUALIFIER cerr << "Unknown -wbom= value: " << parm << XERCES_STD_QUALIFIER endl;
                 XMLPlatformUtils::Terminate();
                 return 2;
             }
         }
          else
         {
-            cerr << "Unknown option '" << argV[parmInd]
-                 << "', ignoring it.\n" << endl;
+            XERCES_STD_QUALIFIER cerr << "Unknown option '" << argV[parmInd]
+                 << "', ignoring it.\n" << XERCES_STD_QUALIFIER endl;
         }
     }
 
@@ -411,111 +391,132 @@ int main(int argC, char* argV[])
     {
         parser->parse(gXmlFile);
     }
-
+    catch (const OutOfMemoryException&)
+    {
+        XERCES_STD_QUALIFIER cerr << "OutOfMemoryException" << XERCES_STD_QUALIFIER endl;
+        errorsOccured = true;
+    }
     catch (const XMLException& e)
     {
-        cerr << "An error occurred during parsing\n   Message: "
-             << StrX(e.getMessage()) << endl;
+        XERCES_STD_QUALIFIER cerr << "An error occurred during parsing\n   Message: "
+             << StrX(e.getMessage()) << XERCES_STD_QUALIFIER endl;
         errorsOccured = true;
     }
 
     catch (const DOMException& e)
     {
-       cerr << "A DOM error occurred during parsing\n   DOMException code: "
-             << e.code << endl;
+        const unsigned int maxChars = 2047;
+        XMLCh errText[maxChars + 1];
+
+        XERCES_STD_QUALIFIER cerr << "\nDOM Error during parsing: '" << gXmlFile << "'\n"
+             << "DOMException code is:  " << e.code << XERCES_STD_QUALIFIER endl;
+
+        if (DOMImplementation::loadDOMExceptionMsg(e.code, errText, maxChars))
+             XERCES_STD_QUALIFIER cerr << "Message is: " << StrX(errText) << XERCES_STD_QUALIFIER endl;
+
         errorsOccured = true;
     }
 
     catch (...)
     {
-        cerr << "An error occurred during parsing\n " << endl;
+        XERCES_STD_QUALIFIER cerr << "An error occurred during parsing\n " << XERCES_STD_QUALIFIER endl;
         errorsOccured = true;
     }
 
     // If the parse was successful, output the document data from the DOM tree
     if (!errorsOccured && !errReporter->getSawErrors())
     {
-		DOMPrintFilter   *myFilter = 0;
+        DOMPrintFilter   *myFilter = 0;
 
         try
         {
-			// get a serializer, an instance of DOMWriter
-			XMLCh tempStr[100];
-			XMLString::transcode("LS", tempStr, 99);
-			DOMImplementation *impl          = DOMImplementationRegistry::getDOMImplementation(tempStr);
-			DOMWriter         *theSerializer = ((DOMImplementationLS*)impl)->createDOMWriter();
+            // get a serializer, an instance of DOMWriter
+            XMLCh tempStr[100];
+            XMLString::transcode("LS", tempStr, 99);
+            DOMImplementation *impl          = DOMImplementationRegistry::getDOMImplementation(tempStr);
+            DOMWriter         *theSerializer = ((DOMImplementationLS*)impl)->createDOMWriter();
 
-			// set user specified end of line sequence and output encoding
-			theSerializer->setNewLine(gMyEOLSequence);
-			theSerializer->setEncoding(gOutputEncoding);
+            // set user specified output encoding
+            theSerializer->setEncoding(gOutputEncoding);
 
-			// plug in user's own filter
-			if (gUseFilter)
-			{
-				// even we say to show attribute, but the DOMWriter
-				// will not show attribute nodes to the filter as
-				// the specs explicitly says that DOMWriter shall
-				// NOT show attributes to DOMWriterFilter.
-				//
-				// so DOMNodeFilter::SHOW_ATTRIBUTE has no effect.
-				// same DOMNodeFilter::SHOW_DOCUMENT_TYPE, no effect.
-				//
-				myFilter = new DOMPrintFilter(DOMNodeFilter::SHOW_ELEMENT   |
+            // plug in user's own filter
+            if (gUseFilter)
+            {
+                // even we say to show attribute, but the DOMWriter
+                // will not show attribute nodes to the filter as
+                // the specs explicitly says that DOMWriter shall
+                // NOT show attributes to DOMWriterFilter.
+                //
+                // so DOMNodeFilter::SHOW_ATTRIBUTE has no effect.
+                // same DOMNodeFilter::SHOW_DOCUMENT_TYPE, no effect.
+                //
+                myFilter = new DOMPrintFilter(DOMNodeFilter::SHOW_ELEMENT   |
                                               DOMNodeFilter::SHOW_ATTRIBUTE |
-                                              DOMNodeFilter::SHOW_DOCUMENT_TYPE
-											  );
-				theSerializer->setFilter(myFilter);
-			}
+                                              DOMNodeFilter::SHOW_DOCUMENT_TYPE);
+                theSerializer->setFilter(myFilter);
+            }
 
-			// plug in user's own error handler
-			DOMErrorHandler *myErrorHandler = new DOMPrintErrorHandler();
-			theSerializer->setErrorHandler(myErrorHandler);
+            // plug in user's own error handler
+            DOMErrorHandler *myErrorHandler = new DOMPrintErrorHandler();
+            theSerializer->setErrorHandler(myErrorHandler);
 
-			// set feature if the serializer supports the feature/mode
-			if (theSerializer->canSetFeature(XMLUni::fgDOMWRTSplitCdataSections, gSplitCdataSections))
-				theSerializer->setFeature(XMLUni::fgDOMWRTSplitCdataSections, gSplitCdataSections);
-			
-			if (theSerializer->canSetFeature(XMLUni::fgDOMWRTDiscardDefaultContent, gDiscardDefaultContent))
-				theSerializer->setFeature(XMLUni::fgDOMWRTDiscardDefaultContent, gDiscardDefaultContent);
+            // set feature if the serializer supports the feature/mode
+            if (theSerializer->canSetFeature(XMLUni::fgDOMWRTSplitCdataSections, gSplitCdataSections))
+                theSerializer->setFeature(XMLUni::fgDOMWRTSplitCdataSections, gSplitCdataSections);
 
-			if (theSerializer->canSetFeature(XMLUni::fgDOMWRTFormatPrettyPrint, gFormatPrettyPrint))
-				theSerializer->setFeature(XMLUni::fgDOMWRTFormatPrettyPrint, gFormatPrettyPrint);
+            if (theSerializer->canSetFeature(XMLUni::fgDOMWRTDiscardDefaultContent, gDiscardDefaultContent))
+                theSerializer->setFeature(XMLUni::fgDOMWRTDiscardDefaultContent, gDiscardDefaultContent);
+
+            if (theSerializer->canSetFeature(XMLUni::fgDOMWRTFormatPrettyPrint, gFormatPrettyPrint))
+                theSerializer->setFeature(XMLUni::fgDOMWRTFormatPrettyPrint, gFormatPrettyPrint);
+
+            if (theSerializer->canSetFeature(XMLUni::fgDOMWRTBOM, gWriteBOM))
+                theSerializer->setFeature(XMLUni::fgDOMWRTBOM, gWriteBOM);
 
             //
-			// Plug in a format target to receive the resultant
-			// XML stream from the serializer.
+            // Plug in a format target to receive the resultant
+            // XML stream from the serializer.
             //
-			// StdOutFormatTarget prints the resultant XML stream
-			// to stdout once it receives any thing from the serializer.
-			//
-			XMLFormatTarget *myFormTarget = new StdOutFormatTarget();
+            // StdOutFormatTarget prints the resultant XML stream
+            // to stdout once it receives any thing from the serializer.
+            //
+            XMLFormatTarget *myFormTarget;
+            if (goutputfile)
+                myFormTarget = new LocalFileFormatTarget(goutputfile);
+            else
+                myFormTarget = new StdOutFormatTarget();
 
-			// get the DOM representation
-			DOMNode                     *doc = parser->getDocument();
-
-			//
-			// do the serialization through DOMWriter::writeNode();
-			//
-			theSerializer->writeNode(myFormTarget, *doc);
-
-			delete theSerializer;
+            // get the DOM representation
+            DOMNode                     *doc = parser->getDocument();
 
             //
-			// Filter, formatTarget and error handler
-			// are NOT owned by the serializer.
-			//
-			delete myFormTarget;
-			delete myErrorHandler;
+            // do the serialization through DOMWriter::writeNode();
+            //
+            theSerializer->writeNode(myFormTarget, *doc);
 
-			if (gUseFilter)
-				delete myFilter;      	
+            delete theSerializer;
 
+            //
+            // Filter, formatTarget and error handler
+            // are NOT owned by the serializer.
+            //
+            delete myFormTarget;
+            delete myErrorHandler;
+
+            if (gUseFilter)
+                delete myFilter;
+
+        }
+        catch (const OutOfMemoryException&)
+        {
+            XERCES_STD_QUALIFIER cerr << "OutOfMemoryException" << XERCES_STD_QUALIFIER endl;
+            retval = 5;
         }
         catch (XMLException& e)
         {
-            cerr << "An error occurred during creation of output transcoder. Msg is:"
-                << endl
-                << StrX(e.getMessage()) << endl;
+            XERCES_STD_QUALIFIER cerr << "An error occurred during creation of output transcoder. Msg is:"
+                << XERCES_STD_QUALIFIER endl
+                << StrX(e.getMessage()) << XERCES_STD_QUALIFIER endl;
             retval = 4;
         }
 
@@ -538,8 +539,7 @@ int main(int argC, char* argV[])
     // And call the termination method
     XMLPlatformUtils::Terminate();
 
-	delete (void *)gOutputEncoding;        // const problems.
-	delete (void *)gMyEOLSequence;         // const problems.
+    XMLString::release(&gOutputEncoding);
 
     return retval;
 }
