@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: RedirectHandlers.cpp,v 1.10 2004/09/08 13:55:33 peiyongz Exp $
+ * $Id: RedirectHandlers.cpp 176370 2005-04-05 15:16:36Z cargilld $
  */
 
 
@@ -61,9 +61,9 @@ static const XMLCh  gRedirectToFile[] =
 // ---------------------------------------------------------------------------
 RedirectHandlers::RedirectHandlers() :
 
-    fElementCount(0)
-    , fAttrCount(0)
+    fAttrCount(0)
     , fCharacterCount(0)
+    , fElementCount(0)
     , fSpaceCount(0)
 {
 }
@@ -76,20 +76,20 @@ RedirectHandlers::~RedirectHandlers()
 // ---------------------------------------------------------------------------
 //  RedirectHandlers: Implementation of the SAX DocumentHandler interface
 // ---------------------------------------------------------------------------
-void RedirectHandlers::startElement(const   XMLCh* const    name
+void RedirectHandlers::startElement(const   XMLCh* const    /* name */
                                     ,       AttributeList&  attributes)
 {
     fElementCount++;
     fAttrCount += attributes.getLength();
 }
 
-void RedirectHandlers::characters(  const   XMLCh* const    chars
+void RedirectHandlers::characters(  const   XMLCh* const    /* chars */
                                     , const unsigned int    length)
 {
     fCharacterCount += length;
 }
 
-void RedirectHandlers::ignorableWhitespace( const   XMLCh* const chars
+void RedirectHandlers::ignorableWhitespace( const   XMLCh* const /* chars */
                                             , const unsigned int length)
 {
     fSpaceCount += length;
@@ -133,10 +133,12 @@ void RedirectHandlers::warning(const SAXParseException& e)
 }
 
 
+#if 0
+// This is the old resolveEntity interface...
 // -----------------------------------------------------------------------
 //  Handlers for the SAX EntityResolver interface
 // -----------------------------------------------------------------------
-InputSource* RedirectHandlers::resolveEntity(const   XMLCh* const    publicId
+InputSource* RedirectHandlers::resolveEntity(const   XMLCh* const    /* publicId */
                                              , const XMLCh* const    systemId)
 {
     //
@@ -167,3 +169,38 @@ InputSource* RedirectHandlers::resolveEntity(const   XMLCh* const    publicId
     // They were equal, so redirect to our other file
     return new LocalFileInputSource(gRedirectToFile);
 }
+#endif
+// -----------------------------------------------------------------------
+//  Handlers for the XMLEntityResolver interface
+// -----------------------------------------------------------------------
+
+InputSource* RedirectHandlers::resolveEntity(XMLResourceIdentifier* resourceIdentifier)
+{
+    //
+    //  If its our file, then create a new URL input source for the file that
+    //  we want to really be used. Otherwise, just return zero to let the
+    //  default action occur.
+    //
+    //  We cannot assume that the XMLCh type is ok to pass to wcscmp(), so
+    //  just do a comparison ourselves.
+    //
+    const XMLCh* s1 = gFileToTrap;
+    const XMLCh* s2 = resourceIdentifier->getSystemId();
+    while (true)
+    {
+        // Break out on any difference
+        if (*s1 != *s2)
+            return 0;
+
+        // If one is null, then both were null, so they are equal
+        if (!*s1)
+            break;
+
+        // Else get the next char
+        s1++;
+        s2++;
+    }
+
+    // They were equal, so redirect to our other file
+    return new LocalFileInputSource(gRedirectToFile);
+}
