@@ -1,61 +1,36 @@
 /*
-* The Apache Software License, Version 1.1
-*
-* Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
-* reserved.
-*
-* Redistribution and use in source and binary forms, with or without
-* modification, are permitted provided that the following conditions
-* are met:
-*
-* 1. Redistributions of source code must retain the above copyright
-*    notice, this list of conditions and the following disclaimer.
-*
-* 2. Redistributions in binary form must reproduce the above copyright
-*    notice, this list of conditions and the following disclaimer in
-*    the documentation and/or other materials provided with the
-*    distribution.
-*
-* 3. The end-user documentation included with the redistribution,
-*    if any, must include the following acknowledgment:
-*       "This product includes software developed by the
-*        Apache Software Foundation (http://www.apache.org/)."
-*    Alternately, this acknowledgment may appear in the software itself,
-*    if and wherever such third-party acknowledgments normally appear.
-*
-* 4. The names "Xerces" and "Apache Software Foundation" must
-*    not be used to endorse or promote products derived from this
-*    software without prior written permission. For written
-*    permission, please contact apache\@apache.org.
-*
-* 5. Products derived from this software may not be called "Apache",
-*    nor may "Apache" appear in their name, without prior written
-*    permission of the Apache Software Foundation.
-*
-* THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
-* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-* OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-* DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
-* ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-* USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-* OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-* SUCH DAMAGE.
-* ====================================================================
-*
-* This software consists of voluntary contributions made by many
-* individuals on behalf of the Apache Software Foundation, and was
-* originally based on software copyright (c) 1999, International
-* Business Machines, Inc., http://www.ibm.com .  For more information
-* on the Apache Software Foundation, please see
-* <http://www.apache.org/>.
-*/
+ * Copyright 1999-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 /*
-* $Log: SAX2Count.cpp,v $
+* $Log$
+* Revision 1.30  2005/03/16 15:08:33  gareth
+* Fix possible overflow problem. Patch by Matthew Hall.
+*
+* Revision 1.29  2004/09/08 13:55:33  peiyongz
+* Apache License Version 2.0
+*
+* Revision 1.28  2004/09/02 14:59:29  cargilld
+* Add OutOfMemoryException block to samples.
+*
+* Revision 1.27  2004/04/13 19:40:47  peiyongz
+* usage
+*
+* Revision 1.26  2004/04/13 16:47:02  peiyongz
+* command line option to turn on/off Identity Constraint checking
+*
 * Revision 1.25  2003/05/30 09:36:36  gareth
 * Use new macros for iostream.h and std:: issues.
 *
@@ -148,6 +123,7 @@
 #else
 #include <fstream.h>
 #endif
+#include <xercesc/util/OutOfMemoryException.hpp>
 
 // ---------------------------------------------------------------------------
 //  Local helper methods
@@ -169,6 +145,8 @@ void usage()
             "                NOTE: THIS IS OPPOSITE FROM OTHER SAMPLES.\n"
             "    -s          Disable schema processing. Defaults to on.\n"
             "                NOTE: THIS IS OPPOSITE FROM OTHER SAMPLES.\n"
+            "    -i          Disable identity constraint checking. Defaults to on.\n"
+            "                NOTE: THIS IS OPPOSITE FROM OTHER SAMPLES.\n"
             "    -locale=ll_CC specify the locale, default: en_US.\n"
             "    -?          Show this help.\n\n"
             "  * = Default if not provided explicitly.\n"
@@ -194,6 +172,7 @@ int main(int argC, char* argV[])
     bool                         doNamespaces = true;
     bool                         doSchema = true;
     bool                         schemaFullChecking = false;
+    bool                         identityConstraintChecking = true;
     bool                         doList = false;
     bool                         errorOccurred = false;
     bool                         namespacePrefixes = false;
@@ -245,6 +224,11 @@ int main(int argC, char* argV[])
               ||  !strcmp(argV[argInd], "-F"))
         {
             schemaFullChecking = true;
+        }
+         else if (!strcmp(argV[argInd], "-i")
+              ||  !strcmp(argV[argInd], "-I"))
+        {
+            identityConstraintChecking = false;
         }
          else if (!strcmp(argV[argInd], "-l")
               ||  !strcmp(argV[argInd], "-L"))
@@ -267,7 +251,7 @@ int main(int argC, char* argV[])
          else if (!strncmp(argV[argInd], "-locale=", 8))
         {
              // Get out the end of line
-             strcpy(localeStr, &(argV[argInd][8]));
+             strncpy(localeStr, &(argV[argInd][8]), sizeof localeStr);
         }			
         else
         {
@@ -319,6 +303,7 @@ int main(int argC, char* argV[])
     parser->setFeature(XMLUni::fgSAX2CoreNameSpaces, doNamespaces);
     parser->setFeature(XMLUni::fgXercesSchema, doSchema);
     parser->setFeature(XMLUni::fgXercesSchemaFullChecking, schemaFullChecking);
+    parser->setFeature(XMLUni::fgXercesIdentityConstraintChecking, identityConstraintChecking);
     parser->setFeature(XMLUni::fgSAX2CoreNameSpacePrefixes, namespacePrefixes);
 
     if (valScheme == SAX2XMLReader::Val_Auto)
@@ -396,7 +381,12 @@ int main(int argC, char* argV[])
             const unsigned long endMillis = XMLPlatformUtils::getCurrentMillis();
             duration = endMillis - startMillis;
         }
-
+        catch (const OutOfMemoryException&)
+        {
+            XERCES_STD_QUALIFIER cerr << "OutOfMemoryException" << XERCES_STD_QUALIFIER endl;
+            errorOccurred = true;
+            continue;
+        }
         catch (const XMLException& e)
         {
             XERCES_STD_QUALIFIER cerr << "\nError during parsing: '" << xmlFile << "'\n"
