@@ -15,7 +15,10 @@
  */
 
 /*
- * $Log: SAXCountHandlers.cpp,v $
+ * $Log$
+ * Revision 1.8  2005/01/12 20:43:21  cargilld
+ * Remove warning messages.
+ *
  * Revision 1.7  2004/09/08 13:55:33  peiyongz
  * Apache License Version 2.0
  *
@@ -59,9 +62,9 @@
 // ---------------------------------------------------------------------------
 SAXCountHandlers::SAXCountHandlers() :
 
-    fElementCount(0)
-    , fAttrCount(0)
+    fAttrCount(0)
     , fCharacterCount(0)
+    , fElementCount(0)
     , fSpaceCount(0)
     , fSawErrors(false)
 {
@@ -75,20 +78,20 @@ SAXCountHandlers::~SAXCountHandlers()
 // ---------------------------------------------------------------------------
 //  SAXCountHandlers: Implementation of the SAX DocumentHandler interface
 // ---------------------------------------------------------------------------
-void SAXCountHandlers::startElement(const   XMLCh* const    name
+void SAXCountHandlers::startElement(const   XMLCh* const    /* name */
                                     ,       AttributeList&  attributes)
 {
     fElementCount++;
     fAttrCount += attributes.getLength();
 }
 
-void SAXCountHandlers::characters(  const   XMLCh* const    chars
+void SAXCountHandlers::characters(  const   XMLCh* const    /* chars */
 								    , const unsigned int    length)
 {
     fCharacterCount += length;
 }
 
-void SAXCountHandlers::ignorableWhitespace( const   XMLCh* const chars
+void SAXCountHandlers::ignorableWhitespace( const   XMLCh* const /* chars */
 										    , const unsigned int length)
 {
     fSpaceCount += length;
