@@ -15,7 +15,13 @@
  */
 
 /*
- * $Log: SCMPrint.cpp,v $
+ * $Log$
+ * Revision 1.7  2005/01/18 19:09:20  cargilld
+ * Delete memory for parser and grammarpool.  Fix from Steve Dulin.
+ *
+ * Revision 1.6  2005/01/12 21:00:47  cargilld
+ * Fix for xercesc-1219.
+ *
  * Revision 1.5  2004/09/28 04:42:21  cargilld
  * Update sample to use an error handler and only generate xsmodel when a schema document has been loaded successfully.
  *
@@ -279,17 +285,19 @@ int main(int argC, char* argV[])
         return 1;
     }
     
+    XMLGrammarPool *grammarPool;
+    SAX2XMLReaderImpl* parser;
     try
     {        
-        XMLGrammarPool *grammarPool = new XMLGrammarPoolImpl(XMLPlatformUtils::fgMemoryManager);
+        grammarPool = new XMLGrammarPoolImpl(XMLPlatformUtils::fgMemoryManager);
 
-        SAX2XMLReaderImpl* parser = new SAX2XMLReaderImpl(XMLPlatformUtils::fgMemoryManager, grammarPool);
+        parser = new SAX2XMLReaderImpl(XMLPlatformUtils::fgMemoryManager, grammarPool);
         parser->setFeature(XMLUni::fgSAX2CoreNameSpaces, true);
         parser->setFeature(XMLUni::fgXercesSchema, true);
         parser->setFeature(XMLUni::fgXercesSchemaFullChecking, schemaFullChecking);
         parser->setFeature(XMLUni::fgSAX2CoreNameSpacePrefixes, false);
-	    parser->setFeature(XMLUni::fgSAX2CoreValidation, true);
-	    parser->setFeature(XMLUni::fgXercesDynamic, true);
+        parser->setFeature(XMLUni::fgSAX2CoreValidation, true);
+        parser->setFeature(XMLUni::fgXercesDynamic, true);
         parser->setProperty(XMLUni::fgXercesScannerName, (void *)XMLUni::fgSGXMLScanner);
 
         SCMPrintHandler handler;    
@@ -395,6 +403,8 @@ int main(int argC, char* argV[])
         errorCode = 5;        
     }
     
+    delete parser;
+    delete grammarPool;
     XMLPlatformUtils::Terminate();
     
     return errorCode;
@@ -507,6 +517,10 @@ void printCompositorTypeConnector(XSModelGroup::COMPOSITOR_TYPE type)
 
 void processParticle(XSParticle *xsParticle)
 {
+    if (!xsParticle) {
+        XERCES_STD_QUALIFIER cout << "xsParticle is NULL"; 
+        return;
+    }
     XSParticle::TERM_TYPE termType = xsParticle->getTermType();
     if (termType == XSParticle::TERM_ELEMENT) {
         XSElementDeclaration *xsElement = xsParticle->getElementTerm();
