@@ -26,10 +26,10 @@ $|=1;   # Force a flush after every print
 # Setup global variables
 #
 &Getopt('sopcxmntrb');
-my $XERCESCROOT = $opt_s;
-my $targetdir              = $opt_o;
-my $ICUROOT           = $ENV{'ICUROOT'};
-my $ICUIsPresent      = (($opt_t =~ m/icu/i || $opt_m =~ m/icu/i) && length($ICUROOT) > 0);
+my $XERCESCROOT    = $opt_s;
+my $targetdir      = $opt_o;
+my $ICUROOT        = $ENV{'ICUROOT'};
+my $ICUIsPresent   = (($opt_t =~ m/icu/i || $opt_m =~ m/icu/i) && length($ICUROOT) > 0);
 my $ICUResourceDir = "$XERCESCROOT/src/xercesc/util/MsgLoaders/ICU/resources";
     
 # Check for the environment variables and exit if error
@@ -38,8 +38,8 @@ if (!length($XERCESCROOT) || !length($targetdir) || (length($opt_h) > 0) ) {
     print ("  where options are:\n");
     print ("    -s <source_directory>\n");
     print ("    -o <target_directory>\n");
-    print ("    -c <C compiler name> (e.g. gcc, cc, xlc_r, VC6, VC7, ecl or icl)\n");
-    print ("    -x <C++ compiler name> (e.g. g++, CC, aCC, c++, xlC_r, cl, ecl, ecc, icl, VC6 or VC7)\n");
+    print ("    -c <C compiler name> (e.g. gcc, cc, xlc_r, VC6, VC7, VC7.1, ecl or icl)\n");
+    print ("    -x <C++ compiler name> (e.g. g++, CC, aCC, c++, xlC_r, cl, ecl, ecc, icl, VC6, VC7 or VC7.1)\n");
     print ("    -m <message loader> can be 'inmem' \(default\), 'icu' or 'iconv'\n");
     print ("    -n <net accessor> can be 'fileonly' or 'socket' \(default\)\n");
     print ("    -t <transcoder> can be 'icu' or 'native' \(default\)\n");
@@ -48,10 +48,10 @@ if (!length($XERCESCROOT) || !length($targetdir) || (length($opt_h) > 0) ) {
     print ("    -j suppress building of ICU (speeds up builds when debugging)\n");
     print ("    -h to get help on these commands\n\n");
     print ("Example: Under unix's\n");
-    print ("    perl packageBinaries.pl -s \$HOME/xerces-c-src2_6");
-    print (" -o \$HOME/xerces-c2_6-linux -c gcc -x g++ -m inmem -n fileonly -t native\n\n");
+    print ("    perl packageBinaries.pl -s \$HOME/xerces-c-src2_7");
+    print (" -o \$HOME/xerces-c2_7-linux -c gcc -x g++ -m inmem -n fileonly -t native\n\n");
     print ("Example: Under Windows\n");
-    print ("    perl packageBinaries.pl -s \\xerces-c-src2_6");
+    print ("    perl packageBinaries.pl -s \\xerces-c-src2_7");
     print (" -o\\xerces-c2_5-win32 [-n fileonly] [-t icu]\n\n");
     print ("Note:\n");
     print ("    Under Windows, by default the XercesLib project files is\n");
@@ -145,27 +145,33 @@ if ($platform =~ m/Windows/  || ($platform =~ m/CYGWIN/ && !($opt_c =~ m/gcc/)))
       
     if ($opt_x eq "" || $opt_x =~ m/VC6/i )
     {
-        $DevStudioVer = "6.0";
+        $DevStudioVer   = "6.0";
         $VCBuildDir     = "VC6"; 
-        $ProjectDir      = "$XERCESCROOT/Projects/Win32/$VCBuildDir/xerces-all";
+        $ProjectDir     = "$XERCESCROOT/Projects/Win32/$VCBuildDir/xerces-all";
     }
+    elsif ($opt_x =~ m/VC7.1/i ) 
+    {
+        $DevStudioVer   = "7.1";
+        $VCBuildDir     = "VC7.1"; 
+        $ProjectDir     = "$XERCESCROOT/Projects/Win32/$VCBuildDir/xerces-all";
+    }    
     elsif ($opt_x =~ m/VC7/i ) 
     {
-        $DevStudioVer = "7.0";
+        $DevStudioVer   = "7.0";
         $VCBuildDir     = "VC7"; 
-        $ProjectDir      = "$XERCESCROOT/Projects/Win32/$VCBuildDir/xerces-all";
+        $ProjectDir     = "$XERCESCROOT/Projects/Win32/$VCBuildDir/xerces-all";
     }
     elsif ($opt_x =~ m/ecl/i || $opt_x =~ m/icl/i )
     {
-        $DevStudioVer = "6.1";
+        $DevStudioVer   = "6.1";
         $VCBuildDir     = "VC6"; 
-        $PlatformName = "Win64";
-        $ProjectDir       = "$XERCESCROOT/Projects/Win32/$VCBuildDir/xerces-all/all";
+        $PlatformName   = "Win64";
+        $ProjectDir     = "$XERCESCROOT/Projects/Win32/$VCBuildDir/xerces-all/all";
     }
     else
     {
         print ("Error: Invalid compilers used \n");
-        print ("-x <C++ compiler name> VC6, VC7, ecl and icl \n");        
+        print ("-x <C++ compiler name> VC6, VC7, VC7.1, ecl and icl \n");        
         exit(1);            	    	
     }
 
@@ -213,7 +219,9 @@ if ($platform =~ m/Windows/  || ($platform =~ m/CYGWIN/ && !($opt_c =~ m/gcc/)))
             changeWindowsProjectForFileOnlyNA("$XERCESCROOT/Projects/Win32/VC6/xerces-all/XercesLib/XercesLib.dsp");
         } elsif ($DevStudioVer eq "7.0") {
             changeWindowsProjectForFileOnlyNA_VC7("$XERCESCROOT/Projects/Win32/VC7/xerces-all/XercesLib/XercesLib.vcproj");
-        }
+        } elsif ($DevStudioVer eq "7.1") {
+            changeWindowsProjectForFileOnlyNA_VC7("$XERCESCROOT/Projects/Win32/VC7.1/xerces-all/XercesLib/XercesLib.vcproj");
+        }        
         #else: for now we do not build FO with ecl
     }
 
@@ -253,7 +261,17 @@ if ($platform =~ m/Windows/  || ($platform =~ m/CYGWIN/ && !($opt_c =~ m/gcc/)))
                 psystem("type buildlog_release.txt");
 
                 psystem("devenv /rebuild debug /out buildlog_debug.txt /project all allinone.sln");
-                psystem("type buildlog_debug.txt");                            	
+                psystem("type buildlog_debug.txt");
+            } elsif ($DevStudioVer eq "7.1") {
+            	# ICU only has allinone.sln for VC7.0
+            	# So the build with ICU on VC7.1 may fail until the VC7.1 version is available            	
+                pchdir ("$ICUROOT/source/allinone");
+                
+                psystem("devenv.com allinone.sln /rebuild Release /out buildlog_release.txt");
+                psystem("type buildlog_release.txt");
+
+				psystem("devenv.com allinone.sln /rebuild debug /out buildlog_debug.txt");                
+                psystem("type buildlog_debug.txt");                
             } else { #"6.1"
                 pchdir ("$ICUROOT/source/allinone/all");            	
  	  #ship release dlls only
@@ -275,7 +293,10 @@ if ($platform =~ m/Windows/  || ($platform =~ m/CYGWIN/ && !($opt_c =~ m/gcc/)))
             # clean up intermediate files to make it rebuildable
             psystem ("del /s /f *.DLL *.dll *.res *.DAT *.lib *.obj");            
             psystem( "nmake /f resources.mak > buildlog.txt 2>&1 ");
-            system("type buildlog.txt");              
+            system("type buildlog.txt");
+            # to follow 2 digits convention
+            psystem("ren XercesMessages2_7_0.DLL XercesMessages2_7.DLL");
+            psystem("ren XercesMessages2_7_0.lib XercesMessages2_7.lib");            
         }
 
         #
@@ -285,6 +306,8 @@ if ($platform =~ m/Windows/  || ($platform =~ m/CYGWIN/ && !($opt_c =~ m/gcc/)))
             change_windows_project_for_ICU("$XERCESCROOT/Projects/Win32/VC6/xerces-all/XercesLib/XercesLib.dsp", $Transcoder , $MsgLoader);
         } elsif ($DevStudioVer eq "7.0") {
             change_windows_project_for_ICU_VC7("$XERCESCROOT/Projects/Win32/VC7/xerces-all/XercesLib/XercesLib.vcproj", $Transcoder , $MsgLoader);
+        } elsif ($DevStudioVer eq "7.1") {
+            change_windows_project_for_ICU_VC7("$XERCESCROOT/Projects/Win32/VC7.1/xerces-all/XercesLib/XercesLib.vcproj", $Transcoder , $MsgLoader);            
         } else { # "6.1"
             change_windows_makefile_for_ICU("$XERCESCROOT/Projects/Win32/VC6/xerces-all/XercesLib/XercesLib.mak", $Transcoder, $MsgLoader);
         }
@@ -315,25 +338,30 @@ if ($platform =~ m/Windows/  || ($platform =~ m/CYGWIN/ && !($opt_c =~ m/gcc/)))
     if ($DevStudioVer eq "6.0") {
         if ($PlatformName eq "Win64") { # /USEENV
             psystem("msdev xerces-all.dsw /MAKE \"all - $PlatformName Release\" /USEENV /REBUILD /OUT buildlog_release.txt");
-          # psystem("msdev xerces-all.dsw /MAKE \"XercesLib - $PlatformName Debug\" /USEENV /REBUILD /OUT buildlog_debug.txt");
-          # psystem("msdev xerces-all.dsw /MAKE \"XercesDeprecatedDOMLib - $PlatformName Debug\" /USEENV /REBUILD /OUT buildlog_depdom_debug.txt");
+            psystem("msdev xerces-all.dsw /MAKE \"XercesLib - $PlatformName Debug\" /USEENV /REBUILD /OUT buildlog_debug.txt");
+            psystem("msdev xerces-all.dsw /MAKE \"XercesDeprecatedDOMLib - $PlatformName Debug\" /USEENV /REBUILD /OUT buildlog_depdom_debug.txt");
         }
         else {
             psystem("msdev xerces-all.dsw /MAKE \"all - $PlatformName Release\" /REBUILD /OUT buildlog_release.txt");
-          # psystem("msdev xerces-all.dsw /MAKE \"XercesLib - $PlatformName Debug\" /REBUILD /OUT buildlog_debug.txt");
-          # psystem("msdev xerces-all.dsw /MAKE \"XercesDeprecatedDOMLib - $PlatformName Debug\" /REBUILD /OUT buildlog_depdom_debug.txt");
+            psystem("msdev xerces-all.dsw /MAKE \"XercesLib - $PlatformName Debug\" /REBUILD /OUT buildlog_debug.txt");
+            psystem("msdev xerces-all.dsw /MAKE \"XercesDeprecatedDOMLib - $PlatformName Debug\" /REBUILD /OUT buildlog_depdom_debug.txt");
         }	
     } elsif ($DevStudioVer eq "7.0") {
         psystem("devenv /rebuild Release /out buildlog_release.txt /project all xerces-all.sln");
-      # psystem("devenv /rebuild debug /out buildlog_debug.txt /project XercesLib xerces-all.sln");        
-      # psystem("devenv /rebuild debug /out buildlog_depdom_debug.txt /project XercesDeprecatedDOMLib xerces-all.sln");                
+        psystem("devenv /rebuild debug /out buildlog_debug.txt /project XercesLib xerces-all.sln");        
+        psystem("devenv /rebuild debug /out buildlog_depdom_debug.txt /project XercesDeprecatedDOMLib xerces-all.sln");
+    } elsif ($DevStudioVer eq "7.1") {
+        psystem("devenv /rebuild Release /out buildlog_release.txt /project all xerces-all.sln");
+        psystem("devenv /rebuild debug /out buildlog_debug.txt /project XercesLib xerces-all.sln");        
+        psystem("devenv /rebuild debug /out buildlog_depdom_debug.txt /project XercesDeprecatedDOMLib xerces-all.sln");        
     } else { # "6.1"
         psystem( "nmake -f all.mak \"CFG=all - $PlatformName Release\" CPP=$opt_x.exe >buildlog_release.txt 2>&1");
     }
 
     system("type buildlog_release.txt");
-  # system("type buildlog_debug.txt");
-  # system("type buildlog_depdom_debug.txt");
+    system("type buildlog_debug.txt");
+    system("type buildlog_depdom_debug.txt");
+
 
 #
 # Population Begin
@@ -352,13 +380,13 @@ if ($platform =~ m/Windows/  || ($platform =~ m/CYGWIN/ && !($opt_c =~ m/gcc/)))
     	
         print ("\n\nCopying icu outputs ...\n");        	
         # Copy the ICU dlls and libs
-        psystem("cp -fv $ICUROOT/bin/icuuc30.dll $targetdir/bin");
-        psystem("cp -fv $ICUROOT/bin/icuuc30d.dll $targetdir/bin");
+        psystem("cp -fv $ICUROOT/bin/icuuc32.dll $targetdir/bin");
+        psystem("cp -fv $ICUROOT/bin/icuuc32d.dll $targetdir/bin");
 
-        # it seems icudt30*.DLL is generated (upper case dll)
+        # it seems icudt32*.DLL is generated (upper case dll)
         # but just case, try lower case .dll as well
-        psystem("cp -fv $ICUROOT/bin/icudt30*.DLL $targetdir/bin");
-        psystem("cp -fv $ICUROOT/bin/icudt30*.dll $targetdir/bin");
+        psystem("cp -fv $ICUROOT/bin/icudt32*.DLL $targetdir/bin");
+        psystem("cp -fv $ICUROOT/bin/icudt32*.dll $targetdir/bin");
 
         psystem("cp -fv $ICUROOT/lib/icuuc.lib $targetdir/lib");
         psystem("cp -fv $ICUROOT/lib/icuucd.lib $targetdir/lib");
@@ -382,11 +410,15 @@ if ($platform =~ m/Windows/  || ($platform =~ m/CYGWIN/ && !($opt_c =~ m/gcc/)))
     # Population::Xerces-c
     # 
     print ("\n\nCopying Xerces-c outputs ...\n");            
-    psystem("cp -fv $ReleaseBuildDir/*.dll   $targetdir/bin");
-    psystem("cp -fv $ReleaseBuildDir/*.exe $targetdir/bin");    
-    psystem("cp -fv $ReleaseBuildDir/xerces-c_*.lib $targetdir/lib");
+    psystem("cp -fv $ReleaseBuildDir/*.dll               $targetdir/bin");
+    psystem("cp -fv $ReleaseBuildDir/*.exe               $targetdir/bin");        
+    psystem("cp -fv $ReleaseBuildDir/xerces-c_*.lib      $targetdir/lib");
     psystem("cp -fv $ReleaseBuildDir/xerces-depdom_*.lib $targetdir/lib");
-           
+
+    psystem("cp -fv $DebugBuildDir/*.dll                 $targetdir/bin");
+    psystem("cp -fv $DebugBuildDir/xerces-c_*.lib        $targetdir/lib");
+    psystem("cp -fv $DebugBuildDir/xerces-depdom_*.lib   $targetdir/lib");
+               
     # Populate the etc output directory like config.status and the map file
     print ("\n\nCopying misc output to etc ...\n");
     psystem("cp -fv $XERCESCROOT/Build/Win32/$VCBuildDir/Release/obj/*.map $targetdir/etc");
@@ -677,7 +709,15 @@ if ( ($platform =~ m/AIX/i)      ||
                 else {
                     psystem ("CC=$opt_c CXX=$cXX CXXFLAGS=$icu_cxxflags CFLAGS=$icu_cflags sh ./configure --prefix=$ICUROOT");
                 }
-                                                    
+           }elsif ($platform eq 'solaris') {                       
+                if ($opt_b eq "32") {               	
+                    psystem ("CC=$opt_c CXX=$opt_x CXXFLAGS=$icu_cxxflags CFLAGS=$icu_cflags sh ./configure --prefix=$ICUROOT --disable-64bit-libs");
+                }
+                else {
+                    $icu_cxxflags = '"-w -O3 -xarch=v9"';
+                    $icu_cflags = '"-w -xO3 -xarch=v9"';                 	
+                    psystem ("CC=$opt_c CXX=$opt_x CXXFLAGS=$icu_cxxflags CFLAGS=$icu_cflags sh ./configure --prefix=$ICUROOT");
+                }                                         
             } else {
             # set the 32 bit or 64 bit
                 if ($opt_b eq "32") {
@@ -784,21 +824,21 @@ if ( ($platform =~ m/AIX/i)      ||
             print ("\n\nCopying ICU message bundles ...\n");        	
             psystem("cp -f $XERCESCROOT/msg/XercesMessages*.res $targetdir/msg");
            
-            psystem("cp -f $XERCESCROOT/lib/libXercesMessages26.0.so .");
-            psystem("find . -name 'libXercesMessages26.0.so' -exec ln -s {} libXercesMessages26.so \\;");
-            psystem("find . -name 'libXercesMessages26.so'   -exec ln -s {} libXercesMessages.so \\;");
+            psystem("cp -f $XERCESCROOT/lib/libXercesMessages27.0.so .");
+            psystem("find . -name 'libXercesMessages27.0.so' -exec ln -s {} libXercesMessages27.so \\;");
+            psystem("find . -name 'libXercesMessages27.so'   -exec ln -s {} libXercesMessages.so \\;");
                     
-            psystem("cp -f $XERCESCROOT/lib/libXercesMessages.so.26.0 .");
-            psystem("find . -name 'libXercesMessages.so.26.0' -exec ln -s {} libXercesMessages.so.26 \\;");
-            psystem("find . -name 'libXercesMessages.so.26'   -exec ln -s {} libXercesMessages.so \\;");
+            psystem("cp -f $XERCESCROOT/lib/libXercesMessages.so.27.0 .");
+            psystem("find . -name 'libXercesMessages.so.27.0' -exec ln -s {} libXercesMessages.so.27 \\;");
+            psystem("find . -name 'libXercesMessages.so.27'   -exec ln -s {} libXercesMessages.so \\;");
             
-            psystem("cp -f $XERCESCROOT/lib/libXercesMessages.sl.26.0 .");
-            psystem("find . -name 'libXercesMessages.sl.26.0' -exec ln -s {} libXercesMessages.sl.26 \\;");
-            psystem("find . -name 'libXercesMessages.sl.26'   -exec ln -s {} libXercesMessages.sl \\;");            
+            psystem("cp -f $XERCESCROOT/lib/libXercesMessages.sl.27.0 .");
+            psystem("find . -name 'libXercesMessages.sl.27.0' -exec ln -s {} libXercesMessages.sl.27 \\;");
+            psystem("find . -name 'libXercesMessages.sl.27'   -exec ln -s {} libXercesMessages.sl \\;");            
 
-            psystem("cp -f $XERCESCROOT/lib/libXercesMessages26.0.a .");
-            psystem("find . -name 'libXercesMessages26.0.a'   -exec ln -s {} libXercesMessages26.a \\;");
-            psystem("find . -name 'libXercesMessages26.a'     -exec ln -s {} libXercesMessages.a \\;");
+            psystem("cp -f $XERCESCROOT/lib/libXercesMessages27.0.a .");
+            psystem("find . -name 'libXercesMessages27.0.a'   -exec ln -s {} libXercesMessages27.a \\;");
+            psystem("find . -name 'libXercesMessages27.a'     -exec ln -s {} libXercesMessages.a \\;");
                                
         }        	
 
@@ -817,59 +857,59 @@ if ( ($platform =~ m/AIX/i)      ||
     pchdir ("$targetdir/lib");
     psystem("rm -f libxerces-c* ");
 
-    if ((-e "$XERCESCROOT/lib/libxerces-c.so.26.0" )) {
-        psystem("cp -f $XERCESCROOT/lib/libxerces-c.so.26.0 .");
-        psystem("ln -s libxerces-c.so.26.0 libxerces-c.so.26 ");
-        psystem("ln -s libxerces-c.so.26   libxerces-c.so    ");     
+    if ((-e "$XERCESCROOT/lib/libxerces-c.so.27.0" )) {
+        psystem("cp -f $XERCESCROOT/lib/libxerces-c.so.27.0 .");
+        psystem("ln -s libxerces-c.so.27.0 libxerces-c.so.27 ");
+        psystem("ln -s libxerces-c.so.27   libxerces-c.so    ");     
     }
 
-    if ((-e "$XERCESCROOT/lib/libxerces-depdom.so.26.0" )) {
-        psystem("cp -f $XERCESCROOT/lib/libxerces-depdom.so.26.0 .");
-        psystem("ln -s libxerces-depdom.so.26.0 libxerces-depdom.so.26 ");
-        psystem("ln -s libxerces-depdom.so.26   libxerces-depdom.so    ");        
+    if ((-e "$XERCESCROOT/lib/libxerces-depdom.so.27.0" )) {
+        psystem("cp -f $XERCESCROOT/lib/libxerces-depdom.so.27.0 .");
+        psystem("ln -s libxerces-depdom.so.27.0 libxerces-depdom.so.27 ");
+        psystem("ln -s libxerces-depdom.so.27   libxerces-depdom.so    ");        
     }
 
-    if ((-e "$XERCESCROOT/lib/libxerces-c.sl.26.0" )) {
-        psystem("cp -f $XERCESCROOT/lib/libxerces-c.sl.26.0 .");
-        psystem("ln -s libxerces-c.sl.26.0 libxerces-c.sl.26 ");
-        psystem("ln -s libxerces-c.sl.26   libxerces-c.sl    ");               
+    if ((-e "$XERCESCROOT/lib/libxerces-c.sl.27.0" )) {
+        psystem("cp -f $XERCESCROOT/lib/libxerces-c.sl.27.0 .");
+        psystem("ln -s libxerces-c.sl.27.0 libxerces-c.sl.27 ");
+        psystem("ln -s libxerces-c.sl.27   libxerces-c.sl    ");               
     }
 
-    if ((-e "$XERCESCROOT/lib/libxerces-depdom.sl.26.0" )) {
-        psystem("cp -f $XERCESCROOT/lib/libxerces-depdom.sl.26.0 .");
-        psystem("ln -s libxerces-depdom.sl.26.0 libxerces-depdom.sl.26 ");
-        psystem("ln -s libxerces-depdom.sl.26   libxerces-depdom.sl    ");
+    if ((-e "$XERCESCROOT/lib/libxerces-depdom.sl.27.0" )) {
+        psystem("cp -f $XERCESCROOT/lib/libxerces-depdom.sl.27.0 .");
+        psystem("ln -s libxerces-depdom.sl.27.0 libxerces-depdom.sl.27 ");
+        psystem("ln -s libxerces-depdom.sl.27   libxerces-depdom.sl    ");
     }
                 
-    if ((-e "$XERCESCROOT/lib/libxerces-c26.0.so" )) {
-        psystem("cp -f $XERCESCROOT/lib/libxerces-c26.0.so .");
-        psystem("ln -s libxerces-c26.0.so libxerces-c26.so  ");
-        psystem("ln -s libxerces-c26.so   libxerces-c.so    ");
+    if ((-e "$XERCESCROOT/lib/libxerces-c27.0.so" )) {
+        psystem("cp -f $XERCESCROOT/lib/libxerces-c27.0.so .");
+        psystem("ln -s libxerces-c27.0.so libxerces-c27.so  ");
+        psystem("ln -s libxerces-c27.so   libxerces-c.so    ");
     }
 
-    if ((-e "$XERCESCROOT/lib/libxerces-depdom26.0.so" )) {
-        psystem("cp -f $XERCESCROOT/lib/libxerces-depdom26.0.so .");
-        psystem("ln -s libxerces-depdom26.0.so libxerces-depdom26.so  ");
-        psystem("ln -s libxerces-depdom26.so   libxerces-depdom.so    ");
+    if ((-e "$XERCESCROOT/lib/libxerces-depdom27.0.so" )) {
+        psystem("cp -f $XERCESCROOT/lib/libxerces-depdom27.0.so .");
+        psystem("ln -s libxerces-depdom27.0.so libxerces-depdom27.so  ");
+        psystem("ln -s libxerces-depdom27.so   libxerces-depdom.so    ");
     }
     
-    if ((-e "$XERCESCROOT/lib/libxerces-c26.0.a" )) {
-        psystem("cp -f $XERCESCROOT/lib/libxerces-c26.0.a . ");
-        psystem("ln -s libxerces-c26.0.a  libxerces-c26.a ");
-        psystem("ln -s libxerces-c26.a    libxerces-c.a ");         
+    if ((-e "$XERCESCROOT/lib/libxerces-c27.0.a" )) {
+        psystem("cp -f $XERCESCROOT/lib/libxerces-c27.0.a . ");
+        psystem("ln -s libxerces-c27.0.a  libxerces-c27.a ");
+        psystem("ln -s libxerces-c27.a    libxerces-c.a ");         
     }
         
-    if ((-e "$XERCESCROOT/lib/libxerces-depdom26.0.a" )) {
-        psystem("cp -f $XERCESCROOT/lib/libxerces-depdom26.0.a . ");
-        psystem("ln -s libxerces-depdom26.0.a  libxerces-depdom26.a ");
-        psystem("ln -s libxerces-depdom26.a    libxerces-depdom.a ");         
+    if ((-e "$XERCESCROOT/lib/libxerces-depdom27.0.a" )) {
+        psystem("cp -f $XERCESCROOT/lib/libxerces-depdom27.0.a . ");
+        psystem("ln -s libxerces-depdom27.0.a  libxerces-depdom27.a ");
+        psystem("ln -s libxerces-depdom27.a    libxerces-depdom.a ");         
     }        
     
     # Mac OS X
-    if ((-e "$XERCESCROOT/lib/libxerces-c.26.0.dylib" )) {
-        psystem("cp -f $XERCESCROOT/lib/libxerces-c.26.0.dylib .");
-        psystem("ln -s libxerces-c.26.0.dylib libxerces-c.26.dylib ");
-        psystem("ln -s libxerces-c.26.dylib   libxerces-c.dylib    ");
+    if ((-e "$XERCESCROOT/lib/libxerces-c.27.0.dylib" )) {
+        psystem("cp -f $XERCESCROOT/lib/libxerces-c.27.0.dylib .");
+        psystem("ln -s libxerces-c.27.0.dylib libxerces-c.27.dylib ");
+        psystem("ln -s libxerces-c.27.dylib   libxerces-c.dylib    ");
     }
 
     # Populate the Message Catalog Files
@@ -1101,52 +1141,52 @@ sub copyICUOnUNIX() {
 
         #
         # copy icudata dll
-        # For ICU 2.6:
-        # on AIX,              it is called libicudata30.0.a
-        # on Solaris/Linux,    it is called libicudata.so.30.0
-        # on HP,               it is called libicudata.sl.30.0
+        # For ICU 3.2:
+        # on AIX,              it is called libicudata32.0.a
+        # on Solaris/Linux,    it is called libicudata.so.32.0
+        # on HP,               it is called libicudata.sl.32.0
         #
         psystem("rm -f libicudata*");
-        psystem("cp -f $ICUROOT/lib/libicudata30.0.so .");
-        psystem("cp -f $ICUROOT/lib/libicudata30.0.a .");        
-        psystem("cp -f $ICUROOT/lib/libicudata.so.30.0 .");
-        psystem("cp -f $ICUROOT/lib/libicudata.sl.30.0 .");
+        psystem("cp -f $ICUROOT/lib/libicudata32.0.so .");
+        psystem("cp -f $ICUROOT/lib/libicudata32.0.a .");        
+        psystem("cp -f $ICUROOT/lib/libicudata.so.32.0 .");
+        psystem("cp -f $ICUROOT/lib/libicudata.sl.32.0 .");
         
-        psystem("find . -name 'libicudata30.0.so' -exec ln -s {} libicudata.so \\;");
-        psystem("find . -name 'libicudata30.0.so' -exec ln -s {} libicudata30.so \\;");
+        psystem("find . -name 'libicudata32.0.so' -exec ln -s {} libicudata.so \\;");
+        psystem("find . -name 'libicudata32.0.so' -exec ln -s {} libicudata32.so \\;");
 
-        psystem("find . -name 'libicudata30.0.a'  -exec ln -s {} libicudata.a \\;");
-        psystem("find . -name 'libicudata30.0.a'  -exec ln -s {} libicudata30.a \\;");
+        psystem("find . -name 'libicudata32.0.a'  -exec ln -s {} libicudata.a \\;");
+        psystem("find . -name 'libicudata32.0.a'  -exec ln -s {} libicudata32.a \\;");
         
-        psystem("find . -name 'libicudata.so.30.0' -exec ln -s {} libicudata.so \\;");
-        psystem("find . -name 'libicudata.so.30.0' -exec ln -s {} libicudata.so.30 \\;");
+        psystem("find . -name 'libicudata.so.32.0' -exec ln -s {} libicudata.so \\;");
+        psystem("find . -name 'libicudata.so.32.0' -exec ln -s {} libicudata.so.32 \\;");
 
-        psystem("find . -name 'libicudata.sl.30.0' -exec ln -s {} libicudata.sl \\;");
-        psystem("find . -name 'libicudata.sl.30.0' -exec ln -s {} libicudata.sl.30 \\;");
+        psystem("find . -name 'libicudata.sl.32.0' -exec ln -s {} libicudata.sl \\;");
+        psystem("find . -name 'libicudata.sl.32.0' -exec ln -s {} libicudata.sl.32 \\;");
 
         #
         # copy icuuc dll
-        # on AIX,              it is called libicuuc30.0.a
-        # on Solaris/Linux,    it is called libicuuc.so.30.0
-        # on HP,               it is called libicuuc.sl.30.0
+        # on AIX,              it is called libicuuc32.0.a
+        # on Solaris/Linux,    it is called libicuuc.so.32.0
+        # on HP,               it is called libicuuc.sl.32.0
         #
         psystem("rm -f libicuuc*");
-        psystem("cp -f $ICUROOT/lib/libicuuc30.0.so .");
-        psystem("cp -f $ICUROOT/lib/libicuuc30.0.a  .");        
-        psystem("cp -f $ICUROOT/lib/libicuuc.so.30.0  .");
-        psystem("cp -f $ICUROOT/lib/libicuuc.sl.30.0  .");
+        psystem("cp -f $ICUROOT/lib/libicuuc32.0.so .");
+        psystem("cp -f $ICUROOT/lib/libicuuc32.0.a  .");        
+        psystem("cp -f $ICUROOT/lib/libicuuc.so.32.0  .");
+        psystem("cp -f $ICUROOT/lib/libicuuc.sl.32.0  .");
         
-        psystem("find . -name 'libicuuc30.0.so' -exec ln -s {} libicuuc.so \\;");
-        psystem("find . -name 'libicuuc30.0.so' -exec ln -s {} libicuuc30.so \\;");
+        psystem("find . -name 'libicuuc32.0.so' -exec ln -s {} libicuuc.so \\;");
+        psystem("find . -name 'libicuuc32.0.so' -exec ln -s {} libicuuc32.so \\;");
         
-        psystem("find . -name 'libicuuc30.0.a'  -exec ln -s {} libicuuc.a \\;");
-        psystem("find . -name 'libicuuc30.0.a'  -exec ln -s {} libicuuc30.a \\;");
+        psystem("find . -name 'libicuuc32.0.a'  -exec ln -s {} libicuuc.a \\;");
+        psystem("find . -name 'libicuuc32.0.a'  -exec ln -s {} libicuuc32.a \\;");
                 
-        psystem("find . -name 'libicuuc.so.30.0' -exec ln -s {} libicuuc.so \\;");
-        psystem("find . -name 'libicuuc.so.30.0' -exec ln -s {} libicuuc.so.30 \\;");
+        psystem("find . -name 'libicuuc.so.32.0' -exec ln -s {} libicuuc.so \\;");
+        psystem("find . -name 'libicuuc.so.32.0' -exec ln -s {} libicuuc.so.32 \\;");
 
-        psystem("find . -name 'libicuuc.sl.30.0' -exec ln -s {} libicuuc.sl \\;");
-        psystem("find . -name 'libicuuc.sl.30.0' -exec ln -s {} libicuuc.sl.30 \\;");
+        psystem("find . -name 'libicuuc.sl.32.0' -exec ln -s {} libicuuc.sl \\;");
+        psystem("find . -name 'libicuuc.sl.32.0' -exec ln -s {} libicuuc.sl.32 \\;");
                
 }
 
@@ -1174,7 +1214,7 @@ sub change_windows_project_for_ICU() {
        
         if ($MsgLoader)
         {
-            $line =~ s/user32.lib/user32.lib $icuuc.lib XercesMessages2_6_0.lib/g;
+            $line =~ s/user32.lib/user32.lib $icuuc.lib XercesMessages2_7.lib/g;
         }        
         elsif ($Transcoder)
         {
@@ -1223,7 +1263,7 @@ sub change_windows_makefile_for_ICU() {
 
         if ($MsgLoader)
         {
-            $line =~ s/user32.lib/user32.lib $icuuc.lib XercesMessages2_6_0.lib/g;
+            $line =~ s/user32.lib/user32.lib $icuuc.lib XercesMessages2_7.lib/g;
         }        
         elsif ($Transcoder)
         {
@@ -1270,7 +1310,7 @@ sub change_windows_project_for_ICU_VC7() {
         
         if ($MsgLoader)
         {
-            $line =~ s/AdditionalDependencies=\"([^"]*)/AdditionalDependencies=\"$icuuc.lib XercesMessages2_6_0.lib $1/;
+            $line =~ s/AdditionalDependencies=\"([^"]*)/AdditionalDependencies=\"$icuuc.lib XercesMessages2_7.lib $1/;
         }        
         elsif ($Transcoder)
         {
