@@ -16,7 +16,7 @@
 #
 
 #
-# $Id: sanityTest.pl,v 1.26 2004/09/08 13:55:35 peiyongz Exp $
+# $Id: sanityTest.pl 176254 2004-12-24 19:21:47Z amassari $
 #
 
 
@@ -71,6 +71,8 @@ system ("SAX2Print");
 system ("SAX2Print -v=never personal.xml");
 system ("SAX2Print personal.xml");
 system ("SAX2Print -p personal-schema.xml");
+system ("SAX2Print personal.xsd");
+system ("SAX2Print -sa personal.xsd");
 
 #  Run MemParse
 system ("MemParse");
