@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: XMLDOMDocument.cpp,v 1.8 2004/09/08 13:55:35 peiyongz Exp $
+ * $Id: XMLDOMDocument.cpp 176283 2005-01-08 14:24:20Z amassari $
  */
 
 #include "stdafx.h"
@@ -926,13 +926,15 @@ STDMETHODIMP CXMLDOMDocument::load(VARIANT xmlSource, VARIANT_BOOL  *isSuccessfu
 			// try appending baseurl if exists
 			_bstr_t baseURL;
 			if (S_OK == GetBaseURL(baseURL)) {
+				TCHAR szCurFile[MAX_PATH];
+				_tcscpy(szCurFile, m_FileName);
 				// change any backslashes to slashes
-				LPTSTR loc = _tcschr(m_FileName,_T('\\'));
+				LPTSTR loc = _tcschr(szCurFile,_T('\\'));
 				while (loc != NULL) {
 					*loc = _T('/');
-					loc = _tcschr(m_FileName,_T('\\'));
+					loc = _tcschr(szCurFile,_T('\\'));
 				}
-				m_FileName = baseURL + _T("/") + m_FileName;
+				m_FileName = baseURL + _T("/") + szCurFile;
 			}
 			else {
 				TCHAR szCurDir[MAX_PATH];
