@@ -15,34 +15,7 @@
  */
 
 /*
- * $Log: XMLDOMParseError.h,v $
- * Revision 1.6  2004/09/08 13:55:36  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.5  2004/02/12 13:49:43  amassari
- * Updated version to 2.5
- *
- * Revision 1.4  2003/11/21 12:05:48  amassari
- * Updated version to 2.4
- *
- * Revision 1.3  2003/10/21 21:21:32  amassari
- * When the COM object is loaded by a late-binding engine (like WSH, or
- * Visual Basic when the type library is not preloaded in the editor), the type
- * library version stored in the resource must match the version specified in the
- * IDispatchImpl template (defaulted to 1.0), or trying to invoke a method will fail
- *
- * Revision 1.2  2003/03/14 12:44:49  tng
- * [Bug 17147] C++ namespace breaks build of XercesCOM DLL
- *
- * Revision 1.1.1.1  2002/02/01 22:21:42  peiyongz
- * sane_include
- *
- * Revision 1.3  2000/06/03 00:29:01  andyh
- * COM Wrapper changes from Curt Arnold
- *
- * Revision 1.2  2000/03/30 02:00:10  abagchi
- * Initial checkin of working code with Copyright Notice
- *
+ * $Id: XMLDOMParseError.h 191054 2005-06-17 02:56:35Z jberry $
  */
 
 #ifndef ___xmldomparseerror_h___
@@ -53,7 +26,7 @@ XERCES_CPP_NAMESPACE_USE
 
 class ATL_NO_VTABLE CXMLDOMParseError : 
 	public CComObjectRootEx<CComSingleThreadModel>,
-	public IDispatchImpl<IXMLDOMParseError, &IID_IXMLDOMParseError, &LIBID_Xerces, 2, 50>
+	public IDispatchImpl<IXMLDOMParseError, &IID_IXMLDOMParseError, &LIBID_Xerces, XERCES_VERSION_MAJOR, INVK_CAT2_RAW_NUMERIC(XERCES_VERSION_MINOR,XERCES_VERSION_REVISION)>
 {
 public:
 	CXMLDOMParseError()
