@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: XMLDOMUtil.cpp,v 1.4 2004/09/08 13:55:36 peiyongz Exp $
+ * $Id: XMLDOMUtil.cpp 176383 2005-04-22 08:27:51Z amassari $
  */
 
 #include "stdafx.h"
@@ -135,7 +135,7 @@ private:
 
 
 template <class Base>
-CComObjectPool<Base>::CComObjectPool<Base>(unsigned long poolSize) {
+CComObjectPool<Base>::CComObjectPool(unsigned long poolSize) {
 	m_pool = NULL;
 	m_size = poolSize;
 	m_pool = new Base*[m_size];
@@ -146,7 +146,7 @@ CComObjectPool<Base>::CComObjectPool<Base>(unsigned long poolSize) {
 }
 
 template <class Base>
-CComObjectPool<Base>::~CComObjectPool<Base>() {
+CComObjectPool<Base>::~CComObjectPool() {
 	for(unsigned long i = 0; i < m_size; i++) {
 		if(m_pool[i]) delete m_pool[i];
 	}
