@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: DOMCDATASection.hpp,v 1.8 2004/09/26 15:38:02 gareth Exp $
+ * $Id: DOMCDATASection.hpp 176280 2005-01-07 15:32:34Z amassari $
  */
 
 #include <xercesc/util/XercesDefs.hpp>
@@ -69,16 +69,16 @@ protected:
     // -----------------------------------------------------------------------
     /** @name Hidden constructors */
     //@{    
-    DOMCDATASection() {};
+    DOMCDATASection() {}
+    DOMCDATASection(const DOMCDATASection &other) : DOMText(other) {}
     //@}
 
 private:
     // -----------------------------------------------------------------------
     // Unimplemented constructors and operators
     // -----------------------------------------------------------------------
-    /** @name Unimplemented constructors and operators */
+    /** @name Unimplemented operators */
     //@{
-    DOMCDATASection(const DOMCDATASection &);
     DOMCDATASection & operator = (const DOMCDATASection &);
     //@}
 
