@@ -18,7 +18,7 @@
  */
 
 /*
- * $Id: DOMCharacterData.hpp,v 1.9 2004/09/08 13:55:38 peiyongz Exp $
+ * $Id: DOMCharacterData.hpp 176280 2005-01-07 15:32:34Z amassari $
  */
 
 #include <xercesc/util/XercesDefs.hpp>
@@ -49,16 +49,16 @@ protected:
     // -----------------------------------------------------------------------
     /** @name Hidden constructors */
     //@{    
-    DOMCharacterData() {};
+    DOMCharacterData() {}
+    DOMCharacterData(const DOMCharacterData &other) : DOMNode(other) {}
     //@}
 
 private:
     // -----------------------------------------------------------------------
     // Unimplemented constructors and operators
     // -----------------------------------------------------------------------
-    /** @name Unimplemented constructors and operators */
+    /** @name Unimplemented operators */
     //@{
-    DOMCharacterData(const DOMCharacterData &);
     DOMCharacterData & operator = (const DOMCharacterData &);
     //@}
 
