@@ -18,7 +18,7 @@
  */
 
 /*
- * $Id: DOMNotation.hpp,v 1.8 2004/09/26 15:38:02 gareth Exp $
+ * $Id: DOMNotation.hpp 176280 2005-01-07 15:32:34Z amassari $
  */
 
 #include <xercesc/util/XercesDefs.hpp>
@@ -47,16 +47,16 @@ protected:
     // -----------------------------------------------------------------------
     /** @name Hidden constructors */
     //@{    
-    DOMNotation() {};
+    DOMNotation() {}
+    DOMNotation(const DOMNotation &other) : DOMNode(other) {}
     //@}
 
 private:
     // -----------------------------------------------------------------------
     // Unimplemented constructors and operators
     // -----------------------------------------------------------------------
-    /** @name Unimplemented constructors and operators */
+    /** @name Unimplemented operators */
     //@{
-    DOMNotation(const DOMNotation &);
     DOMNotation & operator = (const DOMNotation &);
     //@}
 
