@@ -19,7 +19,7 @@
  */
 
 /*
- * $Id: DOMProcessingInstruction.hpp,v 1.8 2004/09/26 15:38:02 gareth Exp $
+ * $Id: DOMProcessingInstruction.hpp 176280 2005-01-07 15:32:34Z amassari $
  */
 
 #include <xercesc/util/XercesDefs.hpp>
@@ -42,16 +42,16 @@ protected:
     // -----------------------------------------------------------------------
     /** @name Hidden constructors */
     //@{    
-    DOMProcessingInstruction() {};
+    DOMProcessingInstruction() {}
+    DOMProcessingInstruction(const DOMProcessingInstruction &other) : DOMNode(other) {}
     //@}
 
 private:
     // -----------------------------------------------------------------------
     // Unimplemented constructors and operators
     // -----------------------------------------------------------------------
-    /** @name Unimplemented constructors and operators */
+    /** @name Unimplemented operators */
     //@{
-    DOMProcessingInstruction(const DOMProcessingInstruction &);
     DOMProcessingInstruction & operator = (const DOMProcessingInstruction &);
     //@}
 
