@@ -18,7 +18,7 @@
  */
 
 /*
- * $Id: DOMRange.hpp,v 1.9 2004/09/08 13:55:39 peiyongz Exp $
+ * $Id: DOMRange.hpp 176280 2005-01-07 15:32:34Z amassari $
  */
 
 #include <xercesc/util/XercesDefs.hpp>
@@ -39,16 +39,16 @@ protected:
     // -----------------------------------------------------------------------
     /** @name Hidden constructors */
     //@{    
-    DOMRange() {};
+    DOMRange() {}
+    DOMRange(const DOMRange &) {}
     //@}
 
 private:
     // -----------------------------------------------------------------------
     // Unimplemented constructors and operators
     // -----------------------------------------------------------------------
-    /** @name Unimplemented constructors and operators */
+    /** @name Unimplemented operators */
     //@{
-    DOMRange(const DOMRange &);
     DOMRange & operator = (const DOMRange &);
     //@}
 
