@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: AttrImpl.cpp,v 1.9 2004/09/08 13:55:42 peiyongz Exp $
+ * $Id: AttrImpl.cpp 176278 2005-01-07 14:38:22Z amassari $
  *
  * <p><b>WARNING</b>: Some of the code here is partially duplicated in
  * ParentNode, be careful to keep these two classes in sync!
@@ -61,7 +61,7 @@ AttrImpl::AttrImpl(DocumentImpl *ownerDoc, const DOMString &aName)
     value.child = null;
 };
 
-AttrImpl::AttrImpl(const AttrImpl &other, bool deep)
+AttrImpl::AttrImpl(const AttrImpl &other, bool /*deep*/)
     : NodeImpl(other)
 {
     name = other.name.clone();
