@@ -19,7 +19,7 @@
 *  handler with the scanner. In these handler methods, appropriate DOM nodes
 *  are created and added to the DOM tree.
 *
-* $Id: DOMParser.cpp,v 1.33 2004/09/08 13:55:42 peiyongz Exp $
+* $Id: DOMParser.cpp 176291 2005-01-14 10:37:42Z amassari $
 *
 */
 
@@ -548,8 +548,8 @@ void DOMParser::parseReset(XMLPScanToken& token)
 // ---------------------------------------------------------------------------
 //  DOMParser: Implementation of the XMLErrorReporter interface
 // ---------------------------------------------------------------------------
-void DOMParser::error(  const   unsigned int                code
-                      , const XMLCh* const                msgDomain
+void DOMParser::error(  const   unsigned int              /*code*/
+                      , const XMLCh* const                /*msgDomain*/
                       , const XMLErrorReporter::ErrTypes  errType
                       , const XMLCh* const                errorText
                       , const XMLCh* const                systemId
@@ -597,7 +597,7 @@ void DOMParser::resetErrors()
 InputSource*
 DOMParser::resolveEntity(const XMLCh* const publicId,
                          const XMLCh* const systemId,
-                         const XMLCh* const baseURI)
+                         const XMLCh* const /*baseURI*/)
 {
     //
     //  Just map it to the SAX entity resolver. If there is not one installed,
@@ -687,6 +687,10 @@ void DOMParser::endEntityReference(const XMLEntityDecl& entDecl)
     if (fCreateEntityReferenceNodes == true)
     {
         if (fCurrentParent.getNodeType() == DOM_Node::ENTITY_REFERENCE_NODE) {
+		    // stick the parsed content of this entity reference into the entity definition node
+		    EntityImpl* entity = (EntityImpl*)fDocumentType->entities->getNamedItem(entDecl.getName());
+		    entity->setEntityRef((EntityReferenceImpl*)fCurrentParent.fImpl);
+
             ((DOM_EntityReference&)fCurrentParent).fImpl->setReadOnly(true, true);
         }
         fCurrentParent = fNodeStack->pop();
@@ -695,10 +699,10 @@ void DOMParser::endEntityReference(const XMLEntityDecl& entDecl)
 }
 
 
-void DOMParser::endElement( const   XMLElementDecl&    elemDecl
-                           , const unsigned int        urlId
-                           , const bool                isRoot
-                           , const XMLCh* const        elemPrefix)
+void DOMParser::endElement( const   XMLElementDecl&    /*elemDecl*/
+                           , const unsigned int        /*urlId*/
+                           , const bool                /*isRoot*/
+                           , const XMLCh* const        /*elemPrefix*/)
 {
     fCurrentNode   = fCurrentParent;
     fCurrentParent = fNodeStack->pop();
@@ -711,7 +715,7 @@ void DOMParser::endElement( const   XMLElementDecl&    elemDecl
 
 void DOMParser::ignorableWhitespace(const   XMLCh* const    chars
                                     , const unsigned int    length
-                                    , const bool            cdataSection)
+                                    , const bool            /*cdataSection*/)
 {
     // Ignore chars before the root element
     if (!fWithinElement || !fIncludeIgnorableWhitespace)
@@ -869,13 +873,6 @@ void DOMParser::startEntityReference(const XMLEntityDecl& entDecl)
         fCurrentParent = er;
         fCurrentNode = er;
 
-		// this entityRef needs to be stored in Entity map too.
-        // We'd decide later whether the entity nodes should be created by a
-        // separated method in parser or not. For now just stick it in if
-        // the ref nodes are created
-		EntityImpl* entity = (EntityImpl*)fDocumentType->entities->getNamedItem(entName);
-		entity->setEntityRef((EntityReferenceImpl*)er.fImpl);
-
     }
 }
 
@@ -883,7 +880,7 @@ void DOMParser::startEntityReference(const XMLEntityDecl& entDecl)
 void DOMParser::XMLDecl(const   XMLCh* const version
                         , const XMLCh* const encoding
                         , const XMLCh* const standalone
-                        , const XMLCh* const actualEncStr)
+                        , const XMLCh* const /*actualEncStr*/)
 {
     //This is a non-standard extension to creating XMLDecl type nodes and attching to DOM Tree
     // currently this flag it set to false unless user explicitly asks for it
@@ -932,7 +929,7 @@ void DOMParser::attDef
 (
     const   DTDElementDecl&     elemDecl
     , const DTDAttDef&          attDef
-    , const bool                ignoring
+    , const bool                /*ignoring*/
 	)
 {	
     if (fDocumentType->isIntSubsetReading())
@@ -992,25 +989,30 @@ void DOMParser::attDef
                 break;
 
             case XMLAttDef::Enumeration :
-                attString.appendData(chSpace);
-                //  attString.appendData(XMLUni::fgEnumerationString);
-                const XMLCh* enumString = attDef.getEnumeration();
-                int length = XMLString::stringLen(enumString);
-                if (length > 0) {
+                {
+                    attString.appendData(chSpace);
+                    //  attString.appendData(XMLUni::fgEnumerationString);
+                    const XMLCh* enumString = attDef.getEnumeration();
+                    int length = XMLString::stringLen(enumString);
+                    if (length > 0) {
 
-                    DOMString anotherEnumString;
+                        DOMString anotherEnumString;
 
-                    anotherEnumString.appendData(chOpenParen );
-                    for(int i=0; i<length; i++) {
-                        if (enumString[i] == chSpace)
-                            anotherEnumString.appendData(chPipe);
-                        else
-                            anotherEnumString.appendData(enumString[i]);
+                        anotherEnumString.appendData(chOpenParen );
+                        for(int i=0; i<length; i++) {
+                            if (enumString[i] == chSpace)
+                                anotherEnumString.appendData(chPipe);
+                            else
+                                anotherEnumString.appendData(enumString[i]);
+                        }
+                        anotherEnumString.appendData(chCloseParen);
+                        attString.appendData(anotherEnumString);
                     }
-                    anotherEnumString.appendData(chCloseParen);
-                    attString.appendData(anotherEnumString);
                 }
                 break;
+            default:
+                // remaining types don't belong to a DTD
+                break;
             }
             //get te default types of the attlist
             const XMLAttDef::DefAttTypes def = attDef.getDefaultType();
@@ -1028,6 +1030,9 @@ void DOMParser::attDef
                 attString.appendData(chSpace);
                 attString.appendData(XMLUni::fgFixedString);
                 break;
+            default:
+                // remaining types don't belong to a DTD
+                break;
             }
 
             const XMLCh* defaultValue = attDef.getValue();
@@ -1071,8 +1076,8 @@ void DOMParser::doctypeDecl
     const   DTDElementDecl& elemDecl
     , const XMLCh* const    publicId
     , const XMLCh* const    systemId
-    , const bool            hasIntSubset
-    , const bool            hasExtSubset
+    , const bool            /*hasIntSubset*/
+    , const bool            /*hasExtSubset*/
 )
 {
 	DOM_DocumentType dt;
@@ -1109,7 +1114,7 @@ void DOMParser::doctypePI
 void DOMParser::doctypeWhitespace
 (
     const   XMLCh* const    chars
-    , const unsigned int    length
+    , const unsigned int    /*length*/
 )
 {
     if (fDocumentType->isIntSubsetReading())
@@ -1119,7 +1124,7 @@ void DOMParser::doctypeWhitespace
 void DOMParser::elementDecl
 (
     const   DTDElementDecl& decl
-    , const bool            isIgnored
+    , const bool            /*isIgnored*/
 )
 {
     if (fDocumentType->isIntSubsetReading())
@@ -1240,8 +1245,8 @@ void DOMParser::endExtSubset()
 void DOMParser::entityDecl
 (
     const   DTDEntityDecl&  entityDecl
-    , const bool            isPEDecl
-    , const bool            isIgnored
+    , const bool            /*isPEDecl*/
+    , const bool            /*isIgnored*/
 )
 {
 	EntityImpl* entity = ((DocumentImpl*)fDocument.fImpl)->createEntity(entityDecl.getName());
@@ -1323,7 +1328,7 @@ void DOMParser::resetDocType()
 void DOMParser::notationDecl
 (
     const   XMLNotationDecl&    notDecl
-    , const bool                isIgnored
+    , const bool                /*isIgnored*/
 )
 {
 	NotationImpl* notation = ((DocumentImpl*)fDocument.fImpl)->createNotation(notDecl.getName());
@@ -1345,7 +1350,7 @@ void DOMParser::notationDecl
 
 void DOMParser::startAttList
 (
-    const   DTDElementDecl& elemDecl
+    const   DTDElementDecl& /*elemDecl*/
 )
 {
 }
@@ -1361,8 +1366,8 @@ void DOMParser::startExtSubset()
 
 void DOMParser::TextDecl
 (
-    const   XMLCh* const    versionStr
-    , const XMLCh* const    encodingStr
+    const   XMLCh* const    /*versionStr*/
+    , const XMLCh* const    /*encodingStr*/
 )
 {
 }
