@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: RangeImpl.cpp,v 1.4 2003/05/18 14:02:03 knoaman Exp $
+ * $Id: RangeImpl.cpp 176278 2005-01-07 14:38:22Z amassari $
  */
 
 #include <xercesc/util/RefVectorOf.hpp>
@@ -80,18 +40,18 @@ XERCES_CPP_NAMESPACE_BEGIN
 
 RangeImpl::RangeImpl(DOM_Document doc)
 
-    :   fDocument(doc),
-        fStartContainer(doc),
+    :   fStartContainer(doc),
         fStartOffset(0),
         fEndContainer(doc),
         fEndOffset(0),
-        fDetached(false),
         fCollapsed(true),
+        fDocument(doc),
+        fDetached(false),
         fRemoveChild(0)
 {
 }
 
-RangeImpl::RangeImpl(const RangeImpl& other)
+RangeImpl::RangeImpl(const RangeImpl& other) : RefCountedImpl()
 {
     fDocument = other.fDocument;
     fStartContainer = other.fStartContainer;
@@ -584,6 +544,9 @@ short RangeImpl::compareBoundaryPoints(DOM_Range::CompareHow how, RangeImpl* src
         offsetB = srcRange->getEndOffset();
         offsetA = fEndOffset;
         break;
+    default:
+        throw DOM_DOMException(
+            DOM_DOMException::INVALID_STATE_ERR, null);
     }
 
     // case 1: same container
@@ -913,7 +876,7 @@ const DOM_Node RangeImpl::commonAncestorOf(const DOM_Node& pointA, const DOM_Nod
     int s = startV->size()-1;
     int e = endV->size()-1;
 
-    NodeImpl* commonAncestor;
+    NodeImpl* commonAncestor = 0;
 
     while (s>=0 && e>=0) {
         if (startV->elementAt(s) == endV->elementAt(e)) {
@@ -932,10 +895,6 @@ const DOM_Node RangeImpl::commonAncestorOf(const DOM_Node& pointA, const DOM_Nod
 
 void RangeImpl::checkIndex(const DOM_Node& node, unsigned int offset) const
 {
-    if (offset < 0) {
-        throw DOM_DOMException( DOM_DOMException::INDEX_SIZE_ERR, null );
-    }
-
     short type = node.getNodeType();
 
     if((type == DOM_Node::TEXT_NODE
