@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: DOMAttrImpl.cpp,v 1.21 2004/09/20 15:00:50 amassari Exp $
+ * $Id: DOMAttrImpl.cpp 176280 2005-01-07 15:32:34Z amassari $
  */
 
 #include <xercesc/dom/DOMDocument.hpp>
@@ -37,8 +37,12 @@ DOMAttrImpl::DOMAttrImpl(DOMDocument *ownerDoc, const XMLCh *aName)
     fNode.isSpecified(true);
 }
 
-DOMAttrImpl::DOMAttrImpl(const DOMAttrImpl &other, bool)
-    : fNode(other.fNode), fParent (other.fParent), fName(other.fName), fSchemaType(other.fSchemaType)
+DOMAttrImpl::DOMAttrImpl(const DOMAttrImpl &other, bool /*deep*/)
+    : DOMAttr(other)
+    , fNode(other.fNode)
+    , fParent (other.fParent)
+    , fName(other.fName)
+    , fSchemaType(other.fSchemaType)
 {    
     if (other.fNode.isSpecified())
         fNode.isSpecified(true);
