@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: DOMDocumentImpl.cpp,v 1.58 2004/09/08 13:55:51 peiyongz Exp $
+ * $Id: DOMDocumentImpl.cpp 176280 2005-01-07 15:32:34Z amassari $
  */
 #include "DOMDocumentImpl.hpp"
 #include "DOMCasts.hpp"
@@ -795,9 +795,9 @@ const XMLCh *  DOMDocumentImpl::getPooledString(const XMLCh *src)
 static const int kHeapAllocSize = 0x10000;    // The chunk size to allocate from the
                                               //   system allocator.
 
-static const int kMaxSubAllocationSize = 4096;   // Any request for more bytes
-                                                 //  than this will be handled by
-                                                 //  allocating directly with system.
+static const size_t kMaxSubAllocationSize = 4096;  // Any request for more bytes
+                                                   //  than this will be handled by
+                                                   //  allocating directly with system.
 
 void *         DOMDocumentImpl::allocate(size_t amount)
 {	
@@ -1016,7 +1016,7 @@ DOMNode *DOMDocumentImpl::importNode(DOMNode *source, bool deep, bool cloningDoc
                 for(XMLSize_t i=0;i<srcattr->getLength();++i)
                 {
                     DOMAttr *attr = (DOMAttr *) srcattr->item(i);
-                    if (attr -> getSpecified()) { // not a default attribute
+                    if (attr -> getSpecified() || cloningDoc) { // not a default attribute or we are in the process of cloning the elements from inside a DOMDocumentType
                         DOMAttr *nattr = (DOMAttr *) importNode(attr, true, false);
                         if (attr -> getLocalName() == 0)
                             newelement->setAttributeNode(nattr);
@@ -1111,11 +1111,23 @@ DOMNode *DOMDocumentImpl::importNode(DOMNode *source, bool deep, bool cloningDoc
                 ((DOMDocumentTypeImpl *)newdoctype)->setInternalSubset(intSubset);
             }
 
-            // NOTE: At this time, the DOM definition of DocumentType
-            // doesn't cover Elements and their Attributes. domimpl's
-            // extentions in that area will not be preserved, even if
-            // copying from domimpl to domimpl. We could special-case
-            // that here. Arguably we should. Consider. ?????
+            // detect if the DTD being copied is our own implementation, and use the provided methods
+            try
+            {
+                DOMDocumentTypeImpl* docTypeImpl=(DOMDocumentTypeImpl*)(srcdoctype->getInterface(XMLUni::fgXercescInterfaceDOMDocumentTypeImpl));
+                if(docTypeImpl)
+                {
+                    smap = docTypeImpl->getElements();
+                    tmap = ((DOMDocumentTypeImpl *)newdoctype)->getElements();
+                    if (smap != 0) {
+                        for(XMLSize_t i = 0; i < smap->getLength(); i++) {
+                            tmap->setNamedItem(importNode(smap->item(i), true, true));
+                        }
+                    }
+                }
+            } catch(DOMException&) {
+            }
+
             newnode = newdoctype;
         }
         break;
@@ -1239,11 +1251,10 @@ void DOMDocumentImpl::callUserDataHandlers(const DOMNodeImpl* n, DOMUserDataHand
                 const XMLCh* userKey = fUserDataTableKeys.getValueForId(key2);
                 handler->handle(operation, userKey, data, src, dst);
             }
-
-            // if the operation is deleted, we in fact should remove the data from the table
-            if (operation == DOMUserDataHandler::NODE_DELETED)
-                fUserDataTable->removeKey((void*)n,key2);
         }
+        // if the operation is NODE_DELETED, we in fact should remove the data from the table
+        if (operation == DOMUserDataHandler::NODE_DELETED)
+            fUserDataTable->removeKey((void*)n);
     }
 }
 
