@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: DOMDocumentTypeImpl.cpp,v 1.26 2004/09/08 13:55:51 peiyongz Exp $
+ * $Id: DOMDocumentTypeImpl.cpp 176257 2004-12-28 17:31:19Z amassari $
  */
 
 #include "DOMDocumentTypeImpl.hpp"
@@ -439,7 +439,6 @@ void DOMDocumentTypeImpl::release()
            const XMLCh*     DOMDocumentTypeImpl::lookupNamespacePrefix(const XMLCh* namespaceURI, bool useDefault) const  {return fNode.lookupNamespacePrefix(namespaceURI, useDefault); }
            bool             DOMDocumentTypeImpl::isDefaultNamespace(const XMLCh* namespaceURI) const {return fNode.isDefaultNamespace(namespaceURI); }
            const XMLCh*     DOMDocumentTypeImpl::lookupNamespaceURI(const XMLCh* prefix) const  {return fNode.lookupNamespaceURI(prefix); }
-           DOMNode*         DOMDocumentTypeImpl::getInterface(const XMLCh* feature)      {return fNode.getInterface(feature); }
 
 
 bool DOMDocumentTypeImpl::isEqualNode(const DOMNode* arg) const
@@ -534,5 +533,12 @@ bool DOMDocumentTypeImpl::isEqualNode(const DOMNode* arg) const
     return fParent.isEqualNode(arg);
 }
 
+DOMNode * DOMDocumentTypeImpl::getInterface(const XMLCh* feature)
+{
+    if(XMLString::equals(feature, XMLUni::fgXercescInterfaceDOMDocumentTypeImpl))
+        return (DOMNode*)(DOMDocumentTypeImpl*)this;
+    return fNode.getInterface(feature);
+}
+
 XERCES_CPP_NAMESPACE_END
 
