@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001-2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DOMElementImpl.cpp,v 1.23 2004/01/29 11:44:26 cargilld Exp $
+ * $Id: DOMElementImpl.cpp 176280 2005-01-07 15:32:34Z amassari $
  */
 
 #include "DOMElementImpl.hpp"
@@ -70,23 +30,19 @@
 #include "DOMAttrImpl.hpp"
 #include "DOMDocumentImpl.hpp"
 #include "DOMParentNode.hpp"
-#include "DOMStringPool.hpp"
 #include "DOMCasts.hpp"
 #include "DOMElementNSImpl.hpp"
 #include "DOMTypeInfoImpl.hpp"
 
-#include "DOMDeepNodeListImpl.hpp"
 #include "DOMDocumentTypeImpl.hpp"
-#include "DOMNamedNodeMapImpl.hpp"
 #include <xercesc/util/OutOfMemoryException.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
-
 class DOMAttr;
 
 DOMElementImpl::DOMElementImpl(DOMDocument *ownerDoc, const XMLCh *eName)
-    : fNode(ownerDoc), fParent(ownerDoc), fAttributes(0), fDefaultAttributes(0), fSchemaType(0)
+    : fNode(ownerDoc), fParent(ownerDoc), fAttributes(0), fDefaultAttributes(0)
 {
     DOMDocumentImpl *docImpl = (DOMDocumentImpl *)ownerDoc;
     fName = docImpl->getPooledString(eName);
@@ -102,11 +58,11 @@ DOMElementImpl::DOMElementImpl(DOMDocument *ownerDoc, const XMLCh *eName)
 
 
 DOMElementImpl::DOMElementImpl(const DOMElementImpl &other, bool deep)
-    : fNode(other.getOwnerDocument()),
+    : DOMElement(other),
+      fNode(other.getOwnerDocument()),
       fParent(other.getOwnerDocument()),
       fAttributes(0),
-      fDefaultAttributes(0),
-      fSchemaType(other.fSchemaType)      
+      fDefaultAttributes(0)
 {
     fName = other.fName;
 
@@ -208,7 +164,7 @@ void DOMElementImpl::removeAttribute(const XMLCh *nam)
 {
     if (fNode.isReadOnly())
         throw DOMException(
-             DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+             DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     XMLSSize_t i = fAttributes->findNamePoint(nam);
     if (i >= 0)
@@ -225,7 +181,7 @@ DOMAttr *DOMElementImpl::removeAttributeNode(DOMAttr *oldAttr)
 {
     if (fNode.isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     DOMNode* found = 0;
 
@@ -245,11 +201,11 @@ DOMAttr *DOMElementImpl::removeAttributeNode(DOMAttr *oldAttr)
             ((DOMAttrImpl *)oldAttr)->removeAttrFromIDNodeMap();
         }
         else
-            throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+            throw DOMException(DOMException::NOT_FOUND_ERR, 0, GetDOMNodeMemoryManager);
 
     }
     else
-        throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+        throw DOMException(DOMException::NOT_FOUND_ERR, 0, GetDOMNodeMemoryManager);
 
    return (DOMAttr *)found;
 }
@@ -260,7 +216,7 @@ void DOMElementImpl::setAttribute(const XMLCh *nam, const XMLCh *val)
 {
     if (fNode.isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     DOMAttr* newAttr = getAttributeNode(nam);
     if (!newAttr)
@@ -276,12 +232,12 @@ void DOMElementImpl::setIdAttribute(const XMLCh* name)
 {
     if (fNode.isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     DOMAttr *attr = getAttributeNode(name);
 
     if (!attr) 
-        throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+        throw DOMException(DOMException::NOT_FOUND_ERR, 0, GetDOMNodeMemoryManager);
 
     ((DOMAttrImpl *)attr)->addAttrToIDNodeMap();
 }
@@ -290,12 +246,12 @@ void DOMElementImpl::setIdAttributeNS(const XMLCh* namespaceURI, const XMLCh* lo
 
     if (fNode.isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     DOMAttr *attr = getAttributeNodeNS(namespaceURI, localName);
 
     if (!attr) 
-        throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+        throw DOMException(DOMException::NOT_FOUND_ERR, 0, GetDOMNodeMemoryManager);
 
     ((DOMAttrImpl *)attr)->addAttrToIDNodeMap();
 
@@ -306,7 +262,7 @@ void DOMElementImpl::setIdAttributeNode(const DOMAttr *idAttr) {
 
     if (fNode.isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     DOMAttr *attr;
     const XMLCh* localName = idAttr->getLocalName();
@@ -316,7 +272,7 @@ void DOMElementImpl::setIdAttributeNode(const DOMAttr *idAttr) {
         attr = getAttributeNode(idAttr->getName());
     
     if(!attr) 
-        throw DOMException(DOMException::NOT_FOUND_ERR, 0);
+        throw DOMException(DOMException::NOT_FOUND_ERR, 0, GetDOMNodeMemoryManager);
 
     ((DOMAttrImpl *)attr)->addAttrToIDNodeMap();
 }
@@ -326,10 +282,10 @@ DOMAttr * DOMElementImpl::setAttributeNode(DOMAttr *newAttr)
 {
     if (fNode.isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     if (newAttr->getNodeType() != DOMNode::ATTRIBUTE_NODE)
-        throw DOMException(DOMException::WRONG_DOCUMENT_ERR, 0);
+        throw DOMException(DOMException::WRONG_DOCUMENT_ERR, 0, GetDOMNodeMemoryManager);
         // revisit.  Exception doesn't match test.
 
     // This will throw INUSE if necessary
@@ -368,7 +324,7 @@ void DOMElementImpl::setAttributeNS(const XMLCh *fNamespaceURI,
 {
     if (fNode.isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     DOMAttr* newAttr = getAttributeNodeNS(fNamespaceURI, qualifiedName);
 
@@ -387,7 +343,7 @@ void DOMElementImpl::removeAttributeNS(const XMLCh *fNamespaceURI,
 {
     if (fNode.isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     XMLSSize_t i = fAttributes->findNamePoint(fNamespaceURI, fLocalName);
     if (i >= 0)
@@ -409,10 +365,10 @@ DOMAttr *DOMElementImpl::setAttributeNodeNS(DOMAttr *newAttr)
 {
     if (fNode.isReadOnly())
         throw DOMException(
-            DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+            DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     if (newAttr -> getOwnerDocument() != this -> getOwnerDocument())
-        throw DOMException(DOMException::WRONG_DOCUMENT_ERR, 0);
+        throw DOMException(DOMException::WRONG_DOCUMENT_ERR, 0, GetDOMNodeMemoryManager);
 
     // This will throw INUSE if necessary
     DOMAttr *oldAttr = (DOMAttr *) fAttributes->setNamedItemNS(newAttr);
@@ -472,10 +428,10 @@ DOMAttr * DOMElementImpl::setDefaultAttributeNode(DOMAttr *newAttr)
 {
     if (fNode.isReadOnly())
         throw DOMException(
-        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+        DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     if (newAttr->getNodeType() != DOMNode::ATTRIBUTE_NODE)
-        throw DOMException(DOMException::WRONG_DOCUMENT_ERR, 0);
+        throw DOMException(DOMException::WRONG_DOCUMENT_ERR, 0, GetDOMNodeMemoryManager);
         // revisit.  Exception doesn't match test.
 
     // This will throw INUSE if necessary
@@ -490,10 +446,10 @@ DOMAttr *DOMElementImpl::setDefaultAttributeNodeNS(DOMAttr *newAttr)
 {
     if (fNode.isReadOnly())
         throw DOMException(
-            DOMException::NO_MODIFICATION_ALLOWED_ERR, 0);
+            DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
 
     if (newAttr -> getOwnerDocument() != this -> getOwnerDocument())
-        throw DOMException(DOMException::WRONG_DOCUMENT_ERR, 0);
+        throw DOMException(DOMException::WRONG_DOCUMENT_ERR, 0, GetDOMNodeMemoryManager);
 
     // This will throw INUSE if necessary
     DOMAttr *oldAttr = (DOMAttr *) fDefaultAttributes->setNamedItemNS(newAttr);
@@ -505,7 +461,7 @@ DOMAttr *DOMElementImpl::setDefaultAttributeNodeNS(DOMAttr *newAttr)
 void DOMElementImpl::release()
 {
     if (fNode.isOwned() && !fNode.isToBeReleased())
-        throw DOMException(DOMException::INVALID_ACCESS_ERR,0);
+        throw DOMException(DOMException::INVALID_ACCESS_ERR,0, GetDOMNodeMemoryManager);
 
     DOMDocumentImpl* doc = (DOMDocumentImpl*) getOwnerDocument();
     if (doc) {
@@ -515,7 +471,7 @@ void DOMElementImpl::release()
     }
     else {
         // shouldn't reach here
-        throw DOMException(DOMException::INVALID_ACCESS_ERR,0);
+        throw DOMException(DOMException::INVALID_ACCESS_ERR,0, GetDOMNodeMemoryManager);
     }
 }
 
@@ -687,15 +643,7 @@ DOMNode* DOMElementImpl::rename(const XMLCh* namespaceURI, const XMLCh* name)
 
 const DOMTypeInfo *DOMElementImpl::getTypeInfo() const
 {
-    if(!fSchemaType) 
-        ((DOMElementImpl *)(this))->fSchemaType = new (getOwnerDocument()) DOMTypeInfoImpl(0, 0, (DOMDocumentImpl *)getOwnerDocument());
-    return fSchemaType;
-}
-
-
-void DOMElementImpl::setTypeInfo(const XMLCh* typeName, const XMLCh* typeURI) 
-{
-    fSchemaType = new (getOwnerDocument()) DOMTypeInfoImpl(typeName, typeURI, (DOMDocumentImpl *)getOwnerDocument());
+    return &DOMTypeInfoImpl::g_DtdValidatedElement;
 }
 
 XERCES_CPP_NAMESPACE_END
