@@ -1,79 +1,40 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001-2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DOMElementNSImpl.cpp,v 1.14 2003/10/01 16:32:37 neilg Exp $
+ * $Id: DOMElementNSImpl.cpp 231069 2005-08-09 17:48:47Z amassari $
  */
 
 #include <xercesc/util/XMLUniDefs.hpp>
 #include "DOMElementNSImpl.hpp"
 #include "DOMDocumentImpl.hpp"
+#include "DOMTypeInfoImpl.hpp"
 #include <xercesc/dom/DOMException.hpp>
 #include <xercesc/util/XMLUri.hpp>
 #include <xercesc/util/OutOfMemoryException.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
-
 DOMElementNSImpl::DOMElementNSImpl(DOMDocument *ownerDoc, const XMLCh *nam) :
     DOMElementImpl(ownerDoc, nam)
 {
     this->fNamespaceURI=0;	  //DOM Level 2
     this->fLocalName=0;       //DOM Level 2
     this->fPrefix=0;
+    this->fSchemaType = 0;
 }
 
 //Introduced in DOM Level 2
@@ -83,6 +44,7 @@ DOMElementNSImpl::DOMElementNSImpl(DOMDocument *ownerDoc,
     DOMElementImpl(ownerDoc, qualifiedName)
 {
     setName(namespaceURI, qualifiedName);
+    this->fSchemaType = 0;
 }
 
 DOMElementNSImpl::DOMElementNSImpl(const DOMElementNSImpl &other, bool deep) :
@@ -91,7 +53,8 @@ DOMElementNSImpl::DOMElementNSImpl(const DOMElementNSImpl &other, bool deep) :
     this->fNamespaceURI = other.fNamespaceURI;	        //DOM Level 2
     this->fLocalName = other.fLocalName;                //DOM Level 2
     this->fPrefix = other.fPrefix;
-};
+    this->fSchemaType = other.fSchemaType;
+}
 
 DOMNode * DOMElementNSImpl::cloneNode(bool deep) const {
     DOMNode* newNode = new (getOwnerDocument(), DOMDocumentImpl::ELEMENT_NS_OBJECT) DOMElementNSImpl(*this, deep);
@@ -127,18 +90,22 @@ const XMLCh* DOMElementNSImpl::getBaseURI() const
         if (attrNode) {
             const XMLCh* uri =  attrNode->getNodeValue();
             if (uri && *uri) {// attribute value is always empty string
-                try {
-                    XMLUri temp(baseURI, ((DOMDocumentImpl *)this->getOwnerDocument())->getMemoryManager());
-                    XMLUri temp2(&temp, uri, ((DOMDocumentImpl *)this->getOwnerDocument())->getMemoryManager());
-                    uri = ((DOMDocumentImpl *)this->getOwnerDocument())->cloneString(temp2.getUriText());
-                }
-                catch(const OutOfMemoryException&)
+                // if there is a base URI for the parent node, use it to resolve relative URI
+                if(baseURI)
                 {
-                    throw;
-                }
-                catch (...){
-                    // REVISIT: what should happen in this case?
-                    return 0;
+                    try {
+                        XMLUri temp(baseURI, ((DOMDocumentImpl *)this->getOwnerDocument())->getMemoryManager());
+                        XMLUri temp2(&temp, uri, ((DOMDocumentImpl *)this->getOwnerDocument())->getMemoryManager());
+                        uri = ((DOMDocumentImpl *)this->getOwnerDocument())->cloneString(temp2.getUriText());
+                    }
+                    catch(const OutOfMemoryException&)
+                    {
+                        throw;
+                    }
+                    catch (...){
+                        // REVISIT: what should happen in this case?
+                        return 0;
+                    }
                 }
                 return uri;
             }
@@ -150,30 +117,30 @@ const XMLCh* DOMElementNSImpl::getBaseURI() const
 
 void DOMElementNSImpl::setPrefix(const XMLCh *prefix)
 {
-    const XMLCh * xml      = DOMNodeImpl::getXmlString();
-    const XMLCh * xmlURI   = DOMNodeImpl::getXmlURIString();
-
     if (fNode.isReadOnly())
-        throw DOMException(DOMException::NO_MODIFICATION_ALLOWED_ERR,
-                               0);
-    if(prefix != 0 && !((DOMDocumentImpl *)this->getOwnerDocument())->isXMLName(prefix))
-        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0);
-
+        throw DOMException(DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMNodeMemoryManager);
     if (fNamespaceURI == 0 || fNamespaceURI[0] == chNull)
-        throw DOMException(DOMException::NAMESPACE_ERR, 0);
+        throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
 
     if (prefix == 0 || *prefix == 0) {
+        fPrefix = 0;
         fName = fLocalName;
         return;
     }
 
+    if(!((DOMDocumentImpl *)this->getOwnerDocument())->isXMLName(prefix))
+        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0, GetDOMNodeMemoryManager);
+
+    const XMLCh * xml      = DOMNodeImpl::getXmlString();
+    const XMLCh * xmlURI   = DOMNodeImpl::getXmlURIString();
+
     if (XMLString::equals(prefix, xml) &&
         !XMLString::equals(fNamespaceURI, xmlURI))
-        throw DOMException(DOMException::NAMESPACE_ERR, 0);
+        throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
 
 
     if (XMLString::indexOf(prefix, chColon) != -1) {
-        throw DOMException(DOMException::NAMESPACE_ERR, 0);
+        throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
     }
 
     this-> fPrefix = ((DOMDocumentImpl *)this->getOwnerDocument())->getPooledString(prefix);
@@ -184,7 +151,7 @@ void DOMElementNSImpl::setPrefix(const XMLCh *prefix)
     XMLCh *newName;
     XMLCh temp[4000];
     if (newQualifiedNameLen >= 3999)
-        newName = (XMLCh*) XMLPlatformUtils::fgMemoryManager->allocate
+        newName = (XMLCh*) ((DOMDocumentImpl *)this->getOwnerDocument())->getMemoryManager()->allocate
         (
             newQualifiedNameLen * sizeof(XMLCh)
         );//new XMLCh[newQualifiedNameLen];
@@ -200,14 +167,14 @@ void DOMElementNSImpl::setPrefix(const XMLCh *prefix)
                                            getPooledString(newName);
 
     if (newQualifiedNameLen >= 3999)
-        XMLPlatformUtils::fgMemoryManager->deallocate(newName);//delete[] newName;
+        ((DOMDocumentImpl *)this->getOwnerDocument())->getMemoryManager()->deallocate(newName);//delete[] newName;
 
 }
 
 void DOMElementNSImpl::release()
 {
     if (fNode.isOwned() && !fNode.isToBeReleased())
-        throw DOMException(DOMException::INVALID_ACCESS_ERR,0);
+        throw DOMException(DOMException::INVALID_ACCESS_ERR,0, GetDOMNodeMemoryManager);
 
     DOMDocumentImpl* doc = (DOMDocumentImpl*) getOwnerDocument();
     if (doc) {
@@ -217,7 +184,7 @@ void DOMElementNSImpl::release()
     }
     else {
         // shouldn't reach here
-        throw DOMException(DOMException::INVALID_ACCESS_ERR,0);
+        throw DOMException(DOMException::INVALID_ACCESS_ERR,0, GetDOMNodeMemoryManager);
     }
 }
 
@@ -236,7 +203,7 @@ void DOMElementNSImpl::setName(const XMLCh *namespaceURI,
 
     int index = DOMDocumentImpl::indexofQualifiedName(qualifiedName);
     if (index < 0)
-        throw DOMException(DOMException::NAMESPACE_ERR, 0);
+        throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
 
     if (index == 0) {	//qualifiedName contains no ':'
         this -> fPrefix = 0;
@@ -245,7 +212,7 @@ void DOMElementNSImpl::setName(const XMLCh *namespaceURI,
         XMLCh* newName;
         XMLCh temp[4000];
         if (index >= 3999)
-            newName = (XMLCh*) XMLPlatformUtils::fgMemoryManager->allocate
+            newName = (XMLCh*) ownerDoc->getMemoryManager()->allocate
             (
                 (XMLString::stringLen(qualifiedName) + 1) * sizeof(XMLCh)
             );//new XMLCh[XMLString::stringLen(qualifiedName)+1];
@@ -258,11 +225,11 @@ void DOMElementNSImpl::setName(const XMLCh *namespaceURI,
         this -> fLocalName = ownerDoc->getPooledString(fName+index+1);
 
         if (index >= 3999)
-            XMLPlatformUtils::fgMemoryManager->deallocate(newName);//delete[] newName;
+            ownerDoc->getMemoryManager()->deallocate(newName);//delete[] newName;
 
         // Before we carry on, we should check if the prefix or localName are valid XMLName
         if (!((DOMDocumentImpl *)this->getOwnerDocument())->isXMLName(fPrefix) || !((DOMDocumentImpl *)this->getOwnerDocument())->isXMLName(fLocalName))
-            throw DOMException(DOMException::NAMESPACE_ERR, 0);
+            throw DOMException(DOMException::NAMESPACE_ERR, 0, GetDOMNodeMemoryManager);
     }
 
     // DOM Level 3: namespace URI is never empty string.
@@ -273,7 +240,26 @@ void DOMElementNSImpl::setName(const XMLCh *namespaceURI,
             DOMNode::ELEMENT_NODE
         );
     this -> fNamespaceURI = (URI == 0) ? 0 : ownerDoc->getPooledString(URI);
-};
+}
+
+const DOMTypeInfo *DOMElementNSImpl::getTypeInfo() const
+{
+    if(!fSchemaType) 
+        return &DOMTypeInfoImpl::g_DtdValidatedElement;
+    return fSchemaType;
+}
+
+void DOMElementNSImpl::setTypeInfo(const DOMTypeInfoImpl* typeInfo) 
+{
+    fSchemaType = typeInfo;
+}
+
+DOMNode * DOMElementNSImpl::getInterface(const XMLCh* feature)
+{
+    if(XMLString::equals(feature, XMLUni::fgXercescInterfacePSVITypeInfo))
+        return (DOMNode*)(DOMPSVITypeInfo*)fSchemaType;
+    return DOMElementImpl::getInterface(feature);
+}
 
 XERCES_CPP_NAMESPACE_END
 
