@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001-2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DOMImplementationImpl.cpp,v 1.22 2004/01/29 11:44:26 cargilld Exp $
+ * $Id: DOMImplementationImpl.cpp 180016 2005-06-04 19:49:30Z jberry $
  */
 
 #include "DOMImplementationImpl.hpp"
@@ -67,6 +27,7 @@
 #include <xercesc/dom/DOMDocumentType.hpp>
 #include <xercesc/dom/DOMException.hpp>
 #include <xercesc/util/PlatformUtils.hpp>
+#include <xercesc/util/XMLInitializer.hpp>
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/XMLChar.hpp>
 #include <xercesc/util/XMLRegisterCleanup.hpp>
@@ -106,6 +67,8 @@ static const XMLCh  gLS[] =     // Points to "LS"
 // -----------------------------------------------------------------------
 static XMLMsgLoader  *sMsgLoader4DOM = 0;   // Points to the singleton instance
 static XMLMutex      *sMutex4DOM = 0;
+static XMLRegisterCleanup mutex4DOMCleanup;
+static XMLRegisterCleanup msgLoader4DOMCleanup;
 
 static void reinitMsgLoader4DOM()
 {
@@ -121,7 +84,6 @@ static void reinitMutex4DOM()
 
 static XMLMutex& getMutex4DOM()
 {
-    static XMLRegisterCleanup mutex4DOMCleanup;
     if (!sMutex4DOM)
     {
         XMLMutexLock lock(XMLPlatformUtils::fgAtomicMutex);
@@ -129,7 +91,7 @@ static XMLMutex& getMutex4DOM()
         // If we got here first, then register it and set the registered flag
         if (!sMutex4DOM)
         {
-            sMutex4DOM = new XMLMutex;
+            sMutex4DOM = new XMLMutex(XMLPlatformUtils::fgMemoryManager);
             mutex4DOMCleanup.registerCleanup(reinitMutex4DOM);
         }
     }
@@ -138,7 +100,6 @@ static XMLMutex& getMutex4DOM()
 
 XMLMsgLoader* DOMImplementationImpl::getMsgLoader4DOM()
 {
-    static XMLRegisterCleanup msgLoader4DOMCleanup;
     if (!sMsgLoader4DOM)
     {
         XMLMutexLock lock(&getMutex4DOM());
@@ -157,12 +118,21 @@ XMLMsgLoader* DOMImplementationImpl::getMsgLoader4DOM()
     return sMsgLoader4DOM;
 }
 
+void XMLInitializer::initializeMsgLoader4DOM()
+{
+    sMsgLoader4DOM = XMLPlatformUtils::loadMsgSet(XMLUni::fgXMLDOMMsgDomain);
+    if (sMsgLoader4DOM) {
+        msgLoader4DOMCleanup.registerCleanup(reinitMsgLoader4DOM);
+    }
+}
+
 // -----------------------------------------------------------------------
 //  Singleton DOMImplementationImpl
 // -----------------------------------------------------------------------
 static DOMImplementationImpl    *gDomimp = 0;   // Points to the singleton instance
                                             //  of DOMImplementation that is returnedreturned
                                             //  by any call to getImplementation().
+static XMLRegisterCleanup implementationCleanup;
 
 static void reinitImplementation()
 {
@@ -180,7 +150,6 @@ static void reinitImplementation()
 //
 DOMImplementationImpl *DOMImplementationImpl::getDOMImplementationImpl()
 {
-    static XMLRegisterCleanup implementationCleanup;
     if (!gDomimp)
     {
         XMLMutexLock lock(&getMutex4DOM());
@@ -195,6 +164,14 @@ DOMImplementationImpl *DOMImplementationImpl::getDOMImplementationImpl()
     return gDomimp;
 }
 
+void XMLInitializer::initializeDOMImplementationImpl()
+{
+    gDomimp = new DOMImplementationImpl;
+    if (gDomimp) {
+        implementationCleanup.registerCleanup(reinitImplementation);
+    }
+}
+
 // ------------------------------------------------------------
 // DOMImplementation Virtual interface
 // ------------------------------------------------------------
@@ -209,23 +186,23 @@ bool  DOMImplementationImpl::hasFeature(const  XMLCh * feature,  const  XMLCh *
     bool version3_0 = XMLString::equals(version, g3_0);
 
     // Currently, we support only XML Level 1 version 1.0
-    if (XMLString::compareIString(feature, XMLUni::fgXMLString) == 0
+    if (XMLString::compareIStringASCII(feature, XMLUni::fgXMLString) == 0
         && (anyVersion || version1_0 || version2_0))
         return true;
 
-    if (XMLString::compareIString(feature, gCore) == 0
+    if (XMLString::compareIStringASCII(feature, gCore) == 0
         && (anyVersion || version1_0 || version2_0 || version3_0))
         return true;
 
-    if (XMLString::compareIString(feature, gTrav) == 0
+    if (XMLString::compareIStringASCII(feature, gTrav) == 0
         && (anyVersion || version2_0))
         return true;
 
-    if (XMLString::compareIString(feature, gRange) == 0
+    if (XMLString::compareIStringASCII(feature, gRange) == 0
         && (anyVersion || version2_0))
         return true;
 
-    if (XMLString::compareIString(feature, gLS) == 0
+    if (XMLString::compareIStringASCII(feature, gLS) == 0
         && (anyVersion || version3_0))
         return true;
 
@@ -239,7 +216,9 @@ DOMDocumentType *DOMImplementationImpl::createDocumentType(const XMLCh *qualifie
 {
     // assume XML 1.0 since we do not know its version yet.
     if(!XMLChar1_0::isValidName(qualifiedName, XMLString::stringLen(qualifiedName)))
-        throw DOMException(DOMException::INVALID_CHARACTER_ERR,0);
+        throw DOMException(DOMException::INVALID_CHARACTER_ERR, 0);
+
+    //to do: do we need to create with user's memorymanager???
     DOMDocumentTypeImpl* docType = new DOMDocumentTypeImpl(0, qualifiedName, publicId, systemId, true);
     return docType;
 }
@@ -255,6 +234,7 @@ DOMDocument *DOMImplementationImpl::createDocument(const XMLCh *namespaceURI,
 //Introduced in DOM Level 3
 DOMImplementation* DOMImplementationImpl::getInterface(const XMLCh*){
     throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+
     return 0;
 }
 
@@ -305,7 +285,7 @@ DOMBuilder* DOMImplementationImpl::createDOMBuilder(const short           mode,
                                                     XMLGrammarPool* const gramPool)
 {
     if (mode == DOMImplementationLS::MODE_ASYNCHRONOUS)
-        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+        throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0, manager);
 
     return new (manager) DOMBuilderImpl(0, manager, gramPool);
 }
@@ -319,6 +299,7 @@ DOMWriter* DOMImplementationImpl::createDOMWriter(MemoryManager* const manager)
 DOMInputSource* DOMImplementationImpl::createDOMInputSource()
 {
     throw DOMException(DOMException::NOT_SUPPORTED_ERR, 0);
+
     return 0;
 }
 
