@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: DOMNodeImpl.cpp,v 1.34 2004/09/08 13:55:52 peiyongz Exp $
+ * $Id: DOMNodeImpl.cpp 180016 2005-06-04 19:49:30Z jberry $
  */
 
 // This class doesn't support having any children, and implements the behavior
@@ -35,6 +35,7 @@
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/XMLRegisterCleanup.hpp>
 #include <xercesc/util/PlatformUtils.hpp>
+#include <xercesc/util/XMLInitializer.hpp>
 #include <stdio.h>
 #include <assert.h>
 
@@ -73,6 +74,14 @@ static void reinitEmptyNodeList()
     gEmptyNodeListMutex = 0;
 }
 
+void XMLInitializer::initializeEmptyNodeList()
+{
+    gEmptyNodeList = new DOMNodeListImpl(0);
+    if (gEmptyNodeList) {
+        emptyNodeListCleanup.registerCleanup(reinitEmptyNodeList);
+    }
+}
+
 // -----------------------------------------------------------------------
 //  DOMNodeImpl Functions
 // -----------------------------------------------------------------------
@@ -125,7 +134,7 @@ DOMNodeList *DOMNodeImpl::getChildNodes() const {
             XMLMutexLock lock(XMLPlatformUtils::fgAtomicMutex);
 			
             if (!gEmptyNodeListMutex)
-                gEmptyNodeListMutex = new XMLMutex;
+                gEmptyNodeListMutex = new XMLMutex(XMLPlatformUtils::fgMemoryManager);
         }
 
         // Use a faux scope to synchronize while we do this
@@ -354,10 +363,8 @@ const XMLCh* DOMNodeImpl::mapPrefix(const XMLCh *prefix,
         if (XMLString::equals(namespaceURI, XMLUni::fgXMLNSURIName))
             return XMLUni::fgXMLNSURIName;
         throw DOMException(DOMException::NAMESPACE_ERR, 0);
-    } else if (namespaceURI == 0 || *namespaceURI == 0) {
+    } else if (namespaceURI == 0 || *namespaceURI == 0)
         throw DOMException(DOMException::NAMESPACE_ERR, 0);
-    } else
-        return namespaceURI;
     return namespaceURI;
 }
 
