@@ -2,63 +2,23 @@
 #define DOMNodeImpl_HEADER_GUARD_
 
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001-2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: DOMNodeImpl.hpp,v 1.9 2002/08/16 19:20:28 tng Exp $
+ * $Id: DOMNodeImpl.hpp 176026 2004-09-08 13:57:07Z peiyongz $
  */
 
 //
@@ -91,6 +51,9 @@
 #include <xercesc/util/XercesDefs.hpp>
 #include <xercesc/dom/DOMUserDataHandler.hpp>
 
+XERCES_CPP_NAMESPACE_BEGIN
+
+
 class DOMNamedNodeMap;
 class DOMNodeList;
 class DOMNode;
@@ -152,11 +115,12 @@ public:
     // Introduced in DOM Level 3
     void*             setUserData(const XMLCh* key, void* data, DOMUserDataHandler* handler);
     void*             getUserData(const XMLCh* key) const;
-    bool              isSameNode(const DOMNode* other);
-    bool              isEqualNode(const DOMNode* arg);
+    bool              isSameNode(const DOMNode* other) const;
+    bool              isEqualNode(const DOMNode* arg) const;
     const XMLCh*      getBaseURI() const ;
-    short             compareTreePosition(DOMNode* other) ;
+    short             compareTreePosition(const DOMNode* other) const;
     const XMLCh*      getTextContent() const ;
+    const XMLCh*      getTextContent(XMLCh* pzBuffer, unsigned int& rnBufferLength) const;
     void              setTextContent(const XMLCh* textContent) ;
     const XMLCh*      lookupNamespacePrefix(const XMLCh* namespaceURI, bool useDefault) const ;
     bool              isDefaultNamespace(const XMLCh* namespaceURI) const ;
@@ -348,11 +312,12 @@ public: // should really be protected - ALH
     virtual       void             setPrefix(const XMLCh * prefix) ;\
     virtual       void*            setUserData(const XMLCh* key, void* data, DOMUserDataHandler* handler) ;\
     virtual       void*            getUserData(const XMLCh* key) const ;\
-    virtual       bool             isSameNode(const DOMNode* other);\
-    virtual       bool             isEqualNode(const DOMNode* arg);\
+    virtual       bool             isSameNode(const DOMNode* other) const;\
+    virtual       bool             isEqualNode(const DOMNode* arg) const;\
     virtual const XMLCh*           getBaseURI() const ;\
-    virtual short                  compareTreePosition(DOMNode* other) ;\
+    virtual short                  compareTreePosition(const DOMNode* other) const ;\
     virtual const XMLCh*           getTextContent() const ;\
+            const XMLCh*           getTextContent(XMLCh* pzBuffer, unsigned int& rnBufferLength) const;\
     virtual void                   setTextContent(const XMLCh* textContent) ;\
     virtual const XMLCh*           lookupNamespacePrefix(const XMLCh* namespaceURI, bool useDefault) const  ;\
     virtual bool                   isDefaultNamespace(const XMLCh* namespaceURI) const;\
@@ -391,13 +356,13 @@ public: // should really be protected - ALH
                                                                          {return fNode.isSupported (feature, version); };
            void             xxx::setPrefix(const XMLCh  *prefix)         {fNode.setPrefix(prefix); };
            bool             xxx::hasAttributes() const                   {return fNode.hasAttributes(); };
-           bool             xxx::isSameNode(const DOMNode* other)        {return fNode.isSameNode(other); };
-           bool             xxx::isEqualNode(const DOMNode* arg)         {return fNode.isEqualNode(arg); };
+           bool             xxx::isSameNode(const DOMNode* other) const  {return fNode.isSameNode(other); };
+           bool             xxx::isEqualNode(const DOMNode* arg) const   {return fNode.isEqualNode(arg); };
            void*            xxx::setUserData(const XMLCh* key, void* data, DOMUserDataHandler* handler)
                                                                          {return fNode.setUserData(key, data, handler); };
            void*            xxx::getUserData(const XMLCh* key) const     {return fNode.getUserData(key); };
            const XMLCh*     xxx::getBaseURI() const                      {return fNode.getBaseURI(); };
-           short            xxx::compareTreePosition(DOMNode* other)     {return fNode.compareTreePosition(other); };
+           short            xxx::compareTreePosition(const DOMNode* other) const {return fNode.compareTreePosition(other); };
            const XMLCh*     xxx::getTextContent() const                  {return fNode.getTextContent(); };
            void             xxx::setTextContent(const XMLCh* textContent){fNode.setTextContent(textContent); };
            const XMLCh*     xxx::lookupNamespacePrefix(const XMLCh* namespaceURI, bool useDefault) const {return fNode.lookupNamespacePrefix(namespaceURI, useDefault); };
@@ -410,4 +375,6 @@ public: // should really be protected - ALH
 
 
 
+XERCES_CPP_NAMESPACE_END
+
 #endif
