@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: DOMNodeIteratorImpl.cpp,v 1.8 2004/09/08 13:55:52 peiyongz Exp $
+ * $Id: DOMNodeIteratorImpl.cpp 176280 2005-01-07 15:32:34Z amassari $
  */
 
 //////////////////////////////////////////////////////////////////////
@@ -53,7 +53,8 @@ DOMNodeIteratorImpl::DOMNodeIteratorImpl (DOMDocument* doc,
 
 
 DOMNodeIteratorImpl::DOMNodeIteratorImpl ( const DOMNodeIteratorImpl& toCopy)
-    :   fRoot(toCopy.fRoot),
+    : DOMNodeIterator(toCopy),
+    fRoot(toCopy.fRoot),
     fDocument(toCopy.fDocument),
     fWhatToShow(toCopy.fWhatToShow),
     fNodeFilter(toCopy.fNodeFilter),
@@ -250,7 +251,8 @@ DOMNode* DOMNodeIteratorImpl::nextNode (DOMNode* node, bool visitChildren) {
     // only check children if we visit children.
     if (visitChildren) {
         //if hasChildren, return 1st child.
-        if (node->hasChildNodes()) {
+        if ((fExpandEntityReferences || node->getNodeType()!=DOMNode::ENTITY_REFERENCE_NODE) && 
+            node->hasChildNodes()) {
             result = node->getFirstChild();
             return result;
         }
@@ -303,7 +305,8 @@ DOMNode* DOMNodeIteratorImpl::previousNode (DOMNode* node) {
 
     // if sibling has children, keep getting last child of child.
     if (result->hasChildNodes()) {
-        while (result->hasChildNodes()) {
+        while ((fExpandEntityReferences || result->getNodeType()!=DOMNode::ENTITY_REFERENCE_NODE) && 
+               result->hasChildNodes()) {
             result = result->getLastChild();
         }
     }
