@@ -23,6 +23,7 @@
 
 #include <xercesc/util/Mutexes.hpp>
 #include <xercesc/util/PlatformUtils.hpp>
+#include <xercesc/util/XMLInitializer.hpp>
 #include <xercesc/util/XMLMsgLoader.hpp>
 #include <xercesc/util/XMLRegisterCleanup.hpp>
 #include <xercesc/util/XMLString.hpp>
@@ -85,7 +86,7 @@ static XMLMutex& gNormalizerMutex()
         // If we got here first, then register it and set the registered flag
         if (!sRegistered)
         {
-            sNormalizerMutex = new XMLMutex;
+            sNormalizerMutex = new XMLMutex(XMLPlatformUtils::fgMemoryManager);
             normalizerMutexCleanup.registerCleanup(DOMNormalizer::reinitNormalizerMutex);
             sRegistered = true;
         }
@@ -114,6 +115,15 @@ static XMLMsgLoader& gNormalizerMsgLoader()
     return *gMsgLoader;
 }
 
+void XMLInitializer::initializeDOMNormalizerMsgLoader()
+{
+    gMsgLoader = XMLPlatformUtils::loadMsgSet(XMLUni::fgXMLErrDomain);
+
+    // Register this object to be cleaned up at termination
+    if (gMsgLoader) {
+        cleanupMsgLoader.registerCleanup(DOMNormalizer::reinitMsgLoader);
+    }
+}
 
 DOMNormalizer::DOMNormalizer(MemoryManager* const manager) 
     : fDocument(0)
