@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: DOMParentNode.cpp,v 1.17 2004/09/08 13:55:52 peiyongz Exp $
+ * $Id: DOMParentNode.cpp 176377 2005-04-07 15:08:57Z amassari $
  */
 
 #include <xercesc/util/XercesDefs.hpp>
@@ -139,6 +139,10 @@ bool DOMParentNode::hasChildNodes() const
 
 
 DOMNode *DOMParentNode::insertBefore(DOMNode *newChild, DOMNode *refChild) {
+    //not really in the specs, but better than nothing
+    if(newChild==NULL)
+        throw DOMException(DOMException::HIERARCHY_REQUEST_ERR,0, GetDOMParentNodeMemoryManager);
+
     DOMNodeImpl *thisNodeImpl = castToNodeImpl(this);
     if (thisNodeImpl->isReadOnly())
         throw DOMException(DOMException::NO_MODIFICATION_ALLOWED_ERR, 0, GetDOMParentNodeMemoryManager);
