@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: DOMTreeWalkerImpl.cpp,v 1.9 2004/09/08 13:55:52 peiyongz Exp $
+ * $Id: DOMTreeWalkerImpl.cpp 176280 2005-01-07 15:32:34Z amassari $
  */
 
 #include "DOMTreeWalkerImpl.hpp"
@@ -42,7 +42,8 @@ DOMTreeWalkerImpl::DOMTreeWalkerImpl (
 
 
 DOMTreeWalkerImpl::DOMTreeWalkerImpl (const DOMTreeWalkerImpl& twi)
-:   fWhatToShow(twi.fWhatToShow),
+:   DOMTreeWalker(twi),
+    fWhatToShow(twi.fWhatToShow),
     fNodeFilter(twi.fNodeFilter),
     fCurrentNode(twi.fCurrentNode),
     fRoot(twi.fRoot),    
@@ -132,6 +133,9 @@ DOMNode* DOMTreeWalkerImpl::firstChild () {
 
     if (!fCurrentNode) return 0;
 
+    if(!fExpandEntityReferences && fCurrentNode->getNodeType()==DOMNode::ENTITY_REFERENCE_NODE)
+        return 0;
+
     DOMNode* node = getFirstChild(fCurrentNode);
 
     if (node != 0) {
@@ -149,6 +153,9 @@ DOMNode* DOMTreeWalkerImpl::lastChild () {
 
     if (!fCurrentNode) return 0;
 
+    if(!fExpandEntityReferences && fCurrentNode->getNodeType()==DOMNode::ENTITY_REFERENCE_NODE)
+        return 0;
+
     DOMNode* node = getLastChild(fCurrentNode);
     if (node != 0) {
         fCurrentNode = node;
@@ -386,6 +393,9 @@ DOMNode* DOMTreeWalkerImpl::getFirstChild (DOMNode* node) {
 		
     if (!node) return 0;
 
+    if(!fExpandEntityReferences && node->getNodeType()==DOMNode::ENTITY_REFERENCE_NODE)
+        return 0;
+
     DOMNode* newNode = node->getFirstChild();
     if (!newNode)  return 0;
 
@@ -414,6 +424,9 @@ DOMNode* DOMTreeWalkerImpl::getLastChild (DOMNode* node) {
 	
     if (!node) return 0;
 
+    if(!fExpandEntityReferences && node->getNodeType()==DOMNode::ENTITY_REFERENCE_NODE)
+        return 0;
+
     DOMNode* newNode = node->getLastChild();
     if (!newNode)  return 0;
 
