@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /**
- * $Id: XMLAttDef.cpp,v 1.5 2003/05/16 21:36:55 knoaman Exp $
+ * $Id: XMLAttDef.cpp 191705 2005-06-21 19:01:19Z cargilld $
  */
 
 
@@ -65,6 +25,7 @@
 #include <xercesc/framework/XMLAttDef.hpp>
 #include <xercesc/util/ArrayIndexOutOfBoundsException.hpp>
 #include <xercesc/util/XMLUni.hpp>
+#include <xercesc/util/OutOfMemoryException.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -122,19 +83,21 @@ const unsigned int XMLAttDef::fgInvalidAttrId = 0xFFFFFFFE;
 // ---------------------------------------------------------------------------
 //  XMLAttDef: Public, static methods
 // ---------------------------------------------------------------------------
-const XMLCh* XMLAttDef::getAttTypeString(const XMLAttDef::AttTypes attrType)
+const XMLCh* XMLAttDef::getAttTypeString(const XMLAttDef::AttTypes attrType
+                                         , MemoryManager* const manager)
 {
     // Check for an invalid attribute type and return a null
     if ((attrType < AttTypes_Min) || (attrType > AttTypes_Max))
-        ThrowXML(ArrayIndexOutOfBoundsException, XMLExcepts::AttDef_BadAttType);
+        ThrowXMLwithMemMgr(ArrayIndexOutOfBoundsException, XMLExcepts::AttDef_BadAttType, manager);
     return gAttTypeStrings[attrType];
 }
 
-const XMLCh* XMLAttDef::getDefAttTypeString(const XMLAttDef::DefAttTypes attrType)
+const XMLCh* XMLAttDef::getDefAttTypeString(const XMLAttDef::DefAttTypes attrType
+                                            , MemoryManager* const manager)
 {
     // Check for an invalid attribute type and return a null
     if ((attrType < DefAttTypes_Min) || (attrType > DefAttTypes_Max))
-        ThrowXML(ArrayIndexOutOfBoundsException, XMLExcepts::AttDef_BadDefAttType);
+        ThrowXMLwithMemMgr(ArrayIndexOutOfBoundsException, XMLExcepts::AttDef_BadDefAttType, manager);
     return gDefAttTypeStrings[attrType];
 }
 
@@ -167,6 +130,8 @@ XMLAttDef::XMLAttDef( const XMLAttDef::AttTypes    type
 {
 }
 
+typedef JanitorMemFunCall<XMLAttDef>    CleanupType;
+
 XMLAttDef::XMLAttDef( const XMLCh* const           attrValue
                     , const XMLAttDef::AttTypes    type
                     , const XMLAttDef::DefAttTypes defType
@@ -183,15 +148,21 @@ XMLAttDef::XMLAttDef( const XMLCh* const           attrValue
     , fEnumeration(0)
     , fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &XMLAttDef::cleanUp);
+
     try
     {
         fValue = XMLString::replicate(attrValue, fMemoryManager);
         fEnumeration = XMLString::replicate(enumValues, fMemoryManager);
     }
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        cleanUp();
+        cleanup.release();
+
+        throw;
     }
+
+    cleanup.release();
 }
 
 
@@ -207,5 +178,47 @@ void XMLAttDef::cleanUp()
         fMemoryManager->deallocate(fValue);
 }
 
+/***
+ * Support for Serialization/De-serialization
+ ***/
+
+IMPL_XSERIALIZABLE_NOCREATE(XMLAttDef)
+
+void XMLAttDef::serialize(XSerializeEngine& serEng)
+{
+
+    if (serEng.isStoring())
+    {
+        serEng<<(int)fDefaultType;
+        serEng<<(int)fType;
+        serEng<<(int)fCreateReason;
+        serEng<<fProvided;
+        serEng<<fExternalAttribute;
+        serEng<<fId;
+
+        serEng.writeString(fValue);
+        serEng.writeString(fEnumeration);
+    }
+    else
+    {
+        int i;
+        serEng>>i;
+        fDefaultType = (DefAttTypes) i;
+
+        serEng>>i;
+        fType = (AttTypes)i;
+
+        serEng>>i;
+        fCreateReason = (CreateReasons)i;
+
+        serEng>>fProvided;
+        serEng>>fExternalAttribute;
+        serEng>>fId;
+
+        serEng.readString(fValue);
+        serEng.readString(fEnumeration);
+    }
+}
+
 XERCES_CPP_NAMESPACE_END
 
