@@ -15,100 +15,7 @@
  */
 
 /*
- * $Log: XMLFormatter.hpp,v $
- * Revision 1.21  2004/09/08 13:55:59  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.20  2004/01/29 11:46:29  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.19  2003/12/01 23:23:25  neilg
- * fix for bug 25118; thanks to Jeroen Witmond
- *
- * Revision 1.18  2003/10/10 02:06:09  neilg
- * fix for bug 21780; thanks to David Cargill
- *
- * Revision 1.17  2003/09/22 08:50:04  gareth
- * doc fix
- *
- * Revision 1.16  2003/09/08 21:48:36  peiyongz
- * Restore pre2.3 constructors
- *
- * Revision 1.15  2003/05/30 16:11:43  gareth
- * Fixes so we compile under VC7.1. Patch by Alberto Massari.
- *
- * Revision 1.14  2003/05/16 21:36:55  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.13  2003/05/15 18:26:07  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.12  2003/03/17 03:19:52  peiyongz
- * Bug#18051 memory leakage in XMLFormatter
- *
- * Revision 1.11  2003/03/16 06:00:43  peiyongz
- * Bug#17983 Formatter does not escape control characters
- *
- * Revision 1.10  2003/03/11 12:58:36  tng
- * Fix compilation error on AIX.
- *
- * Revision 1.9  2003/03/07 21:42:37  tng
- * [Bug 17589] Refactoring ... .  Patch from Jacques Legare.
- *
- * Revision 1.8  2003/03/07 18:08:10  tng
- * Return a reference instead of void for operator=
- *
- * Revision 1.7  2003/01/31 00:30:48  jberry
- * Syntax error in declaration
- *
- * Revision 1.6  2003/01/28 18:32:33  peiyongz
- * Bug#13694: Allow Xerces to write the BOM to XML files
- *
- * Revision 1.5  2003/01/24 20:20:22  tng
- * Add method flush to XMLFormatTarget
- *
- * Revision 1.4  2002/11/04 15:00:21  tng
- * C++ Namespace Support.
- *
- * Revision 1.3  2002/07/30 16:29:16  tng
- * [Bug 8550] No explanation of XMLFormatter escape options.
- *
- * Revision 1.2  2002/06/21 19:31:23  peiyongz
- * getTranscoder() added;
- *
- * Revision 1.1.1.1  2002/02/01 22:21:52  peiyongz
- * sane_include
- *
- * Revision 1.7  2000/10/17 19:25:38  andyh
- * XMLFormatTarget, removed version of writeChars with no length.  Can not be
- * safely used, and obscured other errors.
- *
- * Revision 1.6  2000/10/10 23:54:58  andyh
- * XMLFormatter patch, contributed by Bill Schindler.  Fix problems with
- * output to multi-byte encodings.
- *
- * Revision 1.5  2000/04/07 01:01:56  roddey
- * Fixed an error message so that it indicated the correct radix for the rep
- * token. Get all of the basic output formatting functionality in place for
- * at least ICU and Win32 transcoders.
- *
- * Revision 1.4  2000/04/06 23:50:38  roddey
- * Now the low level formatter handles doing char refs for
- * unrepresentable chars (in addition to the replacement char style
- * already done.)
- *
- * Revision 1.3  2000/04/06 19:09:21  roddey
- * Some more improvements to output formatting. Now it will correctly
- * handle doing the 'replacement char' style of dealing with chars
- * that are unrepresentable.
- *
- * Revision 1.2  2000/04/05 00:20:16  roddey
- * More updates for the low level formatted output support
- *
- * Revision 1.1  2000/03/28 19:43:17  roddey
- * Fixes for signed/unsigned warnings. New work for two way transcoding
- * stuff.
- *
+ * $Id: XMLFormatter.hpp 202337 2005-06-29 08:35:12Z amassari $
  */
 
 #if !defined(XMLFORMATTER_HPP)
@@ -405,6 +312,22 @@ public:
     //@}
 
 
+    // -----------------------------------------------------------------------
+    //  Getter methods
+    // -----------------------------------------------------------------------
+    /** @name Setter methods */
+    //@{
+    /**
+     * @return return the escape style for the formatted content
+     */
+    EscapeFlags getEscapeFlags() const;
+
+    /**
+     * @return return the reaction for unrepresentable character
+     */
+    UnRepFlags getUnRepFlags() const;
+    //@}
+
 private :
     // -----------------------------------------------------------------------
     //  Unimplemented constructors and operators
@@ -587,6 +510,19 @@ inline XMLFormatter& XMLFormatter::operator<<(const UnRepFlags newFlags)
     return *this;
 }
 
+// ---------------------------------------------------------------------------
+//  XMLFormatter: Getter methods
+// ---------------------------------------------------------------------------
+inline XMLFormatter::EscapeFlags XMLFormatter::getEscapeFlags() const
+{
+    return fEscapeFlags;
+}
+
+inline XMLFormatter::UnRepFlags XMLFormatter::getUnRepFlags() const
+{
+    return fUnRepFlags;
+}
+
 XERCES_CPP_NAMESPACE_END
 
 #endif
