@@ -15,34 +15,7 @@
  */
 
 /*
- * $Log: XMLPScanToken.hpp,v $
- * Revision 1.4  2004/09/08 13:55:59  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.3  2003/05/15 18:26:07  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.2  2002/11/04 15:00:21  tng
- * C++ Namespace Support.
- *
- * Revision 1.1.1.1  2002/02/01 22:21:52  peiyongz
- * sane_include
- *
- * Revision 1.4  2000/02/24 20:00:23  abagchi
- * Swat for removing Log from API docs
- *
- * Revision 1.3  2000/02/15 01:21:31  roddey
- * Some initial documentation improvements. More to come...
- *
- * Revision 1.2  2000/02/06 07:47:48  rahulj
- * Year 2K copyright swat.
- *
- * Revision 1.1.1.1  1999/11/09 01:08:36  twl
- * Initial checkin
- *
- * Revision 1.2  1999/11/08 20:44:39  rahul
- * Swat for adding in Product name and CVS comment log variable.
- *
+ * $Id: XMLPScanToken.hpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -137,8 +110,8 @@ inline XMLPScanToken::XMLPScanToken() :
 }
 
 inline XMLPScanToken::XMLPScanToken(const XMLPScanToken& toCopy) :
-
-    fScannerId(toCopy.fScannerId)
+    XMemory(toCopy)
+    , fScannerId(toCopy.fScannerId)
     , fSequenceId(toCopy.fSequenceId)
 {
 }
