@@ -15,83 +15,7 @@
  */
 
 /*
- * $Log: ElemStack.hpp,v $
- * Revision 1.11  2004/09/08 13:56:13  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.10  2004/06/02 19:58:10  neilg
- * Fix bug where scanners would accept malformed tags of the form
- * <p:a xmlns:p="b" xmlns:q="b"></q:a> when namespace processing was
- * enabled.  This also opened the way for some end-tag scanning
- * performance improvements.
- *
- * Revision 1.9  2004/04/27 19:17:52  peiyongz
- * XML1.0-3rd VC: element content(children) dont allow white space from
- * EntityRef/CharRef
- *
- * Revision 1.8  2004/04/23 21:20:40  peiyongz
- * fCommentOrPISeen to keep track if any comment or PI seen for the current
- * element
- *
- * Revision 1.7  2003/10/22 20:22:30  knoaman
- * Prepare for annotation support.
- *
- * Revision 1.6  2003/05/16 21:36:57  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.5  2003/05/15 18:26:29  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.4  2003/03/07 18:08:58  tng
- * Return a reference instead of void for operator=
- *
- * Revision 1.3  2002/12/04 02:23:50  knoaman
- * Scanner re-organization.
- *
- * Revision 1.2  2002/11/04 14:58:18  tng
- * C++ Namespace Support.
- *
- * Revision 1.1.1.1  2002/02/01 22:21:58  peiyongz
- * sane_include
- *
- * Revision 1.11  2001/12/12 14:29:50  tng
- * Remove obsolete code in ElemStack which can help performance.
- *
- * Revision 1.10  2001/08/07 13:47:47  tng
- * Schema: Fix unmatched end tag for qualified/unqualifed start tag.
- *
- * Revision 1.9  2001/05/28 20:55:19  tng
- * Schema: Store Grammar in ElemStack as well.
- *
- * Revision 1.8  2001/05/11 13:26:16  tng
- * Copyright update.
- *
- * Revision 1.7  2001/05/03 20:34:28  tng
- * Schema: SchemaValidator update
- *
- * Revision 1.6  2001/04/19 18:16:58  tng
- * Schema: SchemaValidator update, and use QName in Content Model
- *
- * Revision 1.5  2000/04/18 23:54:29  roddey
- * Got rid of some foward references to no longer used classes.
- *
- * Revision 1.4  2000/03/02 19:54:28  roddey
- * This checkin includes many changes done while waiting for the
- * 1.1.0 code to be finished. I can't list them all here, but a list is
- * available elsewhere.
- *
- * Revision 1.3  2000/02/24 20:18:07  abagchi
- * Swat for removing Log from API docs
- *
- * Revision 1.2  2000/02/06 07:47:52  rahulj
- * Year 2K copyright swat.
- *
- * Revision 1.1.1.1  1999/11/09 01:08:06  twl
- * Initial checkin
- *
- * Revision 1.2  1999/11/08 20:44:42  rahul
- * Swat for adding in Product name and CVS comment log variable.
- *
+ * $Id: ElemStack.hpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 #if !defined(ELEMSTACK_HPP)
@@ -192,6 +116,8 @@ public :
         unsigned int        fCurrentURI;
         XMLCh *             fSchemaElemName;
         unsigned int        fSchemaElemNameMaxLen;
+        
+        int                 fPrefixColonPos;
     };
 
     enum MapModes
@@ -244,6 +170,9 @@ public :
     inline void setCurrentSchemaElemName(const XMLCh * const schemaElemName);
     inline XMLCh *getCurrentSchemaElemName();
 
+    void setPrefixColonPos(int colonPos);
+    int getPrefixColonPos() const;
+
     // -----------------------------------------------------------------------
     //  Prefix map methods
     // -----------------------------------------------------------------------
@@ -623,6 +552,15 @@ inline const XMLCh* ElemStack::getPrefixForId(unsigned int prefId) const
     return fPrefixPool.getValueForId(prefId);
 }
 
+inline void ElemStack::setPrefixColonPos(int colonPos)
+{
+    fStack[fStackTop-1]->fPrefixColonPos = colonPos;
+}
+ 
+inline int ElemStack::getPrefixColonPos() const {
+    return fStack[fStackTop-1]->fPrefixColonPos;
+}
+
 // ---------------------------------------------------------------------------
 //  WFElemStack: Miscellaneous methods
 // ---------------------------------------------------------------------------
