@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: ReaderMgr.cpp,v 1.28 2004/09/08 13:56:13 peiyongz Exp $
+ * $Id: ReaderMgr.cpp 231514 2005-08-11 20:53:29Z amassari $
  */
 
 // ---------------------------------------------------------------------------
@@ -387,6 +387,8 @@ XMLReader* ReaderMgr::createReader( const   InputSource&        src
     if (!newStream)
         return 0;
 
+    Janitor<BinInputStream>   streamJanitor(newStream);
+
     //
     //  Create a new reader and return it. If the source has an encoding that
     //  it wants to force, then we call the constructor that does that.
@@ -438,19 +440,14 @@ XMLReader* ReaderMgr::createReader( const   InputSource&        src
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch (...) //NetAccessorException&
-    {
-        delete newStream;
+        streamJanitor.release();
+
         throw;
     }
 
-    // If it failed for any reason, then return zero.
-    if (!retVal) {
-        delete newStream;
-        return 0;
-    }
+    assert(retVal);
+
+    streamJanitor.release();
 
     // Set the next available reader number on this reader
     retVal->setReaderNum(fNextReaderNum++);
@@ -465,7 +462,8 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        sysId
                                     , const XMLReader::Types    type
                                     , const XMLReader::Sources  source
                                     ,       InputSource*&       srcToFill
-                                    , const bool                calcSrcOfs)
+                                    , const bool                calcSrcOfs
+                                    , const bool                disableDefaultEntityResolution)
 {
     //Normalize sysId 
     XMLBuffer normalizedSysId(1023, fMemoryManager);
@@ -496,7 +494,8 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        sysId
         LastExtEntityInfo lastInfo;
         getLastExtEntityInfo(lastInfo);
         XMLResourceIdentifier resourceIdentifier(XMLResourceIdentifier::ExternalEntity,
-                            expSysId.getRawBuffer(), XMLUni::fgZeroLenString, pubId, lastInfo.systemId);
+                            expSysId.getRawBuffer(), XMLUni::fgZeroLenString, pubId, lastInfo.systemId,
+                            this);
         srcToFill = fEntityHandler->resolveEntity(&resourceIdentifier);
     }
 
@@ -506,6 +505,9 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        sysId
     //
     if (!srcToFill)
     {
+        if (disableDefaultEntityResolution)
+            return 0;
+
         LastExtEntityInfo lastInfo;
         getLastExtEntityInfo(lastInfo);
 
@@ -612,7 +614,8 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        baseURI
                                     , const XMLReader::Types    type
                                     , const XMLReader::Sources  source
                                     ,       InputSource*&       srcToFill
-                                    , const bool                calcSrcOfs)
+                                    , const bool                calcSrcOfs
+                                    , const bool                disableDefaultEntityResolution)
 {
     //Normalize sysId 
     XMLBuffer normalizedSysId(1023, fMemoryManager);
@@ -641,7 +644,8 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        baseURI
     if (fEntityHandler)
     {
         XMLResourceIdentifier resourceIdentifier(XMLResourceIdentifier::ExternalEntity,
-                            expSysId.getRawBuffer(), XMLUni::fgZeroLenString, pubId, baseURI);
+                            expSysId.getRawBuffer(), XMLUni::fgZeroLenString, pubId, baseURI,
+                            this);
         srcToFill = fEntityHandler->resolveEntity(&resourceIdentifier);
     }
 
@@ -651,6 +655,9 @@ XMLReader* ReaderMgr::createReader( const   XMLCh* const        baseURI
     //
     if (!srcToFill)
     {
+        if (disableDefaultEntityResolution)
+            return 0;
+
         LastExtEntityInfo lastInfo;
 
         const XMLCh* baseuri=baseURI;
