@@ -15,73 +15,7 @@
  */
 
 /*
- * $Log: SGXMLScanner.hpp,v $
- * Revision 1.21  2004/09/27 21:04:38  knoaman
- * Update SGXMLScanner to allow access of data and methods to XSAXMLScanner
- *
- * Revision 1.20  2004/09/08 13:56:13  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.19  2004/05/25 18:09:51  peiyongz
- * XML1.0 3rd: 4.2.2 ...Since escaping is not always a fully reversible process,
- * it must be performed only when absolutely necessary and as late as possible
- * in a processing chain...
- *
- * Revision 1.18  2004/04/13 16:56:58  peiyongz
- * IdentityConstraintHandler
- *
- * Revision 1.17  2004/04/07 14:14:08  peiyongz
- * make resolveSystemId virutal
- *
- * Revision 1.16  2004/01/29 11:46:30  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.15  2003/11/28 19:54:31  knoaman
- * PSVIElement update
- *
- * Revision 1.14  2003/11/27 22:52:37  knoaman
- * PSVIElement implementation
- *
- * Revision 1.13  2003/11/27 06:10:31  neilg
- * PSVIAttribute implementation
- *
- * Revision 1.12  2003/11/26 16:20:00  knoaman
- * Store XSModel.
- *
- * Revision 1.11  2003/11/24 05:09:38  neilg
- * implement new, statless, method for detecting duplicate attributes
- *
- * Revision 1.10  2003/10/22 20:22:30  knoaman
- * Prepare for annotation support.
- *
- * Revision 1.9  2003/09/22 19:51:41  neilg
- * scanners should maintain their own pools of undeclared elements, rather than requiring grammars to do this.  This makes grammar objects stateless with regard to validation.
- *
- * Revision 1.8  2003/07/10 19:47:23  peiyongz
- * Stateless Grammar: Initialize scanner with grammarResolver,
- *                                creating grammar through grammarPool
- *
- * Revision 1.7  2003/05/16 21:36:57  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.6  2003/05/15 18:26:29  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.5  2003/03/07 18:08:58  tng
- * Return a reference instead of void for operator=
- *
- * Revision 1.4  2003/01/29 19:59:35  gareth
- * we now detect when elements and attributes are validated/ the result of the validation and store that information.
- *
- * Revision 1.3  2003/01/15 15:49:49  knoaman
- * Change constant declaration name to match its value.
- *
- * Revision 1.2  2003/01/13 16:30:18  knoaman
- * [Bug 14469] Validator doesn't enforce xsd:key.
- *
- * Revision 1.1  2002/12/05 16:19:27  knoaman
- * Initial check-in.
- *
+ * $Id: SGXMLScanner.hpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -158,6 +92,7 @@ public :
         , const short           grammarType
         , const bool            toCache = false
     );
+    virtual Grammar::GrammarType getCurrentGrammarType() const;
 
 protected:
     // -----------------------------------------------------------------------
@@ -202,7 +137,20 @@ protected:
     );
     void resizeElemState();
 
-
+    void updateNSMap
+    (
+        const   XMLCh* const    attrName
+        , const XMLCh* const    attrValue
+        , const int             colonPosition
+    );
+    void resizeRawAttrColonList();
+    unsigned int resolveQNameWithColon
+    (
+        const   XMLCh* const        qName
+        ,       XMLBuffer&          prefixBufToFill
+        , const short               mode
+        , const int                 prefixColonPos
+    );
     // -----------------------------------------------------------------------
     //  Data members
     //
@@ -245,6 +193,8 @@ protected:
     XMLBuffer                               fContent;
     ValueHashTableOf<XMLCh>*                fEntityTable;
     RefVectorOf<KVStringPair>*              fRawAttrList;
+    unsigned int                            fRawAttrColonListSize;
+    int*                                    fRawAttrColonList;
     SchemaGrammar*                          fSchemaGrammar;
     SchemaValidator*                        fSchemaValidator;
     IdentityConstraintHandler*              fICHandler;
@@ -280,7 +230,8 @@ private :
     );
     virtual void scanDocTypeDecl();
     virtual void sendCharData(XMLBuffer& toSend);
-    virtual InputSource* resolveSystemId(const XMLCh* const sysId);
+    virtual InputSource* resolveSystemId(const XMLCh* const sysId
+                                        ,const XMLCh* const pubId);
 
     // -----------------------------------------------------------------------
     //  Private helper methods
@@ -359,6 +310,11 @@ inline bool SGXMLScanner::toCheckIdentityConstraint()  const
     return fValidate && fIdentityConstraintChecking && fICHandler;
 }
 
+inline Grammar::GrammarType SGXMLScanner::getCurrentGrammarType() const
+{
+    return fGrammarType;
+}
+
 XERCES_CPP_NAMESPACE_END
 
 #endif
