@@ -15,7 +15,7 @@
  */
 
 /*
-  * $Id: WFXMLScanner.cpp,v 1.25 2004/09/28 21:27:38 peiyongz Exp $
+  * $Id: WFXMLScanner.cpp 191707 2005-06-21 19:01:55Z cargilld $
  */
 
 
@@ -39,6 +39,12 @@ XERCES_CPP_NAMESPACE_BEGIN
 // ---------------------------------------------------------------------------
 //  WFXMLScanner: Constructors and Destructor
 // ---------------------------------------------------------------------------
+
+
+typedef JanitorMemFunCall<WFXMLScanner> CleanupType;
+typedef JanitorMemFunCall<ReaderMgr>    ReaderMgrResetType;
+
+
 WFXMLScanner::WFXMLScanner( XMLValidator* const  valToAdopt
                           , GrammarResolver* const grammarResolver
                           , MemoryManager* const manager) :
@@ -51,19 +57,22 @@ WFXMLScanner::WFXMLScanner( XMLValidator* const  valToAdopt
     , fAttrNSList(0)
     , fElementLookup(0)
 {
+    CleanupType cleanup(this, &WFXMLScanner::cleanUp);
+
     try
     {
         commonInit();
     }
     catch(const OutOfMemoryException&)
     {
+        // Don't cleanup when out of memory, since executing the
+        // code can cause problems.
+        cleanup.release();
+
         throw;
     }
-    catch(...)
-    {
-        cleanUp();
-        throw;
-    }
+
+    cleanup.release();
 }
 
 WFXMLScanner::WFXMLScanner( XMLDocumentHandler* const docHandler
@@ -82,19 +91,22 @@ WFXMLScanner::WFXMLScanner( XMLDocumentHandler* const docHandler
     , fAttrNSList(0)
     , fElementLookup(0)
 {
+    CleanupType cleanup(this, &WFXMLScanner::cleanUp);
+
     try
     {	
         commonInit();
     }
     catch(const OutOfMemoryException&)
     {
+        // Don't cleanup when out of memory, since executing the
+        // code can cause problems.
+        cleanup.release();
+
         throw;
     }
-    catch(...)
-    {
-        cleanUp();
-        throw;
-    }
+
+    cleanup.release();
 }
 
 WFXMLScanner::~WFXMLScanner()
@@ -124,6 +136,8 @@ void WFXMLScanner::scanDocument(const InputSource& src)
     //  any previous progressive scan tokens.
     fSequenceId++;
 
+    ReaderMgrResetType  resetReaderMgr(&fReaderMgr, &ReaderMgr::reset);
+
     try
     {
         //  Reset the scanner and its plugged in stuff for a new run. This
@@ -159,9 +173,6 @@ void WFXMLScanner::scanDocument(const InputSource& src)
         // If we have a document handler, then call the end document
         if (fDocHandler)
             fDocHandler->endDocument();
-
-        // Reset the reader manager to close all files, sockets, etc...
-        fReaderMgr.reset();
     }
     //  NOTE:
     //
@@ -170,13 +181,11 @@ void WFXMLScanner::scanDocument(const InputSource& src)
     //  to find out the position in the XML source of the error.
     catch(const XMLErrs::Codes)
     {
-        // This is a 'first fatal error' type exit, so reset and fall through
-        fReaderMgr.reset();
+        // This is a 'first failure' exception, so fall through
     }
     catch(const XMLValid::Codes)
     {
-        // This is a 'first fatal error' type exit, so reset and fall through
-        fReaderMgr.reset();
+        // This is a 'first fatal error' type exit, so fall through
     }
     catch(const XMLException& excToCatch)
     {
@@ -209,26 +218,21 @@ void WFXMLScanner::scanDocument(const InputSource& src)
         }
         catch(const OutOfMemoryException&)
         {
-            throw;
-        }
-        catch(...)
-        {
-            // Flush the reader manager and rethrow user's error
-            fReaderMgr.reset();
-            throw;
-        }
+            // This is a special case for out-of-memory
+            // conditions, because resetting the ReaderMgr
+            // can be problematic.
+            resetReaderMgr.release();
 
-        // If it returned, then reset the reader manager and fall through
-        fReaderMgr.reset();
+            throw;
+        }
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch(...)
-    {
-        // Reset and rethrow
-        fReaderMgr.reset();
+        // This is a special case for out-of-memory
+        // conditions, because resetting the ReaderMgr
+        // can be problematic.
+        resetReaderMgr.release();
+
         throw;
     }
 }
@@ -245,6 +249,8 @@ bool WFXMLScanner::scanNext(XMLPScanToken& token)
     XMLTokens curToken;
     bool retVal = true;
 
+    ReaderMgrResetType  resetReaderMgr(&fReaderMgr, &ReaderMgr::reset);
+
     try
     {
         while (true)
@@ -341,15 +347,13 @@ bool WFXMLScanner::scanNext(XMLPScanToken& token)
     //  to find out the position in the XML source of the error.
     catch(const XMLErrs::Codes)
     {
-        // This is a 'first failure' exception, so reset and return failure
-        fReaderMgr.reset();
-        return false;
+        // This is a 'first failure' exception, so return failure
+        retVal = false;
     }
     catch(const XMLValid::Codes)
     {
-        // This is a 'first fatal error' type exit, so reset and reuturn failure
-        fReaderMgr.reset();
-        return false;
+        // This is a 'first fatal error' type exit, so return failure
+        retVal = false;
     }
     catch(const XMLException& excToCatch)
     {
@@ -382,33 +386,26 @@ bool WFXMLScanner::scanNext(XMLPScanToken& token)
         }
         catch(const OutOfMemoryException&)
         {
-            throw;
-        }
-        catch(...)
-        {
-            // Reset and rethrow user error
-            fReaderMgr.reset();
+            // This is a special case for out-of-memory
+            // conditions, because resetting the ReaderMgr
+            // can be problematic.
+            resetReaderMgr.release();
+
             throw;
         }
 
-        // Reset and return failure
-        fReaderMgr.reset();
-        return false;
+        // Return failure
+        retVal = false;
     }
     catch(const OutOfMemoryException&)
     {
         throw;
     }
-    catch(...)
-    {
-        // Reset and rethrow original error
-        fReaderMgr.reset();
-        throw;
-    }
 
-    // If we hit the end, then flush the reader manager
-    if (!retVal)
-        fReaderMgr.reset();
+    // If we are not at the end, release the object that will
+    // reset the ReaderMgr.
+    if (retVal)
+        resetReaderMgr.release();
 
     return retVal;
 }
@@ -976,7 +973,7 @@ bool WFXMLScanner::scanStartTag(bool& gotData)
             {
                 curAtt = new (fMemoryManager) XMLAttr
                 (
-                    -1
+                    0
                     , attNameRawBuf
                     , XMLUni::fgZeroLenString
                     , fAttValueBuf.getRawBuffer()
@@ -992,7 +989,7 @@ bool WFXMLScanner::scanStartTag(bool& gotData)
                 curAtt = fAttrList->elementAt(attCount);
                 curAtt->set
                 (
-                    -1
+                    0
                     , attNameRawBuf
                     , XMLUni::fgZeroLenString
                     , fAttValueBuf.getRawBuffer()
@@ -1097,9 +1094,13 @@ bool WFXMLScanner::scanStartTagNS(bool& gotData)
 
     //  The current position is after the open bracket, so we need to read in
     //  in the element name.
-    if (!fReaderMgr.getName(fQNameBuf))
-    {
-        emitError(XMLErrs::ExpectedElementName);
+    int colonPosition;
+    if (!fReaderMgr.getQName(fQNameBuf, &colonPosition))
+    {        
+        if (fQNameBuf.isEmpty())
+            emitError(XMLErrs::ExpectedElementName);
+        else
+            emitError(XMLErrs::InvalidElementName, fQNameBuf.getRawBuffer());
         fReaderMgr.skipToChar(chOpenAngle);
         return false;
     }
@@ -1182,9 +1183,13 @@ bool WFXMLScanner::scanStartTagNS(bool& gotData)
         {
             //  Assume its going to be an attribute, so get a name from
             //  the input.
-            if (!fReaderMgr.getName(fAttNameBuf))
-            {
-                emitError(XMLErrs::ExpectedAttrName);
+            int colonPosition;
+            if (!fReaderMgr.getQName(fAttNameBuf, &colonPosition))
+            {                
+                if (fAttNameBuf.isEmpty())
+                    emitError(XMLErrs::ExpectedAttrName);
+                else
+                    emitError(XMLErrs::InvalidAttrName, fAttNameBuf.getRawBuffer()); 
                 fReaderMgr.skipPastChar(chCloseAngle);
                 return false;
             }
@@ -1322,27 +1327,6 @@ bool WFXMLScanner::scanStartTagNS(bool& gotData)
                 fAttrNameHashList->setElementAt(attNameHash, attCount);
             }
 
-            // Make sure that the name is basically well formed for namespace
-            //  enabled rules. It either has no colons, or it has one which
-            //  is neither the first or last char.
-            const int colonFirst = XMLString::indexOf(attNameRawBuf, chColon);
-            if (colonFirst != -1)
-            {
-                const int colonLast = XMLString::lastIndexOf(attNameRawBuf, chColon);
-
-                if (colonFirst != colonLast)
-                {
-                    emitError(XMLErrs::TooManyColonsInName);
-                    continue;
-                }
-                else if ((colonFirst == 0)
-                      ||  (colonLast == (int)fAttNameBuf.getLen() - 1))
-                {
-                    emitError(XMLErrs::InvalidColonPos);
-                    continue;
-                }
-            }
-
             // Map prefix to namespace
             const XMLCh* attPrefix = curAtt->getPrefix();
             const XMLCh* attLocalName = curAtt->getName();
@@ -2053,7 +2037,8 @@ void WFXMLScanner::scanCharData(XMLBuffer& toUse)
     sendCharData(toUse);
 }
 
-InputSource* WFXMLScanner::resolveSystemId(const XMLCh* const)
+InputSource* WFXMLScanner::resolveSystemId(const XMLCh* const /*sysId*/
+                                          ,const XMLCh* const /*pubId*/)
 {
     return 0;
 }
