@@ -1,5 +1,5 @@
 /*
- * Copyright 1999-2004 The Apache Software Foundation.
+ * Copyright 1999-2005 The Apache Software Foundation.
  * 
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: XMLReader.cpp,v 1.25 2004/09/29 00:24:01 knoaman Exp $
+ * $Id: XMLReader.cpp 176382 2005-04-21 09:05:57Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
@@ -40,7 +40,7 @@ XERCES_CPP_NAMESPACE_BEGIN
 //  not. Breaks out on the first non-whitespace.
 //
 bool XMLReader::isAllSpaces(const   XMLCh* const    toCheck
-                            , const unsigned int    count)
+                            , const unsigned int    count) const
 {
     const XMLCh* curCh = toCheck;
     const XMLCh* endPtr = toCheck + count;
@@ -58,7 +58,7 @@ bool XMLReader::isAllSpaces(const   XMLCh* const    toCheck
 //  not.
 //
 bool XMLReader::containsWhiteSpace(const   XMLCh* const    toCheck
-                            , const unsigned int    count)
+                            , const unsigned int    count) const
 {
     const XMLCh* curCh = toCheck;
     const XMLCh* endPtr = toCheck + count;
@@ -73,7 +73,7 @@ bool XMLReader::containsWhiteSpace(const   XMLCh* const    toCheck
 //
 //  This one is not called terribly often, so call the XMLChar utility
 //
-bool XMLReader::isPublicIdChar(const XMLCh toCheck)
+bool XMLReader::isPublicIdChar(const XMLCh toCheck) const
 {
     if (fXMLVersion == XMLV1_1)
         return XMLChar1_1::isPublicIdChar(toCheck);
@@ -207,7 +207,7 @@ XMLReader::XMLReader(const  XMLCh* const          pubId
 
     // Copy the encoding string to our member
     fEncodingStr = XMLString::replicate(encodingStr, fMemoryManager);
-    XMLString::upperCase(fEncodingStr);
+    XMLString::upperCaseASCII(fEncodingStr);
 
     // Ask the transcoding service if it supports src offset info
     fSrcOfsSupported = XMLPlatformUtils::fgTransService->supportsSrcOfs();
@@ -408,6 +408,7 @@ unsigned int XMLReader::getSrcOffset() const
     }
 
     if( fCharIndex < fCharsAvail ) {
+ 
         return (fSrcOfsBase + fCharOfsBuf[fCharIndex]);
     }
 
@@ -591,66 +592,195 @@ bool XMLReader::getName(XMLBuffer& toFill, const bool token)
             return false;
     }
 
+    unsigned int charIndex_start = fCharIndex;
+
     //  Lets check the first char for being a first name char. If not, then
     //  what's the point in living mannnn? Just give up now. We only do this
     //  if its a name and not a name token that they want.
     if (!token)
     {
         if (fXMLVersion == XMLV1_1 && ((fCharBuf[fCharIndex] >= 0xD800) && (fCharBuf[fCharIndex] <= 0xDB7F))) {
+           // make sure one more char is in the buffer, the transcoder
+           // should put only a complete surrogate pair into the buffer
+           assert(fCharIndex+1 < fCharsAvail);
            if ((fCharBuf[fCharIndex+1] < 0xDC00) || (fCharBuf[fCharIndex+1] > 0xDFFF))
                return false;
 
-            // Looks ok, so lets eat it and put it in our buffer
-            toFill.append(fCharBuf[fCharIndex++]);
-            fCurCol++;
-            toFill.append(fCharBuf[fCharIndex++]);
-            fCurCol++;
+            // Looks ok, so lets eat it
+            fCharIndex += 2;
         }
         else {
             if (!isFirstNameChar(fCharBuf[fCharIndex]))
                 return false;
 
-            // Looks ok, so lets eat it and put it in our buffer.  Update column also!
-            toFill.append(fCharBuf[fCharIndex++]);
-            fCurCol++;
+            // Looks ok, so lets eat it
+            fCharIndex ++;
         }
 
     }
 
     //  And now we loop until we run out of data in this reader or we hit
     //  a non-name char.
-    do {
-
-        while (fCharIndex < fCharsAvail)
+    while (true)
+    {
+        if (fXMLVersion == XMLV1_1)
         {
-            //  Check the current char and take it if its a name char. Else
-            //  break out.
-            if (fXMLVersion == XMLV1_1 && ((fCharBuf[fCharIndex] >= 0xD800) && (fCharBuf[fCharIndex] <= 0xDB7F))) {
-               if ((fCharBuf[fCharIndex+1] < 0xDC00) || (fCharBuf[fCharIndex+1] > 0xDFFF))
-                   return !toFill.isEmpty();
-
-                toFill.append(fCharBuf[fCharIndex++]);
-                fCurCol++;
-                toFill.append(fCharBuf[fCharIndex++]);
-                fCurCol++;
-            }
-            else {
-                if (!isNameChar(fCharBuf[fCharIndex]))
+            while (fCharIndex < fCharsAvail)
+            {
+                //  Check the current char and take it if its a name char. Else
+                //  break out.
+                if ( (fCharBuf[fCharIndex] >= 0xD800) && (fCharBuf[fCharIndex] <= 0xDB7F) )
                 {
-                    return !toFill.isEmpty();
-                }
+                    // make sure one more char is in the buffer, the transcoder
+                    // should put only a complete surrogate pair into the buffer
+                    assert(fCharIndex+1 < fCharsAvail);
+                    if ( (fCharBuf[fCharIndex+1] < 0xDC00) ||
+                         (fCharBuf[fCharIndex+1] > 0xDFFF)  )
+                        break;
+                    fCharIndex += 2;
 
-                toFill.append(fCharBuf[fCharIndex++]);
-                fCurCol++;
+                } 
+                else
+                {
+                    if (!isNameChar(fCharBuf[fCharIndex]))
+                        break;
+                    fCharIndex++;
+                }
+            }
+        }
+        else // XMLV1_0
+        {
+            while (fCharIndex < fCharsAvail)
+            {
+                if (!isNameChar(fCharBuf[fCharIndex]))
+                    break;
+                fCharIndex++;
             }
         }
 
-    // If we don't get no more, then break out.
-    } while (refreshCharBuffer());
+        // we have to copy the accepted character(s), and update column
+        if (fCharIndex != charIndex_start)
+        {
+            fCurCol += fCharIndex - charIndex_start;
+            toFill.append(&fCharBuf[charIndex_start], fCharIndex - charIndex_start);
+        }
+
+        // something is wrong if there is still something in the buffer
+        // or if we don't get no more, then break out.
+        if ((fCharIndex < fCharsAvail) ||
+             !refreshCharBuffer())
+            break;
+
+        charIndex_start = fCharIndex;
+    }
 
     return !toFill.isEmpty();
 }
 
+bool XMLReader::getQName(XMLBuffer& toFill, int* colonPosition)
+{
+    unsigned int charIndex_start;
+    bool checkNextCharacterForFirstNCName = true;
+
+    // We are only looking for two iterations (i.e. 'NCANAME':'NCNAME').
+    // We will stop when we finished scanning for a QName (i.e. either a second
+    // colon or an invalid char).
+    *colonPosition = -1;
+    for (;;) {
+
+        //  Ok, first lets see if we have chars in the buffer. If not, then lets
+        //  reload.
+        if (fCharIndex == fCharsAvail) {
+            if (!refreshCharBuffer()) {
+                break;
+            }
+        }
+
+        charIndex_start = fCharIndex;
+        if (checkNextCharacterForFirstNCName) {
+
+            checkNextCharacterForFirstNCName = false;
+            //  Lets check the first char for being a first name char. If not, then
+            //  what's the point in living mannnn? Just give up now. We only do this
+            //  if its a name and not a name token that they want.
+            if (fXMLVersion == XMLV1_1 
+                && ((fCharBuf[fCharIndex] >= 0xD800) && (fCharBuf[fCharIndex] <= 0xDB7F))) {
+                // make sure one more char is in the buffer, the transcoder
+                // should put only a complete surrogate pair into the buffer
+                assert(fCharIndex+1 < fCharsAvail);
+                if ((fCharBuf[fCharIndex+1] < 0xDC00) || (fCharBuf[fCharIndex+1] > 0xDFFF))
+                    return false;
+
+                // Looks ok, so lets eat it
+                fCharIndex += 2;
+            }
+            else {
+                if (!isFirstNCNameChar(fCharBuf[fCharIndex])) {
+                    return false;
+                }
+
+                // Looks ok, so lets eat it
+                fCharIndex++;
+            }
+        }
+
+        while (fCharIndex < fCharsAvail) {
+            //  Check the current char and take it if its a name char. Else
+            //  break out.
+            if ( (fCharBuf[fCharIndex] >= 0xD800) && (fCharBuf[fCharIndex] <= 0xDB7F) )
+            {
+                // make sure one more char is in the buffer, the transcoder
+                // should put only a complete surrogate pair into the buffer
+                assert(fCharIndex+1 < fCharsAvail);
+                if ( (fXMLVersion == XMLV1_0) ||
+                     (fCharBuf[fCharIndex+1] < 0xDC00) ||
+                     (fCharBuf[fCharIndex+1] > 0xDFFF)  ) {
+                    break;
+                }
+
+                fCharIndex += 2;
+                continue;
+            }
+
+            if (!isNCNameChar(fCharBuf[fCharIndex])) {
+                break;
+            }
+
+            fCharIndex++;
+        }
+
+        // we have to copy the accepted character(s), and update column
+        if (fCharIndex != charIndex_start)
+        {
+            fCurCol += fCharIndex - charIndex_start;
+            toFill.append(&fCharBuf[charIndex_start], fCharIndex - charIndex_start);
+        }
+
+        // something is wrong if there is still something in the buffer
+        // or if we don't get no more, then break out.
+        if (fCharIndex < fCharsAvail) {
+            if (fCharBuf[fCharIndex] != chColon) {
+                break;
+            }
+
+            if (*colonPosition != -1) {
+                return false;
+            }
+
+            *colonPosition = toFill.getLen();
+            toFill.append(chColon);
+            fCharIndex++;
+            fCurCol++;
+            checkNextCharacterForFirstNCName = true;
+        }
+    }
+
+    if (checkNextCharacterForFirstNCName) {
+        return false;
+    }
+
+    return !toFill.isEmpty();
+}
 
 bool XMLReader::getSpaces(XMLBuffer& toFill)
 {
@@ -679,7 +809,28 @@ bool XMLReader::getSpaces(XMLBuffer& toFill)
                 // Eat this char
                 fCharIndex++;
 
-                handleEOL(curCh, false);
+                //
+                //  'curCh' is a whitespace(x20|x9|xD|xA), so we only can have
+                //  end-of-line combinations with a leading chCR(xD) or chLF(xA)
+                //
+                //  100000 x20
+                //  001001 x9
+                //  001010 chLF
+                //  001101 chCR
+                //  -----------
+                //  000110 == (chCR|chLF) & ~(0x9|0x20)
+                //
+                //  if the result of thelogical-& operation is
+                //  true  : 'curCh' must be xA  or xD
+                //  false : 'curCh' must be x20 or x9
+                //
+                if ( ( curCh & (chCR|chLF) & ~(0x9|0x20) ) == 0 )
+                {
+                    fCurCol++;
+                } else
+                {
+                    handleEOL(curCh, false);
+                }
 
                 // Ok we can add this guy to our buffer
                 toFill.append(curCh);
@@ -722,7 +873,27 @@ bool XMLReader::getUpToCharOrWS(XMLBuffer& toFill, const XMLCh toCheck)
                 // Eat this char
                 fCharIndex++;
 
-                handleEOL(curCh, false);
+                //
+                //  'curCh' is not a whitespace(x20|x9|xD|xA), so we only can
+                //  have end-of-line combinations with a leading chNEL(x85) or
+                //  chLineSeparator(x2028)
+                //
+                //  0010000000101000 chLineSeparator
+                //  0000000010000101 chNEL
+                //  ---------------------
+                //  1101111101010010 == ~(chNEL|chLineSeparator)
+                //
+                //  if the result of the logical-& operation is
+                //  true  : 'curCh' can not be chNEL or chLineSeparator
+                //  false : 'curCh' can be chNEL or chLineSeparator
+                //
+                if ( curCh & (XMLCh) ~(chNEL|chLineSeparator) )
+                {
+                    fCurCol++;
+                } else
+                {
+                    handleEOL(curCh, false);
+                }
 
                 // Add it to our buffer
                 toFill.append(curCh);
@@ -788,7 +959,28 @@ bool XMLReader::skipSpaces(bool& skippedSomething, bool inDecl)
                 // Get the current char out of the buffer and eat it
                 XMLCh curCh = fCharBuf[fCharIndex++];
 
-                handleEOL(curCh, inDecl);
+                //
+                //  'curCh' is a whitespace(x20|x9|xD|xA), so we only can have
+                //  end-of-line combinations with a leading chCR(xD) or chLF(xA)
+                //
+                //  100000 x20
+                //  001001 x9
+                //  001010 chLF
+                //  001101 chCR
+                //  -----------
+                //  000110 == (chCR|chLF) & ~(0x9|0x20)
+                //
+                //  if the result of the logical-& operation is
+                //  true  : 'curCh' must be xA  or xD
+                //  false : 'curCh' must be x20 or x9
+                //
+                if ( ( curCh & (chCR|chLF) & ~(0x9|0x20) ) == 0 )
+                {
+                    fCurCol++;
+                } else
+                {
+                    handleEOL(curCh, inDecl);
+                }
 
             }
             else
@@ -858,7 +1050,28 @@ bool XMLReader::skippedSpace()
         // Eat the character
         fCharIndex++;
 
-        handleEOL((XMLCh&)curCh, false);
+        //
+        //  'curCh' is a whitespace(x20|x9|xD|xA), so we only can have
+        //  end-of-line combinations with a leading chCR(xD) or chLF(xA)
+        //
+        //  100000 x20
+        //  001001 x9
+        //  001010 chLF
+        //  001101 chCR
+        //  -----------
+        //  000110 == (chCR|chLF) & ~(0x9|0x20)
+        //
+        //  if the result of the logical-& operation is
+        //  true  : 'curCh' must be xA  or xD
+        //  false : 'curCh' must be x20 or x9
+        //
+        if ( ( curCh & (chCR|chLF) & ~(0x9|0x20) ) == 0 )
+        {
+            fCurCol++;
+        } else
+        {
+            handleEOL((XMLCh&)curCh, false);
+        }
 
         return true;
     }
@@ -978,7 +1191,7 @@ bool XMLReader::setEncoding(const XMLCh* const newEncoding)
     // upperCase the newEncoding first for better performance
     //
     XMLCh* inputEncoding = XMLString::replicate(newEncoding, fMemoryManager);
-    XMLString::upperCase(inputEncoding);
+    XMLString::upperCaseASCII(inputEncoding);
 
     //
     //  Try to map the string to one of our standard encodings. If its not
@@ -1006,7 +1219,9 @@ bool XMLReader::setEncoding(const XMLCh* const newEncoding)
         ||  !XMLString::compareString(inputEncoding, XMLUni::fgUTF16EncodingString2)
         ||  !XMLString::compareString(inputEncoding, XMLUni::fgUTF16EncodingString3)
         ||  !XMLString::compareString(inputEncoding, XMLUni::fgUTF16EncodingString4)
-        ||  !XMLString::compareString(inputEncoding, XMLUni::fgUTF16EncodingString5))
+        ||  !XMLString::compareString(inputEncoding, XMLUni::fgUTF16EncodingString5)
+        ||  !XMLString::compareString(inputEncoding, XMLUni::fgUTF16EncodingString6)
+        ||  !XMLString::compareString(inputEncoding, XMLUni::fgUTF16EncodingString7))
         {
             fMemoryManager->deallocate(inputEncoding);
 
@@ -1497,4 +1712,101 @@ XMLReader::xcodeMoreChars(          XMLCh* const            bufToFill
     return charsDone;
 }
 
+/***
+ *
+ * XML1.1
+ *
+ * 2.11 End-of-Line Handling
+ *
+ *    XML parsed entities are often stored in computer files which, for editing 
+ *    convenience, are organized into lines. These lines are typically separated 
+ *    by some combination of the characters CARRIAGE RETURN (#xD) and LINE FEED (#xA).
+ *
+ *    To simplify the tasks of applications, the XML processor MUST behave as if 
+ *    it normalized all line breaks in external parsed entities (including the document 
+ *    entity) on input, before parsing, by translating all of the following to a single 
+ *    #xA character:
+ *
+ *  1. the two-character sequence #xD #xA
+ *  2. the two-character sequence #xD #x85
+ *  3. the single character #x85
+ *  4. the single character #x2028
+ *  5. any #xD character that is not immediately followed by #xA or #x85.
+ *
+ *
+ ***/
+void XMLReader::handleEOL(XMLCh& curCh, bool inDecl)
+{
+    // 1. the two-character sequence #xD #xA
+    // 2. the two-character sequence #xD #x85
+    // 5. any #xD character that is not immediately followed by #xA or #x85.
+    if (curCh == chCR)
+    {
+        fCurCol = 1;
+        fCurLine++;
+
+        //
+        //  If not already internalized, then convert it to an
+        //  LF and eat any following LF.
+        //
+        if (fSource == Source_External)
+        {
+            if ((fCharIndex < fCharsAvail) || refreshCharBuffer())
+            {
+                if ( fCharBuf[fCharIndex] == chLF              || 
+                    ((fCharBuf[fCharIndex] == chNEL) && fNEL)  )
+                {
+                    fCharIndex++;
+                }
+            }
+            curCh = chLF;
+        }
+    }
+    else if (curCh == chLF)                   
+    {
+        fCurCol = 1;
+        fCurLine++;
+    }
+    // 3. the single character #x85
+    // 4. the single character #x2028
+    else if (curCh == chNEL || curCh == chLineSeparator)
+    {
+        if (inDecl && fXMLVersion == XMLV1_1)
+        {
+
+        /***
+         * XML1.1
+         *
+         * 2.11 End-of-Line Handling
+         *  ...
+         *   The characters #x85 and #x2028 cannot be reliably recognized and translated 
+         *   until an entity's encoding declaration (if present) has been read. 
+         *   Therefore, it is a fatal error to use them within the XML declaration or 
+         *   text declaration. 
+         *
+         ***/
+            ThrowXMLwithMemMgr1
+                (
+                TranscodingException
+                , XMLExcepts::Reader_NelLsepinDecl
+                , fSystemId
+                , fMemoryManager
+                );
+        }
+
+        if (fNEL && fSource == Source_External)
+        {
+            fCurCol = 1;
+            fCurLine++;
+            curCh = chLF;
+        }
+    }
+    else
+    {
+        fCurCol++;
+    }
+
+    return;
+}
+
 XERCES_CPP_NAMESPACE_END
