@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: XMLScanner.cpp,v 1.73 2004/09/30 15:20:14 peiyongz Exp $
+ * $Id: XMLScanner.cpp 231514 2005-08-11 20:53:29Z amassari $
  */
 
 
@@ -30,6 +30,7 @@
 #include <xercesc/util/UnexpectedEOFException.hpp>
 #include <xercesc/util/XMLMsgLoader.hpp>
 #include <xercesc/util/XMLRegisterCleanup.hpp>
+#include <xercesc/util/XMLInitializer.hpp>
 #include <xercesc/framework/LocalFileInputSource.hpp>
 #include <xercesc/framework/URLInputSource.hpp>
 #include <xercesc/framework/XMLDocumentHandler.hpp>
@@ -88,7 +89,7 @@ static XMLMutex& gScannerMutex()
 
         if (!sRegistered)
         {
-            sScannerMutex = new XMLMutex;
+            sScannerMutex = new XMLMutex(XMLPlatformUtils::fgMemoryManager);
             scannerMutexCleanup.registerCleanup(XMLScanner::reinitScannerMutex);
             sRegistered = true;
         }
@@ -117,6 +118,27 @@ static XMLMsgLoader& gScannerMsgLoader()
     return *gMsgLoader;
 }
 
+void XMLInitializer::initializeScannerMsgLoader()
+{
+    gMsgLoader = XMLPlatformUtils::loadMsgSet(XMLUni::fgXMLErrDomain);
+
+    // Register this object to be cleaned up at termination
+    if (gMsgLoader) {
+        cleanupMsgLoader.registerCleanup(XMLScanner::reinitMsgLoader);
+    }
+
+    sScannerMutex = new XMLMutex(XMLPlatformUtils::fgMemoryManager);
+    if (sScannerMutex) {
+        scannerMutexCleanup.registerCleanup(XMLScanner::reinitScannerMutex);
+        sRegistered = true;
+    }
+}
+
+
+typedef JanitorMemFunCall<XMLScanner>   CleanupType;
+typedef JanitorMemFunCall<ReaderMgr>    ReaderMgrResetType;
+
+
 // ---------------------------------------------------------------------------
 //  XMLScanner: Constructors and Destructor
 // ---------------------------------------------------------------------------
@@ -143,6 +165,10 @@ XMLScanner::XMLScanner(XMLValidator* const valToAdopt,
     , fNormalizeData(true)
     , fGenerateSyntheticAnnotations(false)
     , fValidateAnnotations(false)
+    , fIgnoreCachedDTD(false)
+    , fIgnoreAnnotations(false)
+    , fDisableDefaultEntityResolution(false)
+    , fSkipDTDValidation(false)
     , fErrorCount(0)
     , fEntityExpansionLimit(0)
     , fEntityExpansionCount(0)
@@ -188,14 +214,25 @@ XMLScanner::XMLScanner(XMLValidator* const valToAdopt,
     , fQNameBuf(1023, manager)
     , fPrefixBuf(1023, manager)
     , fURIBuf(1023, manager)
+    , fWSNormalizeBuf(1023, manager)
     , fElemStack(manager)   
 {
-   commonInit();
+    CleanupType cleanup(this, &XMLScanner::cleanUp);
 
-   if (fValidator) {
-       fValidatorFromUser = true;
-       initValidator(fValidator);
-   }
+    try
+    {
+        commonInit();
+    }
+    catch(const OutOfMemoryException&)
+    {
+        // Don't cleanup when out of memory, since executing the
+        // code can cause problems.
+        cleanup.release();
+
+        throw;
+    }
+
+    cleanup.release();
 }
 
 XMLScanner::XMLScanner( XMLDocumentHandler* const  docHandler
@@ -226,6 +263,10 @@ XMLScanner::XMLScanner( XMLDocumentHandler* const  docHandler
     , fNormalizeData(true)
     , fGenerateSyntheticAnnotations(false)
     , fValidateAnnotations(false)
+    , fIgnoreCachedDTD(false)
+    , fIgnoreAnnotations(false)
+    , fDisableDefaultEntityResolution(false)
+    , fSkipDTDValidation(false)
     , fErrorCount(0)
     , fEntityExpansionLimit(0)
     , fEntityExpansionCount(0)
@@ -271,30 +312,30 @@ XMLScanner::XMLScanner( XMLDocumentHandler* const  docHandler
     , fQNameBuf(1023, manager)
     , fPrefixBuf(1023, manager)
     , fURIBuf(1023, manager)
+    , fWSNormalizeBuf(1023, manager)
     , fElemStack(manager)
 {
-   commonInit();
+    CleanupType cleanup(this, &XMLScanner::cleanUp);
 
-   if (valToAdopt){
-       fValidatorFromUser = true;
-       initValidator(fValidator);
-   }
+    try
+    {
+        commonInit();
+    }
+    catch(const OutOfMemoryException&)
+    {
+        // Don't cleanup when out of memory, since executing the
+        // code can cause problems.
+        cleanup.release();
+
+        throw;
+    }
+
+    cleanup.release();
 }
 
 XMLScanner::~XMLScanner()
 {
-    delete fAttrList;
-    delete fAttrDupChkRegistry;
-    delete fValidationContext;
-    fMemoryManager->deallocate(fRootElemName);//delete [] fRootElemName;
-    fMemoryManager->deallocate(fExternalSchemaLocation);//delete [] fExternalSchemaLocation;
-    fMemoryManager->deallocate(fExternalNoNamespaceSchemaLocation);//delete [] fExternalNoNamespaceSchemaLocation;
-    // delete fUIntPool
-    for (unsigned int i=0; i<=fUIntPoolRow; i++)
-    {
-        fMemoryManager->deallocate(fUIntPool[i]);
-    }
-    fMemoryManager->deallocate(fUIntPool);
+    cleanUp();
 }
 
 
@@ -540,7 +581,9 @@ bool XMLScanner::scanFirst( const   InputSource&    src
     //  any previous tokens we've returned.
     fSequenceId++;
 
-    // Reset the scanner and its plugged in stuff for a new run.  This
+    ReaderMgrResetType  resetReaderMgr(&fReaderMgr, &ReaderMgr::reset);
+
+   // Reset the scanner and its plugged in stuff for a new run.  This
     // resets all the data structures, creates the initial reader and
     // pushes it on the stack, and sets up the base document path
     scanReset(src);
@@ -570,14 +613,12 @@ bool XMLScanner::scanFirst( const   InputSource&    src
     //  to find out the position in the XML source of the error.
     catch(const XMLErrs::Codes)
     {
-        // This is a 'first failure' exception so reset and return a failure
-        fReaderMgr.reset();
+        // This is a 'first failure' exception so return failure
         return false;
     }
     catch(const XMLValid::Codes)
     {
-        // This is a 'first fatal error' type exit, so reset and reuturn failure
-        fReaderMgr.reset();
+        // This is a 'first fatal error' type exit, return failure
         return false;
     }
     catch(const XMLException& excToCatch)
@@ -611,32 +652,33 @@ bool XMLScanner::scanFirst( const   InputSource&    src
         }
         catch(const OutOfMemoryException&)
         {
-            throw;
-        }
-        catch(...)
-        {
-            // Reset and rethrow the user error
-            fReaderMgr.reset();
+            // This is a special case for out-of-memory
+            // conditions, because resetting the ReaderMgr
+            // can be problematic.
+            resetReaderMgr.release();
+
             throw;
         }
 
-        // Reset and return a failure
-        fReaderMgr.reset();
         return false;
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch(...)
-    {
-        // Reset and rethrow original error
-        fReaderMgr.reset();
+        // This is a special case for out-of-memory
+        // conditions, because resetting the ReaderMgr
+        // can be problematic.
+        resetReaderMgr.release();
+
         throw;
     }
 
     // Fill in the caller's token to make it legal and return success
     toFill.set(fScannerId, fSequenceId);
+
+    // Release the object that will reset the ReaderMgr, since there's
+    // more to scan.
+    resetReaderMgr.release();
+
     return true;
 }
 
@@ -720,8 +762,28 @@ void XMLScanner::commonInit()
 
     // Register self as handler for XMLBufferFull events on the CDATA buffer
     fCDataBuf.setFullHandler(this, fBufferSize);
+
+   if (fValidator) {
+       fValidatorFromUser = true;
+       initValidator(fValidator);
+   }
 }
 
+void XMLScanner::cleanUp()
+{
+    delete fAttrList;
+    delete fAttrDupChkRegistry;
+    delete fValidationContext;
+    fMemoryManager->deallocate(fRootElemName);//delete [] fRootElemName;
+    fMemoryManager->deallocate(fExternalSchemaLocation);//delete [] fExternalSchemaLocation;
+    fMemoryManager->deallocate(fExternalNoNamespaceSchemaLocation);//delete [] fExternalNoNamespaceSchemaLocation;
+    // delete fUIntPool
+    for (unsigned int i=0; i<=fUIntPoolRow; i++)
+    {
+        fMemoryManager->deallocate(fUIntPool[i]);
+    }
+    fMemoryManager->deallocate(fUIntPool);
+}
 
 void XMLScanner::initValidator(XMLValidator* theValidator) {
 
@@ -1038,7 +1100,11 @@ void XMLScanner::scanPI()
     namePtr = bbName.getRawBuffer();
 
     // See if it is some form of 'xml' and emit a warning
-    if (!XMLString::compareIString(namePtr, XMLUni::fgXMLString))
+    //if (!XMLString::compareIString(namePtr, XMLUni::fgXMLString))
+    if (bbName.getLen() == 3 &&
+        (((namePtr[0] == chLatin_x) || (namePtr[0] == chLatin_X)) &&
+         ((namePtr[1] == chLatin_m) || (namePtr[1] == chLatin_M)) &&
+         ((namePtr[2] == chLatin_l) || (namePtr[2] == chLatin_L))))   
         emitError(XMLErrs::NoPIStartsWithXML);
 
     // If namespaces are enabled, then no colons allowed
@@ -1397,9 +1463,16 @@ void XMLScanner::scanXMLDecl(const DeclTypes type)
             else
             {
                 emitError(XMLErrs::BadStandalone);
-                if (!XMLString::compareIString(rawValue, XMLUni::fgYesString))
-                    fStandalone = true;
-                else if (!XMLString::compareIString(rawValue, XMLUni::fgNoString))
+                //if (!XMLString::compareIString(rawValue, XMLUni::fgYesString))
+                //else if (!XMLString::compareIString(rawValue, XMLUni::fgNoString))
+                if (buffers[curString]->getLen() == 3 &&
+                    (((rawValue[0] == chLatin_y) || (rawValue[0] == chLatin_Y)) &&
+                     ((rawValue[1] == chLatin_e) || (rawValue[1] == chLatin_E)) &&
+                     ((rawValue[2] == chLatin_s) || (rawValue[2] == chLatin_S))))   
+                    fStandalone = true;                
+                else if (buffers[curString]->getLen() == 2 &&
+                    (((rawValue[0] == chLatin_n) || (rawValue[0] == chLatin_N)) &&
+                     ((rawValue[1] == chLatin_o) || (rawValue[1] == chLatin_O))))   
                     fStandalone = false;
             }
         }
@@ -1585,13 +1658,16 @@ Grammar* XMLScanner::loadGrammar(const   XMLCh* const systemId
         ReaderMgr::LastExtEntityInfo lastInfo;
         fReaderMgr.getLastExtEntityInfo(lastInfo);
         XMLResourceIdentifier resourceIdentifier(XMLResourceIdentifier::ExternalEntity,
-                            systemId, 0, XMLUni::fgZeroLenString, lastInfo.systemId);
+                            systemId, 0, XMLUni::fgZeroLenString, lastInfo.systemId,
+                            &fReaderMgr);
         srcToUse = fEntityHandler->resolveEntity(&resourceIdentifier);
     }
 
     //  First we try to parse it as a URL. If that fails, we assume its
     //  a file and try it that way.
     if (!srcToUse) {
+        if (fDisableDefaultEntityResolution)
+            return 0;
 
         try
         {
@@ -1728,20 +1804,24 @@ void XMLScanner::setURIStringPool(XMLStringPool* const stringPool)
  *   otherwise it is allowed.
  *
  ***/
-void XMLScanner::checkInternalDTD(bool hasExtSubset, const XMLCh* const sysId)
+void XMLScanner::checkInternalDTD(bool hasExtSubset
+                                 ,const XMLCh* const sysId
+                                 ,const XMLCh* const pubId)
 {
     if (fToCacheGrammar)
         ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Val_CantHaveIntSS, fMemoryManager);
 
-    if (fUseCachedGrammar && hasExtSubset )
+    if (fUseCachedGrammar && hasExtSubset && !fIgnoreCachedDTD)
     {
-        InputSource* sysIdSrc = resolveSystemId(sysId);
-        Janitor<InputSource> janSysIdSrc(sysIdSrc);
-        Grammar* grammar = fGrammarResolver->getGrammar(sysIdSrc->getSystemId());
+        InputSource* sysIdSrc = resolveSystemId(sysId, pubId);
+        if (sysIdSrc) {
+            Janitor<InputSource> janSysIdSrc(sysIdSrc);
+            Grammar* grammar = fGrammarResolver->getGrammar(sysIdSrc->getSystemId());
 
-        if (grammar && grammar->getGrammarType() == Grammar::DTDGrammarType) 
-        {
-            ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Val_CantHaveIntSS, fMemoryManager);
+            if (grammar && grammar->getGrammarType() == Grammar::DTDGrammarType) 
+            {
+                ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::Val_CantHaveIntSS, fMemoryManager);
+            }
         }
     }
 
