@@ -1,61 +1,33 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2003,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: XSObjectFactory.cpp,v $
+ * $Log$
+ * Revision 1.24  2005/01/06 21:39:43  amassari
+ * Removed warnings
+ *
+ * Revision 1.23  2004/09/08 13:56:14  peiyongz
+ * Apache License Version 2.0
+ *
+ * Revision 1.22  2004/07/06 14:58:15  cargilld
+ * Rename VALUE_CONSTRAINT enumeration names to avoid naming conflict with AIX system header which already uses VC_DEFAULT as a macro.  Will need to document that this fix breaks source code compatibility.
+ *
+ * Revision 1.21  2004/03/05 16:28:21  knoaman
+ * PSVI: prohibited attributes should not be part of attribute use. Patch by Mike Boos.
+ *
  * Revision 1.20  2004/02/05 18:09:53  cargilld
  * Fix a seg fault with PSVI and set basetype of anysimpletype to be anytype.
  *
@@ -615,7 +587,7 @@ XSObjectFactory::addOrFind(ComplexTypeInfo* const typeInfo,
             (typeInfo->getDatatypeValidator()))
             xsSimpleType = addOrFind(typeInfo->getDatatypeValidator(), xsModel);
         
-        unsigned int attCount;
+        unsigned int attCount=0;
         if (typeInfo->hasAttDefs())
         {
             SchemaAttDefList& attDefList = (SchemaAttDefList&) typeInfo->getAttDefList();
@@ -676,9 +648,12 @@ XSObjectFactory::addOrFind(ComplexTypeInfo* const typeInfo,
                 else
                     xsAttDecl = addOrFind(&attDef, xsModel, xsObj);
 
-                XSAttributeUse* attUse = createXSAttributeUse(xsAttDecl, xsModel);
-                xsAttList->addElement(attUse);
-                processAttUse(&attDef, attUse);
+                if (attDef.getDefaultType() != XMLAttDef::Prohibited) {
+
+                    XSAttributeUse* attUse = createXSAttributeUse(xsAttDecl, xsModel);
+                    xsAttList->addElement(attUse);
+                    processAttUse(&attDef, attUse);
+                }
             }
         }
 
@@ -858,7 +833,7 @@ XSObjectFactory::createXSAttGroupDefinition(XercesAttGroupInfo* const attGroupIn
             else
                 xsAttDecl = addOrFind(attDef, xsModel);
 
-            if (xsAttDecl) // just for sanity
+            if (xsAttDecl && (attDef->getDefaultType() != XMLAttDef::Prohibited)) // just for sanity
             {
                 XSAttributeUse* attUse = createXSAttributeUse(xsAttDecl, xsModel);
                 xsAttList->addElement(attUse);
@@ -1110,16 +1085,16 @@ void XSObjectFactory::processAttUse(SchemaAttDef* const attDef,
                                     XSAttributeUse* const xsAttUse)
 {
     bool isRequired = false;
-    XSConstants::VALUE_CONSTRAINT constraintType = XSConstants::VC_NONE;
+    XSConstants::VALUE_CONSTRAINT constraintType = XSConstants::VALUE_CONSTRAINT_NONE;
     
     if (attDef->getDefaultType() == XMLAttDef::Default)
     {
-        constraintType = XSConstants::VC_DEFAULT;
+        constraintType = XSConstants::VALUE_CONSTRAINT_DEFAULT;
     }
     else if ((attDef->getDefaultType() == XMLAttDef::Fixed) ||
              (attDef->getDefaultType() == XMLAttDef::Required_And_Fixed))
     {
-        constraintType = XSConstants::VC_FIXED;
+        constraintType = XSConstants::VALUE_CONSTRAINT_FIXED;
     }
 
     if (attDef->getDefaultType() == XMLAttDef::Required ||
