@@ -15,65 +15,7 @@
  */
 
 /*
- * $Log: XSerializeEngine.hpp,v $
- * Revision 1.18  2004/09/08 13:56:14  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.17  2004/03/05 22:21:45  peiyongz
- * readBytes()/writeBytes between BinOutputStream/BinInputStream and
- * XSerializeEngine will always be the full size of the buffer to maintain the exact
- * position for aligned data.
- *
- * Revision 1.16  2004/03/01 23:19:03  peiyongz
- * Grant XSerializeEngine access to GrammarPool
- *
- * Revision 1.15  2004/02/20 20:57:39  peiyongz
- * Bug#27046: path from David Bertoni
- *
- * Revision 1.14  2004/02/11 20:38:50  peiyongz
- * Fix to bug#26864, thanks to David Bertoni.
- *
- * Revision 1.13  2004/01/29 11:46:30  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.12  2004/01/16 21:55:18  peiyongz
- * maintain the same size on both 32/64 bit architecture
- *
- * Revision 1.11  2004/01/15 23:42:32  peiyongz
- * proper allignment for built-in datatype read/write
- *
- * Revision 1.10  2003/12/17 00:18:34  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.9  2003/11/25 20:37:40  jberry
- * Cleanup build errors/warnings from CodeWarrior
- *
- * Revision 1.8  2003/11/11 22:48:13  knoaman
- * Serialization of XSAnnotation.
- *
- * Revision 1.7  2003/10/17 21:09:03  peiyongz
- * renaming methods
- *
- * Revision 1.6  2003/10/14 15:18:20  peiyongz
- * getMemoryManager()
- *
- * Revision 1.5  2003/10/09 19:11:53  peiyongz
- * Fix to linkage error on Solaris
- *
- * Revision 1.4  2003/10/07 19:38:31  peiyongz
- * API for Template_Class Object Serialization/Deserialization
- *
- * Revision 1.3  2003/09/25 22:22:00  peiyongz
- * Introduction of readString/writeString
- *
- * Revision 1.2  2003/09/19 04:29:11  neilg
- * fix compilation problems under GCC
- *
- * Revision 1.1  2003/09/18 18:31:24  peiyongz
- * OSU: Object Serialization Utilities
- *
- * $Id: XSerializeEngine.hpp,v 1.18 2004/09/08 13:56:14 peiyongz Exp $
- *
+ * $Id: XSerializeEngine.hpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 #if !defined(XSERIALIZE_ENGINE_HPP)
@@ -94,6 +36,7 @@ class XSerializedObjectId;
 class BinOutputStream;
 class BinInputStream;
 class XMLGrammarPool;
+class XMLGrammarPoolImpl;
 class XMLStringPool;
 
 class XMLUTIL_EXPORT XSerializeEngine
@@ -251,6 +194,20 @@ public:
       ***/
     MemoryManager* getMemoryManager() const;
 
+    /***
+      *
+      *  Get the storer level (the level of the serialize engine
+      *  which created the binary stream that this serialize engine
+      *  is loading).
+      *
+      *  The level returned is meaningful only when
+      *  the engine isLoading.
+      *
+      *  Return: level
+      *
+      ***/
+    inline unsigned short getStorerLevel() const;
+
     /***
       *
       *  Write object to the internal buffer.
@@ -595,6 +552,25 @@ public:
            XSerializeEngine& operator>>(double&);
            XSerializeEngine& operator>>(bool&);
 
+    /***
+      *
+      *  Getters
+      *
+      ***/
+    inline 
+    unsigned long   getBufSize()    const; 
+
+    inline 
+    unsigned long   getBufCur()     const; 
+
+    inline 
+    unsigned long   getBufCurAccumulated()     const; 
+
+    inline 
+    unsigned long   getBufCount()    const; 
+
+    void                  trace(char*)     const;
+
 private:
     // -----------------------------------------------------------------------
     //  Unimplemented constructors and operators
@@ -634,6 +610,8 @@ private:
 
            void           pumpCount();
 
+    inline void           resetBuffer();
+
     /***
       *   
       *    Helper
@@ -654,9 +632,12 @@ private:
     inline void            Assert(bool  toEval
                                 , const XMLExcepts::Codes toThrow)  const;
 
-    inline size_t          allignAdjust()                           const;
 
-    inline void            allignBufCur();
+    inline size_t          calBytesNeeded(size_t)  const;
+
+    inline size_t          alignAdjust(size_t)     const;
+
+    inline void            alignBufCur(size_t);
 
     // Make XTemplateSerializer friend of XSerializeEngine so that
     // we can call lookupStorePool and lookupLoadPool in the case of
@@ -669,6 +650,12 @@ private:
     //  fStoreLoad: 
     //               Indicator: storing(serialization) or loading(de-serialization)
     //
+    //  fStorerLevel:
+    //              The level of the serialize engine which created the binary 
+    //              stream that this serialize engine is loading
+    //
+    //              It is set by GrammarPool when loading
+    //
     //  fGrammarPool:
     //               Thw owning GrammarPool which instantiate this SerializeEngine 
     //               instance
@@ -705,11 +692,15 @@ private:
     //
     //  fMapCount:
     // -------------------------------------------------------------------------------
-    const short                            fStoreLoad;  
+    const short                            fStoreLoad;
+    short                                  fStorerLevel;
+
     XMLGrammarPool*  const                 fGrammarPool;
     BinInputStream*  const                 fInputStream;
     BinOutputStream* const                 fOutputStream;
 
+    unsigned long                          fBufCount;
+
     //buffer
     const unsigned long                    fBufSize;
 	XMLByte* const                         fBufStart;
@@ -717,6 +708,8 @@ private:
     XMLByte*                               fBufCur;
     XMLByte*                               fBufLoadMax; 
 
+
+
     /***
      *   Map for storing object
      *
@@ -741,6 +734,9 @@ private:
      *   object counter
      ***/
 	XSerializedObjectId_t                  fObjectCount;
+
+    //to allow grammar pool to set storer level when loading
+    friend class XMLGrammarPoolImpl;
 };
 
 inline bool XSerializeEngine::isStoring() const
@@ -782,36 +778,6 @@ inline void XSerializeEngine::Assert(bool toEval
 
 }
 
-// For the following built-in datatype, we assume
-// the same allignment requirement
-//
-// short    unsigned short
-// int      unsigned long
-// long     unsigned long
-// float
-// double
-//
-// Based on the current position (fBufCur), calculated the needed size
-// to read/write
-//
-inline size_t XSerializeEngine::allignAdjust() const
-{
-	#ifdef XML_PLATFORM_NEW_BLOCK_ALIGNMENT
-		size_t alignment = XML_PLATFORM_NEW_BLOCK_ALIGNMENT;
-	#else
-		size_t alignment = (sizeof(void*) >= sizeof(double)) ? sizeof(void*) : sizeof(double);
-	#endif
-	
-	size_t remainder = (size_t) fBufCur % alignment;	
-	return (remainder == 0) ? 0 : (alignment - remainder);
-}
-
-// Adjust the fBufCur
-inline void XSerializeEngine::allignBufCur()
-{
-    fBufCur+=allignAdjust();
-}
-
 inline void XSerializeEngine::readString(XMLCh*&        toRead
                                        , int&           bufferLen)
 {
@@ -840,6 +806,36 @@ inline void XSerializeEngine::readString(XMLByte*&      toRead)
     readString(toRead, dummyBufferLen, dummyDataLen);
 }
 
+inline 
+unsigned long XSerializeEngine::getBufSize() const
+{
+    return fBufSize;
+}
+
+inline 
+unsigned long XSerializeEngine::getBufCur() const
+{
+    return (fBufCur-fBufStart);
+}
+
+inline 
+unsigned long XSerializeEngine::getBufCurAccumulated() const
+{
+    return (fBufCount - (isStoring() ? 0: 1)) * fBufSize + (fBufCur-fBufStart);
+}
+
+inline 
+unsigned long XSerializeEngine::getBufCount() const
+{
+    return fBufCount;
+}
+
+inline 
+unsigned short XSerializeEngine::getStorerLevel() const
+{
+    return fStorerLevel;
+}
+
 /***
  *  Ought to be nested class
  ***/
