@@ -19,7 +19,7 @@
 *  handler with the scanner. In these handler methods, appropriate DOM nodes
 *  are created and added to the DOM tree.
 *
-* $Id: AbstractDOMParser.cpp,v 1.68 2004/09/28 02:14:13 cargilld Exp $
+* $Id: AbstractDOMParser.cpp 191708 2005-06-21 19:02:15Z cargilld $
 *
 */
 
@@ -69,6 +69,12 @@ XERCES_CPP_NAMESPACE_BEGIN
 // ---------------------------------------------------------------------------
 //  AbstractDOMParser: Constructors and Destructor
 // ---------------------------------------------------------------------------
+
+
+typedef JanitorMemFunCall<AbstractDOMParser>    CleanupType;
+typedef JanitorMemFunCall<AbstractDOMParser>    ResetInProgressType;
+
+
 AbstractDOMParser::AbstractDOMParser( XMLValidator* const   valToAdopt
                                     , MemoryManager* const  manager
                                     , XMLGrammarPool* const gramPool) :
@@ -98,19 +104,22 @@ AbstractDOMParser::AbstractDOMParser( XMLValidator* const   valToAdopt
 , fInternalSubset(fBufMgr.bidOnBuffer())
 , fPSVIHandler(0)
 {
+    CleanupType cleanup(this, &AbstractDOMParser::cleanUp);
+
     try
     {
         initialize();
     }
     catch(const OutOfMemoryException&)
     {
+        // Don't cleanup when out of memory, since executing the
+        // code can cause problems.
+        cleanup.release();
+
         throw;
     }
-    catch(...)
-    {
-       cleanUp();
-       throw;
-    }
+
+    cleanup.release();
 }
 
 
@@ -185,6 +194,12 @@ void AbstractDOMParser::reset()
 }
 
 
+void AbstractDOMParser::resetInProgress()
+{
+    fParseInProgress = false;
+}
+
+
 void AbstractDOMParser::resetPool()
 {
     //  We cannot enter here while a regular parse is in progress.
@@ -312,6 +327,20 @@ bool AbstractDOMParser::getStandardUriConformant() const
     return fScanner->getStandardUriConformant();
 }
 
+bool AbstractDOMParser::getIgnoreAnnotations() const
+{
+    return fScanner->getIgnoreAnnotations();
+}
+
+bool AbstractDOMParser::getDisableDefaultEntityResolution() const
+{
+    return fScanner->getDisableDefaultEntityResolution();
+}
+
+bool AbstractDOMParser::getSkipDTDValidation() const
+{
+    return fScanner->getSkipDTDValidation();
+}
 
 // ---------------------------------------------------------------------------
 //  AbstractDOMParser: Setter methods
@@ -449,6 +478,26 @@ void AbstractDOMParser::setCreateSchemaInfo(const bool create)
         fScanner->setPSVIHandler(0);
 }
 
+void AbstractDOMParser::setIgnoreAnnotations(const bool newValue)
+{
+    fScanner->setIgnoreAnnotations(newValue);
+}
+
+void AbstractDOMParser::setDisableDefaultEntityResolution(const bool newValue)
+{
+    fScanner->setDisableDefaultEntityResolution(newValue);
+}
+
+void AbstractDOMParser::setSkipDTDValidation(const bool newValue)
+{
+    fScanner->setSkipDTDValidation(newValue);
+}
+
+void AbstractDOMParser::setDocument(DOMDocument* toSet)
+{
+    fDocument = (DOMDocumentImpl *)toSet;
+}
+
 // ---------------------------------------------------------------------------
 //  AbstractDOMParser: Parsing methods
 // ---------------------------------------------------------------------------
@@ -458,21 +507,19 @@ void AbstractDOMParser::parse(const InputSource& source)
     if (fParseInProgress)
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
+    ResetInProgressType     resetInProgress(this, &AbstractDOMParser::resetInProgress);
+
     try
     {
         fParseInProgress = true;
         fScanner->scanDocument(source);
-        fParseInProgress = false;
     }
     catch(const OutOfMemoryException&)
     {
+        resetInProgress.release();
+
         throw;
     }    
-    catch(...)
-    {
-        fParseInProgress = false;
-        throw;
-    }
 }
 
 void AbstractDOMParser::parse(const XMLCh* const systemId)
@@ -481,21 +528,19 @@ void AbstractDOMParser::parse(const XMLCh* const systemId)
     if (fParseInProgress)
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
+    ResetInProgressType     resetInProgress(this, &AbstractDOMParser::resetInProgress);
+
     try
     {
         fParseInProgress = true;
         fScanner->scanDocument(systemId);
-        fParseInProgress = false;
     }
     catch(const OutOfMemoryException&)
     {
+        resetInProgress.release();
+
         throw;
-    }
-    catch(...)
-    {
-        fParseInProgress = false;
-        throw;
-    }
+    }    
 }
 
 void AbstractDOMParser::parse(const char* const systemId)
@@ -504,21 +549,19 @@ void AbstractDOMParser::parse(const char* const systemId)
     if (fParseInProgress)
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
+    ResetInProgressType     resetInProgress(this, &AbstractDOMParser::resetInProgress);
+
     try
     {
         fParseInProgress = true;
         fScanner->scanDocument(systemId);
-        fParseInProgress = false;
     }
     catch(const OutOfMemoryException&)
     {
+        resetInProgress.release();
+
         throw;
-    }
-    catch(...)
-    {
-        fParseInProgress = false;
-        throw;
-    }
+    }    
 }
 
 
@@ -759,12 +802,9 @@ void AbstractDOMParser::endEntityReference(const XMLEntityDecl&)
     if (!fCreateEntityReferenceNodes) return;
 
     DOMEntityReferenceImpl *erImpl = 0;
-    DOMNode* firstChild = 0;
 
-    if (fCurrentParent->getNodeType() == DOMNode::ENTITY_REFERENCE_NODE) {
+    if (fCurrentParent->getNodeType() == DOMNode::ENTITY_REFERENCE_NODE)
         erImpl = (DOMEntityReferenceImpl *) fCurrentParent;
-        firstChild = erImpl->getFirstChild();
-    }
 
     fCurrentParent = fNodeStack->pop();
 
@@ -788,15 +828,15 @@ void AbstractDOMParser::endElement( const   XMLElementDecl&
         fWithinElement = false;
 }
 
-void AbstractDOMParser::elementTypeInfo( const   XMLCh * const  typeName
-                           , const XMLCh *const                 typeURI)
+void AbstractDOMParser::elementTypeInfo( const XMLCh * const  /*typeName*/
+                                       , const XMLCh * const  /*typeURI*/)
 {
 }
 
 
-void AbstractDOMParser::ignorableWhitespace(const   XMLCh* const    chars
-                                    , const unsigned int    length
-                                    , const bool)
+void AbstractDOMParser::ignorableWhitespace(  const XMLCh* const    chars
+                                            , const unsigned int    length
+                                            , const bool)
 {
     // Ignore chars before the root element
     if (!fWithinElement || !fIncludeIgnorableWhitespace)
@@ -1205,21 +1245,26 @@ void AbstractDOMParser::attDef
                 break;
 
             case XMLAttDef::Enumeration :
-                fInternalSubset.append(chSpace);
-                const XMLCh* enumString = attDef.getEnumeration();
-                int length = XMLString::stringLen(enumString);
-                if (length > 0) {
+                {
+                    fInternalSubset.append(chSpace);
+                    const XMLCh* enumString = attDef.getEnumeration();
+                    int length = XMLString::stringLen(enumString);
+                    if (length > 0) {
 
-                    fInternalSubset.append(chOpenParen );
-                    for(int i=0; i<length; i++) {
-                        if (enumString[i] == chSpace)
-                            fInternalSubset.append(chPipe);
-                        else
-                            fInternalSubset.append(enumString[i]);
+                        fInternalSubset.append(chOpenParen );
+                        for(int i=0; i<length; i++) {
+                            if (enumString[i] == chSpace)
+                                fInternalSubset.append(chPipe);
+                            else
+                                fInternalSubset.append(enumString[i]);
+                        }
+                        fInternalSubset.append(chCloseParen);
                     }
-                    fInternalSubset.append(chCloseParen);
                 }
                 break;
+            default:
+                // remaining types don't belong to a DTD
+                break;
             }
             //get te default types of the attlist
             const XMLAttDef::DefAttTypes def = attDef.getDefaultType();
@@ -1237,6 +1282,9 @@ void AbstractDOMParser::attDef
                 fInternalSubset.append(chSpace);
                 fInternalSubset.append(XMLUni::fgFixedString);
                 break;
+            default:
+                // remaining types don't belong to a DTD
+                break;
             }
 
             const XMLCh* defaultValue = attDef.getValue();
