@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: AbstractDOMParser.hpp,v 1.35 2004/09/28 02:14:14 cargilld Exp $
+ * $Id: AbstractDOMParser.hpp 191708 2005-06-21 19:02:15Z cargilld $
  *
  */
 #if !defined(ABSTRACTDOMPARSER_HPP)
@@ -430,6 +430,33 @@ public :
       */
     bool getValidateAnnotations() const;
 
+    /** Get the 'ignore annotations' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         ignore annotations, false otherwise.
+      *
+      * @see #setIgnoreAnnotations
+      */
+    bool getIgnoreAnnotations() const;
+
+    /** Get the 'disable default entity resolution' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         not perform default entity resolution, false otherwise.
+      *
+      * @see #setDisableDefaultEntityResolution
+      */
+    bool getDisableDefaultEntityResolution() const;
+
+    /** Get the 'skip DTD validation' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         skip DTD validation, false otherwise.
+      *
+      * @see #setSkipDTDValidation
+      */
+    bool getSkipDTDValidation() const;
+
     //@}
 
 
@@ -797,6 +824,46 @@ public :
       */
     void  setCreateSchemaInfo(const bool newState);
 
+    /** Set the 'ignore annotation' flag
+      *
+      * This method gives users the option to not generate XSAnnotations
+      * when "traversing" a schema.
+      *
+      * The parser's default state is false
+      *
+      * @param newValue The state to set
+      */
+    void setIgnoreAnnotations(const bool newValue);
+
+    /** Set the 'disable default entity resolution' flag
+      *
+      * This method gives users the option to not perform default entity
+      * resolution.  If the user's resolveEntity method returns NULL the
+      * parser will try to resolve the entity on its own.  When this option
+      * is set to true, the parser will not attempt to resolve the entity
+      * when the resolveEntity method returns NULL.
+      *    
+      * The parser's default state is false
+      *
+      * @param newValue The state to set
+      *
+      * @see #entityResolver
+      */
+    void setDisableDefaultEntityResolution(const bool newValue);
+
+    /** Set the 'skip DTD validation' flag
+      *
+      * This method gives users the option to skip DTD validation only when 
+      * schema validation is on (i.e. when performing validation,  we will
+      * ignore the DTD, except for entities, when schema validation is enabled).
+      *
+      * NOTE: This option is ignored if schema validation is disabled.
+      *
+      * The parser's default state is false
+      *
+      * @param newValue The state to set
+      */
+    void setSkipDTDValidation(const bool newValue);
     //@}
 
 
@@ -1581,6 +1648,7 @@ private :
     // -----------------------------------------------------------------------
     void initialize();
     void cleanUp();
+    void resetInProgress();
 
     // -----------------------------------------------------------------------
     //  Unimplemented constructors and operators
@@ -1790,11 +1858,6 @@ inline void AbstractDOMParser::setCurrentNode(DOMNode* toSet)
     fCurrentNode = toSet;
 }
 
-inline void AbstractDOMParser::setDocument(DOMDocument* toSet)
-{
-    fDocument = (DOMDocumentImpl *)toSet;
-}
-
 inline void AbstractDOMParser::setParseInProgress(const bool toSet)
 {
     fParseInProgress = toSet;
