@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: DOMBuilderImpl.hpp,v 1.17 2004/09/08 13:56:17 peiyongz Exp $
+ * $Id: DOMBuilderImpl.hpp 191708 2005-06-21 19:02:15Z cargilld $
  *
  */
 
@@ -652,6 +652,7 @@ public :
 
     /**
       * Returns the current src offset within the input source.
+      * To be used only while parsing is in progress.
       *
       * @return offset within the input source
       */
@@ -835,6 +836,11 @@ public :
 
 
 private :
+    // -----------------------------------------------------------------------
+    //  Initialize/Cleanup methods
+    // -----------------------------------------------------------------------
+    void resetParse();
+
     // -----------------------------------------------------------------------
     //  Private data members
     //
