@@ -15,274 +15,10 @@
  */
 
 /*
- * $Log: SAX2XMLReaderImpl.cpp,v $
- * Revision 1.38  2004/09/30 14:07:23  peiyongz
- * setInputBufferSize
- *
- * Revision 1.37  2004/09/28 02:14:14  cargilld
- * Add support for validating annotations.
- *
- * Revision 1.36  2004/09/23 01:09:55  cargilld
- * Add support for generating synthetic XSAnnotations.  When a schema component has non-schema attributes and no child attributes create a synthetic XSAnnotation (under feature control) so the non-schema attributes can be recovered under PSVI.
- *
- * Revision 1.35  2004/09/08 13:56:17  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.34  2004/04/13 16:53:26  peiyongz
- * get/setIdentityConstraintChecking
- *
- * Revision 1.33  2004/01/29 11:46:32  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.32  2003/12/17 00:18:35  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.31  2003/11/21 22:38:50  neilg
- * Enable grammar pools and grammar resolvers to manufacture
- * XSModels.  This also cleans up handling in the
- * parser classes by eliminating the need to tell
- * the grammar pool that schema compoments need to be produced.
- * Thanks to David Cargill.
- *
- * Revision 1.30  2003/11/06 15:30:07  neilg
- * first part of PSVI/schema component model implementation, thanks to David Cargill.  This covers setting the PSVIHandler on parser objects, as well as implementing XSNotation, XSSimpleTypeDefinition, XSIDCDefinition, and most of XSWildcard, XSComplexTypeDefinition, XSElementDeclaration, XSAttributeDeclaration and XSAttributeUse.
- *
- * Revision 1.29  2003/10/30 21:37:31  knoaman
- * Enhanced Entity Resolver Support. Thanks to David Cargill.
- *
- * Revision 1.28  2003/10/01 16:32:38  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.27  2003/09/16 18:30:54  neilg
- * make Grammar pool be responsible for creating and owning URI string pools.  This is one more step towards having grammars be independent of the parsers involved in their creation
- *
- * Revision 1.26  2003/08/13 15:43:24  knoaman
- * Use memory manager when creating SAX exceptions.
- *
- * Revision 1.25  2003/07/31 17:05:48  peiyongz
- * using getGrammar(URI)
- *
- * Revision 1.24  2003/07/10 19:48:24  peiyongz
- * Stateless Grammar: Initialize scanner with grammarResolver,
- *
- * Revision 1.23  2003/06/25 22:36:46  peiyongz
- * to use new GrammarResolver::getGrammar()
- *
- * Revision 1.22  2003/06/20 18:55:54  peiyongz
- * Stateless Grammar Pool :: Part I
- *
- * Revision 1.21  2003/05/18 14:02:05  knoaman
- * Memory manager implementation: pass per instance manager.
- *
- * Revision 1.20  2003/05/16 21:36:59  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.19  2003/05/16 06:01:52  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.18  2003/05/15 18:26:50  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.17  2003/04/17 21:58:50  neilg
- * Adding a new property,
- * http://apache.org/xml/properties/security-manager, with
- * appropriate getSecurityManager/setSecurityManager methods on DOM
- * and SAX parsers.  Also adding a new SecurityManager class.
- *
- * The purpose of these modifications is to permit applications a
- * means to have the parser reject documents whose processing would
- * otherwise consume large amounts of system resources.  Malicious
- * use of such documents could be used to launch a denial-of-service
- * attack against a system running the parser.  Initially, the
- * SecurityManager only knows about attacks that can result from
- * exponential entity expansion; this is the only known attack that
- * involves processing a single XML document.  Other, simlar attacks
- * can be launched if arbitrary schemas may be parsed; there already
- * exist means (via use of the EntityResolver interface) by which
- * applications can deny processing of untrusted schemas.  In future,
- * the SecurityManager will be expanded to take these other exploits
- * into account.
- *
- * Adding SecurityManager support
- * 
- * Revision 1.16  2003/01/03 20:09:36  tng
- * New feature StandardUriConformant to force strict standard uri conformance.
- *
- * Revision 1.15  2002/12/27 16:16:51  knoaman
- * Set scanner options and handlers.
- *
- * Revision 1.14  2002/12/11 22:14:54  knoaman
- * Performance: no need to use temporary buffer to hold namespace value.
- *
- * Revision 1.13  2002/12/04 01:57:09  knoaman
- * Scanner re-organization.
- *
- * Revision 1.12  2002/11/04 14:57:03  tng
- * C++ Namespace Support.
- *
- * Revision 1.11  2002/09/24 20:00:32  tng
- * Performance: use XMLString::equals instead of XMLString::compareString
- *
- * Revision 1.10  2002/08/14 15:20:38  knoaman
- * [Bug 3111] Problem with LexicalHandler::startDTD() and LexicalHandler::endDTD().
- *
- * Revision 1.9  2002/07/11 18:27:20  knoaman
- * Grammar caching/preparsing - initial implementation.
- *
- * Revision 1.8  2002/06/17 15:41:15  tng
- * To be consistent, SAX2 is updated with:
- * 1. the progressive parse methods should use the fReuseGrammar flag set from setFeature instead of using parameter
- * 2. add feature "http://apache.org/xml/features/continue-after-fatal-error", and users should use setFeature instead of setExitOnFirstFatalError
- * 3. add feature "http://apache.org/xml/features/validation-error-as-fatal", and users should use setFeature instead of setValidationConstraintFatal
- *
- * Revision 1.7  2002/05/30 16:20:09  tng
- * Add feature to optionally ignore external DTD.
- *
- * Revision 1.6  2002/05/29 21:37:47  knoaman
- * Add baseURI to resolveEntity to support DOMInputSource.
- *
- * Revision 1.5  2002/05/28 20:44:14  tng
- * [Bug 9104] prefixes dissapearing when schema validation turned on.
- *
- * Revision 1.4  2002/05/27 18:39:21  tng
- * To get ready for 64 bit large file, use XMLSSize_t to represent line and column number.
- *
- * Revision 1.3  2002/05/22 20:53:41  knoaman
- * Prepare for DOM L3 :
- * - Make use of the XMLEntityHandler/XMLErrorReporter interfaces, instead of using
- * EntityHandler/ErrorHandler directly.
- * - Add 'AbstractDOMParser' class to provide common functionality for XercesDOMParser
- * and DOMBuilder.
- *
- * Revision 1.2  2002/02/13 16:09:24  knoaman
- * Move SAX2 features/properties names constants to XMLUni.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:06  peiyongz
- * sane_include
- *
- * Revision 1.25  2002/01/28 17:47:41  knoaman
- * Some SAX calls were not passed to the LexicalHandler.
- *
- * Revision 1.24  2002/01/28 17:08:47  knoaman
- * SAX2-ext's DeclHandler support.
- *
- * Revision 1.23  2002/01/28 16:29:21  knoaman
- * The namespace-prefixes feature in SAX2 should be off by default.
- *
- * Revision 1.22  2002/01/24 16:30:34  tng
- * [Bug 3111] Problem with LexicalHandler::startDTD() and LexicalHandler::endDTD() .
- *
- * Revision 1.21  2001/12/21 18:03:25  tng
- * [Bug 1833] LexicalHandler::startDTD not called correctly.
- *
- * Revision 1.20  2001/11/20 18:51:44  tng
- * Schema: schemaLocation and noNamespaceSchemaLocation to be specified outside the instance document.  New methods setExternalSchemaLocation and setExternalNoNamespaceSchemaLocation are added (for SAX2, two new properties are added).
- *
- * Revision 1.19  2001/10/25 19:46:15  tng
- * Comment outside root element should also be reported.
- *
- * Revision 1.18  2001/09/12 13:03:43  tng
- * [Bug 3155] SAX2 does not offer progressive parse.
- *
- * Revision 1.17  2001/08/02 19:00:46  tng
- * [Bug 1329] SAX2XMLReaderImpl leaks XMLBuffers.
- *
- * Revision 1.16  2001/08/01 19:11:02  tng
- * Add full schema constraint checking flag to the samples and the parser.
- *
- * Revision 1.15  2001/06/27 17:39:50  knoaman
- * Fix for bug #2353.
- *
- * Revision 1.14  2001/06/19 16:45:08  tng
- * Add installAdvDocHandler to SAX2XMLReader as the code is there already.
- *
- * Revision 1.13  2001/06/03 19:26:19  jberry
- * Add support for querying error count following parse; enables simple parse without requiring error handler.
- *
- * Revision 1.12  2001/05/11 13:26:21  tng
- * Copyright update.
- *
- * Revision 1.11  2001/05/03 20:34:33  tng
- * Schema: SchemaValidator update
- *
- * Revision 1.10  2001/03/30 16:46:57  tng
- * Schema: Use setDoSchema instead of setSchemaValidation which makes more sense.
- *
- * Revision 1.9  2001/03/21 21:56:08  tng
- * Schema: Add Schema Grammar, Schema Validator, and split the DTDValidator into DTDValidator, DTDScanner, and DTDGrammar.
- *
- * Revision 1.8  2001/02/15 15:56:29  tng
- * Schema: Add setSchemaValidation and getSchemaValidation for DOMParser and SAXParser.
- * Add feature "http://apache.org/xml/features/validation/schema" for SAX2XMLReader.
- * New data field  fSchemaValidation in XMLScanner as the flag.
- *
- * Revision 1.7  2001/01/15 21:26:33  tng
- * Performance Patches by David Bertoni.
- *
- * Details: (see xerces-c-dev mailing Jan 14)
- * XMLRecognizer.cpp: the internal encoding string XMLUni::fgXMLChEncodingString
- * was going through this function numerous times.  As a result, the top hot-spot
- * for the parse was _wcsicmp().  The real problem is that the Microsofts wide string
- * functions are unbelievably slow.  For things like encodings, it might be
- * better to use a special comparison function that only considers a-z and
- * A-Z as characters with case.  This works since the character set for
- * encodings is limit to printable ASCII characters.
- *
- *  XMLScanner2.cpp: This also has some case-sensitive vs. insensitive compares.
- * They are also much faster.  The other tweak is to only make a copy of an attribute
- * string if it needs to be split.  And then, the strategy is to try to use a
- * stack-based buffer, rather than a dynamically-allocated one.
- *
- * SAX2XMLReaderImpl.cpp: Again, more case-sensitive vs. insensitive comparisons.
- *
- * KVStringPair.cpp & hpp: By storing the size of the allocation, the storage can
- * likely be re-used many times, cutting down on dynamic memory allocations.
- *
- * XMLString.hpp: a more efficient implementation of stringLen().
- *
- * DTDValidator.cpp: another case of using a stack-based buffer when possible
- *
- * These patches made a big difference in parse time in some of our test
- * files, especially the ones are very attribute-heavy.
- *
- * Revision 1.6  2000/12/22 20:41:52  tng
- * XMLUni::fgEmptyString which is defined as "EMPTY" is incorrectly used as an empty string; in fact XMLUni::fgZeroLenString should be used instead
- *
- * Revision 1.5  2000/12/22 15:16:51  tng
- * SAX2-ext's LexicalHandler support added by David Bertoni.
- *
- * Revision 1.4  2000/08/09 23:39:58  jpolast
- * should be namespace-prefixes; not namespaces-prefixes
- *
- * Revision 1.3  2000/08/09 22:16:12  jpolast
- * many conformance & stability changes:
- *   - ContentHandler::resetDocument() removed
- *   - attrs param of ContentHandler::startDocument() made const
- *   - SAXExceptions thrown now have msgs
- *   - removed duplicate function signatures that had 'const'
- *       [ eg: getContentHander() ]
- *   - changed getFeature and getProperty to apply to const objs
- *   - setProperty now takes a void* instead of const void*
- *   - SAX2XMLReaderImpl does not inherit from SAXParser anymore
- *   - Reuse Validator (http://apache.org/xml/features/reuse-validator) implemented
- *   - Features & Properties now read-only during parse
- *
- * Revision 1.2  2000/08/07 22:53:44  jpolast
- * fixes for when 'namespaces' feature is turned off:
- *   * namespaces-prefixes only used when namespaces is on
- *   * URIs not looked up when namespaces is off, blank string instead
- *   * default validation scheme is validation on, auto-validation off.
- *
- * Revision 1.1  2000/08/02 18:04:41  jpolast
- * initial checkin of sax2 implemenation
- * submitted by Simon Fell (simon@fell.com)
- * and Joe Polastre (jpolast@apache.org)
- *
- *
+ * $Id: SAX2XMLReaderImpl.cpp 191671 2005-06-21 15:48:06Z cargilld $
  */
 
 #include <xercesc/util/IOException.hpp>
-#include <xercesc/util/XMLChTranscoder.hpp>
 #include <xercesc/util/RefStackOf.hpp>
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/Janitor.hpp>
@@ -311,6 +47,12 @@ const XMLCh gDTDEntityStr[] =
     chOpenSquare, chLatin_d, chLatin_t, chLatin_d, chCloseSquare, chNull
 };
 
+
+
+typedef JanitorMemFunCall<SAX2XMLReaderImpl>    CleanupType;
+typedef JanitorMemFunCall<SAX2XMLReaderImpl>    ResetInProgressType;
+
+
 SAX2XMLReaderImpl::SAX2XMLReaderImpl(MemoryManager* const  manager
                                    , XMLGrammarPool* const gramPool):
 
@@ -324,6 +66,7 @@ SAX2XMLReaderImpl::SAX2XMLReaderImpl(MemoryManager* const  manager
     , fAdvDHListSize(32)
     , fDocHandler(0)
     , fTempAttrVec(0)
+    , fPrefixesStorage(0)
     , fPrefixes(0)
     , fPrefixCounts(0)
     , fDTDHandler(0)
@@ -340,21 +83,23 @@ SAX2XMLReaderImpl::SAX2XMLReaderImpl(MemoryManager* const  manager
     , fValidator(0)
     , fMemoryManager(manager)
     , fGrammarPool(gramPool)
-    , fStringBuffers(manager)
 {
+    CleanupType cleanup(this, &SAX2XMLReaderImpl::cleanUp);
+
     try
     {
         initialize();
     }
     catch(const OutOfMemoryException&)
     {
+        // Don't cleanup when out of memory, since executing the
+        // code can cause problems.
+        cleanup.release();
+
         throw;
     }
-    catch(...)
-    {
-        cleanUp();
-        throw;
-    }
+
+    cleanup.release();
 }
 
 SAX2XMLReaderImpl::~SAX2XMLReaderImpl()
@@ -389,7 +134,8 @@ void SAX2XMLReaderImpl::initialize()
 	// default: schema is on
 	setDoSchema(true);
 	
-	fPrefixes    = new (fMemoryManager) RefStackOf<XMLBuffer> (10, false, fMemoryManager) ;
+    fPrefixesStorage = new (fMemoryManager) XMLStringPool(109, fMemoryManager) ;
+	fPrefixes    = new (fMemoryManager) ValueStackOf<unsigned int> (30, fMemoryManager) ;
 	fTempAttrVec  = new (fMemoryManager) RefVectorOf<XMLAttr>  (10, false, fMemoryManager) ;
 	fPrefixCounts = new (fMemoryManager) ValueStackOf<unsigned int>(10, fMemoryManager) ;
 }
@@ -399,6 +145,7 @@ void SAX2XMLReaderImpl::cleanUp()
 {
     fMemoryManager->deallocate(fAdvDHList);//delete [] fAdvDHList;
     delete fScanner;
+    delete fPrefixesStorage;
     delete fPrefixes;
     delete fTempAttrVec;
     delete fPrefixCounts;
@@ -641,19 +388,17 @@ void SAX2XMLReaderImpl::parse (const   InputSource&    source)
     if (fParseInProgress)
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
+    ResetInProgressType     resetInProgress(this, &SAX2XMLReaderImpl::resetInProgress);
+
     try
     {
         fParseInProgress = true;
         fScanner->scanDocument(source);
-        fParseInProgress = false;
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch (...)
-    {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 }
@@ -664,19 +409,17 @@ void SAX2XMLReaderImpl::parse (const   XMLCh* const    systemId)
     if (fParseInProgress)
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
+    ResetInProgressType     resetInProgress(this, &SAX2XMLReaderImpl::resetInProgress);
+
     try
     {
         fParseInProgress = true;
         fScanner->scanDocument(systemId);
-        fParseInProgress = false;
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch (...)
-    {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 }
@@ -687,6 +430,8 @@ void SAX2XMLReaderImpl::parse (const   char* const     systemId)
     if (fParseInProgress)
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
+    ResetInProgressType     resetInProgress(this, &SAX2XMLReaderImpl::resetInProgress);
+
     try
     {
         fParseInProgress = true;
@@ -695,11 +440,8 @@ void SAX2XMLReaderImpl::parse (const   char* const     systemId)
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch (...)
-    {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 }
@@ -765,20 +507,20 @@ void SAX2XMLReaderImpl::docCharacters(  const   XMLCh* const    chars
                                 , const bool            cdataSection)
 {
     // Suppress the chars before the root element.
-    if (!fElemDepth)
-        return;
+    if (fElemDepth)
+    {
+        // Call the installed LexicalHandler.
+        if (cdataSection && fLexicalHandler)
+            fLexicalHandler->startCDATA();
 
-   // Call the installed LexicalHandler.
-   if (cdataSection && fLexicalHandler)
-        fLexicalHandler->startCDATA();
+        // Just map to the SAX document handler
+        if (fDocHandler)
+            fDocHandler->characters(chars, length);
 
-    // Just map to the SAX document handler
-    if (fDocHandler)
-        fDocHandler->characters(chars, length);
-
-   // Call the installed LexicalHandler.
-   if (cdataSection && fLexicalHandler)
-        fLexicalHandler->endCDATA();
+        // Call the installed LexicalHandler.
+        if (cdataSection && fLexicalHandler)
+            fLexicalHandler->endCDATA();
+    }
 
     //
     //  If there are any installed advanced handlers, then lets call them
@@ -791,17 +533,17 @@ void SAX2XMLReaderImpl::docCharacters(  const   XMLCh* const    chars
 
 void SAX2XMLReaderImpl::docComment(const XMLCh* const commentText)
 {
-   // Call the installed LexicalHandler.
-   if (fLexicalHandler)
-   {
+    // Call the installed LexicalHandler.
+    if (fLexicalHandler)
+    {
         // SAX2 reports comment text like characters -- as an
         // array with a length.
         fLexicalHandler->comment(commentText, XMLString::stringLen(commentText));
-   }
+    }
 
     //
     //  OK, if there are any installed advanced handlers,
-   // then let's call them with this info.
+    // then let's call them with this info.
     //
     for (unsigned int index = 0; index < fAdvDHCount; index++)
         fAdvDHList[index]->docComment(commentText);
@@ -903,16 +645,10 @@ void SAX2XMLReaderImpl::resetDocument()
     // Make sure our element depth flag gets set back to zero
     fElemDepth = 0;
 
-    // Pop any prefix buffers left over from previous uses
-    while (!fPrefixCounts->empty())
-    {
-        unsigned int numPrefix = fPrefixCounts->pop();
-        for (unsigned int i = 0; i < numPrefix; i++)
-        {
-            XMLBuffer * buf = fPrefixes->pop() ;
-            fStringBuffers.releaseBuffer(*buf) ;
-        }
-    }
+    // reset prefix counters and prefix map
+    fPrefixCounts->removeAllElements();
+    fPrefixes->removeAllElements();
+    fPrefixesStorage->flushAll();
 }
 
 
@@ -949,19 +685,13 @@ startElement(   const   XMLElementDecl&         elemDecl
 
     if (fDocHandler)
     {
-        XMLBufBid elemQName( &fStringBuffers ) ;
-        if (elemPrefix && *elemPrefix) {
-            elemQName.set(elemPrefix);
-            elemQName.append(chColon);
-        }
-        elemQName.append(elemDecl.getBaseName());
+        const XMLCh* const elemQName =
+            elemDecl.getFullName();
 
         if (getDoNamespaces())
         {
             unsigned int numPrefix = 0;
             const XMLCh*   nsString = XMLUni::fgXMLNSString;
-            const XMLCh*   nsPrefix = 0;
-            const XMLCh*   nsURI    = 0;
             const XMLAttr* tempAttr = 0;
 
             if (!fNamespacePrefix)
@@ -971,6 +701,9 @@ startElement(   const   XMLElementDecl&         elemDecl
 
             for (unsigned int i = 0; i < attrCount; i++)
             {
+                const XMLCh*   nsPrefix = 0;
+                const XMLCh*   nsURI    = 0;
+
                 tempAttr = attrList.elementAt(i);
                 if (XMLString::equals(tempAttr->getQName(), nsString))
                     nsURI = tempAttr->getValue();
@@ -982,20 +715,17 @@ startElement(   const   XMLElementDecl&         elemDecl
                 if (!fNamespacePrefix)
                 {
                     if (nsURI == 0)
-                        fTempAttrVec->addElement((XMLAttr* const)tempAttr);
+                        fTempAttrVec->addElement((XMLAttr*)tempAttr);
                 }
                 if (nsURI != 0)
                 {
                     if (nsPrefix == 0)
                         nsPrefix = XMLUni::fgZeroLenString;
                     fDocHandler->startPrefixMapping(nsPrefix, nsURI);
-                    XMLBuffer &buf = fStringBuffers.bidOnBuffer();
-                    buf.set ( nsPrefix ) ;
-                    fPrefixes->push(&buf) ;
+                    unsigned int nPrefixId=fPrefixesStorage->addOrFind(nsPrefix);
+                    fPrefixes->push(nPrefixId) ;
                     numPrefix++;
                 }
-                nsURI = 0;
-                nsPrefix = 0;
             }
             fPrefixCounts->push(numPrefix) ;
             if (!fNamespacePrefix)
@@ -1008,7 +738,7 @@ startElement(   const   XMLElementDecl&         elemDecl
             (
                 fScanner->getURIText(elemURLId)
                 , elemDecl.getBaseName()
-                , elemQName.getRawBuffer()
+                , elemQName
                 , fAttrList
             );
         }
@@ -1017,7 +747,7 @@ startElement(   const   XMLElementDecl&         elemDecl
             fAttrList.setVector(&attrList, attrCount, fScanner);
             fDocHandler->startElement(XMLUni::fgZeroLenString,
 										elemDecl.getBaseName(),
-										elemDecl.getFullName(),
+										elemQName,
 										fAttrList);
         }
 
@@ -1032,22 +762,21 @@ startElement(   const   XMLElementDecl&         elemDecl
                 (
                     fScanner->getURIText(elemURLId)
                     , elemDecl.getBaseName()
-                    , elemQName.getRawBuffer()
+                    , elemQName
                 );
 
                 unsigned int numPrefix = fPrefixCounts->pop();
                 for (unsigned int i = 0; i < numPrefix; ++i)
                 {
-                    XMLBuffer * buf = fPrefixes->pop() ;
-                    fDocHandler->endPrefixMapping( buf->getRawBuffer() );
-                    fStringBuffers.releaseBuffer(*buf) ;
+                    unsigned int nPrefixId = fPrefixes->pop() ;
+                    fDocHandler->endPrefixMapping( fPrefixesStorage->getValueForId(nPrefixId) );
                 }
             }
             else
             {
                 fDocHandler->endElement(XMLUni::fgZeroLenString,
                                 elemDecl.getBaseName(),
-                                elemDecl.getFullName());
+                                elemQName);
             }
         }
     }
@@ -1083,26 +812,18 @@ void SAX2XMLReaderImpl::endElement( const   XMLElementDecl& elemDecl
         // get the prefixes back so that we can call endPrefixMapping()
         if (getDoNamespaces())
         {
-            XMLBufBid elemQName( &fStringBuffers ) ;
-            if (elemPrefix && *elemPrefix) {
-                elemQName.set(elemPrefix);
-                elemQName.append(chColon);
-            }
-            elemQName.append(elemDecl.getBaseName());
-
             fDocHandler->endElement
             (
                 fScanner->getURIText(uriId)
                 , elemDecl.getBaseName()
-                , elemQName.getRawBuffer()
+                , elemDecl.getFullName()
             );
 
             unsigned int numPrefix = fPrefixCounts->pop();
             for (unsigned int i = 0; i < numPrefix; i++)
             {
-                XMLBuffer * buf = fPrefixes->pop() ;
-                fDocHandler->endPrefixMapping( buf->getRawBuffer() );
-                fStringBuffers.releaseBuffer(*buf) ;
+                unsigned int nPrefixId = fPrefixes->pop() ;
+                fDocHandler->endPrefixMapping( fPrefixesStorage->getValueForId(nPrefixId) );
             }
         }
         else
@@ -1491,11 +1212,11 @@ void SAX2XMLReaderImpl::setFeature(const XMLCh* const name, const bool value)
     if (fParseInProgress)
         throw SAXNotSupportedException("Feature modification is not supported during parse.", fMemoryManager);
 	
-    if (XMLString::compareIString(name, XMLUni::fgSAX2CoreNameSpaces) == 0)
+    if (XMLString::compareIStringASCII(name, XMLUni::fgSAX2CoreNameSpaces) == 0)
     {
         setDoNamespaces(value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgSAX2CoreValidation) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgSAX2CoreValidation) == 0)
     {
         fValidation = value;
         if (fValidation)
@@ -1506,11 +1227,11 @@ void SAX2XMLReaderImpl::setFeature(const XMLCh* const name, const bool value)
         else
             setValidationScheme(Val_Never);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgSAX2CoreNameSpacePrefixes) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgSAX2CoreNameSpacePrefixes) == 0)
     {
         fNamespacePrefix = value;
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesDynamic) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesDynamic) == 0)
     {
         fAutoValidation = value;
         // for auto validation, the sax2 core validation feature must also be enabled.
@@ -1522,96 +1243,120 @@ void SAX2XMLReaderImpl::setFeature(const XMLCh* const name, const bool value)
         else
             setValidationScheme(Val_Never);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesSchema) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSchema) == 0)
     {
         setDoSchema(value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesSchemaFullChecking) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSchemaFullChecking) == 0)
     {
         fScanner->setValidationSchemaFullChecking(value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesIdentityConstraintChecking) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesIdentityConstraintChecking) == 0)
     {
         fScanner->setIdentityConstraintChecking(value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesLoadExternalDTD) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesLoadExternalDTD) == 0)
     {
         fScanner->setLoadExternalDTD(value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesContinueAfterFatalError) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesContinueAfterFatalError) == 0)
     {
         fScanner->setExitOnFirstFatal(!value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesValidationErrorAsFatal) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesValidationErrorAsFatal) == 0)
     {
         fScanner->setValidationConstraintFatal(value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesCacheGrammarFromParse) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesCacheGrammarFromParse) == 0)
     {
         fScanner->cacheGrammarFromParse(value);
 
         if (value)
             fScanner->useCachedGrammarInParse(value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesUseCachedGrammarInParse) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesUseCachedGrammarInParse) == 0)
     {
         if (value || !fScanner->isCachingGrammarFromParse())
             fScanner->useCachedGrammarInParse(value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesCalculateSrcOfs) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesCalculateSrcOfs) == 0)
     {
         fScanner->setCalculateSrcOfs(value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesStandardUriConformant) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesStandardUriConformant) == 0)
     {
         fScanner->setStandardUriConformant(value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesGenerateSyntheticAnnotations) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesGenerateSyntheticAnnotations) == 0)
     {
         fScanner->setGenerateSyntheticAnnotations(value);
     }
-    else if (XMLString::compareIString(name, XMLUni::fgXercesValidateAnnotations) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesValidateAnnotations) == 0)
     {
         fScanner->setValidateAnnotations(value);
     }
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesIgnoreCachedDTD) == 0)
+    {
+        fScanner->setIgnoredCachedDTD(value);
+    }
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesIgnoreAnnotations) == 0)
+    {
+        fScanner->setIgnoreAnnotations(value);
+    }
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesDisableDefaultEntityResolution) == 0)
+    {
+        fScanner->setDisableDefaultEntityResolution(value);
+    }
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSkipDTDValidation) == 0)
+    {
+        fScanner->setSkipDTDValidation(value);
+    }
     else
        throw SAXNotRecognizedException("Unknown Feature", fMemoryManager);
 }
 
 bool SAX2XMLReaderImpl::getFeature(const XMLCh* const name) const
 {
-    if (XMLString::compareIString(name, XMLUni::fgSAX2CoreNameSpaces) == 0)
+    if (XMLString::compareIStringASCII(name, XMLUni::fgSAX2CoreNameSpaces) == 0)
         return getDoNamespaces();
-    else if (XMLString::compareIString(name, XMLUni::fgSAX2CoreValidation) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgSAX2CoreValidation) == 0)
         return fValidation;
-    else if (XMLString::compareIString(name, XMLUni::fgSAX2CoreNameSpacePrefixes) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgSAX2CoreNameSpacePrefixes) == 0)
         return fNamespacePrefix;
-    else if (XMLString::compareIString(name, XMLUni::fgXercesDynamic) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesDynamic) == 0)
         return fAutoValidation;
-    else if (XMLString::compareIString(name, XMLUni::fgXercesSchema) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSchema) == 0)
         return getDoSchema();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesSchemaFullChecking) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSchemaFullChecking) == 0)
         return fScanner->getValidationSchemaFullChecking();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesIdentityConstraintChecking) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesIdentityConstraintChecking) == 0)
         return fScanner->getIdentityConstraintChecking();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesLoadExternalDTD) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesLoadExternalDTD) == 0)
         return fScanner->getLoadExternalDTD();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesContinueAfterFatalError) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesContinueAfterFatalError) == 0)
         return !fScanner->getExitOnFirstFatal();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesValidationErrorAsFatal) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesValidationErrorAsFatal) == 0)
         return fScanner->getValidationConstraintFatal();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesCacheGrammarFromParse) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesCacheGrammarFromParse) == 0)
         return fScanner->isCachingGrammarFromParse();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesUseCachedGrammarInParse) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesUseCachedGrammarInParse) == 0)
         return fScanner->isUsingCachedGrammarInParse();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesCalculateSrcOfs) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesCalculateSrcOfs) == 0)
         return fScanner->getCalculateSrcOfs();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesStandardUriConformant) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesStandardUriConformant) == 0)
         return fScanner->getStandardUriConformant();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesGenerateSyntheticAnnotations) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesGenerateSyntheticAnnotations) == 0)
         return fScanner->getGenerateSyntheticAnnotations();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesValidateAnnotations) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesValidateAnnotations) == 0)
         return fScanner->getValidateAnnotations();
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesIgnoreCachedDTD) == 0)
+        return fScanner->getIgnoreCachedDTD();
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesIgnoreAnnotations) == 0)
+        return fScanner->getIgnoreAnnotations();
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesDisableDefaultEntityResolution) == 0)
+        return fScanner->getDisableDefaultEntityResolution();
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSkipDTDValidation) == 0)
+        return fScanner->getSkipDTDValidation();
     else
        throw SAXNotRecognizedException("Unknown Feature", fMemoryManager);
 
@@ -1623,15 +1368,15 @@ void SAX2XMLReaderImpl::setProperty(const XMLCh* const name, void* value)
 	if (fParseInProgress)
 		throw SAXNotSupportedException("Property modification is not supported during parse.", fMemoryManager);
 
-	if (XMLString::compareIString(name, XMLUni::fgXercesSchemaExternalSchemaLocation) == 0)
+	if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSchemaExternalSchemaLocation) == 0)
 	{
 		fScanner->setExternalSchemaLocation((XMLCh*)value);
 	}
-	else if (XMLString::compareIString(name, XMLUni::fgXercesSchemaExternalNoNameSpaceSchemaLocation) == 0)
+	else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSchemaExternalNoNameSpaceSchemaLocation) == 0)
 	{
 		fScanner->setExternalNoNamespaceSchemaLocation((XMLCh*)value);
 	}
-	else if (XMLString::compareIString(name, XMLUni::fgXercesSecurityManager) == 0)
+	else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSecurityManager) == 0)
 	{
 		fScanner->setSecurityManager((SecurityManager*)value);
 	}
@@ -1660,11 +1405,11 @@ void SAX2XMLReaderImpl::setProperty(const XMLCh* const name, void* value)
 
 void* SAX2XMLReaderImpl::getProperty(const XMLCh* const name) const
 {
-    if (XMLString::compareIString(name, XMLUni::fgXercesSchemaExternalSchemaLocation) == 0)
+    if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSchemaExternalSchemaLocation) == 0)
         return (void*)fScanner->getExternalSchemaLocation();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesSchemaExternalNoNameSpaceSchemaLocation) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSchemaExternalNoNameSpaceSchemaLocation) == 0)
         return (void*)fScanner->getExternalNoNamespaceSchemaLocation();
-    else if (XMLString::compareIString(name, XMLUni::fgXercesSecurityManager) == 0)
+    else if (XMLString::compareIStringASCII(name, XMLUni::fgXercesSecurityManager) == 0)
         return (void*)fScanner->getSecurityManager();
     else if (XMLString::equals(name, XMLUni::fgXercesScannerName))
         return (void*)fScanner->getName();
@@ -1720,20 +1465,18 @@ Grammar* SAX2XMLReaderImpl::loadGrammar(const char* const systemId,
     if (fParseInProgress)
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
+    ResetInProgressType     resetInProgress(this, &SAX2XMLReaderImpl::resetInProgress);
+
     Grammar* grammar = 0;
     try
     {
         fParseInProgress = true;
         grammar = fScanner->loadGrammar(systemId, grammarType, toCache);
-        fParseInProgress = false;
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch(...)
-    {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 
@@ -1748,20 +1491,18 @@ Grammar* SAX2XMLReaderImpl::loadGrammar(const XMLCh* const systemId,
     if (fParseInProgress)
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
+    ResetInProgressType     resetInProgress(this, &SAX2XMLReaderImpl::resetInProgress);
+
     Grammar* grammar = 0;
     try
     {
         fParseInProgress = true;
         grammar = fScanner->loadGrammar(systemId, grammarType, toCache);
-        fParseInProgress = false;
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch(...)
-    {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 
@@ -1776,26 +1517,29 @@ Grammar* SAX2XMLReaderImpl::loadGrammar(const InputSource& source,
     if (fParseInProgress)
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
+    ResetInProgressType     resetInProgress(this, &SAX2XMLReaderImpl::resetInProgress);
+
     Grammar* grammar = 0;
     try
     {
         fParseInProgress = true;
         grammar = fScanner->loadGrammar(source, grammarType, toCache);
-        fParseInProgress = false;
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch(...)
-    {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 
     return grammar;
 }
 
+void SAX2XMLReaderImpl::resetInProgress()
+{
+    fParseInProgress = false;
+}
+
 void SAX2XMLReaderImpl::resetCachedGrammarPool()
 {
     fGrammarResolver->resetCachedGrammar();
