@@ -1,232 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: SAXParser.cpp,v $
- * Revision 1.19  2003/05/18 14:02:05  knoaman
- * Memory manager implementation: pass per instance manager.
- *
- * Revision 1.18  2003/05/16 21:36:59  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.17  2003/05/15 18:26:50  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.16  2003/04/17 21:58:50  neilg
- * Adding a new property,
- * http://apache.org/xml/properties/security-manager, with
- * appropriate getSecurityManager/setSecurityManager methods on DOM
- * and SAX parsers.  Also adding a new SecurityManager class.
- *
- * The purpose of these modifications is to permit applications a
- * means to have the parser reject documents whose processing would
- * otherwise consume large amounts of system resources.  Malicious
- * use of such documents could be used to launch a denial-of-service
- * attack against a system running the parser.  Initially, the
- * SecurityManager only knows about attacks that can result from
- * exponential entity expansion; this is the only known attack that
- * involves processing a single XML document.  Other, simlar attacks
- * can be launched if arbitrary schemas may be parsed; there already
- * exist means (via use of the EntityResolver interface) by which
- * applications can deny processing of untrusted schemas.  In future,
- * the SecurityManager will be expanded to take these other exploits
- * into account.
- *
- * add security manager
- * 
- * Revision 1.15  2003/02/04 19:27:43  knoaman
- * Performance: use global buffer to eliminate repetitive memory creation/deletion.
- *
- * Revision 1.14  2003/01/09 19:07:08  tng
- * [Bug 15802] Add "const" qualifier to getURIText.
- *
- * Revision 1.13  2003/01/03 20:09:36  tng
- * New feature StandardUriConformant to force strict standard uri conformance.
- *
- * Revision 1.12  2002/12/27 16:16:51  knoaman
- * Set scanner options and handlers.
- *
- * Revision 1.11  2002/12/23 15:23:18  knoaman
- * Added a public api to various parsers to return the src offset within the input
- * source.
- *
- * Revision 1.10  2002/12/04 01:57:09  knoaman
- * Scanner re-organization.
- *
- * Revision 1.9  2002/11/04 14:57:03  tng
- * C++ Namespace Support.
- *
- * Revision 1.8  2002/08/14 15:20:38  knoaman
- * [Bug 3111] Problem with LexicalHandler::startDTD() and LexicalHandler::endDTD().
- *
- * Revision 1.7  2002/07/11 18:27:04  knoaman
- * Grammar caching/preparsing - initial implementation.
- *
- * Revision 1.6  2002/05/30 16:20:09  tng
- * Add feature to optionally ignore external DTD.
- *
- * Revision 1.5  2002/05/29 21:37:47  knoaman
- * Add baseURI to resolveEntity to support DOMInputSource.
- *
- * Revision 1.4  2002/05/28 20:44:14  tng
- * [Bug 9104] prefixes dissapearing when schema validation turned on.
- *
- * Revision 1.3  2002/05/27 18:39:21  tng
- * To get ready for 64 bit large file, use XMLSSize_t to represent line and column number.
- *
- * Revision 1.2  2002/05/22 20:53:41  knoaman
- * Prepare for DOM L3 :
- * - Make use of the XMLEntityHandler/XMLErrorReporter interfaces, instead of using
- * EntityHandler/ErrorHandler directly.
- * - Add 'AbstractDOMParser' class to provide common functionality for XercesDOMParser
- * and DOMBuilder.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:07  peiyongz
- * sane_include
- *
- * Revision 1.23  2001/11/20 18:51:44  tng
- * Schema: schemaLocation and noNamespaceSchemaLocation to be specified outside the instance document.  New methods setExternalSchemaLocation and setExternalNoNamespaceSchemaLocation are added (for SAX2, two new properties are added).
- *
- * Revision 1.22  2001/10/25 19:46:15  tng
- * Comment outside root element should also be reported.
- *
- * Revision 1.21  2001/08/01 19:11:02  tng
- * Add full schema constraint checking flag to the samples and the parser.
- *
- * Revision 1.20  2001/06/03 19:26:20  jberry
- * Add support for querying error count following parse; enables simple parse without requiring error handler.
- *
- * Revision 1.19  2001/05/11 13:26:22  tng
- * Copyright update.
- *
- * Revision 1.18  2001/05/03 19:09:23  knoaman
- * Support Warning/Error/FatalError messaging.
- * Validity constraints errors are treated as errors, with the ability by user to set
- * validity constraints as fatal errors.
- *
- * Revision 1.17  2001/03/30 16:46:57  tng
- * Schema: Use setDoSchema instead of setSchemaValidation which makes more sense.
- *
- * Revision 1.16  2001/03/21 21:56:08  tng
- * Schema: Add Schema Grammar, Schema Validator, and split the DTDValidator into DTDValidator, DTDScanner, and DTDGrammar.
- *
- * Revision 1.15  2001/02/15 15:56:29  tng
- * Schema: Add setSchemaValidation and getSchemaValidation for DOMParser and SAXParser.
- * Add feature "http://apache.org/xml/features/validation/schema" for SAX2XMLReader.
- * New data field  fSchemaValidation in XMLScanner as the flag.
- *
- * Revision 1.14  2000/09/05 23:38:26  andyh
- * Added advanced callback support for XMLDecl()
- *
- * Revision 1.13  2000/06/19 18:12:56  rahulj
- * Suppress the comments, characters, ignoreableWhitespaces before
- * root element. Only allow the PI's to get through. Still need to come
- * to a consensus on this.
- *
- * Revision 1.12  2000/06/17 02:00:55  rahulj
- * Also pass any PI's, comment's, character's occuring before root
- * element to the registered document Handler. Defect identified
- * by John Smirl and Rich Taylor.
- *
- * Revision 1.11  2000/05/15 22:31:18  andyh
- * Replace #include<memory.h> with <string.h> everywhere.
- *
- * Revision 1.10  2000/04/12 22:58:30  roddey
- * Added support for 'auto validate' mode.
- *
- * Revision 1.9  2000/04/11 19:17:58  roddey
- * If a SAX error handler is installed, then the resetErrors() event handler
- * should call the one on the installed SAX error handler.
- *
- * Revision 1.8  2000/04/05 18:56:17  roddey
- * Init the fDTDHandler member. Enable installation of DTDHandler
- * on SAX parser.
- *
- * Revision 1.7  2000/03/03 01:29:34  roddey
- * Added a scanReset()/parseReset() method to the scanner and
- * parsers, to allow for reset after early exit from a progressive parse.
- * Added calls to new Terminate() call to all of the samples. Improved
- * documentation in SAX and DOM parsers.
- *
- * Revision 1.6  2000/03/02 19:54:33  roddey
- * This checkin includes many changes done while waiting for the
- * 1.1.0 code to be finished. I can't list them all here, but a list is
- * available elsewhere.
- *
- * Revision 1.5  2000/02/17 03:54:26  rahulj
- * Added some new getters to query the parser state and
- * clarified the documentation.
- *
- * Revision 1.4  2000/02/06 07:47:56  rahulj
- * Year 2K copyright swat.
- *
- * Revision 1.3  2000/01/12 00:15:22  roddey
- * Changes to deal with multiply nested, relative pathed, entities and to deal
- * with the new URL class changes.
- *
- * Revision 1.2  1999/12/15 19:57:48  roddey
- * Got rid of redundant 'const' on boolean return value. Some compilers choke
- * on this and its useless.
- *
- * Revision 1.1.1.1  1999/11/09 01:07:50  twl
- * Initial checkin
- *
- * Revision 1.6  1999/11/08 20:44:53  rahul
- * Swat for adding in Product name and CVS comment log variable.
- *
+ * $Id: SAXParser.cpp 191671 2005-06-21 15:48:06Z cargilld $
  */
 
 
@@ -243,6 +32,11 @@
 #include <xercesc/sax/EntityResolver.hpp>
 #include <xercesc/sax/SAXParseException.hpp>
 #include <xercesc/validators/common/GrammarResolver.hpp>
+#include <xercesc/framework/XMLGrammarPool.hpp>
+#include <xercesc/framework/XMLSchemaDescription.hpp>
+#include <xercesc/util/Janitor.hpp>
+#include <xercesc/util/OutOfMemoryException.hpp>
+#include <xercesc/util/XMLEntityResolver.hpp>
 #include <string.h>
 
 XERCES_CPP_NAMESPACE_BEGIN
@@ -251,8 +45,15 @@ XERCES_CPP_NAMESPACE_BEGIN
 // ---------------------------------------------------------------------------
 //  SAXParser: Constructors and Destructor
 // ---------------------------------------------------------------------------
-SAXParser::SAXParser( XMLValidator* const  valToAdopt
-                    , MemoryManager* const manager) :
+
+
+typedef JanitorMemFunCall<SAXParser>    CleanupType;
+typedef JanitorMemFunCall<SAXParser>    ResetInProgressType;
+
+
+SAXParser::SAXParser( XMLValidator* const   valToAdopt
+                    , MemoryManager* const  manager
+                    , XMLGrammarPool* const gramPool):
 
     fParseInProgress(false)
     , fElemDepth(0)
@@ -261,24 +62,34 @@ SAXParser::SAXParser( XMLValidator* const  valToAdopt
     , fDocHandler(0)
     , fDTDHandler(0)
     , fEntityResolver(0)
+    , fXMLEntityResolver(0)
     , fErrorHandler(0)
+    , fPSVIHandler(0)
     , fAdvDHList(0)
     , fScanner(0)
     , fGrammarResolver(0)
     , fURIStringPool(0)
     , fValidator(valToAdopt)
     , fMemoryManager(manager)
+    , fGrammarPool(gramPool)
     , fElemQNameBuf(1023, manager)
 {
+    CleanupType cleanup(this, &SAXParser::cleanUp);
+
     try
     {
         initialize();
     }
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        cleanUp();
+        // Don't cleanup when out of memory, since executing the
+        // code can cause problems.
+        cleanup.release();
+
         throw;
     }
+
+    cleanup.release();
 }
 
 
@@ -293,12 +104,11 @@ SAXParser::~SAXParser()
 void SAXParser::initialize()
 {
     // Create grammar resolver and string pool to pass to scanner
-    fGrammarResolver = new (fMemoryManager) GrammarResolver(fMemoryManager);
-    fURIStringPool = new (fMemoryManager) XMLStringPool(109, fMemoryManager);
+    fGrammarResolver = new (fMemoryManager) GrammarResolver(fGrammarPool, fMemoryManager);
+    fURIStringPool = fGrammarResolver->getStringPool();
 
     // Create our scanner and tell it what validator to use
-    fScanner = XMLScannerResolver::getDefaultScanner(fValidator,fMemoryManager);
-    fScanner->setGrammarResolver(fGrammarResolver);
+    fScanner = XMLScannerResolver::getDefaultScanner(fValidator, fGrammarResolver, fMemoryManager);
     fScanner->setURIStringPool(fURIStringPool);
 
     // Create the initial advanced handler list array and zero it out
@@ -314,7 +124,8 @@ void SAXParser::cleanUp()
     fMemoryManager->deallocate(fAdvDHList);//delete [] fAdvDHList;
     delete fScanner;
     delete fGrammarResolver;
-    delete fURIStringPool;
+    // grammar pool must do this
+    //delete fURIStringPool;
 
     if (fValidator)
         delete fValidator;
@@ -427,6 +238,15 @@ bool SAXParser::getDoNamespaces() const
     return fScanner->getDoNamespaces();
 }
 
+bool SAXParser::getGenerateSyntheticAnnotations() const
+{
+    return fScanner->getGenerateSyntheticAnnotations();
+}
+
+bool SAXParser::getValidateAnnotations() const
+{
+    return fScanner->getValidateAnnotations();
+}
 
 bool SAXParser::getExitOnFirstFatalError() const
 {
@@ -461,6 +281,11 @@ bool SAXParser::getValidationSchemaFullChecking() const
     return fScanner->getValidationSchemaFullChecking();
 }
 
+bool SAXParser::getIdentityConstraintChecking() const
+{
+    return fScanner->getIdentityConstraintChecking();
+}
+
 int SAXParser::getErrorCount() const
 {
     return fScanner->getErrorCount();
@@ -526,6 +351,26 @@ unsigned int SAXParser::getSrcOffset() const
     return fScanner->getSrcOffset();
 }
 
+bool SAXParser::getIgnoreCachedDTD() const
+{
+    return fScanner->getIgnoreCachedDTD();
+}
+
+bool SAXParser::getIgnoreAnnotations() const
+{
+    return fScanner->getIgnoreAnnotations();
+}
+
+bool SAXParser::getDisableDefaultEntityResolution() const
+{
+    return fScanner->getDisableDefaultEntityResolution();
+}
+
+bool SAXParser::getSkipDTDValidation() const
+{
+    return fScanner->getSkipDTDValidation();
+}
+
 // ---------------------------------------------------------------------------
 //  SAXParser: Setter methods
 // ---------------------------------------------------------------------------
@@ -534,6 +379,15 @@ void SAXParser::setDoNamespaces(const bool newState)
     fScanner->setDoNamespaces(newState);
 }
 
+void SAXParser::setGenerateSyntheticAnnotations(const bool newState)
+{
+    fScanner->setGenerateSyntheticAnnotations(newState);
+}
+
+void SAXParser::setValidateAnnotations(const bool newState)
+{
+    fScanner->setValidateAnnotations(newState);
+}
 
 void SAXParser::setExitOnFirstFatalError(const bool newState)
 {
@@ -567,6 +421,11 @@ void SAXParser::setValidationSchemaFullChecking(const bool schemaFullChecking)
     fScanner->setValidationSchemaFullChecking(schemaFullChecking);
 }
 
+void SAXParser::setIdentityConstraintChecking(const bool identityConstraintChecking)
+{
+    fScanner->setIdentityConstraintChecking(identityConstraintChecking);
+}
+
 void SAXParser::setExternalSchemaLocation(const XMLCh* const schemaLocation)
 {
     fScanner->setExternalSchemaLocation(schemaLocation);
@@ -590,7 +449,7 @@ void SAXParser::setSecurityManager(SecurityManager* const securityManager)
     // since this could impact various components, don't permit it to change
     // during a parse
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     fScanner->setSecurityManager(securityManager);
 }
@@ -630,19 +489,43 @@ void SAXParser::useScanner(const XMLCh* const scannerName)
     (
         scannerName
         , fValidator
+        , fGrammarResolver
         , fMemoryManager
     );
 
     if (tempScanner) {
 
         tempScanner->setParseSettings(fScanner);
-        tempScanner->setGrammarResolver(fGrammarResolver);
         tempScanner->setURIStringPool(fURIStringPool);
         delete fScanner;
         fScanner = tempScanner;
     }
 }
 
+void SAXParser::setInputBufferSize(const size_t bufferSize)
+{
+    fScanner->setInputBufferSize(bufferSize);
+}
+
+void SAXParser::setIgnoreCachedDTD(const bool newValue)
+{
+    fScanner->setIgnoredCachedDTD(newValue);
+}
+
+void SAXParser::setIgnoreAnnotations(const bool newValue)
+{
+    fScanner->setIgnoreAnnotations(newValue);
+}
+
+void SAXParser::setDisableDefaultEntityResolution(const bool newValue)
+{
+    fScanner->setDisableDefaultEntityResolution(newValue);
+}
+
+void SAXParser::setSkipDTDValidation(const bool newValue)
+{
+    fScanner->setSkipDTDValidation(newValue);
+}
 
 // ---------------------------------------------------------------------------
 //  SAXParser: Overrides of the SAX Parser interface
@@ -651,18 +534,19 @@ void SAXParser::parse(const InputSource& source)
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
+
+    ResetInProgressType     resetInProgress(this, &SAXParser::resetInProgress);
 
     try
     {
         fParseInProgress = true;
         fScanner->scanDocument(source);
-        fParseInProgress = false;
     }
-
-    catch (...)
+    catch(const OutOfMemoryException&)
     {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 }
@@ -671,18 +555,19 @@ void SAXParser::parse(const XMLCh* const systemId)
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
+
+    ResetInProgressType     resetInProgress(this, &SAXParser::resetInProgress);
 
     try
     {
         fParseInProgress = true;
         fScanner->scanDocument(systemId);
-        fParseInProgress = false;
     }
-
-    catch (...)
+    catch(const OutOfMemoryException&)
     {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 }
@@ -691,18 +576,19 @@ void SAXParser::parse(const char* const systemId)
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
+
+    ResetInProgressType     resetInProgress(this, &SAXParser::resetInProgress);
 
     try
     {
         fParseInProgress = true;
         fScanner->scanDocument(systemId);
-        fParseInProgress = false;
     }
-
-    catch (...)
+    catch(const OutOfMemoryException&)
     {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 }
@@ -759,18 +645,40 @@ void SAXParser::setErrorHandler(ErrorHandler* const handler)
 }
 
 
+void SAXParser::setPSVIHandler(PSVIHandler* const handler)
+{
+    fPSVIHandler = handler;
+    if (fPSVIHandler) {
+        fScanner->setPSVIHandler(fPSVIHandler);      
+    }
+    else {
+        fScanner->setPSVIHandler(0);       
+    }
+}
+
 void SAXParser::setEntityResolver(EntityResolver* const resolver)
 {
     fEntityResolver = resolver;
     if (fEntityResolver) {
         fScanner->setEntityHandler(this);
+        fXMLEntityResolver = 0;
     }
     else {
         fScanner->setEntityHandler(0);
     }
 }
 
-
+void SAXParser::setXMLEntityResolver(XMLEntityResolver* const resolver)
+{
+    fXMLEntityResolver = resolver;
+    if (fXMLEntityResolver) {
+        fScanner->setEntityHandler(this);
+        fEntityResolver = 0;
+    }
+    else {
+        fScanner->setEntityHandler(0);
+    }
+}
 
 // ---------------------------------------------------------------------------
 //  SAXParser: Progressive parse methods
@@ -783,7 +691,7 @@ bool SAXParser::parseFirst( const   XMLCh* const    systemId
     //  is in progress.
     //
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     return fScanner->scanFirst(systemId, toFill);
 }
@@ -796,7 +704,7 @@ bool SAXParser::parseFirst( const   char* const     systemId
     //  is in progress.
     //
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     return fScanner->scanFirst(systemId, toFill);
 }
@@ -809,7 +717,7 @@ bool SAXParser::parseFirst( const   InputSource&    source
     //  is in progress.
     //
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
     return fScanner->scanFirst(source, toFill);
 }
@@ -834,12 +742,12 @@ void SAXParser::docCharacters(  const   XMLCh* const    chars
                                 , const bool            cdataSection)
 {
     // Suppress the chars before the root element.
-    if (!fElemDepth)
-        return;
-
-    // Just map to the SAX document handler
-    if (fDocHandler)
-        fDocHandler->characters(chars, length);
+    if (fElemDepth)
+    {
+        // Just map to the SAX document handler
+        if (fDocHandler)
+            fDocHandler->characters(chars, length);
+    }
 
     //
     //  If there are any installed advanced handlers, then lets call them
@@ -1100,9 +1008,9 @@ void SAXParser::startEntityReference(const XMLEntityDecl& entityDecl)
 // ---------------------------------------------------------------------------
 //  SAXParser: Overrides of the DocTypeHandler interface
 // ---------------------------------------------------------------------------
-void SAXParser::attDef( const   DTDElementDecl& elemDecl
-                        , const DTDAttDef&      attDef
-                        , const bool            ignoring)
+void SAXParser::attDef( const   DTDElementDecl&
+                        , const DTDAttDef&
+                        , const bool)
 {
     // Unused by SAX DTDHandler interface at this time
 }
@@ -1114,11 +1022,11 @@ void SAXParser::doctypeComment(const XMLCh* const)
 }
 
 
-void SAXParser::doctypeDecl(const   DTDElementDecl& elemDecl
-                            , const XMLCh* const    publicId
-                            , const XMLCh* const    systemId
-                            , const bool            hasIntSubset
-                            , const bool            hasExtSubset)
+void SAXParser::doctypeDecl(const   DTDElementDecl&
+                            , const XMLCh* const
+                            , const XMLCh* const
+                            , const bool
+                            , const bool)
 {
     // Unused by SAX DTDHandler interface at this time
 }
@@ -1131,8 +1039,8 @@ void SAXParser::doctypePI(  const   XMLCh* const
 }
 
 
-void SAXParser::doctypeWhitespace(  const   XMLCh* const    chars
-                                    , const unsigned int    length)
+void SAXParser::doctypeWhitespace(  const   XMLCh* const
+                                    , const unsigned int)
 {
     // Unused by SAX DTDHandler interface at this time
 }
@@ -1163,7 +1071,7 @@ void SAXParser::endExtSubset()
 
 
 void SAXParser::entityDecl( const   DTDEntityDecl&  entityDecl
-                            , const bool            isPEDecl
+                            , const bool
                             , const bool            isIgnored)
 {
     //
@@ -1244,8 +1152,8 @@ void SAXParser::resetErrors()
 }
 
 
-void SAXParser::error(  const   unsigned int                code
-                        , const XMLCh* const                msgDomain
+void SAXParser::error(  const   unsigned int
+                        , const XMLCh* const
                         , const XMLErrorReporter::ErrTypes  errType
                         , const XMLCh* const                errorText
                         , const XMLCh* const                systemId
@@ -1260,6 +1168,7 @@ void SAXParser::error(  const   unsigned int                code
         , systemId
         , lineNum
         , colNum
+        , fMemoryManager
     );
 
     if (!fErrorHandler)
@@ -1302,7 +1211,7 @@ void SAXParser::resetEntities()
 InputSource*
 SAXParser::resolveEntity(   const   XMLCh* const    publicId
                             , const XMLCh* const    systemId
-                            , const XMLCh* const    baseURI)
+                            , const XMLCh* const)
 {
     // Just map to the SAX entity resolver handler
     if (fEntityResolver)
@@ -1311,6 +1220,19 @@ SAXParser::resolveEntity(   const   XMLCh* const    publicId
 }
 
 
+InputSource*
+SAXParser::resolveEntity(  XMLResourceIdentifier* resourceIdentifier )
+{
+    // Just map to the SAX entity resolver handler
+    if (fEntityResolver)
+        return fEntityResolver->resolveEntity(resourceIdentifier->getPublicId(), 
+                                                resourceIdentifier->getSystemId());
+    if (fXMLEntityResolver)
+        return fXMLEntityResolver->resolveEntity(resourceIdentifier);
+    return 0;
+}
+
+
 void SAXParser::startInputSource(const InputSource&)
 {
     // Nothing to do for this one
@@ -1353,19 +1275,20 @@ Grammar* SAXParser::loadGrammar(const char* const systemId,
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
+
+    ResetInProgressType     resetInProgress(this, &SAXParser::resetInProgress);
 
     Grammar* grammar = 0;
     try
     {
         fParseInProgress = true;
         grammar = fScanner->loadGrammar(systemId, grammarType, toCache);
-        fParseInProgress = false;
     }
-
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 
@@ -1378,19 +1301,20 @@ Grammar* SAXParser::loadGrammar(const XMLCh* const systemId,
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
+
+    ResetInProgressType     resetInProgress(this, &SAXParser::resetInProgress);
 
     Grammar* grammar = 0;
     try
     {
         fParseInProgress = true;
         grammar = fScanner->loadGrammar(systemId, grammarType, toCache);
-        fParseInProgress = false;
     }
-
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 
@@ -1403,25 +1327,31 @@ Grammar* SAXParser::loadGrammar(const InputSource& source,
 {
     // Avoid multiple entrance
     if (fParseInProgress)
-        ThrowXML(IOException, XMLExcepts::Gen_ParseInProgress);
+        ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
+
+    ResetInProgressType     resetInProgress(this, &SAXParser::resetInProgress);
 
     Grammar* grammar = 0;
     try
     {
         fParseInProgress = true;
         grammar = fScanner->loadGrammar(source, grammarType, toCache);
-        fParseInProgress = false;
     }
-
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        fParseInProgress = false;
+        resetInProgress.release();
+
         throw;
     }
 
     return grammar;
 }
 
+void SAXParser::resetInProgress()
+{
+    fParseInProgress = false;
+}
+
 void SAXParser::resetCachedGrammarPool()
 {
     fGrammarResolver->resetCachedGrammar();
