@@ -15,214 +15,7 @@
  */
 
 /*
- * $Log: SAXParser.hpp,v $
- * Revision 1.36  2004/09/29 19:28:12  cargilld
- * Mark SAXParser as deprecated.
- *
- * Revision 1.35  2004/09/29 19:00:29  peiyongz
- * [jira1207] --patch from Dan Rosen
- *
- * Revision 1.34  2004/09/28 02:14:14  cargilld
- * Add support for validating annotations.
- *
- * Revision 1.33  2004/09/23 01:09:55  cargilld
- * Add support for generating synthetic XSAnnotations.  When a schema component has non-schema attributes and no child attributes create a synthetic XSAnnotation (under feature control) so the non-schema attributes can be recovered under PSVI.
- *
- * Revision 1.32  2004/09/08 13:56:18  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.31  2004/09/02 19:08:09  cargilld
- * Fix API Doc warning message
- *
- * Revision 1.30  2004/04/13 18:58:36  peiyongz
- * correct comment
- *
- * Revision 1.29  2004/04/13 16:53:26  peiyongz
- * get/setIdentityConstraintChecking
- *
- * Revision 1.28  2003/12/01 23:23:26  neilg
- * fix for bug 25118; thanks to Jeroen Witmond
- *
- * Revision 1.27  2003/11/06 15:30:07  neilg
- * first part of PSVI/schema component model implementation, thanks to David Cargill.  This covers setting the PSVIHandler on parser objects, as well as implementing XSNotation, XSSimpleTypeDefinition, XSIDCDefinition, and most of XSWildcard, XSComplexTypeDefinition, XSElementDeclaration, XSAttributeDeclaration and XSAttributeUse.
- *
- * Revision 1.26  2003/10/30 21:37:31  knoaman
- * Enhanced Entity Resolver Support. Thanks to David Cargill.
- *
- * Revision 1.25  2003/10/20 13:41:10  amassari
- * Added getGrammarResolver API
- *
- * Revision 1.24  2003/06/20 18:55:54  peiyongz
- * Stateless Grammar Pool :: Part I
- *
- * Revision 1.23  2003/05/15 18:26:50  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.22  2003/04/17 21:58:50  neilg
- * Adding a new property,
- * http://apache.org/xml/properties/security-manager, with
- * appropriate getSecurityManager/setSecurityManager methods on DOM
- * and SAX parsers.  Also adding a new SecurityManager class.
- *
- * The purpose of these modifications is to permit applications a
- * means to have the parser reject documents whose processing would
- * otherwise consume large amounts of system resources.  Malicious
- * use of such documents could be used to launch a denial-of-service
- * attack against a system running the parser.  Initially, the
- * SecurityManager only knows about attacks that can result from
- * exponential entity expansion; this is the only known attack that
- * involves processing a single XML document.  Other, simlar attacks
- * can be launched if arbitrary schemas may be parsed; there already
- * exist means (via use of the EntityResolver interface) by which
- * applications can deny processing of untrusted schemas.  In future,
- * the SecurityManager will be expanded to take these other exploits
- * into account.
- *
- * Add support for the SecurityManager
- * 
- * Revision 1.21  2003/03/07 18:09:17  tng
- * Return a reference instead of void for operator=
- *
- * Revision 1.20  2003/02/04 19:27:43  knoaman
- * Performance: use global buffer to eliminate repetitive memory creation/deletion.
- *
- * Revision 1.19  2003/01/09 19:07:08  tng
- * [Bug 15802] Add "const" qualifier to getURIText.
- *
- * Revision 1.18  2003/01/03 20:09:36  tng
- * New feature StandardUriConformant to force strict standard uri conformance.
- *
- * Revision 1.17  2002/12/30 20:15:51  knoaman
- * Make calculate src offset option false by default.
- *
- * Revision 1.16  2002/12/23 15:23:18  knoaman
- * Added a public api to various parsers to return the src offset within the input
- * source.
- *
- * Revision 1.15  2002/12/04 01:57:09  knoaman
- * Scanner re-organization.
- *
- * Revision 1.14  2002/11/04 14:57:03  tng
- * C++ Namespace Support.
- *
- * Revision 1.13  2002/08/14 15:20:38  knoaman
- * [Bug 3111] Problem with LexicalHandler::startDTD() and LexicalHandler::endDTD().
- *
- * Revision 1.12  2002/07/11 18:27:03  knoaman
- * Grammar caching/preparsing - initial implementation.
- *
- * Revision 1.11  2002/06/27 18:48:04  tng
- * API Documentation Update and move getScanner as protected
- *
- * Revision 1.10  2002/06/17 15:41:44  tng
- * Update API Documentation
- *
- * Revision 1.9  2002/06/06 20:38:18  tng
- * Document Fix: document that the returned object from resolveEntity is owned by the parser
- *
- * Revision 1.8  2002/05/31 15:13:53  tng
- * Fix doxygen documentation.
- *
- * Revision 1.7  2002/05/30 16:39:06  knoaman
- * DOM L3 LS.
- *
- * Revision 1.6  2002/05/30 16:20:09  tng
- * Add feature to optionally ignore external DTD.
- *
- * Revision 1.5  2002/05/29 21:37:47  knoaman
- * Add baseURI to resolveEntity to support DOMInputSource.
- *
- * Revision 1.4  2002/05/28 20:44:14  tng
- * [Bug 9104] prefixes dissapearing when schema validation turned on.
- *
- * Revision 1.3  2002/05/27 18:39:21  tng
- * To get ready for 64 bit large file, use XMLSSize_t to represent line and column number.
- *
- * Revision 1.2  2002/02/20 18:17:01  tng
- * [Bug 5977] Warnings on generating apiDocs.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:07  peiyongz
- * sane_include
- *
- * Revision 1.22  2001/12/05 22:09:02  tng
- * Update documentation for setExternalSchemaLocation and setExternalNoNamespaceSchemaLocation.
- *
- * Revision 1.21  2001/11/20 18:51:44  tng
- * Schema: schemaLocation and noNamespaceSchemaLocation to be specified outside the instance document.  New methods setExternalSchemaLocation and setExternalNoNamespaceSchemaLocation are added (for SAX2, two new properties are added).
- *
- * Revision 1.20  2001/08/01 19:11:02  tng
- * Add full schema constraint checking flag to the samples and the parser.
- *
- * Revision 1.19  2001/07/27 20:24:21  tng
- * put getScanner() back as they were there before, not to break existing apps.
- *
- * Revision 1.18  2001/07/16 12:52:09  tng
- * APIDocs fix: default for schema processing in DOMParser, IDOMParser, and SAXParser should be false.
- *
- * Revision 1.17  2001/06/23 14:13:16  tng
- * Remove getScanner from the Parser headers as this is not needed and Scanner is not internal class.
- *
- * Revision 1.16  2001/06/03 19:26:20  jberry
- * Add support for querying error count following parse; enables simple parse without requiring error handler.
- *
- * Revision 1.15  2001/05/11 13:26:22  tng
- * Copyright update.
- *
- * Revision 1.14  2001/05/03 19:09:25  knoaman
- * Support Warning/Error/FatalError messaging.
- * Validity constraints errors are treated as errors, with the ability by user to set
- * validity constraints as fatal errors.
- *
- * Revision 1.13  2001/03/30 16:46:57  tng
- * Schema: Use setDoSchema instead of setSchemaValidation which makes more sense.
- *
- * Revision 1.12  2001/03/21 21:56:09  tng
- * Schema: Add Schema Grammar, Schema Validator, and split the DTDValidator into DTDValidator, DTDScanner, and DTDGrammar.
- *
- * Revision 1.11  2001/02/15 15:56:29  tng
- * Schema: Add setSchemaValidation and getSchemaValidation for DOMParser and SAXParser.
- * Add feature "http://apache.org/xml/features/validation/schema" for SAX2XMLReader.
- * New data field  fSchemaValidation in XMLScanner as the flag.
- *
- * Revision 1.10  2001/01/12 21:23:41  tng
- * Documentation Enhancement: explain values of Val_Scheme
- *
- * Revision 1.9  2000/08/02 18:05:15  jpolast
- * changes required for sax2
- * (changed private members to protected)
- *
- * Revision 1.8  2000/04/12 22:58:30  roddey
- * Added support for 'auto validate' mode.
- *
- * Revision 1.7  2000/03/03 01:29:34  roddey
- * Added a scanReset()/parseReset() method to the scanner and
- * parsers, to allow for reset after early exit from a progressive parse.
- * Added calls to new Terminate() call to all of the samples. Improved
- * documentation in SAX and DOM parsers.
- *
- * Revision 1.6  2000/02/17 03:54:27  rahulj
- * Added some new getters to query the parser state and
- * clarified the documentation.
- *
- * Revision 1.5  2000/02/16 03:42:58  rahulj
- * Finished documenting the SAX Driver implementation.
- *
- * Revision 1.4  2000/02/15 04:47:37  rahulj
- * Documenting the SAXParser framework. Not done yet.
- *
- * Revision 1.3  2000/02/06 07:47:56  rahulj
- * Year 2K copyright swat.
- *
- * Revision 1.2  1999/12/15 19:57:48  roddey
- * Got rid of redundant 'const' on boolean return value. Some compilers choke
- * on this and its useless.
- *
- * Revision 1.1.1.1  1999/11/09 01:07:51  twl
- * Initial checkin
- *
- * Revision 1.6  1999/11/08 20:44:54  rahul
- * Swat for adding in Product name and CVS comment log variable.
- *
+ * $Id: SAXParser.hpp 191671 2005-06-21 15:48:06Z cargilld $
  */
 
 #if !defined(SAXPARSER_HPP)
@@ -653,6 +446,7 @@ public :
 
     /**
      * Returns the current src offset within the input source.
+     * To be used only while parsing is in progress.
      *
      * @return offset within the input source
      */
@@ -680,6 +474,42 @@ public :
       */
     bool getValidateAnnotations() const;
 
+    /** Get the 'ignore cached DTD grammar' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         ignore cached DTD, false otherwise.
+      *
+      * @see #setIgnoreCachedDTD
+      */
+    bool getIgnoreCachedDTD() const;
+
+    /** Get the 'ignore annotations' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         ignore annotations, false otherwise.
+      *
+      * @see #setIgnoreAnnotations
+      */
+    bool getIgnoreAnnotations() const;
+
+    /** Get the 'disable default entity resolution' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         not perform default entity resolution, false otherwise.
+      *
+      * @see #setDisableDefaultEntityResolution
+      */
+    bool getDisableDefaultEntityResolution() const;
+
+    /** Get the 'skip DTD validation' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         skip DTD validation, false otherwise.
+      *
+      * @see #setSkipDTDValidation
+      */
+    bool getSkipDTDValidation() const;
+
     //@}
 
 
@@ -948,7 +778,7 @@ public :
       * instead of building the grammar from scratch, to validate XML
       * documents.
       *
-      * If the 'Grammar caching' flag is set to true, this mehod ignore the
+      * If the 'Grammar caching' flag is set to true, this method ignores the
       * value passed in.
       *
       * The parser's default state is: false.
@@ -1008,6 +838,62 @@ public :
       */
     void setInputBufferSize(const size_t bufferSize);
 
+    /** Set the 'ignore cached DTD grammar' flag
+      *
+      * This method gives users the option to ignore a cached DTD grammar, when
+      * an XML document contains both an internal and external DTD, and the use
+      * cached grammar from parse option is enabled. Currently, we do not allow
+      * using cached DTD grammar when an internal subset is present in the
+      * document. This option will only affect the behavior of the parser when
+      * an internal and external DTD both exist in a document (i.e. no effect
+      * if document has no internal subset).
+      *
+      * The parser's default state is false
+      *
+      * @param newValue The state to set
+      */
+    void setIgnoreCachedDTD(const bool newValue);
+
+    /** Set the 'ignore annotation' flag
+      *
+      * This method gives users the option to not generate XSAnnotations
+      * when "traversing" a schema.
+      *
+      * The parser's default state is false
+      *
+      * @param newValue The state to set
+      */
+    void setIgnoreAnnotations(const bool newValue);
+
+    /** Set the 'disable default entity resolution' flag
+      *
+      * This method gives users the option to not perform default entity
+      * resolution.  If the user's resolveEntity method returns NULL the
+      * parser will try to resolve the entity on its own.  When this option
+      * is set to true, the parser will not attempt to resolve the entity
+      * when the resolveEntity method returns NULL.
+      *    
+      * The parser's default state is false
+      *
+      * @param newValue The state to set
+      *
+      * @see #entityResolver
+      */
+    void setDisableDefaultEntityResolution(const bool newValue);
+
+    /** Set the 'skip DTD validation' flag
+      *
+      * This method gives users the option to skip DTD validation only when 
+      * schema validation is on (i.e. when performing validation,  we will
+      * ignore the DTD, except for entities, when schema validation is enabled).
+      *
+      * NOTE: This option is ignored if schema validation is disabled.
+      *
+      * The parser's default state is false
+      *
+      * @param newValue The state to set
+      */
+    void setSkipDTDValidation(const bool newValue);
     //@}
 
 
@@ -2148,6 +2034,7 @@ private:
     // -----------------------------------------------------------------------
     void initialize();
     void cleanUp();
+    void resetInProgress();
 
     // -----------------------------------------------------------------------
     //  Private data members
