@@ -1,57 +1,17 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /**
@@ -59,7 +19,7 @@
 *  handler with the scanner. In these handler methods, appropriate DOM nodes
 *  are created and added to the DOM tree.
 *
-* $Id: XercesDOMParser.cpp,v 1.21 2004/01/29 11:46:32 cargilld Exp $
+* $Id: XercesDOMParser.cpp 191708 2005-06-21 19:02:15Z cargilld $
 *
 */
 
@@ -138,6 +98,11 @@ unsigned int XercesDOMParser::getSrcOffset() const
     return getScanner()->getSrcOffset();
 }
 
+bool XercesDOMParser::getIgnoreCachedDTD() const
+{
+    return getScanner()->getIgnoreCachedDTD();
+}
+
 // ---------------------------------------------------------------------------
 //  XercesDOMParser: Setter methods
 // ---------------------------------------------------------------------------
@@ -193,6 +158,10 @@ void XercesDOMParser::useCachedGrammarInParse(const bool newState)
         getScanner()->useCachedGrammarInParse(newState);
 }
 
+void XercesDOMParser::setIgnoreCachedDTD(const bool newValue)
+{
+    getScanner()->setIgnoredCachedDTD(newValue);
+}
 
 // ---------------------------------------------------------------------------
 //  XercesDOMParser: Utilities
@@ -282,6 +251,8 @@ XercesDOMParser::resolveEntity(XMLResourceIdentifier* resourceIdentifier)
     return 0;
 }
 
+typedef JanitorMemFunCall<XercesDOMParser>  ResetParseType;
+
 // ---------------------------------------------------------------------------
 //  XercesDOMParser: Grammar preparsing methods
 // ---------------------------------------------------------------------------
@@ -293,26 +264,21 @@ Grammar* XercesDOMParser::loadGrammar(const char* const systemId,
     if (getParseInProgress())
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
+    ResetParseType  resetParse(this, &XercesDOMParser::resetParse);
+
     Grammar* grammar = 0;
+
     try
     {
         setParseInProgress(true);
         if (grammarType == Grammar::DTDGrammarType) 
             getScanner()->setDocTypeHandler(0);
         grammar = getScanner()->loadGrammar(systemId, grammarType, toCache);
-        if (grammarType == Grammar::DTDGrammarType) 
-            getScanner()->setDocTypeHandler(this);
-        setParseInProgress(false);
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch(...)
-    {
-        if (grammarType == Grammar::DTDGrammarType) 
-            getScanner()->setDocTypeHandler(this);        
-        setParseInProgress(false);
+        resetParse.release();
+
         throw;
     }
 
@@ -327,26 +293,21 @@ Grammar* XercesDOMParser::loadGrammar(const XMLCh* const systemId,
     if (getParseInProgress())
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
+    ResetParseType  resetParse(this, &XercesDOMParser::resetParse);
+
     Grammar* grammar = 0;
+
     try
     {
         setParseInProgress(true);
         if (grammarType == Grammar::DTDGrammarType) 
             getScanner()->setDocTypeHandler(0);
         grammar = getScanner()->loadGrammar(systemId, grammarType, toCache);
-        if (grammarType == Grammar::DTDGrammarType) 
-            getScanner()->setDocTypeHandler(this);
-        setParseInProgress(false);
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch(...)
-    {
-        if (grammarType == Grammar::DTDGrammarType) 
-            getScanner()->setDocTypeHandler(this);        
-        setParseInProgress(false);
+        resetParse.release();
+
         throw;
     }
 
@@ -361,7 +322,10 @@ Grammar* XercesDOMParser::loadGrammar(const InputSource& source,
     if (getParseInProgress())
         ThrowXMLwithMemMgr(IOException, XMLExcepts::Gen_ParseInProgress, fMemoryManager);
 
-   Grammar* grammar = 0;
+    ResetParseType  resetParse(this, &XercesDOMParser::resetParse);
+
+    Grammar* grammar = 0;
+
     try
     {
         setParseInProgress(true);
@@ -374,19 +338,24 @@ Grammar* XercesDOMParser::loadGrammar(const InputSource& source,
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch(...)
-    {
-        if (grammarType == Grammar::DTDGrammarType) 
-            getScanner()->setDocTypeHandler(this);
-        setParseInProgress(false);
+        resetParse.release();
+
         throw;
     }
 
     return grammar;
 }
 
+void XercesDOMParser::resetParse()
+{
+    if (getScanner()->getDocTypeHandler() == 0)
+    {
+        getScanner()->setDocTypeHandler(this);
+    }
+
+    setParseInProgress(false);
+}
+
 void XercesDOMParser::resetCachedGrammarPool()
 {
     getGrammarResolver()->resetCachedGrammar();
