@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: XercesDOMParser.hpp,v 1.20 2004/09/08 13:56:18 peiyongz Exp $
+ * $Id: XercesDOMParser.hpp 191708 2005-06-21 19:02:15Z cargilld $
  *
  */
 
@@ -195,11 +195,21 @@ public :
 
     /**
      * Returns the current src offset within the input source.
+     * To be used only while parsing is in progress.
      *
      * @return offset within the input source
      */
     unsigned int getSrcOffset() const;
 
+    /** Get the 'ignore cached DTD grammar' flag
+      *    
+      * @return true, if the parser is currently configured to
+      *         ignore cached DTD, false otherwise.
+      *
+      * @see #setIgnoreCachedDTD
+      */
+    bool getIgnoreCachedDTD() const;
+
     //@}
 
 
@@ -301,6 +311,22 @@ public :
       */
     void useCachedGrammarInParse(const bool newState);
 
+    /** Set the 'ignore cached DTD grammar' flag
+      *
+      * This method gives users the option to ignore a cached DTD grammar, when
+      * an XML document contains both an internal and external DTD, and the use
+      * cached grammar from parse option is enabled. Currently, we do not allow
+      * using cached DTD grammar when an internal subset is present in the
+      * document. This option will only affect the behavior of the parser when
+      * an internal and external DTD both exist in a document (i.e. no effect
+      * if document has no internal subset).
+      *
+      * The parser's default state is false
+      *
+      * @param newValue The state to set
+      */
+    void setIgnoreCachedDTD(const bool newValue);
+
     //@}
 
     // -----------------------------------------------------------------------
@@ -613,6 +639,11 @@ public :
 
 
 private :
+    // -----------------------------------------------------------------------
+    //  Initialize/Cleanup methods
+    // -----------------------------------------------------------------------
+    void resetParse();
+
     // -----------------------------------------------------------------------
     //  Unimplemented constructors and operators
     // -----------------------------------------------------------------------
