@@ -15,59 +15,7 @@
  */
 
 /*
- * $Log: SAXException.hpp,v $
- * Revision 1.7  2004/09/08 13:56:19  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.6  2003/12/01 23:23:26  neilg
- * fix for bug 25118; thanks to Jeroen Witmond
- *
- * Revision 1.5  2003/08/13 15:43:24  knoaman
- * Use memory manager when creating SAX exceptions.
- *
- * Revision 1.4  2003/05/15 18:27:05  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.3  2002/12/06 13:17:29  tng
- * [Bug 9083] Make SAXNotSupportedException and SAXNotRecognizedException to be exportable
- *
- * Revision 1.2  2002/11/04 14:56:26  tng
- * C++ Namespace Support.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:08  peiyongz
- * sane_include
- *
- * Revision 1.8  2000/09/07 23:55:02  andyh
- * Fix SAXException assignment operator.  Now non-virtual, and
- * SAXParseException invokes base class operator.
- *
- * Revision 1.7  2000/08/09 22:06:04  jpolast
- * more functionality to SAXException and its children.
- * msgs are now functional for SAXNotSupportedEx and
- * SAXNotRecognizedEx
- *
- * Revision 1.6  2000/08/02 18:04:02  jpolast
- * include SAXNotSupportedException and
- * SAXNotRecognizedException needed for sax2
- *
- * Revision 1.5  2000/02/24 20:12:55  abagchi
- * Swat for removing Log from API docs
- *
- * Revision 1.4  2000/02/09 19:15:17  abagchi
- * Inserted documentation for new APIs
- *
- * Revision 1.3  2000/02/06 07:47:58  rahulj
- * Year 2K copyright swat.
- *
- * Revision 1.2  1999/12/18 00:21:23  roddey
- * Fixed a small reported memory leak
- *
- * Revision 1.1.1.1  1999/11/09 01:07:47  twl
- * Initial checkin
- *
- * Revision 1.2  1999/11/08 20:45:02  rahul
- * Swat for adding in Product name and CVS comment log variable.
- *
+ * $Id: SAXException.hpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -152,8 +100,8 @@ public:
     * @param toCopy The exception to be copy constructed
     */
     SAXException(const SAXException& toCopy) :
-
-        fMsg(XMLString::replicate(toCopy.fMsg, toCopy.fMemoryManager))
+        XMemory(toCopy)
+        , fMsg(XMLString::replicate(toCopy.fMsg, toCopy.fMemoryManager))
         , fMemoryManager(toCopy.fMemoryManager)
     {
     }
