@@ -15,93 +15,7 @@
  */
 
 /*
- * $Log: UnixHTTPURLInputStream.cpp,v $
- * Revision 1.18  2004/09/08 13:56:35  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.17  2004/05/11 13:39:35  amassari
- * The net accessor input source now can be used to get data using PUT or POST, as well as GET
- *
- * Revision 1.16  2004/02/11 12:42:22  cargilld
- * Fix for bug 25541.
- *
- * Revision 1.15  2004/01/29 11:51:20  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.14  2004/01/13 16:34:21  cargilld
- * Misc memory management changes.
- *
- * Revision 1.13  2003/12/24 15:24:13  cargilld
- * More updates to memory management so that the static memory manager.
- *
- * Revision 1.12  2003/05/17 05:54:18  knoaman
- * Update NetAccessors to use the memory manager.
- *
- * Revision 1.11  2003/05/16 14:03:28  knoaman
- * Pass memory manager to makeNewTranscoder.
- *
- * Revision 1.10  2003/02/25 21:22:36  tng
- * Modify UnixHTTPURLInputStream for it to work on ebcdic platform.  Patch from Steve Dulin
- *
- * Revision 1.9  2002/12/09 13:12:12  tng
- * Fix compilation error.
- *
- * Revision 1.8  2002/12/09 09:57:27  gareth
- * Fixed compile error by adding private member. Not very efficient. Should be looked at again.
- *
- * Revision 1.7  2002/12/06 16:43:33  tng
- * Fix the error messages thrown from net accessor module.
- *
- * Revision 1.6  2002/12/02 20:41:17  tng
- * [Bug 12490] Patches required to build Xerces-C++ on BeOS R5.  Patch from Andrew Bachmann.
- *
- * Revision 1.5  2002/11/04 15:11:38  tng
- * C++ Namespace Support.
- *
- * Revision 1.4  2002/05/29 14:30:50  peiyongz
- * Bug9489: Malformed HTTP GET Requests in UnixHTTPUrlInputStream ,
- *                 patch from Gereon Steffens (gereon.steffens@web.de)
- *
- * Revision 1.3  2002/05/07 14:36:44  tng
- * [Bug 8852] UnixHTTPURLInputStream.cpp includes unneeded file.
- *
- * Revision 1.2  2002/03/11 21:08:23  peiyongz
- * Bug#7000: fix to corrupted URL, patch from kent@iastate.edu (Kent)
- *
- * Revision 1.1.1.1  2002/02/01 22:22:23  peiyongz
- * sane_include
- *
- * Revision 1.7  2001/09/04 17:53:09  peiyongz
- * Bugzilla# 3170: patch from Kevin Philips to handle Query in XMLURL.
- *
- * Revision 1.6  2001/06/25 16:27:04  tng
- * AS400 changes by Linda Swan.
- *
- * Revision 1.5  2000/07/21 03:31:41  andyh
- * Improved (but still weak) http access by the parser.
- *
- * Revision 1.4  2000/05/15 22:31:28  andyh
- * Replace #include<memory.h> with <string.h> everywhere.
- *
- * Revision 1.3  2000/03/24 01:30:32  rahulj
- * Connect to the port specified in the URL, rather than the default
- * one.
- *
- * Revision 1.2  2000/03/22 00:58:11  rahulj
- * Now we throw exceptions when errors occur.
- * Simplified code based on assumption that calling
- * function will allocate enough storage to store the
- * incoming data.
- *
- * Revision 1.1  2000/03/20 23:48:51  rahulj
- * Added Socket based NetAccessor. This will enable one to
- * use HTTP URL's for system id's. Default build options do
- * not use this NetAccessor. Specify the '-n socket' option
- * to 'runConfigure' to configure Xerces-C to use this new
- * feature. The code works under Solaris 2.6, Linux, AIX
- * and HPUX 11 with aCC.
- * Todo's: enable proper error handling.
- *
+ * $Id: UnixHTTPURLInputStream.cpp 231011 2005-08-09 08:04:52Z amassari $
  */
 
 #include <stdio.h>
@@ -127,9 +41,42 @@
 #include <xercesc/util/TransService.hpp>
 #include <xercesc/util/TranscodingException.hpp>
 #include <xercesc/util/PlatformUtils.hpp>
+#include <xercesc/util/Base64.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
+class SocketJanitor
+{
+public:
+    // -----------------------------------------------------------------------
+    //  Constructors and Destructor
+    // -----------------------------------------------------------------------
+    SocketJanitor(int* toDelete) : fData(toDelete) {}
+    ~SocketJanitor() { reset(); }
+
+    int* get() const { return fData; }
+    int* release() { int* p = fData; fData = 0; return p; }
+
+    void reset(int* p = 0) { if(fData) close(*fData); fData=p; }
+    bool isDataNull() { return (fData == 0); }
+
+private :
+    // -----------------------------------------------------------------------
+    //  Unimplemented constructors and operators
+    // -----------------------------------------------------------------------
+    SocketJanitor();
+    SocketJanitor(const SocketJanitor&);
+    SocketJanitor& operator=(const SocketJanitor&);
+
+    // -----------------------------------------------------------------------
+    //  Private data members
+    //
+    //  fData
+    //      This is the pointer to the socket that must be closed when 
+    //      this object is destroyed.
+    // -----------------------------------------------------------------------
+    int*  fData;
+};
 
 UnixHTTPURLInputStream::UnixHTTPURLInputStream(const XMLURL& urlSource, const XMLNetHTTPInfo* httpInfo/*=0*/)
       : fSocket(0)
@@ -191,6 +138,12 @@ UnixHTTPURLInputStream::UnixHTTPURLInputStream(const XMLURL& urlSource, const XM
         chColon, chNull
     };
 
+    const char AUTHORIZATION[] =
+    {
+        chLatin_A, chLatin_u, chLatin_t, chLatin_h, chLatin_o, chLatin_r, chLatin_i, chLatin_z, chLatin_a, chLatin_t, 
+        chLatin_i, chLatin_o, chLatin_n, chColon, chSpace, chLatin_B, chLatin_a, chLatin_s, chLatin_i, chLatin_c, chSpace, chNull
+    };
+
     const char resp200 [] =
     {
         chSpace, chDigit_2, chDigit_0, chDigit_0, chSpace, chNull
@@ -243,7 +196,8 @@ UnixHTTPURLInputStream::UnixHTTPURLInputStream(const XMLURL& urlSource, const XM
         pathAsASCII = (char*) fMemoryManager->allocate
         (
             (transSize+1) * sizeof(char)
-        );//new char[transSize+1];        
+        );//new char[transSize+1];
+        janBuf3.reset(pathAsASCII, fMemoryManager);
         trans->transcodeTo(path, transSize, (unsigned char *) pathAsASCII, transSize, charsEaten, XMLTranscoder::UnRep_Throw);
     }
 
@@ -256,6 +210,7 @@ UnixHTTPURLInputStream::UnixHTTPURLInputStream(const XMLURL& urlSource, const XM
         (
             (transSize+1) * sizeof(char)
         );//new char[transSize+1];
+        janBuf4.reset(fragmentAsASCII, fMemoryManager);
         trans->transcodeTo(fragment, transSize, (unsigned char *) fragmentAsASCII, transSize, charsEaten, XMLTranscoder::UnRep_Throw);
     }
 
@@ -268,6 +223,7 @@ UnixHTTPURLInputStream::UnixHTTPURLInputStream(const XMLURL& urlSource, const XM
         (
             (transSize+1) * sizeof(char)
         );//new char[transSize+1];
+        janBuf5.reset(queryAsASCII, fMemoryManager);
         trans->transcodeTo(query, transSize, (unsigned char *) queryAsASCII, transSize, charsEaten, XMLTranscoder::UnRep_Throw);
     }
 
@@ -283,6 +239,7 @@ UnixHTTPURLInputStream::UnixHTTPURLInputStream(const XMLURL& urlSource, const XM
     (
         (transSize+1) * sizeof(char)
     );//new char[transSize+1];
+    ArrayJanitor<char>  janBuf6(portAsASCII, fMemoryManager);
     trans->transcodeTo(portBuffer, transSize, (unsigned char *) portAsASCII, transSize, charsEaten, XMLTranscoder::UnRep_Throw);
 
     delete trans;
@@ -323,6 +280,7 @@ UnixHTTPURLInputStream::UnixHTTPURLInputStream(const XMLURL& urlSource, const XM
         ThrowXMLwithMemMgr1(NetAccessorException,
                  XMLExcepts::NetAcc_CreateSocket, urlSource.getURLText(), fMemoryManager);
     }
+    SocketJanitor janSock(&s);
 
     if (connect(s, (struct sockaddr *) &sa, sizeof(sa)) < 0)
     {
@@ -371,6 +329,37 @@ UnixHTTPURLInputStream::UnixHTTPURLInputStream(const XMLURL& urlSource, const XM
     }
     strcat(fBuffer, CRLF);
 
+    const XMLCh* username = urlSource.getUser();
+    const XMLCh* password = urlSource.getPassword();
+    if (username && password)
+    {
+        XMLBuffer userPass(256, fMemoryManager);
+        userPass.append(username);
+        userPass.append(chColon);
+        userPass.append(password);
+        char* userPassAsCharStar = XMLString::transcode(userPass.getRawBuffer(), fMemoryManager);
+        ArrayJanitor<char>  janBuf(userPassAsCharStar, fMemoryManager);
+
+        unsigned int len;
+        XMLByte* encodedData = Base64::encode((XMLByte *)userPassAsCharStar, strlen(userPassAsCharStar), &len, fMemoryManager);
+        ArrayJanitor<XMLByte>  janBuf2(encodedData, fMemoryManager);
+
+        if (encodedData)
+        {
+            // HTTP doesn't want the 0x0A separating the data in chunks of 76 chars per line
+            XMLByte* authData = (XMLByte*)fMemoryManager->allocate((len+1)*sizeof(XMLByte));
+            ArrayJanitor<XMLByte>  janBuf(authData, fMemoryManager);
+            XMLByte* cursor=authData;
+            for(unsigned int i=0;i<len;i++)
+                if(encodedData[i]!=chLF)
+                    *cursor++=encodedData[i];
+            *cursor++=0;
+            strcat(fBuffer, AUTHORIZATION);
+            strcat(fBuffer, (char*)authData);
+            strcat(fBuffer, CRLF);
+        }
+    }
+
     if(httpInfo!=0 && httpInfo->fHeaders!=0)
         strncat(fBuffer,httpInfo->fHeaders,httpInfo->fHeadersLen);
 
@@ -451,7 +440,7 @@ UnixHTTPURLInputStream::UnixHTTPURLInputStream(const XMLURL& urlSource, const XM
         ThrowXMLwithMemMgr1(NetAccessorException, XMLExcepts::File_CouldNotOpenFile, urlSource.getURLText(), fMemoryManager);
     }
 
-    fSocket = s;
+    fSocket = *janSock.release();
 
 }
 
