@@ -15,88 +15,7 @@
  */
 
 /*
- * $Log: FreeBSDPlatformUtils.cpp,v $
- * Revision 1.23  2004/09/08 13:56:39  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.22  2004/01/29 11:51:20  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.21  2004/01/13 16:34:21  cargilld
- * Misc memory management changes.
- *
- * Revision 1.20  2004/01/06 17:31:20  neilg
- * fix static initialization problems, bug 28517; thanks to Reid Spencer
- *
- * Revision 1.19  2003/12/24 15:24:14  cargilld
- * More updates to memory management so that the static memory manager.
- *
- * Revision 1.18  2003/12/19 23:02:25  cargilld
- * More memory management updates.
- *
- * Revision 1.17  2003/12/17 15:16:10  cargilld
- * Platform update for memory management so that the static memory manager (one
- * used to call Initialize) is only for static data.
- *
- * Revision 1.16  2003/12/17 13:58:02  cargilld
- * Platform update for memory management so that the static memory manager (one
- * used to call Initialize) is only for static data.
- *
- * Revision 1.15  2003/12/02 15:04:52  amassari
- * openFile was opening the file for read and write, while only read was required (bug#20169)
- *
- * Revision 1.14  2003/10/01 16:32:39  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.13  2003/05/15 18:37:47  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.12  2003/04/25 17:19:10  peiyongz
- * throw exception if getcwd() fails
- *
- * Revision 1.11  2003/04/24 02:53:29  peiyongz
- * Logical Path Resolution
- *
- * Revision 1.10  2003/04/21 04:27:22  peiyongz
- * performance tuning
- *
- * Revision 1.9  2003/03/09 16:53:27  peiyongz
- * PanicHandler
- *
- * Revision 1.8  2003/02/23 04:36:55  jberry
- * Minor bug fixes to FreeBSD port
- *
- * Revision 1.7  2002/12/12 16:28:48  peiyongz
- * MsgCatalogLoader added.
- *
- * Revision 1.6  2002/12/02 19:16:26  tng
- * [Bug 14723] Memory leak in atomicOpsMutex.  Patch from Adam Zell.
- *
- * Revision 1.5  2002/11/04 15:13:00  tng
- * C++ Namespace Support.
- *
- * Revision 1.4  2002/07/05 21:29:58  peiyongz
- * Bug# 10250: patch from James Berry
- *
- * Revision 1.3  2002/07/05 21:25:20  peiyongz
- * Bug# 10250: Implementation of new platform methods,
- *                      patch from max@cca.usart.ru (Max Gotlib)
- *
- * Revision 1.2  2002/05/21 20:31:47  tng
- * Minor update: Remove obsolete code
- *
- * Revision 1.1.1.1  2002/02/01 22:22:24  peiyongz
- * sane_include
- *
- * Revision 1.3  2001/12/03 16:25:00  tng
- * [Bug 5237] PATH_MAX undefined during build without threading support.
- *
- * Revision 1.2  2001/12/03 14:45:11  tng
- * FreeBSD native transcoder (IconvFBSD) added by Max Gotlib.
- *
- * Revision 1.1  2001/11/29 18:25:18  tng
- * FreeBSD support by Michael Huedepohl.
- *
+ * $Id: FreeBSDPlatformUtils.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -124,6 +43,7 @@
 #include    <xercesc/util/RuntimeException.hpp>
 #include    <xercesc/util/Janitor.hpp>
 #include    <xercesc/util/Mutexes.hpp>
+#include    <xercesc/util/XMLHolder.hpp>
 #include    <xercesc/util/XMLString.hpp>
 #include    <xercesc/util/XMLUniDefs.hpp>
 #include    <xercesc/util/XMLUni.hpp>
@@ -161,7 +81,7 @@ XERCES_CPP_NAMESPACE_BEGIN
 XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 {
 #if defined (XML_USE_NETACCESSOR_SOCKET)
-    return new SocketNetAccessor();
+    return new (fgMemoryManager) SocketNetAccessor();
 #else
     return 0;
 #endif
@@ -180,12 +100,12 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
     try
     {
 #if defined (XML_USE_ICU_MESSAGELOADER)
-        retVal = new ICUMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) ICUMsgLoader(msgDomain);
 #elif defined (XML_USE_ICONV_MESSAGELOADER)
-        retVal = new MsgCatalogLoader(msgDomain);        
+        retVal = new (fgMemoryManager) MsgCatalogLoader(msgDomain);        
 #else
         // same as -DXML_USE_INMEM_MESSAGELOADER
-        retVal = new InMemMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) InMemMsgLoader(msgDomain);
 #endif
     }
     catch(const OutOfMemoryException&)
@@ -212,11 +132,11 @@ XMLTransService* XMLPlatformUtils::makeTransService()
 #if defined (XML_USE_ICU_TRANSCODER)
     // Use ICU transcoding services.
     // same as -DXML_USE_ICU_MESSAGELOADER
-    return new ICUTransService;
+    return new (fgMemoryManager) ICUTransService;
 #else
     // Use native transcoding services.
     // same as -DXML_USE_INMEM_MESSAGELOADER
-    return new IconvFBSDTransService;
+    return new (fgMemoryManager) IconvFBSDTransService;
 
 #endif
 }
@@ -509,39 +429,48 @@ void XMLPlatformUtils::platformInit()
     // mutex creation that must be broken.
     if(!atomicOpsMutex)
     {
-        atomicOpsMutex = new (fgMemoryManager) XMLMutex();
+        atomicOpsMutex = new (fgMemoryManager) XMLMutex(fgMemoryManager);
         if (atomicOpsMutex->fHandle == 0)
-            atomicOpsMutex->fHandle = XMLPlatformUtils::makeMutex();
+            atomicOpsMutex->fHandle = XMLPlatformUtils::makeMutex(fgMemoryManager);
     }
 }
 
-void* XMLPlatformUtils::makeMutex()
-{
-    pthread_mutex_t* mutex = new pthread_mutex_t;
-    pthread_mutexattr_t*  attr = new pthread_mutexattr_t;
-    pthread_mutexattr_init(attr);
-    pthread_mutexattr_settype(attr, PTHREAD_MUTEX_RECURSIVE);
-    if (pthread_mutex_init(mutex, attr))
-    {
-        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                 XMLExcepts::Mutex_CouldNotCreate, fgMemoryManager);
-    }
-    pthread_mutexattr_destroy(attr);
-    delete attr;
-    return (void*)(mutex);
+typedef XMLHolder<pthread_mutex_t>  MutexHolderType;
 
+void* XMLPlatformUtils::makeMutex(MemoryManager* manager)
+{
+    MutexHolderType* const  holder = new (manager) MutexHolderType;
+
+    pthread_mutexattr_t  attr;
+    pthread_mutexattr_init(&attr);
+    pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
+
+    if (pthread_mutex_init(&holder->fInstance, &attr))
+    {
+        delete holder;
+
+        panic(PanicHandler::Panic_MutexErr);
+    }
+    pthread_mutexattr_destroy(&attr);
+
+    return holder;
 }
 
 void XMLPlatformUtils::closeMutex(void* const mtxHandle)
 {
     if (mtxHandle != NULL)
     {
-        if (pthread_mutex_destroy((pthread_mutex_t*) mtxHandle))
+        MutexHolderType* const  holder =
+            MutexHolderType::castTo(mtxHandle);
+
+        if (pthread_mutex_destroy(&holder->fInstance))
         {
+            delete holder;
+
             ThrowXMLwithMemMgr(XMLPlatformUtilsException,
                      XMLExcepts::Mutex_CouldNotDestroy, fgMemoryManager);
         }
-        delete (pthread_mutex_t*)mtxHandle;
+        delete holder;
     }
 }
 
@@ -550,10 +479,9 @@ void XMLPlatformUtils::lockMutex(void* const mtxHandle)
 {
     if (mtxHandle != NULL)
     {
-        if (pthread_mutex_lock((pthread_mutex_t*) mtxHandle))
+        if (pthread_mutex_lock(&MutexHolderType::castTo(mtxHandle)->fInstance))
         {
-            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotLock, fgMemoryManager);
+            panic(PanicHandler::Panic_MutexErr);
         }
     }
 }
@@ -563,10 +491,9 @@ void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
 {
     if (mtxHandle != NULL)
     {
-        if (pthread_mutex_unlock((pthread_mutex_t*) mtxHandle))
+        if (pthread_mutex_unlock(&MutexHolderType::castTo(mtxHandle)->fInstance))
         {
-            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotUnlock, fgMemoryManager);
+            panic(PanicHandler::Panic_MutexErr);
         }
     }
 }
@@ -609,7 +536,7 @@ void XMLPlatformUtils::platformInit()
 {
 }
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager*)
 {
         return 0;
 }
