@@ -1,188 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: HPPlatformUtils.cpp,v $
- * Revision 1.19  2004/01/13 16:34:21  cargilld
- * Misc memory management changes.
- *
- * Revision 1.18  2004/01/06 17:31:20  neilg
- * fix static initialization problems, bug 28517; thanks to Reid Spencer
- *
- * Revision 1.17  2003/12/24 15:24:14  cargilld
- * More updates to memory management so that the static memory manager.
- *
- * Revision 1.16  2003/12/17 15:16:10  cargilld
- * Platform update for memory management so that the static memory manager (one
- * used to call Initialize) is only for static data.
- *
- * Revision 1.15  2003/12/17 13:58:02  cargilld
- * Platform update for memory management so that the static memory manager (one
- * used to call Initialize) is only for static data.
- *
- * Revision 1.14  2003/10/01 16:32:39  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.13  2003/05/15 18:37:48  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.12  2003/04/25 17:19:26  peiyongz
- * throw exception if getcwd() fails
- *
- * Revision 1.11  2003/04/24 02:53:52  peiyongz
- * Logical Path Resolution
- *
- * Revision 1.10  2003/03/09 16:53:55  peiyongz
- * PanicHandler
- *
- * Revision 1.9  2002/12/02 19:17:00  tng
- * [Bug 14723] Memory leak in atomicOpsMutex.  Patch from Adam Zell.
- *
- * Revision 1.8  2002/11/07 22:37:51  peiyongz
- * build -miconv on hpux and linux
- *
- * Revision 1.7  2002/11/04 15:13:00  tng
- * C++ Namespace Support.
- *
- * Revision 1.6  2002/07/15 21:52:48  peiyongz
- * CouldNotWriteToFile
- *
- * Revision 1.5  2002/06/24 15:55:03  peiyongz
- * Change from James Berry( jberry@criticalpath.com)
- *
- * Revision 1.4  2002/06/20 15:27:27  peiyongz
- * Fix to compilation error
- *
- * Revision 1.2  2002/05/21 20:31:47  tng
- * Minor update: Remove obsolete code
- *
- * Revision 1.1.1.1  2002/02/01 22:22:24  peiyongz
- * sane_include
- *
- * Revision 1.17  2001/10/25 15:20:31  tng
- * Need to guard with NO_APP_THREADS when destroying the mutex.
- *
- * Revision 1.16  2001/10/23 23:10:00  peiyongz
- * [Bug#880] patch to PlatformUtils:init()/term() and related. from Mark Weaver
- *
- * Revision 1.15  2000/09/22 18:31:41  andyh
- * HPUX PlatformUtils - Removed incorrect use of ArrayJanitor on a local array.
- * Patch submitted by "Torbjrn Bckstrm" <torbjorn.backstrom@teleteknik.goteborg.se>
- *
- * Revision 1.14  2000/07/25 22:29:36  aruna1
- * Char definitions in XMLUni moved to XMLUniDefs
- *
- * Revision 1.13  2000/03/24 00:16:00  aruna1
- * Platform initialization taken care for both threaded and non-threaded environment
- *
- * Revision 1.12  2000/03/20 23:48:51  rahulj
- * Added Socket based NetAccessor. This will enable one to
- * use HTTP URL's for system id's. Default build options do
- * not use this NetAccessor. Specify the '-n socket' option
- * to 'runConfigure' to configure Xerces-C to use this new
- * feature. The code works under Solaris 2.6, Linux, AIX
- * and HPUX 11 with aCC.
- * Todo's: enable proper error handling.
- *
- * Revision 1.11  2000/03/17 23:59:59  roddey
- * Initial updates for two way transcoding support
- *
- * Revision 1.10  2000/03/02 21:10:35  abagchi
- * Added empty function platformTerm()
- *
- * Revision 1.9  2000/03/02 20:42:40  abagchi
- * Fixed typo in XMLExcepts
- *
- * Revision 1.8  2000/03/02 19:55:21  roddey
- * This checkin includes many changes done while waiting for the
- * 1.1.0 code to be finished. I can't list them all here, but a list is
- * available elsewhere.
- *
- * Revision 1.7  2000/02/06 07:48:26  rahulj
- * Year 2K copyright swat.
- *
- * Revision 1.6  2000/01/25 22:32:45  aruna1
- * Updated panic information
- *
- * Revision 1.5  2000/01/20 20:37:55  abagchi
- * Removed fgLibLocation and cleaned up ICU path related stuff
- *
- * Revision 1.4  2000/01/18 21:33:17  aruna1
- * Changed getBasePath to getFullPath,
- * added weavePath()
- *
- * Revision 1.3  1999/12/14 23:53:31  rahulj
- * Removed the offending Ctrl-M's from the commit message
- * logs which was giving packaging problems.
- *
- * PR:
- * Obtained from:
- * Submitted by:
- * Reviewed by:
- *
- * Revision 1.2  1999/11/23 02:00:44  rahulj
- * Code now works under HPUX 11. Tested inmemory message loader.
- * Revamped makefiles. Builds with both DCE threads as well as pthread libraries.
- *
- * Revision 1.1.1.1  1999/11/09 01:07:05  twl
- * Initial checkin
- *
- * Revision 1.3  1999/11/08 20:45:29  rahul
- * Swat for adding in Product name and CVS comment log variable.
- *
+ * $Id: HPPlatformUtils.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -197,6 +30,7 @@
 #include    <xercesc/util/PlatformUtils.hpp>
 #include    <xercesc/util/RuntimeException.hpp>
 #include    <xercesc/util/Janitor.hpp>
+#include    <xercesc/util/XMLHolder.hpp>
 #include    <xercesc/util/Mutexes.hpp>
 #include    <dl.h>
 #include    <stdio.h>
@@ -257,7 +91,7 @@ XERCES_CPP_NAMESPACE_BEGIN
 XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 {
 #if defined (XML_USE_NETACCESSOR_SOCKET)
-    return new SocketNetAccessor();
+    return new (fgMemoryManager) SocketNetAccessor();
 #else
     return 0;
 #endif
@@ -276,12 +110,12 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
     try
     {
 #if defined (XML_USE_ICU_MESSAGELOADER)
-        retVal = new ICUMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) ICUMsgLoader(msgDomain);
 #elif defined (XML_USE_ICONV_MESSAGELOADER)
-        retVal = new MsgCatalogLoader(msgDomain);
+        retVal = new (fgMemoryManager) MsgCatalogLoader(msgDomain);
 #else
         // same as -DXML_USE_INMEM_MESSAGELOADER
-        retVal = new InMemMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) InMemMsgLoader(msgDomain);
 #endif
     }
     catch(const OutOfMemoryException&)
@@ -306,12 +140,12 @@ XMLTransService* XMLPlatformUtils::makeTransService()
 {
 
 #if defined (XML_USE_ICU_TRANSCODER)
-    return new ICUTransService;
+    return new (fgMemoryManager) ICUTransService;
 #else
 
     // Use native transcoding services.
     // same as -DXML_USE_INMEM_MESSAGELOADER
-    return new IconvTransService;
+    return new (fgMemoryManager) IconvTransService;
 
 #endif
 
@@ -575,6 +409,8 @@ unsigned long XMLPlatformUtils::getCurrentMillis()
 // ---------------------------------------------------------------------------
 //  XMLPlatformUtils: Platform init method
 // ---------------------------------------------------------------------------
+typedef XMLHolder<pthread_mutex_t>  MutexHolderType;
+
 static XMLMutex *atomicOpsMutex = 0;
 
 void XMLPlatformUtils::platformInit()
@@ -586,50 +422,56 @@ void XMLPlatformUtils::platformInit()
     // mutex creation that must be broken.
     if(!atomicOpsMutex)
     {
-        atomicOpsMutex = new (fgMemoryManager) XMLMutex();
-        if (atomicOpsMutex->fHandle == 0)
-            atomicOpsMutex->fHandle = XMLPlatformUtils::makeMutex();
+        atomicOpsMutex = new (fgMemoryManager) XMLMutex(fgMemoryManager);
     }
 }
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager* manager)
 {
-    pthread_mutex_t* mutex = new pthread_mutex_t;
-    pthread_mutexattr_t*  attr = new pthread_mutexattr_t;
+    MutexHolderType* const  holder = new (manager) MutexHolderType;
+
+    pthread_mutexattr_t     attr;
 
 #if defined(XML_USE_DCE)
-    pthread_mutexattr_create(attr);
-    pthread_mutexattr_setkind_np(attr, MUTEX_RECURSIVE_NP);
-    if (pthread_mutex_init(mutex, *attr))
+    pthread_mutexattr_create(&attr);
+    pthread_mutexattr_setkind_np(&attr, MUTEX_RECURSIVE_NP);
+    if (pthread_mutex_init(&holder->fInstance, attr))
     {
-        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                 XMLExcepts::Mutex_CouldNotCreate, fgMemoryManager);
-    }
-    pthread_mutexattr_delete(attr);
-#else
-    pthread_mutexattr_init(attr);
-    pthread_mutexattr_settype(attr, PTHREAD_MUTEX_RECURSIVE);
-    if (pthread_mutex_init(mutex, attr))
-    {
-        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                 XMLExcepts::Mutex_CouldNotCreate, fgMemoryManager);
-    }
-    pthread_mutexattr_destroy(attr);
-#endif
-    delete attr;
+        delete holder;
 
-    return (void*) mutex;
+        panic(PanicHandler::Panic_MutexErr);
+    }
+    pthread_mutexattr_delete(&attr);
+#else
+    pthread_mutexattr_init(&attr);
+    pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
+    if (pthread_mutex_init(&holder->fInstance, &attr))
+    {
+        delete holder;
+
+        panic(PanicHandler::Panic_MutexErr);
+    }
+    pthread_mutexattr_destroy(&attr);
+#endif
+
+    return holder;
 }
 
 void XMLPlatformUtils::closeMutex(void* const mtxHandle)
 {
-    pthread_mutex_t* mutex = (pthread_mutex_t *) mtxHandle;
-    if (mutex != NULL)
+    if (mtxHandle != NULL)
     {
-        if (pthread_mutex_destroy(mutex))
+        MutexHolderType* const  holder = MutexHolderType::castTo(mtxHandle);
+
+        if (pthread_mutex_destroy(&holder->fInstance))
+        {
+            delete holder;
+
             ThrowXMLwithMemMgr(XMLPlatformUtilsException,
                   XMLExcepts::Mutex_CouldNotDestroy, fgMemoryManager);
-        delete mutex;
+        }
+
+        delete holder;
     }
 }
 
@@ -637,10 +479,9 @@ void XMLPlatformUtils::lockMutex(void* const mtxHandle)
 {
     if (mtxHandle != NULL)
     {
-        if (pthread_mutex_lock((pthread_mutex_t *) mtxHandle))
+        if (pthread_mutex_lock(&MutexHolderType::castTo(mtxHandle)->fInstance))
         {
-            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotLock, fgMemoryManager);
+            panic(PanicHandler::Panic_MutexErr);
         }
     }
 }
@@ -649,10 +490,9 @@ void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
 {
     if (mtxHandle != NULL)
     {
-        if (pthread_mutex_unlock((pthread_mutex_t *) mtxHandle))
+        if (pthread_mutex_unlock(&MutexHolderType::castTo(mtxHandle)->fInstance))
         {
-            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotUnlock, fgMemoryManager);
+            panic(PanicHandler::Panic_MutexErr);
         }
     }
 }
@@ -695,20 +535,20 @@ void XMLPlatformUtils::platformInit()
 {
 }
 
-void XMLPlatformUtils::closeMutex(void* const mtxHandle)
+void XMLPlatformUtils::closeMutex(void* const)
 {
 }
 
-void XMLPlatformUtils::lockMutex(void* const mtxHandle)
+void XMLPlatformUtils::lockMutex(void* const)
 {
 }
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager*)
 {
     return 0;
 }
 
-void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
+void XMLPlatformUtils::unlockMutex(void* const)
 {
 }
 
