@@ -15,120 +15,7 @@
  */
 
 /*
- * $Log: IRIXPlatformUtils.cpp,v $
- * Revision 1.20  2004/09/08 13:56:39  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.19  2004/01/13 16:34:21  cargilld
- * Misc memory management changes.
- *
- * Revision 1.18  2004/01/06 17:31:20  neilg
- * fix static initialization problems, bug 28517; thanks to Reid Spencer
- *
- * Revision 1.17  2003/12/24 15:24:14  cargilld
- * More updates to memory management so that the static memory manager.
- *
- * Revision 1.16  2003/12/19 23:02:25  cargilld
- * More memory management updates.
- *
- * Revision 1.15  2003/12/17 15:16:10  cargilld
- * Platform update for memory management so that the static memory manager (one
- * used to call Initialize) is only for static data.
- *
- * Revision 1.14  2003/12/17 13:58:03  cargilld
- * Platform update for memory management so that the static memory manager (one
- * used to call Initialize) is only for static data.
- *
- * Revision 1.13  2003/10/01 16:32:39  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.12  2003/05/15 18:37:48  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.11  2003/04/25 17:19:40  peiyongz
- * throw exception if getcwd() fails
- *
- * Revision 1.10  2003/04/24 02:54:24  peiyongz
- * Logical Path Resolution
- *
- * Revision 1.9  2003/04/21 04:28:04  peiyongz
- * performance tuning
- *
- * Revision 1.8  2003/03/09 16:54:25  peiyongz
- * PanicHandler
- *
- * Revision 1.7  2003/02/05 18:28:21  tng
- * [Bug 13437] Incorrect memory management in XXXPlatformUtils.cpp.
- *
- * Revision 1.6  2002/12/12 16:28:55  peiyongz
- * MsgCatalogLoader added.
- *
- * Revision 1.5  2002/12/02 19:16:38  tng
- * [Bug 14723] Memory leak in atomicOpsMutex.  Patch from Adam Zell.
- *
- * Revision 1.4  2002/11/15 21:05:45  tng
- * [Bug 14598] IRIX 6.5 / g++ 3.0.4 compilation bugs.  Patch from Richard Balint
- * .
- *
- * Revision 1.3  2002/11/04 15:13:00  tng
- * C++ Namespace Support.
- *
- * Revision 1.2  2002/05/21 20:31:47  tng
- * Minor update: Remove obsolete code
- *
- * Revision 1.1.1.1  2002/02/01 22:22:24  peiyongz
- * sane_include
- *
- * Revision 1.14  2001/12/11 14:46:39  tng
- * [Bug 5320] 1.5.2 Build fails on IRIX.  The variable "atomicOpsMutex" has been defined twice.  Fixed by Christopher Just.
- *
- * Revision 1.13  2001/10/23 23:10:20  peiyongz
- * [Bug#880] patch to PlatformUtils:init()/term() and related. from Mark Weaver
- *
- * Revision 1.12  2001/09/04 19:05:44  peiyongz
- * Patch to support IRIX's sproc(), from Christopher Just
- *
- * Revision 1.11  2001/01/26 15:42:00  tng
- * Undefined symbol error when building a single threaded version of the xerces lib on irix.  Fixed by Walker.
- *
- * Revision 1.10  2000/07/25 22:29:45  aruna1
- * Char definitions in XMLUni moved to XMLUniDefs
- *
- * Revision 1.9  2000/04/03 19:27:19  abagchi
- * Included changes for SGI IRIX 6.5
- *
- * Revision 1.8  2000/03/02 21:10:36  abagchi
- * Added empty function platformTerm()
- *
- * Revision 1.7  2000/03/02 20:42:40  abagchi
- * Fixed typo in XMLExcepts
- *
- * Revision 1.6  2000/03/02 19:55:22  roddey
- * This checkin includes many changes done while waiting for the
- * 1.1.0 code to be finished. I can't list them all here, but a list is
- * available elsewhere.
- *
- * Revision 1.5  2000/02/06 07:48:27  rahulj
- * Year 2K copyright swat.
- *
- * Revision 1.4  2000/01/25 22:32:35  aruna1
- * Updated panic information
- *
- * Revision 1.3  1999/12/18 00:54:43  rahulj
- * Merged in changes for IRIX submitted by Marc Stuessel
- *
- * Revision 1.2  1999/12/14 23:53:32  rahulj
- * Removed the offending Ctrl-M's from the commit message
- * logs which was giving packaging problems.
- *
- * PR:
- * Obtained from:
- * Submitted by:
- * Reviewed by:
- *
- * Revision 1.1  1999/12/01 17:16:18  rahulj
- * Added support for IRIX 6.5.5 using SGI MIPSpro C++ 7.3 and 7.21 generating 32 bit objects. Changes submitted by Marc Stuessel
- *
+ * $Id: IRIXPlatformUtils.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -155,6 +42,7 @@
 #include    <xercesc/util/RuntimeException.hpp>
 #include    <xercesc/util/Janitor.hpp>
 #include    <xercesc/util/Mutexes.hpp>
+#include    <xercesc/util/XMLHolder.hpp>
 #include    <xercesc/util/XMLString.hpp>
 #include    <xercesc/util/XMLUniDefs.hpp>
 #include    <xercesc/util/XMLUni.hpp>
@@ -192,7 +80,7 @@ XERCES_CPP_NAMESPACE_BEGIN
 XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 {
 #if defined (XML_USE_NETACCESSOR_SOCKET)
-    return new SocketNetAccessor();
+    return new (fgMemoryManager) SocketNetAccessor();
 #else
     return 0;
 #endif
@@ -209,12 +97,12 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
     try
     {
 #if defined (XML_USE_ICU_MESSAGELOADER)
-        retVal = new ICUMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) ICUMsgLoader(msgDomain);
 #elif defined (XML_USE_ICONV_MESSAGELOADER)
-        retVal = new MsgCatalogLoader(msgDomain);
+        retVal = new (fgMemoryManager) MsgCatalogLoader(msgDomain);
 #else
         // same as -DXML_USE_INMEM_MESSAGELOADER
-        retVal = new InMemMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) InMemMsgLoader(msgDomain);
 #endif
     }
     catch(const OutOfMemoryException&)
@@ -241,11 +129,11 @@ XMLTransService* XMLPlatformUtils::makeTransService()
 #if defined (XML_USE_ICU_TRANSCODER)
     // Use ICU transcoding services.
     // same as -DXML_USE_ICU_MESSAGELOADER
-    return new ICUTransService;
+    return new (fgMemoryManager) ICUTransService;
 #else
     // Use native transcoding services.
     // same as -DXML_USE_INMEM_MESSAGELOADER
-    return new IconvTransService;
+    return new (fgMemoryManager) IconvTransService;
 
 #endif
 }
@@ -532,9 +420,9 @@ void XMLPlatformUtils::platformInit()
 
     if(!atomicOpsMutex)
     {
-        atomicOpsMutex = new (fgMemoryManager) XMLMutex();
+        atomicOpsMutex = new (fgMemoryManager) XMLMutex(fgMemoryManager);
         if (atomicOpsMutex->fHandle == 0)
-            atomicOpsMutex->fHandle = XMLPlatformUtils::makeMutex();
+            atomicOpsMutex->fHandle = XMLPlatformUtils::makeMutex(fgMemoryManager);
     }
 }
 
@@ -555,7 +443,7 @@ void XMLPlatformUtils::platformTerm()
 }
 
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager*)
 {
     if (arena) {
         usema_t* sema = usnewsema (arena, 1);
@@ -563,8 +451,7 @@ void* XMLPlatformUtils::makeMutex()
             return (void*)sema;
         }
         else
-            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                      XMLExcepts::Mutex_CouldNotCreate, fgMemoryManager);
+            panic(PanicHandler::Panic_MutexErr);
     }
     else {
         // arena==0; therefore platformInit hasn't been called.
@@ -593,8 +480,7 @@ void XMLPlatformUtils::lockMutex(void* const mtxHandle)
 
     if (mtxHandle != NULL) {
         if (uspsema (mtxHandle) != 1)
-            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotLock, fgMemoryManager);
+            panic(PanicHandler::Panic_MutexErr);
     }
 
 }
@@ -606,8 +492,7 @@ void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
     {
         if (usvsema(mtxHandle) == -1)
         {
-            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotUnlock, fgMemoryManager);
+            panic(PanicHandler::Panic_MutexErr);
         }
     }
 }
@@ -627,9 +512,9 @@ void XMLPlatformUtils::platformInit()
     // mutex creation that must be broken.
     if(!atomicOpsMutex)
     {
-        atomicOpsMutex = new (fgMemoryManager) XMLMutex();
+        atomicOpsMutex = new (fgMemoryManager) XMLMutex(fgMemoryManager);
         if (atomicOpsMutex->fHandle == 0)
-            atomicOpsMutex->fHandle = XMLPlatformUtils::makeMutex();
+            atomicOpsMutex->fHandle = XMLPlatformUtils::makeMutex(fgMemoryManager);
     }
 }
 
@@ -642,33 +527,41 @@ void XMLPlatformUtils::platformTerm()
     atomicOpsMutex = 0;
 }
 
-void* XMLPlatformUtils::makeMutex()
-{
-    pthread_mutex_t* mutex = new pthread_mutex_t;
-    pthread_mutexattr_t*  attr = new pthread_mutexattr_t;
-    pthread_mutexattr_init(attr);
-    pthread_mutexattr_settype(attr, PTHREAD_MUTEX_RECURSIVE);
-    if (pthread_mutex_init(mutex, attr))
-    {
-        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                 XMLExcepts::Mutex_CouldNotCreate, fgMemoryManager);
-    }
-    pthread_mutexattr_destroy(attr);
-    delete attr;
-    return (void*)(mutex);
+typedef XMLHolder<pthread_mutex_t>  MutexHolderType;
 
+void* XMLPlatformUtils::makeMutex(MemoryManager* manager)
+{
+    MutexHolderType* const  holder = new (manager) MutexHolderType;
+
+    pthread_mutexattr_t  attr;
+    pthread_mutexattr_init(&attr);
+    pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE);
+    if (pthread_mutex_init(&holder->fInstance, &attr))
+    {
+        delete holder;
+
+        panic(PanicHandler::Panic_MutexErr);
+    }
+    pthread_mutexattr_destroy(&attr);
+
+    return holder;
 }
 
 void XMLPlatformUtils::closeMutex(void* const mtxHandle)
 {
     if (mtxHandle != NULL)
     {
-        if (pthread_mutex_destroy((pthread_mutex_t*) mtxHandle))
+        MutexHolderType* const  holder =
+            MutexHolderType::castTo(mtxHandle);
+
+        if (pthread_mutex_destroy(&holder->fInstance))
         {
+            delete holder;
+
             ThrowXMLwithMemMgr(XMLPlatformUtilsException,
                      XMLExcepts::Mutex_CouldNotDestroy, fgMemoryManager);
         }
-        delete (pthread_mutex_t*) mtxHandle;
+        delete holder;
     }
 }
 
@@ -677,10 +570,9 @@ void XMLPlatformUtils::lockMutex(void* const mtxHandle)
 {
     if (mtxHandle != NULL)
     {
-        if (pthread_mutex_lock((pthread_mutex_t*) mtxHandle))
+        if (pthread_mutex_lock(&MutexHolderType::castTo(mtxHandle)->fInstance))
         {
-            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotLock, fgMemoryManager);
+            panic(PanicHandler::Panic_MutexErr);
         }
     }
 }
@@ -690,10 +582,9 @@ void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
 {
     if (mtxHandle != NULL)
     {
-        if (pthread_mutex_unlock((pthread_mutex_t*) mtxHandle))
+        if (pthread_mutex_unlock(&MutexHolderType::castTo(mtxHandle)->fInstance))
         {
-            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotUnlock, fgMemoryManager);
+            panic(PanicHandler::Panic_MutexErr);
         }
     }
 }
