@@ -15,163 +15,7 @@
  */
 
 /*
- * $Log: LinuxPlatformUtils.cpp,v $
- * Revision 1.24  2004/09/08 13:56:40  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.23  2004/05/05 17:37:12  amassari
- * Enable libWWW on Linux
- *
- * Revision 1.22  2004/01/13 16:34:21  cargilld
- * Misc memory management changes.
- *
- * Revision 1.21  2004/01/06 17:31:20  neilg
- * fix static initialization problems, bug 28517; thanks to Reid Spencer
- *
- * Revision 1.20  2003/12/24 15:24:14  cargilld
- * More updates to memory management so that the static memory manager.
- *
- * Revision 1.19  2003/12/17 15:16:10  cargilld
- * Platform update for memory management so that the static memory manager (one
- * used to call Initialize) is only for static data.
- *
- * Revision 1.18  2003/12/17 13:58:03  cargilld
- * Platform update for memory management so that the static memory manager (one
- * used to call Initialize) is only for static data.
- *
- * Revision 1.17  2003/10/01 16:32:39  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.16  2003/05/15 18:37:48  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.15  2003/04/25 17:19:53  peiyongz
- * throw exception if getcwd() fails
- *
- * Revision 1.14  2003/04/24 02:54:46  peiyongz
- * Logical Path Resolution
- *
- * Revision 1.13  2003/04/21 04:28:45  peiyongz
- * performance tuning
- *
- * Revision 1.12  2003/03/09 16:56:11  peiyongz
- * PanicHandler
- *
- * Revision 1.11  2003/02/05 18:27:34  tng
- * [Bug 13437] Incorrect memory management in LinuxPlatformUtils.cpp.  Fixed by Adam Zell.
- *
- * Revision 1.10  2002/12/02 19:16:46  tng
- * [Bug 14723] Memory leak in atomicOpsMutex.  Patch from Adam Zell.
- *
- * Revision 1.9  2002/11/07 22:38:13  peiyongz
- * build -miconv on hpux and linux
- *
- * Revision 1.8  2002/11/04 15:13:00  tng
- * C++ Namespace Support.
- *
- * Revision 1.7  2002/08/19 19:38:17  tng
- * [Bug 11771] Linux specific IconvGNU transcoder.  Patch from Vasily Tchekalkin.
- *
- * Revision 1.6  2002/07/15 21:53:04  peiyongz
- * CouldNotWriteToFile
- *
- * Revision 1.5  2002/06/24 15:55:21  peiyongz
- * Change from James Berry( jberry@criticalpath.com)
- *
- * Revision 1.4  2002/06/20 15:28:08  peiyongz
- * Fix to compilation error
- *
- * Revision 1.2  2002/05/21 20:31:47  tng
- * Minor update: Remove obsolete code
- *
- * Revision 1.1.1.1  2002/02/01 22:22:24  peiyongz
- * sane_include
- *
- * Revision 1.22  2001/10/25 15:36:35  tng
- * [Bug 4318] Single threaded build fails due to obsolete #define .
- *
- * Revision 1.21  2001/10/25 15:20:31  tng
- * Need to guard with NO_APP_THREADS when destroying the mutex.
- *
- * Revision 1.20  2001/10/23 23:10:48  peiyongz
- * [Bug#880] patch to PlatformUtils:init()/term() and related. from Mark Weaver
- *
- * Revision 1.19  2001/05/11 12:03:40  tng
- * Need to add header <linux/limits> for definition of PATH_MAX
- *
- * Revision 1.18  2001/05/10 20:40:44  lehors
- * built-in buffer limit could be smaller than system limit,
- * we now use PATH_MAX instead - patch from Christian Schuhegger - bug #1158
- *
- * Revision 1.17  2000/07/25 22:29:55  aruna1
- * Char definitions in XMLUni moved to XMLUniDefs
- *
- * Revision 1.16  2000/03/24 00:13:03  aruna1
- * Platform initialization taken care for both threaded and non-threaded environment
- *
- * Revision 1.15  2000/03/20 23:48:52  rahulj
- * Added Socket based NetAccessor. This will enable one to
- * use HTTP URL's for system id's. Default build options do
- * not use this NetAccessor. Specify the '-n socket' option
- * to 'runConfigure' to configure Xerces-C to use this new
- * feature. The code works under Solaris 2.6, Linux, AIX
- * and HPUX 11 with aCC.
- * Todo's: enable proper error handling.
- *
- * Revision 1.14  2000/03/18 00:00:00  roddey
- * Initial updates for two way transcoding support
- *
- * Revision 1.13  2000/03/02 21:10:36  abagchi
- * Added empty function platformTerm()
- *
- * Revision 1.12  2000/03/02 20:42:41  abagchi
- * Fixed typo in XMLExcepts
- *
- * Revision 1.11  2000/03/02 19:55:24  roddey
- * This checkin includes many changes done while waiting for the
- * 1.1.0 code to be finished. I can't list them all here, but a list is
- * available elsewhere.
- *
- * Revision 1.10  2000/02/22 00:58:15  aruna1
- * openFile API updated
- *
- * Revision 1.9  2000/02/06 07:48:28  rahulj
- * Year 2K copyright swat.
- *
- * Revision 1.8  2000/01/25 22:32:56  aruna1
- * Updated panic information
- *
- * Revision 1.7  2000/01/19 23:21:37  abagchi
- * Made this file compatible with ICU 1.4
- *
- * Revision 1.6  2000/01/19 17:37:48  abagchi
- * Removed the streaming classes
- *
- * Revision 1.5  2000/01/14 02:04:43  abagchi
- * Introduced getFullPath() and weavePath()
- *
- * Revision 1.4  1999/12/14 23:53:33  rahulj
- * Removed the offending Ctrl-M's from the commit message
- * logs which was giving packaging problems.
- *
- * PR:
- * Obtained from:
- * Submitted by:
- * Reviewed by:
- *
- * Revision 1.3  1999/11/23 02:00:48  rahulj
- * Code now works under HPUX 11. Tested inmemory message loader.
- * Revamped makefiles. Builds with both DCE threads as well as pthread libraries.
- *
- * Revision 1.2  1999/11/17 22:35:33  rahulj
- * Replaced default attr mutexes with recursive mutexes. Also code works with ICU transcoding service
- *
- * Revision 1.1.1.1  1999/11/09 01:07:01  twl
- * Initial checkin
- *
- * Revision 1.6  1999/11/08 20:45:30  rahul
- * Swat for adding in Product name and CVS comment log variable.
- *
+ * $Id: LinuxPlatformUtils.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -199,6 +43,7 @@
 #include    <xercesc/util/RuntimeException.hpp>
 #include    <xercesc/util/Janitor.hpp>
 #include    <xercesc/util/Mutexes.hpp>
+#include    <xercesc/util/XMLHolder.hpp>
 #include    <xercesc/util/XMLString.hpp>
 #include    <xercesc/util/XMLUniDefs.hpp>
 #include    <xercesc/util/XMLUni.hpp>
@@ -241,9 +86,9 @@ XERCES_CPP_NAMESPACE_BEGIN
 XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 {
 #if defined (XML_USE_NETACCESSOR_SOCKET)
-    return new SocketNetAccessor();
+    return new (fgMemoryManager) SocketNetAccessor();
 #elif defined (XML_USE_NETACCESSOR_LIBWWW)
-    return new LibWWWNetAccessor();
+    return new (fgMemoryManager) LibWWWNetAccessor();
 #else
     return 0;
 #endif
@@ -262,12 +107,12 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
     try
     {
 #if defined (XML_USE_ICU_MESSAGELOADER)
-        retVal = new ICUMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) ICUMsgLoader(msgDomain);
 #elif defined (XML_USE_ICONV_MESSAGELOADER)
-        retVal = new MsgCatalogLoader(msgDomain);
+        retVal = new (fgMemoryManager) MsgCatalogLoader(msgDomain);
 #else
         // same as -DXML_USE_INMEM_MESSAGELOADER
-        retVal = new InMemMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) InMemMsgLoader(msgDomain);
 #endif
     }
     catch(const OutOfMemoryException&)
@@ -294,13 +139,13 @@ XMLTransService* XMLPlatformUtils::makeTransService()
 #if defined (XML_USE_ICU_TRANSCODER)
     // Use ICU transcoding services.
     // same as -DXML_USE_ICU_MESSAGELOADER
-    return new ICUTransService;
+    return new (fgMemoryManager) ICUTransService;
 #elif defined (XML_USE_GNU_TRANSCODER)
-    return new IconvGNUTransService;
+    return new (fgMemoryManager) IconvGNUTransService;
 #else
     // Use native transcoding services.
     // same as -DXML_USE_NATIVE_TRANSCODER
-    return new IconvTransService;
+    return new (fgMemoryManager) IconvTransService;
 
 #endif
 }
@@ -378,7 +223,7 @@ FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName
 }
 
 FileHandle XMLPlatformUtils::openFile(const char* const fileName
-                                      , MemoryManager* const manager)
+                                      , MemoryManager* const /* manager */)
 {
     FileHandle retVal = (FILE*)fopen( fileName , "rb" );
 
@@ -396,12 +241,12 @@ FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName
 }
 
 FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName
-                                             , MemoryManager* const manager)
+                                             , MemoryManager* const /* manager */)
 {
     return fopen( fileName , "wb" );
 }
 
-FileHandle XMLPlatformUtils::openStdInHandle(MemoryManager* const manager)
+FileHandle XMLPlatformUtils::openStdInHandle(MemoryManager* const /* manager */)
 {
     return (FileHandle)fdopen(dup(0), "rb");
 }
@@ -496,7 +341,7 @@ XMLCh* XMLPlatformUtils::getFullPath(const XMLCh* const srcPath,
 }
 
 bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck
-                                  , MemoryManager* const manager)
+                                  , MemoryManager* const /* manager */)
 {
     // Check for pathological case of empty path
     if (!toCheck[0])
@@ -566,39 +411,48 @@ void XMLPlatformUtils::platformInit()
     // mutex creation that must be broken.
     if ( atomicOpsMutex == 0 )
     {
-	    atomicOpsMutex = new (fgMemoryManager) XMLMutex;
+	    atomicOpsMutex = new (fgMemoryManager) XMLMutex(fgMemoryManager);
 	    if (atomicOpsMutex->fHandle == 0)
-	        atomicOpsMutex->fHandle = XMLPlatformUtils::makeMutex();
+	        atomicOpsMutex->fHandle = XMLPlatformUtils::makeMutex(fgMemoryManager);
     }
 }
 
-void* XMLPlatformUtils::makeMutex()
-{
-    pthread_mutex_t* mutex = new pthread_mutex_t;
-    pthread_mutexattr_t*  attr = new pthread_mutexattr_t;
-    pthread_mutexattr_init(attr);
-    pthread_mutexattr_settype(attr, PTHREAD_MUTEX_RECURSIVE_NP);
-    if (pthread_mutex_init(mutex, attr))
-    {
-        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                 XMLExcepts::Mutex_CouldNotCreate, fgMemoryManager);
-    }
-    pthread_mutexattr_destroy(attr);
-    delete attr;
-    return (void*)(mutex);
+typedef XMLHolder<pthread_mutex_t>  MutexHolderType;
 
+void* XMLPlatformUtils::makeMutex(MemoryManager* manager)
+{
+    MutexHolderType* const  holder = new (manager) MutexHolderType;
+
+    pthread_mutexattr_t  attr;
+    pthread_mutexattr_init(&attr);
+    pthread_mutexattr_settype(&attr, PTHREAD_MUTEX_RECURSIVE_NP);
+
+    if (pthread_mutex_init(&holder->fInstance, &attr))
+    {
+        delete holder;
+
+        panic(PanicHandler::Panic_MutexErr);
+    }
+    pthread_mutexattr_destroy(&attr);
+
+    return holder;
 }
 
 void XMLPlatformUtils::closeMutex(void* const mtxHandle)
 {
     if (mtxHandle != NULL)
     {
-        if (pthread_mutex_destroy((pthread_mutex_t*) mtxHandle))
+        MutexHolderType* const  holder =
+            MutexHolderType::castTo(mtxHandle);
+
+        if (pthread_mutex_destroy(&holder->fInstance))
         {
+            delete holder;
+
             ThrowXMLwithMemMgr(XMLPlatformUtilsException,
                      XMLExcepts::Mutex_CouldNotDestroy, fgMemoryManager);
         }
-        delete (pthread_mutex_t*) mtxHandle;
+        delete holder;
     }
 }
 
@@ -607,10 +461,9 @@ void XMLPlatformUtils::lockMutex(void* const mtxHandle)
 {
     if (mtxHandle != NULL)
     {
-        if (pthread_mutex_lock((pthread_mutex_t*) mtxHandle))
+        if (pthread_mutex_lock(&MutexHolderType::castTo(mtxHandle)->fInstance))
         {
-            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotLock, fgMemoryManager);
+            panic(PanicHandler::Panic_MutexErr);
         }
     }
 }
@@ -620,10 +473,9 @@ void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
 {
     if (mtxHandle != NULL)
     {
-        if (pthread_mutex_unlock((pthread_mutex_t*) mtxHandle))
+        if (pthread_mutex_unlock(&MutexHolderType::castTo(mtxHandle)->fInstance))
         {
-            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                     XMLExcepts::Mutex_CouldNotUnlock, fgMemoryManager);
+            panic(PanicHandler::Panic_MutexErr);
         }
     }
 }
@@ -666,20 +518,20 @@ void XMLPlatformUtils::platformInit()
 {
 }
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager*)
 {
         return 0;
 }
 
-void XMLPlatformUtils::closeMutex(void* const mtxHandle)
+void XMLPlatformUtils::closeMutex(void* const)
 {
 }
 
-void XMLPlatformUtils::lockMutex(void* const mtxHandle)
+void XMLPlatformUtils::lockMutex(void* const)
 {
 }
 
-void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
+void XMLPlatformUtils::unlockMutex(void* const)
 {
 }
 
