@@ -1,74 +1,35 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /**
- * $Id: OS400PlatformUtils.cpp,v 1.18 2004/01/29 11:51:20 cargilld Exp $
+ * $Id: OS400PlatformUtils.cpp 232395 2005-08-12 21:14:44Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
 //  Includes
 // ---------------------------------------------------------------------------
 #define MY_XP_CPLUSPLUS
-#include    "OS400PlatformUtils.hpp"
+#include    <xercesc/util/XMLUniDefs.hpp>
+#include    <xercesc/util/XercesDefs.hpp>
 #include    <pthread.h>
 #include    <xercesc/util/PlatformUtils.hpp>
 #include    <xercesc/util/RuntimeException.hpp>
 #include    <xercesc/util/Janitor.hpp>
 #include    <xercesc/util/XMLString.hpp>
-#include    <xercesc/util/XMLUniDefs.hpp>
+#include    <xercesc/util/XMLHolder.hpp>
 #include    <xercesc/util/PanicHandler.hpp>
 #include    <stdio.h>
 #include    <stdlib.h>
@@ -78,13 +39,20 @@
 #include    <mimchint.h>
 #include    <string.h>
 #include    <qmhsndpm.h>
+#include    <qmhrtvm.h>
+#include    <qusec.h>
+#include    <unistd.h>
+#include    <string.h>
 #include    <except.h>
-#include <mih/cmpswp.h>
+#include    <mih/cmpswp.h>
+#include    "OS400PlatformUtils.hpp"
 #include    <xercesc/util/OutOfMemoryException.hpp>
 
 #if defined (XML_USE_ICONV400_TRANSCODER)
     #include <xercesc/util/Transcoders/Iconv400/Iconv400TransService.hpp>
+XERCES_CPP_NAMESPACE_BEGIN    
 	void cleanupDefaultConverter();
+XERCES_CPP_NAMESPACE_END    
 #elif defined (XML_USE_ICU_TRANSCODER)
     #include <xercesc/util/Transcoders/ICU/ICUTransService.hpp>
 #else
@@ -115,7 +83,7 @@ char* PackingRepText(const char * const repText1,
 XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 {
 #if defined (XML_USE_NETACCESSOR_SOCKET)
-    return new SocketNetAccessor();
+    return new (fgMemoryManager) SocketNetAccessor();
 #else
     return 0;
 #endif
@@ -133,15 +101,15 @@ XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 XMLTransService* XMLPlatformUtils::makeTransService()
 #if defined (XML_USE_ICU_TRANSCODER)
 {
-    return new ICUTransService;
+    return new (fgMemoryManager) ICUTransService;
 }
 #elif defined (XML_USE_ICONV400_TRANSCODER)
 {
-    return new Iconv400TransService;
+    return new (fgMemoryManager) Iconv400TransService;
 }
 #else
 {
-    return new IconvTransService;
+    return new (fgMemoryManager) IconvTransService;
 }
 #endif
 
@@ -155,15 +123,14 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
     XMLMsgLoader* retVal;
     try
     {
-#if defined(XML_USE_MSGFILE_MESSAGELOADER)
-        #include <xercesc/util/MsgLoaders/MsgFile/MsgLoader.hpp>
-        retVal = new MsgCatalogLoader(msgDomain);
+#if defined(XML_USE_MSGFILE_MESSAGELOADER)        
+        retVal = new (fgMemoryManager) MsgCatalogLoader(msgDomain);
 #elif defined (XML_USE_ICU_MESSAGELOADER)
-	retVal = new ICUMsgLoader(msgDomain);
+	retVal = new (fgMemoryManager) ICUMsgLoader(msgDomain);
 #elif defined (XML_USE_ICONV_MESSAGELOADER)
-	retVal = new MsgCatalogLoader(msgDomain);
+	retVal = new (fgMemoryManager) MsgCatalogLoader(msgDomain);
 #else
-	retVal = new InMemMsgLoader(msgDomain);
+	retVal = new (fgMemoryManager) InMemMsgLoader(msgDomain);
 #endif
     }
     catch(const OutOfMemoryException&)
@@ -252,8 +219,6 @@ unsigned int XMLPlatformUtils::fileSize(FileHandle theFile
     return (unsigned int)retVal;
 }
 
-#include <qmhrtvm.h>
-#include <qusec.h>
 FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName
                                       , MemoryManager* const manager)
 {   char errno_id[7];
@@ -379,31 +344,177 @@ void XMLPlatformUtils::resetFile(FileHandle theFile
 // ---------------------------------------------------------------------------
 //  XMLPlatformUtils: File system methods
 // ---------------------------------------------------------------------------
-/* since we do not have the realpath function on AS/400 and it appears
-to no be important that we convert the name to the real path we will
-only verify that the path exists  - note that this may make AS/400 output a different error for the pathname but customer should
-be able to determine what the name is suppose to be*/
+
+//-------------------------
+//-- BEGIN realpath code --
+//-------------------------
+
+#include <limits.h>
 #include <unistd.h>
 #include <errno.h>
-#include <string.h>
-char *realpath(const char *file_name, char *resolved_name)
-{
- if (file_name== NULL)
- {
-   errno = EINVAL;
-   return(NULL);
- }
- if (access(file_name,F_OK)) /* verify that the file exists*/
- {
-  errno = EACCES;
-  return(NULL);
- }
- else
- /* code says that we make a copy of the file name so do it */
-  strcpy(resolved_name,file_name);
-  return(resolved_name);
+
+//
+// realpath
+//
+// Resolve a file name into its absolute name
+// This function doesn't exist in the iSeries C runtime library so this partial replacement was
+//  written to handle most of its function.  This implementation doesn't resolve symbolic links
+//  to their "real" paths because for the purposes of reading files the symlinks will work just
+//  fine.
+//
+char *realpath(const char *file_name, char *resolved_name) {
+    // Input: file_name - the name of a file or directory
+    // Output: resolved_name - file_name with a fully qualified path and all "extraneous" path stuff removed
+    // Returned value: Same as resolved_name unless there is an error in which case NULL is returned
+    //
+    // Possible errors:  (no)==we don't check that
+    //  EACCES      Read or search permission was denied for a component of the path name.
+    //  EINVAL     File_name or resolved_name is a null pointer.
+    //  (no) ELOOP     Too many symbolic links are encountered in translating file_name.
+    //  ENAMETOOLONG     The length of file_name or resolved_name exceeds PATH_MAX or a path name component is longer than NAME_MAX.
+    //  ENOENT     The file_name parameter does not exist or points to an empty string.
+    //  (no) ENOTDIR     A component of the file_name prefix is not a directory.
+    // If there is an error in resolving the name the return value will be NULL (i.e., 0) and resolved_name
+    //  will be changed to an empty string (a 0 will be written into its first character position)
+
+    // Note for future expansion:  "readlink" for links
+
+    // Check for null name errors
+     if (resolved_name == NULL) {
+        errno = EINVAL;
+        return(NULL);
+     }
+    // Assumption: At this point resolved_name points to a character array large enough to hold at least PATH_MAX characters
+     if (file_name == NULL) {
+        errno = EINVAL;
+        *resolved_name = '\0';
+        return(NULL);
+     }
+    // Assumption: At this point file_name is a valid null terminated string
+
+    // Check for empty name error
+     if (*file_name == '\0') {
+        errno = ENOENT;
+        *resolved_name = '\0';
+        return(NULL);
+     }
+
+    char *from = (char*)file_name;
+    char *to = resolved_name;
+    int fromIdx=0, toIdx=0;
+
+    if (*file_name == '/') {
+        // If file_name starts with a '/', it's an absolute path
+        // Everything's already set up properly
+        to[toIdx++] = '/';
+    } // if
+    else {
+        // file_name doesn't start with a '/' so it is relative to the current directory
+        // Prepend the current working directory before the file name
+        getcwd(to, PATH_MAX);
+        size_t cwd_len = strlen(resolved_name);
+        // Assumption: getcwd returns a non-empty, valid, null terminated string
+
+        // Add '/' on the cwd if needed
+        // Note: I think the only time a '/' will end the cwd is if it is just "/"
+        //  but this covers otherwise just in case
+        toIdx = cwd_len;
+        if ((toIdx < PATH_MAX-1) &&
+            (to[toIdx] != '/')) {
+             to[toIdx++] = '/';
+        } // if
+    } // else
+
+    // The target ends in a '/' at this point
+    // Skip any leading '/'s in the source
+    while (from[fromIdx] == '/') {
+        fromIdx++;
+    } // while
+
+    // Copy from the source to the target removing extraneous "."s, "/"s, and ".."s as we go
+    // Assumption: looking ahead for characters is OK because all the string end with '/0'
+    while (from[fromIdx] != '\0' ) {
+        // Assumption - at top of loop we are either at '..', '.', or 'xxxxxxxx' (where x is any non-'/' character), each either followed by a '/' or a closing '\0'
+        //  "../" => "/", also strips trailing ".."
+        if ((from[fromIdx] == '.') &&
+            (from[fromIdx+1] == '.') &&
+            ((from[fromIdx+2] == '/') || (from[fromIdx+2] == '\0'))) {
+            fromIdx += (from[fromIdx+2] == '\0') ? 2 : 3;
+            // Back up to the previous '/' in the target except if we are at the first '/' already
+            if (toIdx >= 2) {
+                // Back up past the current '/'
+                --toIdx;
+                // Look back until we find the previous '/'
+                while(to[toIdx-1] != '/') {
+                     --toIdx;
+                } // while
+            } // if
+        } // if
+
+        // "./" => "/", also strips trailing "."
+        else if ((from[fromIdx] == '.') &&
+                 ((from[fromIdx+1] == '/') || (from[fromIdx+1] == '\0'))) {
+             fromIdx += (from[fromIdx+1] == '\0') ? 1 : 2;
+        } // else if
+
+        else {
+            // Copy the characters up to the next '/' or to the closing '\0'
+            while((from[fromIdx] != '/') && (from[fromIdx] != '\0')) {
+                // Check that the file name won't be too long (allow for the '\0' too)
+                if (toIdx >= PATH_MAX-1) {
+                    errno = ENAMETOOLONG;
+                    *resolved_name = '\0';
+                    return(NULL);
+                } // if
+
+                to[toIdx++] = from[fromIdx++];
+            } // while
+        } // else
+
+        if (from[fromIdx] == '/') {
+            // Skip any remaining '/'s in the source
+            while (from[fromIdx] == '/') {
+                fromIdx++;
+            } // while
+
+            // insert a '/' if there's more path to come (and room for it)
+            if (from[fromIdx] != '\0') {
+                // Check that the file name won't be too long (allow for the '\0' too)
+                if (toIdx >= PATH_MAX-1) {
+                    errno = ENAMETOOLONG;
+                    *resolved_name = '\0';
+                    return(NULL);
+                } // if
+
+                to[toIdx++] = '/';
+            } // if
+        } // if
+
+    } // while
+
+    // Remove a trailing '/' (except from "/")
+    if ((toIdx > 1) &&
+        (to[toIdx-1] == '/'))
+        --toIdx;
+
+    // End the string properly
+    to[toIdx] = '\0';
+
+    // Check if the file exists
+    if (access(resolved_name,F_OK)) {
+        errno = EACCES;
+        *resolved_name = '\0';
+        return(NULL);
+    } // if
+
+    // The file exists, return its name.
+     return(resolved_name);
 }
 
+//-----------------------
+//-- END realpath code --
+//-----------------------
+
 
 
 
@@ -573,7 +684,11 @@ unsigned long XMLPlatformUtils::getCurrentMillis()
 // -----------------------------------------------------------------------
 
 #if !defined (APP_NO_THREADS)
-static pthread_mutex_t* gAtomicOpMutex =0 ;
+
+typedef XMLHolder<pthread_mutex_t>  MutexHolderType;
+
+static MutexHolderType* gAtomicOpMutex = 0;
+
 void XMLPlatformUtils::platformInit()
 {
     //
@@ -584,12 +699,11 @@ void XMLPlatformUtils::platformInit()
     // circular dependency between compareAndExchange() and
     // mutex creation that must be broken.
 
-    gAtomicOpMutex = new pthread_mutex_t;	
+    gAtomicOpMutex = new (fgMemoryManager) MutexHolderType;
 
-    if (pthread_mutex_init(gAtomicOpMutex, NULL)) {
+    if (pthread_mutex_init(&gAtomicOpMutex->fInstance, NULL)) {
 		delete gAtomicOpMutex;
 		gAtomicOpMutex = 0;
-
         panic( PanicHandler::Panic_SystemInit );
 	}
 }
@@ -600,10 +714,13 @@ public:
     pthread_mutex_t   mutex;
     int               recursionCount;
     pthread_t         tid;
+    MemoryManager*    fManager;
 
-    RecursiveMutex() {
+    RecursiveMutex(MemoryManager* manager) :
+        fManager(manager)
+    {
 		       if (pthread_mutex_init(&mutex, NULL))
-			    ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotCreate, XMLPlatformUtils::fgMemoryManager);
+			    XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
                        recursionCount = 0;
                        tid.reservedHiId = 0;
 		       tid.reservedLoId = 0;
@@ -612,7 +729,7 @@ public:
 
     ~RecursiveMutex() {
 			if (pthread_mutex_destroy(&mutex))
-			    ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotDestroy, XMLPlatformUtils::fgMemoryManager);
+			    ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotDestroy, fManager);
                       }
 
      void lock()      {
@@ -622,7 +739,7 @@ public:
 			      return;
 			  }
 			  if (pthread_mutex_lock(&mutex) != 0)
-			      ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotLock, XMLPlatformUtils::fgMemoryManager);
+			      XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
 			  tid = pthread_self();
 			  recursionCount = 1;
 		      }
@@ -633,16 +750,16 @@ public:
                               return;
 
 			  if (pthread_mutex_unlock(&mutex) != 0)
-			      ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotUnlock, XMLPlatformUtils::fgMemoryManager);
+			      XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
                           tid.reservedHandle= 0;
 			  tid.reservedHiId = 0;
 			  tid.reservedLoId = 0;
                        }
    };
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager* manager)
 {
-    return new RecursiveMutex;
+    return new (manager) RecursiveMutex(manager);
 }
 
 
@@ -685,14 +802,14 @@ void* XMLPlatformUtils::compareAndSwap ( void**      toFill ,
     // the below calls are temporarily made till the above functions are part of user library
     // Currently its supported only in the kernel mode
 
-    if (pthread_mutex_lock( gAtomicOpMutex))
+    if (pthread_mutex_lock( &gAtomicOpMutex->fInstance))
         panic(PanicHandler::Panic_SynchronizationErr);
 
     void *retVal = *toFill;
     if (*toFill == toCompare)
               *toFill = (void *)newValue;
 
-    if (pthread_mutex_unlock( gAtomicOpMutex))
+    if (pthread_mutex_unlock( &gAtomicOpMutex->fInstance))
         panic(PanicHandler::Panic_SynchronizationErr);
 
     return retVal;
@@ -734,20 +851,20 @@ void XMLPlatformUtils::platformInit()
    // do nothing
 }
 
-void XMLPlatformUtils::closeMutex(void* const mtxHandle)
+void XMLPlatformUtils::closeMutex(void* const)
 {
 }
 
-void XMLPlatformUtils::lockMutex(void* const mtxHandle)
+void XMLPlatformUtils::lockMutex(void* constmanager)
 {
 }
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager*)
 {
         return 0;
 }
 
-void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
+void XMLPlatformUtils::unlockMutex(void* const)
 {
 }
 
@@ -787,13 +904,13 @@ return;
 
 FileHandle XMLPlatformUtils::openStdInHandle(MemoryManager* const manager)
 {
-    return (FileHandle)fdopen(dup(0), "rb");
+    return (FileHandle)fdopen(dup(0), "r");
 }
 
 void XMLPlatformUtils::platformTerm()
 {
 #if !defined (APP_NO_THREADS)
-	pthread_mutex_destroy(gAtomicOpMutex);
+	pthread_mutex_destroy(&gAtomicOpMutex->fInstance);
     delete gAtomicOpMutex;
 	gAtomicOpMutex = 0;
 #endif
