@@ -1,88 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: OpenServerPlatformUtils.cpp,v $
- * Revision 1.9  2003/10/01 16:32:40  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.8  2003/05/15 18:37:49  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.7  2003/04/25 17:20:11  peiyongz
- * throw exception if getcwd() fails
- *
- * Revision 1.6  2003/04/24 02:55:58  peiyongz
- * Logical Path Resolution
- *
- * Revision 1.5  2003/03/09 16:57:18  peiyongz
- * PanicHandler
- *
- * Revision 1.4  2002/11/19 13:04:32  gareth
- * Bug# 14661 Caldera implemented openFileToWrite and writeBufferToFile. Patch from Cameron Dorrat.
- *
- * Revision 1.3  2002/11/04 15:13:01  tng
- * C++ Namespace Support.
- *
- * Revision 1.2  2002/05/21 20:31:47  tng
- * Minor update: Remove obsolete code
- *
- * Revision 1.1  2002/02/27 22:57:59  peiyongz
- * Bug# 6445 Caldera (SCO) OpenServer Port : patch from Martin Kalen
- *
+ * $Id: OpenServerPlatformUtils.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -107,6 +40,7 @@
 #include    <xercesc/util/RuntimeException.hpp>
 #include    <xercesc/util/Janitor.hpp>
 #include    <xercesc/util/Mutexes.hpp>
+#include    <xercesc/util/XMLHolder.hpp>
 #include    <xercesc/util/XMLString.hpp>
 #include    <xercesc/util/XMLUniDefs.hpp>
 #include    <xercesc/util/XMLUni.hpp>
@@ -154,11 +88,11 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
     try
     {
 #if defined (XML_USE_ICU_MESSAGELOADER)
-        retVal = new ICUMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) ICUMsgLoader(msgDomain);
 #elif defined (XML_USE_ICONV_MESSAGELOADER)
-        retVal = new MsgCatalogLoader(msgDomain);
+        retVal = new (fgMemoryManager) MsgCatalogLoader(msgDomain);
 #else
-        retVal = new InMemMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) InMemMsgLoader(msgDomain);
 #endif
     }
     catch(const OutOfMemoryException&)
@@ -176,9 +110,9 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
 XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 {
 #if defined (XML_USE_NETACCESSOR_LIBWWW)
-    return new LibWWWNetAccessor();
+    return new (fgMemoryManager) LibWWWNetAccessor();
 #else
-    return new SocketNetAccessor();
+    return new (fgMemoryManager) SocketNetAccessor();
 #endif
 }
 
@@ -193,9 +127,9 @@ XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 XMLTransService* XMLPlatformUtils::makeTransService()
 {
 #if defined (XML_USE_ICU_TRANSCODER)
-	return new ICUTransService;
+	return new (fgMemoryManager) ICUTransService;
 #else
-	return new IconvTransService;
+	return new (fgMemoryManager) IconvTransService;
 #endif
 }
 
@@ -211,54 +145,58 @@ void XMLPlatformUtils::panic(const PanicHandler::PanicReasons reason)
 // ---------------------------------------------------------------------------
 //  XMLPlatformUtils: File Methods
 // ---------------------------------------------------------------------------
-unsigned int XMLPlatformUtils::curFilePos(FileHandle theFile)
+unsigned int XMLPlatformUtils::curFilePos(FileHandle theFile
+                                          , MemoryManager* const manager)
 {
     // Get the current position
     int curPos = ftell((FILE*)theFile);
     if (curPos == -1)
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotGetSize);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotGetSize, manager);
 
     return (unsigned int)curPos;
 }
 
-void XMLPlatformUtils::closeFile(FileHandle theFile)
+void XMLPlatformUtils::closeFile(FileHandle theFile
+                                 , MemoryManager* const manager)
 {
     if (fclose((FILE*)theFile))
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotCloseFile);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotCloseFile, manager);
 }
 
-unsigned int XMLPlatformUtils::fileSize(FileHandle theFile)
+unsigned int XMLPlatformUtils::fileSize(FileHandle theFile
+                                        , MemoryManager* const manager)
 {
     // Get the current position
     long int curPos = ftell((FILE*)theFile);
     if (curPos == -1)
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotGetCurPos);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotGetCurPos, manager);
 
     // Seek to the end and save that value for return
 	if (fseek((FILE*)theFile, 0, SEEK_END))
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotSeekToEnd);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotSeekToEnd, manager);
 
     long int retVal = ftell((FILE*)theFile);
     if (retVal == -1)
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotSeekToEnd);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotSeekToEnd, manager);
 
     // And put the pointer back
     if (fseek((FILE*)theFile, curPos, SEEK_SET))
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotSeekToPos);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotSeekToPos, manager);
 
     return (unsigned int)retVal;
 }
 
-FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName)
+FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName
+                                      , MemoryManager* const manager)
 {
-    const char* tmpFileName = XMLString::transcode(fileName, fgMemoryManager);
-    ArrayJanitor<char> janText((char*)tmpFileName, fgMemoryManager);
+    const char* tmpFileName = XMLString::transcode(fileName, manager);
+    ArrayJanitor<char> janText((char*)tmpFileName, manager);
     FileHandle retVal = (FILE*)fopen(tmpFileName , "rb");
 
     if (retVal == NULL)
@@ -267,7 +205,8 @@ FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName)
     return retVal;
 }
 
-FileHandle XMLPlatformUtils::openFile(const char* const fileName)
+FileHandle XMLPlatformUtils::openFile(const char* const fileName
+                                      , MemoryManager* const manager)
 {
     FileHandle retVal = (FILE*)fopen(fileName, "rb");
 
@@ -277,33 +216,36 @@ FileHandle XMLPlatformUtils::openFile(const char* const fileName)
     return retVal;
 }
 
-FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName)
+FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName
+                                             , MemoryManager* const manager)
 {
-    const char* tmpFileName = XMLString::transcode(fileName, fgMemoryManager);
-    ArrayJanitor<char> janText((char*)tmpFileName, fgMemoryManager);
+    const char* tmpFileName = XMLString::transcode(fileName, manager);
+    ArrayJanitor<char> janText((char*)tmpFileName, manager);
     return fopen( tmpFileName , "wb" );
 }
 
-FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName)
+FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName
+                                             , MemoryManager* const manager)
 {
     return fopen( fileName , "wb" );
 }
 
-FileHandle XMLPlatformUtils::openStdInHandle()
+FileHandle XMLPlatformUtils::openStdInHandle(MemoryManager* const manager)
 {
 	return (FileHandle)fdopen(dup(0), "rb");
 }
 
-unsigned int XMLPlatformUtils::readFileBuffer(FileHandle           theFile,
-											  const unsigned int   toRead,
-											  XMLByte* const       toFill)
+unsigned int XMLPlatformUtils::readFileBuffer(FileHandle            theFile,
+											  const unsigned int    toRead,
+											  XMLByte* const        toFill
+                                              , MemoryManager* const manager)
 {
     size_t noOfItemsRead = fread((void*)toFill, 1, toRead, (FILE*)theFile);
 
     if(ferror((FILE*)theFile))
     {
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotReadFromFile);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotReadFromFile, manager);
     }
 
     return (unsigned int)noOfItemsRead;
@@ -312,7 +254,8 @@ unsigned int XMLPlatformUtils::readFileBuffer(FileHandle           theFile,
 void
 XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
                                    , long                  toWrite
-                                   , const XMLByte* const  toFlush)                                   
+                                   , const XMLByte* const  toFlush
+                                   , MemoryManager* const  manager)                                   
 {
     if (!theFile        ||
         (toWrite <= 0 ) ||
@@ -328,7 +271,7 @@ XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
 
         if(ferror((FILE*)theFile))
         {
-            ThrowXML(XMLPlatformUtilsException, XMLExcepts::File_CouldNotWriteToFile);
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::File_CouldNotWriteToFile, manager);
         }
 
         if (bytesWritten < toWrite) //incomplete write
@@ -344,11 +287,12 @@ XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
     return;
 }
 
-void XMLPlatformUtils::resetFile(FileHandle theFile)
+void XMLPlatformUtils::resetFile(FileHandle theFile
+                                 , MemoryManager* const manager)
 {
     if (fseek((FILE*)theFile, 0, SEEK_SET))
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotResetFile);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotResetFile, manager);
 }
 
 // ---------------------------------------------------------------------------
@@ -362,29 +306,30 @@ XMLCh* XMLPlatformUtils::getFullPath(const XMLCh* const srcPath,
     //  so we know that its not some pathological freaky path. It comes in
     //  in native format, and goes out as Unicode always
     //
-    char* newSrc = XMLString::transcode(srcPath, fgMemoryManager);
-    ArrayJanitor<char> janText(newSrc, fgMemoryManager);
+    char* newSrc = XMLString::transcode(srcPath, manager);
+    ArrayJanitor<char> janText(newSrc, manager);
 
     // Use a local buffer that is big enough for the largest legal path
-	 // Without the *3 we get exceptions with gcc on OpenServer 5.0.5/6 when 
-	 // relative paths are passed in
-    char *absPath = (char*) fgMemoryManager->allocate
+    // Without the *3 we get exceptions with gcc on OpenServer 5.0.5/6 when 
+    // relative paths are passed in
+    char *absPath = (char*) manager->allocate
     (
         (pathconf(newSrc, _PC_PATH_MAX)*3) * sizeof(char)
     );//new char[pathconf(newSrc, _PC_PATH_MAX)*3];
-    ArrayJanitor<char> janText2(absPath, fgMemoryManager);
+    ArrayJanitor<char> janText2(absPath, manager);
     // Get the absolute path
     char* retPath = realpath(newSrc, absPath);
 
     if (!retPath)
     {
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotGetBasePathName);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotGetBasePathName, manager);
     }
     return XMLString::transcode(absPath, manager);
 }
 
-bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck)
+bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck
+                                  , MemoryManager* const manager)
 {
     // Check for pathological case of empty path
     if (!toCheck[0])
@@ -404,13 +349,13 @@ bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck)
 
 XMLCh* XMLPlatformUtils::getCurrentDirectory(MemoryManager* const manager)
 {
-    char  dirBuf[PATH_MAX + 1];
+    char  dirBuf[PATH_MAX + 2];
     char  *curDir = getcwd(&dirBuf[0], PATH_MAX + 1);
 
     if (!curDir)
     {
-        ThrowXML(XMLPlatformUtilsException,
-                 XMLExcepts::File_CouldNotGetBasePathName);
+        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                 XMLExcepts::File_CouldNotGetBasePathName, manager);
     }
 
     return XMLString::transcode(curDir, manager);
@@ -438,7 +383,9 @@ unsigned long XMLPlatformUtils::getCurrentMillis()
 // ---------------------------------------------------------------------------
 #if !defined (APP_NO_THREADS)
 
-static pthread_mutex_t* gAtomicOpMutex = 0;
+typedef XMLHolder<pthread_mutex_t>  MutexHolderType;
+
+static MutexHolderType* gAtomicOpMutex = 0;
 
 // ---------------------------------------------------------------------------
 //  XMLPlatformUtils: Platform init method
@@ -450,9 +397,9 @@ void XMLPlatformUtils::platformInit()
     // Normally, mutexes are created on first use, but there is a
     // circular dependency between compareAndExchange() and
     // mutex creation that must be broken.
-	gAtomicOpMutex = new pthread_mutex_t;
+	gAtomicOpMutex = new (fgMemoryManager) MutexHolderType;
 
-	if (pthread_mutex_init(gAtomicOpMutex, NULL))
+	if (pthread_mutex_init(&gAtomicOpMutex->fInstance, NULL))
 	{
 		delete gAtomicOpMutex;
 		gAtomicOpMutex = 0;
@@ -469,20 +416,22 @@ public:
 	pthread_mutex_t   mutex;
 	int               recursionCount;
 	pthread_t         tid;
+    MemoryManager* const    fMemoryManager;
 
-	RecursiveMutex() {
+	RecursiveMutex(MemoryManager* manager) :
+        mutex(),
+        recursionCount(0),
+        tid(0),
+        fMemoryManager(manager) {
 		if (pthread_mutex_init(&mutex, NULL))
-			ThrowXML(XMLPlatformUtilsException,
-					 XMLExcepts::Mutex_CouldNotCreate);
-		recursionCount = 0;
-		tid = 0;
-	};
+			XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
+	}
 
 	~RecursiveMutex() {
 		if (pthread_mutex_destroy(&mutex))
-			ThrowXML(XMLPlatformUtilsException,
-					 XMLExcepts::Mutex_CouldNotDestroy);
-	};
+			ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+					 XMLExcepts::Mutex_CouldNotDestroy, fMemoryManager);
+	}
 
 	void lock() {
 		if (pthread_equal(tid, pthread_self()))
@@ -491,27 +440,25 @@ public:
 			return;
 		}
 		if (pthread_mutex_lock(&mutex) != 0)
-			ThrowXML(XMLPlatformUtilsException,
-					 XMLExcepts::Mutex_CouldNotLock);
+			XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
 		tid = pthread_self();
 		recursionCount = 1;
-	};
+	}
 
 	void unlock() {
 		if (--recursionCount > 0)
 			return;
 
 		if (pthread_mutex_unlock(&mutex) != 0)
-			ThrowXML(XMLPlatformUtilsException,
-					 XMLExcepts::Mutex_CouldNotUnlock);
+			XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
 		tid = 0;
-	};
+	}
 };
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager* manager)
 {
-	return new RecursiveMutex;
-};
+	return new (manager) RecursiveMutex(manager);
+}
 
 void XMLPlatformUtils::closeMutex(void* const mtxHandle)
 {
@@ -520,7 +467,7 @@ void XMLPlatformUtils::closeMutex(void* const mtxHandle)
 
 	RecursiveMutex *rm = (RecursiveMutex *)mtxHandle;
 	delete rm;
-};
+}
 
 void XMLPlatformUtils::lockMutex(void* const mtxHandle)
 {
@@ -551,14 +498,14 @@ void* XMLPlatformUtils::compareAndSwap(void**              toFill,
 									   const void* const   newValue,
 									   const void* const   toCompare)
 {
-	if (pthread_mutex_lock(gAtomicOpMutex))
+	if (pthread_mutex_lock(&gAtomicOpMutex->fInstance))
 		panic(PanicHandler::Panic_SynchronizationErr);
 
 	void *retVal = *toFill;
 	if (*toFill == toCompare)
 		*toFill = (void *)newValue;
 
-	if (pthread_mutex_unlock(gAtomicOpMutex))
+	if (pthread_mutex_unlock(&gAtomicOpMutex->fInstance))
 		panic(PanicHandler::Panic_SynchronizationErr);
 
 	return retVal;
@@ -566,12 +513,12 @@ void* XMLPlatformUtils::compareAndSwap(void**              toFill,
 
 int XMLPlatformUtils::atomicIncrement(int &location)
 {
-	if (pthread_mutex_lock(gAtomicOpMutex))
+	if (pthread_mutex_lock(&gAtomicOpMutex->fInstance))
 		panic(PanicHandler::Panic_SynchronizationErr);
 
 	int tmp = ++location;
 
-	if (pthread_mutex_unlock(gAtomicOpMutex))
+	if (pthread_mutex_unlock(&gAtomicOpMutex->fInstance))
 		panic(PanicHandler::Panic_SynchronizationErr);
 
 	return tmp;
@@ -579,12 +526,12 @@ int XMLPlatformUtils::atomicIncrement(int &location)
 
 int XMLPlatformUtils::atomicDecrement(int &location)
 {
-	if (pthread_mutex_lock(gAtomicOpMutex))
+	if (pthread_mutex_lock(&gAtomicOpMutex->fInstance))
 		panic(PanicHandler::Panic_SynchronizationErr);
 
 	int tmp = --location;
 
-	if (pthread_mutex_unlock( gAtomicOpMutex))
+	if (pthread_mutex_unlock( &gAtomicOpMutex->fInstance))
 		panic(PanicHandler::Panic_SynchronizationErr);
 
 	return tmp;
@@ -607,20 +554,20 @@ void XMLPlatformUtils::platformInit()
 // -----------------------------------------------------------------------
 //  Mutex- and atomic operation methods
 // -----------------------------------------------------------------------
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager*)
 {
 	return 0;
 }
 
-void XMLPlatformUtils::closeMutex(void* const mtxHandle)
+void XMLPlatformUtils::closeMutex(void* const)
 {
 }
 
-void XMLPlatformUtils::lockMutex(void* const mtxHandle)
+void XMLPlatformUtils::lockMutex(void* const)
 {
 }
 
-void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
+void XMLPlatformUtils::unlockMutex(void* const)
 {
 }
 
@@ -653,7 +600,7 @@ int XMLPlatformUtils::atomicDecrement(int &location)
 void XMLPlatformUtils::platformTerm()
 {
 #if !defined (APP_NO_THREADS)
-	pthread_mutex_destroy(gAtomicOpMutex);
+	pthread_mutex_destroy(&gAtomicOpMutex->fInstance);
 	delete gAtomicOpMutex;
 	gAtomicOpMutex = 0;
 #else
