@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: SolarisPlatformUtils.cpp,v 1.25 2004/01/29 11:51:20 cargilld Exp $
+ * $Id: SolarisPlatformUtils.cpp 180016 2005-06-04 19:49:30Z jberry $
  */
 
 
@@ -89,6 +49,7 @@
 #include    <xercesc/util/PlatformUtils.hpp>
 #include    <xercesc/util/RuntimeException.hpp>
 #include    <xercesc/util/Mutexes.hpp>
+#include    <xercesc/util/XMLHolder.hpp>
 #include    <xercesc/util/XMLString.hpp>
 #include    <xercesc/util/XMLUniDefs.hpp>
 #include    <xercesc/util/XMLUni.hpp>
@@ -110,7 +71,9 @@
 #endif
 
 
-#if defined (XML_USE_NETACCESSOR_SOCKET)
+#if defined (XML_USE_NETACCESSOR_LIBWWW)
+    #include <xercesc/util/NetAccessors/libWWW/LibWWWNetAccessor.hpp>
+#elif defined (XML_USE_NETACCESSOR_SOCKET)
     #include <xercesc/util/NetAccessors/Socket/SocketNetAccessor.hpp>
 #endif
 
@@ -127,8 +90,10 @@ XERCES_CPP_NAMESPACE_BEGIN
 
 XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 {
-#if defined (XML_USE_NETACCESSOR_SOCKET)
-    return new SocketNetAccessor();
+#if defined (XML_USE_NETACCESSOR_LIBWWW)
+    return new (fgMemoryManager) LibWWWNetAccessor();
+#elif defined (XML_USE_NETACCESSOR_SOCKET)
+    return new (fgMemoryManager) SocketNetAccessor();
 #else
     return 0;
 #endif
@@ -147,11 +112,11 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
     try
     {
 #if defined (XML_USE_ICU_MESSAGELOADER)
-        retVal = new ICUMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) ICUMsgLoader(msgDomain);
 #elif defined (XML_USE_ICONV_MESSAGELOADER)
-        retVal = new MsgCatalogLoader(msgDomain);
+        retVal = new (fgMemoryManager) MsgCatalogLoader(msgDomain);
 #else
-        retVal = new InMemMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) InMemMsgLoader(msgDomain);
 #endif
     }
     catch(const OutOfMemoryException&)
@@ -176,15 +141,15 @@ XMLTransService* XMLPlatformUtils::makeTransService()
 
 #if defined (XML_USE_ICU_TRANSCODER)
 {
-    return new ICUTransService;
+    return new (fgMemoryManager) ICUTransService;
 }
 #elif defined (XML_USE_ICONV_TRANSCODER)
 {
-    return new IconvTransService;
+    return new (fgMemoryManager) IconvTransService;
 }
 #else // Use Native transcoding service
 {
-    return new IconvTransService;
+    return new (fgMemoryManager) IconvTransService;
 
 }
 #endif
@@ -251,11 +216,7 @@ unsigned int XMLPlatformUtils::fileSize(FileHandle theFile
 FileHandle XMLPlatformUtils::openFile(const char* const fileName
                                       , MemoryManager* const manager)
 {
-    int retVal = open( fileName , O_RDONLY | O_LARGEFILE);
-
-    if (retVal == -1)
-        return 0;
-    return (FileHandle)retVal;
+    return (FileHandle) open( fileName , O_RDONLY | O_LARGEFILE);
 }
 
 FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName
@@ -263,11 +224,7 @@ FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName
 {
     const char* tmpFileName = XMLString::transcode(fileName, manager);
     ArrayJanitor<char> janText((char*)tmpFileName, manager);
-    int retVal = open( tmpFileName , O_RDONLY | O_LARGEFILE);
-
-    if (retVal == -1)
-        return 0;
-    return (FileHandle)retVal;
+    return (FileHandle) open( tmpFileName , O_RDONLY | O_LARGEFILE); 
 }
 
 FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName
@@ -275,13 +232,13 @@ FileHandle XMLPlatformUtils::openFileToWrite(const XMLCh* const fileName
 {
     const char* tmpFileName = XMLString::transcode(fileName, manager);
     ArrayJanitor<char> janText((char*)tmpFileName, manager);
-    return (FileHandle)open( tmpFileName , O_WRONLY | O_CREAT | O_LARGEFILE, 0666);
+    return (FileHandle)open( tmpFileName , O_WRONLY | O_CREAT | O_TRUNC | O_LARGEFILE, 0666);
 }
 
 FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName
                                              , MemoryManager* const manager)
 {
-    return (FileHandle)open( fileName , O_WRONLY | O_CREAT | O_LARGEFILE, 0666);
+    return (FileHandle)open( fileName , O_WRONLY | O_CREAT | O_TRUNC | O_LARGEFILE, 0666);
 }
 
 unsigned int
@@ -433,7 +390,9 @@ unsigned long XMLPlatformUtils::getCurrentMillis()
 //  XMLPlatformUtils: Platform init method
 // ---------------------------------------------------------------------------
 
-static pthread_mutex_t* gAtomicOpMutex =0 ;
+typedef XMLHolder<pthread_mutex_t>  MutexHolderType;
+
+static MutexHolderType* gAtomicOpMutex = 0;
 
 void XMLPlatformUtils::platformInit()
 {
@@ -445,42 +404,41 @@ void XMLPlatformUtils::platformInit()
     // circular dependency between compareAndExchange() and
     // mutex creation that must be broken.
 
-    gAtomicOpMutex = new pthread_mutex_t;
+    gAtomicOpMutex = new (fgMemoryManager) MutexHolderType;
 
 #if defined(XML_USE_DCE)
-    if (pthread_mutex_init(gAtomicOpMutex, pthread_mutexattr_default)) {
-	delete gAtomicOpMutex;
-	gAtomicOpMutex = 0;
-        panic( PanicHandler::Panic_SystemInit );
-    }
+    if (pthread_mutex_init(&gAtomicOpMutex->fInstance, pthread_mutexattr_default)) {
 #else // XML_USE_DCE
-    if (pthread_mutex_init(gAtomicOpMutex, NULL)) {
-	delete gAtomicOpMutex;
-	gAtomicOpMutex = 0;
+    if (pthread_mutex_init(&gAtomicOpMutex->fInstance, NULL)) {
+#endif // XML_USE_DCE
+	    delete gAtomicOpMutex;
+	    gAtomicOpMutex = 0;
         panic( PanicHandler::Panic_SystemInit );
     }
-#endif // XML_USE_DCE
 }
 
 #ifndef XML_USE_DCE
 // inlining the class with dce threading causes segmentation fault
-class  RecursiveMutex
+class  RecursiveMutex : public XMemory
 {
 public:
-    pthread_mutex_t   mutex;
-    int               recursionCount;
-    pthread_t         tid;
+    pthread_mutex_t         mutex;
+    int                     recursionCount;
+    pthread_t               tid;
+    MemoryManager* const    fMemoryManager;
 
-    RecursiveMutex() {
+    RecursiveMutex(MemoryManager* manager) :
+        mutex(),
+        recursionCount(0),
+        tid(0),
+        fMemoryManager(manager) {
                if (pthread_mutex_init(&mutex, NULL))
-                   ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotCreate, XMLPlatformUtils::fgMemoryManager);
-                       recursionCount = 0;
-                       tid = 0;
+                   XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
                      }
 
     ~RecursiveMutex() {
             if (pthread_mutex_destroy(&mutex))
-                ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotDestroy, XMLPlatformUtils::fgMemoryManager);
+                ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotDestroy, fMemoryManager);
                       }
 
      void lock()      {
@@ -490,7 +448,7 @@ public:
                   return;
               }
               if (pthread_mutex_lock(&mutex) != 0)
-                  ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotLock, XMLPlatformUtils::fgMemoryManager);
+                  XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
               tid = pthread_self();
               recursionCount = 1;
               }
@@ -501,33 +459,33 @@ public:
                               return;
 
               if (pthread_mutex_unlock(&mutex) != 0)
-                  ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotUnlock, XMLPlatformUtils::fgMemoryManager);
+                  XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
                           tid = 0;
                        }
    };
 #endif // ifndef XML_USE_DCE
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager* manager)
 {
 #if defined(XML_USE_DCE)
-    pthread_mutex_t* mutex = new pthread_mutex_t;
-    if (mutex ==  NULL)
+
+    MutexHolderType* const  holder = new (manager) MutexHolderType;
+
+    if (holder ==  NULL)
     {
-        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                 XMLExcepts::Mutex_CouldNotCreate, fgMemoryManager);
+        panic(PanicHandler::Panic_MutexErr);
     }
     pthread_mutexattr_t attr;
     pthread_mutexattr_create(&attr);
     pthread_mutexattr_setkind_np(&attr, MUTEX_RECURSIVE_NP);
-    if (pthread_mutex_init(mutex, attr))
+    if (pthread_mutex_init(&holder->fInstance, attr))
     {
-        ThrowXMLwithMemMgr(XMLPlatformUtilsException,
-                 XMLExcepts::Mutex_CouldNotCreate, fgMemoryManager);
+        panic(PanicHandler::Panic_MutexErr);
     }
     pthread_mutexattr_delete(&attr);
-    return (void*)(mutex);
+    return holder;
 #else
-    return new RecursiveMutex;
+    return new (manager) RecursiveMutex(manager);
 #endif
 }
 
@@ -537,8 +495,8 @@ void XMLPlatformUtils::closeMutex(void* const mtxHandle)
     if (mtxHandle == NULL)
         return;
 #if defined(XML_USE_DCE)
-    pthread_mutex_t *rm = (pthread_mutex_t *)mtxHandle;
-    pthread_mutex_destroy(rm);
+    MutexHolderType *rm = MutexHolderType::castTo(mtxHandle);
+    pthread_mutex_destroy(&rm->fInstance);
 #else
     RecursiveMutex *rm = (RecursiveMutex *)mtxHandle;
 #endif
@@ -551,8 +509,9 @@ void XMLPlatformUtils::lockMutex(void* const mtxHandle)
     if (mtxHandle == NULL)
         return;
 #if defined(XML_USE_DCE)
-    pthread_mutex_t *rm = (pthread_mutex_t *)mtxHandle;
-    pthread_mutex_lock(rm);
+    MutexHolderType *rm = MutexHolderType::castTo(mtxHandle);
+
+    pthread_mutex_lock(&rm->fInstance);
 #else
     RecursiveMutex *rm = (RecursiveMutex *)mtxHandle;
     rm->lock();
@@ -564,8 +523,9 @@ void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
     if (mtxHandle == NULL)
         return;
 #if defined(XML_USE_DCE)
-    pthread_mutex_t *rm = (pthread_mutex_t *)mtxHandle;
-    pthread_mutex_unlock(rm);
+    MutexHolderType *rm = MutexHolderType::castTo(mtxHandle);
+
+    pthread_mutex_unlock(&rm->fInstance);
 #else
     RecursiveMutex *rm = (RecursiveMutex *)mtxHandle;
     rm->unlock();
@@ -587,14 +547,14 @@ void* XMLPlatformUtils::compareAndSwap ( void**      toFill ,
     // the below calls are temporarily made till the above functions are part of user library
     // Currently its supported only in the kernel mode
 
-    if (pthread_mutex_lock( gAtomicOpMutex))
+    if (pthread_mutex_lock(&gAtomicOpMutex->fInstance))
         panic(PanicHandler::Panic_SynchronizationErr);
 
     void *retVal = *toFill;
     if (*toFill == toCompare)
               *toFill = (void *)newValue;
 
-    if (pthread_mutex_unlock( gAtomicOpMutex))
+    if (pthread_mutex_unlock(&gAtomicOpMutex->fInstance))
         panic(PanicHandler::Panic_SynchronizationErr);
 
     return retVal;
@@ -604,12 +564,12 @@ int XMLPlatformUtils::atomicIncrement(int &location)
 {
     //return (int)atomic_add_32_nv( (uint32_t*)&location, 1);
 
-    if (pthread_mutex_lock( gAtomicOpMutex))
+    if (pthread_mutex_lock(&gAtomicOpMutex->fInstance))
         panic(PanicHandler::Panic_SynchronizationErr);
 
     int tmp = ++location;
 
-    if (pthread_mutex_unlock( gAtomicOpMutex))
+    if (pthread_mutex_unlock(&gAtomicOpMutex->fInstance))
         panic(PanicHandler::Panic_SynchronizationErr);
 
     return tmp;
@@ -618,12 +578,12 @@ int XMLPlatformUtils::atomicDecrement(int &location)
 {
     //return (int)atomic_add_32_nv( (uint32_t*)&location, -1);
 
-    if (pthread_mutex_lock( gAtomicOpMutex))
+    if (pthread_mutex_lock(&gAtomicOpMutex->fInstance))
         panic(PanicHandler::Panic_SynchronizationErr);
 
     int tmp = --location;
 
-    if (pthread_mutex_unlock( gAtomicOpMutex))
+    if (pthread_mutex_unlock(&gAtomicOpMutex->fInstance))
         panic(PanicHandler::Panic_SynchronizationErr);
 
     return tmp;
@@ -635,20 +595,20 @@ void XMLPlatformUtils::platformInit()
 {
 }
 
-void XMLPlatformUtils::closeMutex(void* const mtxHandle)
+void XMLPlatformUtils::closeMutex(void* const)
 {
 }
 
-void XMLPlatformUtils::lockMutex(void* const mtxHandle)
+void XMLPlatformUtils::lockMutex(void* const)
 {
 }
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager*)
 {
         return 0;
 }
 
-void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
+void XMLPlatformUtils::unlockMutex(void* const)
 {
 }
 
@@ -684,7 +644,7 @@ FileHandle XMLPlatformUtils::openStdInHandle(MemoryManager* const manager)
 void XMLPlatformUtils::platformTerm()
 {
 #if !defined(APP_NO_THREADS)
-	pthread_mutex_destroy(gAtomicOpMutex);
+	pthread_mutex_destroy(&gAtomicOpMutex->fInstance);
     delete gAtomicOpMutex;
 	gAtomicOpMutex = 0;
 #endif
