@@ -1,116 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2000 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2000,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: TandemPlatformUtils.cpp,v $
- * Revision 1.12  2003/12/17 15:16:10  cargilld
- * Platform update for memory management so that the static memory manager (one
- * used to call Initialize) is only for static data.
- *
- * Revision 1.11  2003/12/17 13:58:03  cargilld
- * Platform update for memory management so that the static memory manager (one
- * used to call Initialize) is only for static data.
- *
- * Revision 1.10  2003/10/01 16:32:40  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.9  2003/05/15 18:37:49  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.8  2003/04/24 02:58:31  peiyongz
- * Logical Path Resolution
- *
- * Revision 1.7  2003/03/09 17:00:11  peiyongz
- * PanicHandler
- *
- * Revision 1.6  2003/02/05 18:29:27  tng
- * [Bug 13437] Incorrect memory management in XXXPlatformUtils.cpp.
- *
- * Revision 1.5  2003/01/09 15:30:39  tng
- * Missing panic function in Tandem
- *
- * Revision 1.4  2002/12/12 16:29:30  peiyongz
- * loadAMsgSet() added
- *
- * Revision 1.3  2002/11/04 15:13:01  tng
- * C++ Namespace Support.
- *
- * Revision 1.2  2002/05/21 20:31:48  tng
- * Minor update: Remove obsolete code
- *
- * Revision 1.1.1.1  2002/02/01 22:22:26  peiyongz
- * sane_include
- *
- * Revision 1.4  2000/03/02 21:10:38  abagchi
- * Added empty function platformTerm()
- *
- * Revision 1.3  2000/03/02 19:55:32  roddey
- * This checkin includes many changes done while waiting for the
- * 1.1.0 code to be finished. I can't list them all here, but a list is
- * available elsewhere.
- *
- * Revision 1.2  2000/02/06 07:48:30  rahulj
- * Year 2K copyright swat.
- *
- * Revision 1.1.1.1  1999/11/09 01:06:24  twl
- * Initial checkin
- *
- * Revision 1.2  1999/11/08 20:45:32  rahul
- * Swat for adding in Product name and CVS comment log variable.
- *
+ * $Id: TandemPlatformUtils.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -131,6 +36,7 @@
 #include    <sys/timeb.h>
 #include    <string.h>
 #include    <xercesc/util/OutOfMemoryException.hpp>
+#include    <xercesc/util/XMLHolder.hpp>
 
 #if defined (XML_USE_ICU_MESSAGELOADER)
     #include <xercesc/util/MsgLoaders/ICU/ICUMsgLoader.hpp>
@@ -160,11 +66,11 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
     try
     {
 #if defined (XML_USE_ICU_MESSAGELOADER)
-        retVal = new ICUMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) ICUMsgLoader(msgDomain);
 #elif defined (XML_USE_ICONV_MESSAGELOADER)
-        retVal = new MsgCatalogLoader(msgDomain);
+        retVal = new (fgMemoryManager) MsgCatalogLoader(msgDomain);
 #else
-        retVal = new InMemMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) InMemMsgLoader(msgDomain);
 #endif
     }
     catch(const OutOfMemoryException&)
@@ -349,49 +255,60 @@ unsigned long XMLPlatformUtils::getCurrentMillis()
 // -----------------------------------------------------------------------
 //  Mutex methods
 // -----------------------------------------------------------------------
+
+typedef XMLHolder<pthread_mutex_t>  MutexHolderType;
+
 void XMLPlatformUtils::closeMutex(void* const mtxHandle)
 {
-    if (mtxHandle == NULL)
-        return;
-    if (pthread_mutex_destroy( (pthread_mutex_t*)mtxHandle))
+    if (mtxHandle != NULL)
     {
-        throw XMLPlatformUtilsException("Could not destroy a mutex");
+        MutexHolderType* const  holder =
+            MutexHolderType::castTo(mtxHandle);
+
+        if (pthread_mutex_destroy(&holder->fInstance))
+        {
+            delete holder;
+
+            ThrowXMLwithMemMgr(XMLPlatformUtilsException,
+                     XMLExcepts::Mutex_CouldNotDestroy, fgMemoryManager);
+        }
+        delete holder;
     }
-    if ( (pthread_mutex_t*)mtxHandle)
-        delete (pthread_mutex_t*) mtxHandle;
 }
+
 void XMLPlatformUtils::lockMutex(void* const mtxHandle)
 {
-    if (mtxHandle == NULL)
-        return;
-    if (pthread_mutex_lock( (pthread_mutex_t*)mtxHandle))
+    if (mtxHandle != NULL)
     {
-        throw XMLPlatformUtilsException("Could not lock a mutex");
+        if (pthread_mutex_lock(&MutexHolderType::castTo(mtxHandle)->fInstance))
+        {
+            panic(PanicHandler::Panic_MutexErr);
+        }
     }
-
 }
-void* XMLPlatformUtils::makeMutex()
+
+void* XMLPlatformUtils::makeMutex(MemoryManager* manager)
 {
-    pthread_mutex_t* mutex = new pthread_mutex_t;
-    if (mutex == NULL)
+    MutexHolderType* const  holder = new (manager) MutexHolderType;
+
+    if (pthread_mutex_init(&holder->fInstance, NULL))
     {
-        throw XMLPlatformUtilsException("Could not initialize a mutex");
+        delete holder;
+
+        panic(PanicHandler::Panic_MutexErr);
     }
 
-    if (pthread_mutex_init(mutex, NULL))
-    {
-        throw XMLPlatformUtilsException("Could not create a mutex");
-    }
-
-    return (void*)(mutex);
+    return holder;
 }
+
 void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
 {
-    if (mtxHandle == NULL)
-        return;
-    if (pthread_mutex_unlock( (pthread_mutex_t*)mtxHandle))
+    if (mtxHandle != NULL)
     {
-        throw XMLPlatformUtilsException("Could not unlock a mutex");
+        if (pthread_mutex_unlock(&MutexHolderType::castTo(mtxHandle)->fInstance))
+        {
+            panic(PanicHandler::Panic_MutexErr);
+        }
     }
 }
 
