@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: Tru64PlatformUtils.cpp,v 1.17 2004/01/29 11:51:21 cargilld Exp $
+ * $Id: Tru64PlatformUtils.cpp 180016 2005-06-04 19:49:30Z jberry $
  */
 
 // ---------------------------------------------------------------------------
@@ -75,6 +35,7 @@
 #include    <xercesc/util/PlatformUtils.hpp>
 #include    <xercesc/util/RuntimeException.hpp>
 #include    <xercesc/util/Mutexes.hpp>
+#include    <xercesc/util/XMLHolder.hpp>
 #include    <xercesc/util/XMLString.hpp>
 #include    <xercesc/util/XMLUni.hpp>
 #include    <xercesc/util/XMLUniDefs.hpp>
@@ -123,11 +84,11 @@ XERCES_CPP_NAMESPACE_BEGIN
 XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 #if defined (XML_USE_NETACCESSOR_LIBWWW)
 {
-    return new LibWWWNetAccessor();
+    return new (fgMemoryManager) LibWWWNetAccessor();
 }
 #elif defined (XML_USE_NETACCESSOR_SOCKET)
 {
-    return new SocketNetAccessor();
+    return new (fgMemoryManager) SocketNetAccessor();
 }
 #else
 {
@@ -146,11 +107,11 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
   try
   {
 #if defined (XML_USE_ICU_MESSAGELOADER)
-    retVal = new ICUMsgLoader(msgDomain);
+    retVal = new (fgMemoryManager) ICUMsgLoader(msgDomain);
 #elif defined (XML_USE_ICONV_MESSAGELOADER)
-    retVal = new MsgCatalogLoader(msgDomain);
+    retVal = new (fgMemoryManager) MsgCatalogLoader(msgDomain);
 #else
-    retVal = new InMemMsgLoader(msgDomain);
+    retVal = new (fgMemoryManager) InMemMsgLoader(msgDomain);
 #endif
   }
   catch(const OutOfMemoryException&)
@@ -174,15 +135,15 @@ XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
 XMLTransService* XMLPlatformUtils::makeTransService()
 #if defined (XML_USE_ICU_TRANSCODER)
 {
-  return new ICUTransService;
+  return new (fgMemoryManager) ICUTransService;
 }
 #elif defined (XML_USE_ICONV_TRANSCODER)
 {
-  return new IconvTransService;
+  return new (fgMemoryManager) IconvTransService;
 }
 #else // Use Native transcoding service
 {
-  return new IconvTransService;
+  return new (fgMemoryManager) IconvTransService;
 }
 #endif
 
@@ -427,7 +388,9 @@ unsigned long XMLPlatformUtils::getCurrentMillis()
 //  XMLPlatformUtils: Platform init method
 // ---------------------------------------------------------------------------
 
-static pthread_mutex_t* gAtomicOpMutex =0 ;
+typedef XMLHolder<pthread_mutex_t>  MutexHolderType;
+
+static MutexHolderType* gAtomicOpMutex = 0;
 
 void XMLPlatformUtils::platformInit()
 {
@@ -439,9 +402,10 @@ void XMLPlatformUtils::platformInit()
   // circular dependency between compareAndExchange() and
   // mutex creation that must be broken.
 
-  gAtomicOpMutex = new pthread_mutex_t;	
+  gAtomicOpMutex = new (fgMemoryManager) MutexHolderType;
 
-  if (pthread_mutex_init(gAtomicOpMutex, NULL)) {
+
+  if (pthread_mutex_init(&gAtomicOpMutex->fInstance, NULL)) {
 	delete gAtomicOpMutex;
 	gAtomicOpMutex = 0;
     panic( PanicHandler::Panic_SystemInit );
@@ -460,19 +424,22 @@ public:
   pthread_mutex_t   mutex;
   int               recursionCount;
   pthread_t         tid;
+  MemoryManager* const    fMemoryManager;
 
-  RecursiveMutex()
+  RecursiveMutex(MemoryManager* manager) :
+        mutex(),
+        recursionCount(0),
+        tid(0),
+        fMemoryManager(manager)
   {
     if (pthread_mutex_init(&mutex, NULL))
-      ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotCreate, XMLPlatformUtils::fgMemoryManager);
-    recursionCount = 0;
-    tid = 0;
+        XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
   }
 
   ~RecursiveMutex()
   {
     if (pthread_mutex_destroy(&mutex))
-      ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotDestroy, XMLPlatformUtils::fgMemoryManager);
+      ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotDestroy, fMemoryManager);
   }
 
   void lock()
@@ -483,7 +450,7 @@ public:
       return;
     }
     if (pthread_mutex_lock(&mutex) != 0)
-      ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotLock, XMLPlatformUtils::fgMemoryManager);
+        XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
     tid = pthread_self();
     recursionCount = 1;
   }
@@ -495,14 +462,14 @@ public:
       return;
 
     if (pthread_mutex_unlock(&mutex) != 0)
-      ThrowXMLwithMemMgr(XMLPlatformUtilsException, XMLExcepts::Mutex_CouldNotUnlock, XMLPlatformUtils::fgMemoryManager);
+        XMLPlatformUtils::panic(PanicHandler::Panic_MutexErr);
     tid = 0;
   }
 };
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager* manager)
 {
-  return new RecursiveMutex;
+  return new (manager) RecursiveMutex(manager);
 }
 
 
@@ -546,14 +513,14 @@ void* XMLPlatformUtils::compareAndSwap (void** toFill,
   // the below calls are temporarily made till the above functions are part of user library
   // Currently its supported only in the kernel mode
 
-  if (pthread_mutex_lock( gAtomicOpMutex))
+  if (pthread_mutex_lock( &gAtomicOpMutex->fInstance))
     panic(PanicHandler::Panic_SynchronizationErr);
 
   void *retVal = *toFill;
   if (*toFill == toCompare)
     *toFill = (void *)newValue;
 
-  if (pthread_mutex_unlock( gAtomicOpMutex))
+  if (pthread_mutex_unlock( &gAtomicOpMutex->fInstance))
     panic(PanicHandler::Panic_SynchronizationErr);
 
   return retVal;
@@ -563,12 +530,12 @@ int XMLPlatformUtils::atomicIncrement(int &location)
 {
   //return (int)atomic_add_32_nv( (uint32_t*)&location, 1);
 
-  if (pthread_mutex_lock( gAtomicOpMutex))
+  if (pthread_mutex_lock( &gAtomicOpMutex->fInstance))
     panic(PanicHandler::Panic_SynchronizationErr);
 
   int tmp = ++location;
 
-  if (pthread_mutex_unlock( gAtomicOpMutex))
+  if (pthread_mutex_unlock( &gAtomicOpMutex->fInstance))
     panic(PanicHandler::Panic_SynchronizationErr);
 
   return tmp;
@@ -577,12 +544,12 @@ int XMLPlatformUtils::atomicDecrement(int &location)
 {
   //return (int)atomic_add_32_nv( (uint32_t*)&location, -1);
 
-  if (pthread_mutex_lock( gAtomicOpMutex))
+  if (pthread_mutex_lock( &gAtomicOpMutex->fInstance))
     panic(PanicHandler::Panic_SynchronizationErr);
 	
   int tmp = --location;
 
-  if (pthread_mutex_unlock( gAtomicOpMutex))
+  if (pthread_mutex_unlock( &gAtomicOpMutex->fInstance))
     panic(PanicHandler::Panic_SynchronizationErr);
 
   return tmp;
@@ -595,20 +562,20 @@ void XMLPlatformUtils::platformInit()
    // do nothing
 }
 
-void XMLPlatformUtils::closeMutex(void* const mtxHandle)
+void XMLPlatformUtils::closeMutex(void* const)
 {
 }
 
-void XMLPlatformUtils::lockMutex(void* const mtxHandle)
+void XMLPlatformUtils::lockMutex(void* const)
 {
 }
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager*)
 {
   return 0;
 }
 
-void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
+void XMLPlatformUtils::unlockMutex(void* const)
 {
 }
 
@@ -644,7 +611,7 @@ FileHandle XMLPlatformUtils::openStdInHandle(MemoryManager* const manager)
 void XMLPlatformUtils::platformTerm()
 {
 #if !defined (APP_NO_THREADS)
-	pthread_mutex_destroy(gAtomicOpMutex);
+	pthread_mutex_destroy(&gAtomicOpMutex->fInstance);
 	delete gAtomicOpMutex;
 	gAtomicOpMutex = 0;
 #endif
