@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: Win32PlatformUtils.cpp,v 1.25 2004/09/08 13:56:43 peiyongz Exp $
+ * $Id: Win32PlatformUtils.cpp 225514 2005-07-27 14:00:24Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
@@ -24,24 +24,19 @@
 #include <xercesc/util/Janitor.hpp>
 #include <xercesc/util/PlatformUtils.hpp>
 #include <xercesc/util/RuntimeException.hpp>
+#include <xercesc/util/XMemory.hpp>
+#include <xercesc/util/XMLHolder.hpp>
 #include <xercesc/util/XMLExceptMsgs.hpp>
 #include <xercesc/util/XMLString.hpp>
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/XMLUni.hpp>
 #include <xercesc/util/PanicHandler.hpp>
+#include <xercesc/util/OutOfMemoryException.hpp>
 
 #include <windows.h>
 #include <stdio.h>
 #include <stdlib.h>
 
-#ifdef _DEBUG
- #ifdef _MSC_VER
-    #include <crtdbg.h>
- #else
-    #include <assert.h>
- #endif
-#endif
-
 //
 //  These control which transcoding service is used by the Win32 version.
 //  They allow this to be controlled from the build process by just defining
@@ -166,7 +161,7 @@ unsigned int XMLPlatformUtils::fileSize(FileHandle theFile
 }
 
 FileHandle XMLPlatformUtils::openFile(const char* const fileName
-                                      , MemoryManager* const manager)
+                                      , MemoryManager* const /*manager*/)
 {
     FileHandle retVal = ::CreateFileA
     (
@@ -313,7 +308,7 @@ FileHandle XMLPlatformUtils::openFile(const XMLCh* const fileName
 }
 
 FileHandle XMLPlatformUtils::openFileToWrite(const char* const fileName
-                                             , MemoryManager* const manager)
+                                             , MemoryManager* const /*manager*/)
 {
     FileHandle retVal = ::CreateFileA
     (
@@ -508,8 +503,6 @@ XMLPlatformUtils::writeBufferToFile( FileHandle     const  theFile
         else
             return;
     }
-
-    return;
 }
 
 void XMLPlatformUtils::resetFile(FileHandle theFile
@@ -566,7 +559,7 @@ XMLCh* XMLPlatformUtils::getFullPath(const XMLCh* const srcPath,
 }
 
 bool XMLPlatformUtils::isRelative(const XMLCh* const toCheck
-                                  , MemoryManager* const manager)
+                                  , MemoryManager* const /*manager*/)
 {
     // Check for pathological case of empty path
     if (!toCheck[0])
@@ -648,34 +641,40 @@ unsigned long XMLPlatformUtils::getCurrentMillis()
 }
 
 
+typedef XMLHolder<CRITICAL_SECTION>  MutexHolderType;
+
 
 // ---------------------------------------------------------------------------
 //  Mutex methods
 // ---------------------------------------------------------------------------
 void XMLPlatformUtils::closeMutex(void* const mtxHandle)
 {
-    ::DeleteCriticalSection((LPCRITICAL_SECTION)mtxHandle);
-    delete (CRITICAL_SECTION*)mtxHandle;
+    MutexHolderType* const  holder = MutexHolderType::castTo(mtxHandle);
+
+    ::DeleteCriticalSection(&holder->fInstance);
+    delete holder;
 }
 
 
 void XMLPlatformUtils::lockMutex(void* const mtxHandle)
 {
-    ::EnterCriticalSection((LPCRITICAL_SECTION)mtxHandle);
+    ::EnterCriticalSection(&MutexHolderType::castTo(mtxHandle)->fInstance);
 }
 
 
-void* XMLPlatformUtils::makeMutex()
+void* XMLPlatformUtils::makeMutex(MemoryManager* manager)
 {
-    CRITICAL_SECTION* newCS = new CRITICAL_SECTION;
-    InitializeCriticalSection(newCS);
-    return newCS;
+    MutexHolderType* const  holder = new (manager) MutexHolderType;
+
+    InitializeCriticalSection(&holder->fInstance);
+
+    return holder;
 }
 
 
 void XMLPlatformUtils::unlockMutex(void* const mtxHandle)
 {
-    ::LeaveCriticalSection((LPCRITICAL_SECTION)mtxHandle);
+    ::LeaveCriticalSection(&MutexHolderType::castTo(mtxHandle)->fInstance);
 }
 
 
@@ -755,9 +754,9 @@ int XMLPlatformUtils::atomicDecrement(int &location)
 XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 {
 #if defined (XML_USE_NETACCESSOR_LIBWWW)
-    return new LibWWWNetAccessor();
+    return new (fgMemoryManager) LibWWWNetAccessor();
 #elif defined (XML_USE_NETACCESSOR_WINSOCK)
-    return new WinSockNetAccessor();
+    return new (fgMemoryManager) WinSockNetAccessor();
 #else
     return 0;
 #endif
@@ -771,15 +770,29 @@ XMLNetAccessor* XMLPlatformUtils::makeNetAccessor()
 //
 XMLMsgLoader* XMLPlatformUtils::loadAMsgSet(const XMLCh* const msgDomain)
 {
+    XMLMsgLoader* retVal;
+    try
+    {
 #if defined (XML_USE_INMEM_MESSAGELOADER)
-    return new InMemMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) InMemMsgLoader(msgDomain);
 #elif defined (XML_USE_WIN32_MSGLOADER)
-    return new Win32MsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) Win32MsgLoader(msgDomain);
 #elif defined (XML_USE_ICU_MESSAGELOADER)
-    return new ICUMsgLoader(msgDomain);
+        retVal = new (fgMemoryManager) ICUMsgLoader(msgDomain);
 #else
-    #error You must provide a message loader
+        #error You must provide a message loader
+        return 0;
 #endif
+    }
+    catch(const OutOfMemoryException&)
+    {
+        throw;
+    }
+    catch(...)
+    {
+        panic(PanicHandler::Panic_CantLoadMsgDomain);
+    }
+    return retVal;
 }
 
 
@@ -798,11 +811,11 @@ XMLTransService* XMLPlatformUtils::makeTransService()
     //  to our DLL.
     //
 #if defined (XML_USE_ICU_TRANSCODER)
-    return new ICUTransService;
+    return new (fgMemoryManager) ICUTransService;
 #elif defined (XML_USE_WIN32_TRANSCODER)
-    return new Win32TransService;
+    return new (fgMemoryManager) Win32TransService;
 #elif defined (XML_USE_CYGWIN_TRANSCODER)
-    return new CygwinTransService;
+    return new (fgMemoryManager) CygwinTransService;
 #else
     #error You must provide a transcoding service implementation
 #endif
@@ -814,12 +827,18 @@ XMLTransService* XMLPlatformUtils::makeTransService()
 //  primary jobs here are getting the path to our DLL and to get the
 //  stdout and stderr file handles setup.
 //
+
+//  Enable this code for memeory leak testing
+//#define MEM_LEAK_TESTING
+
+#ifdef MEM_LEAK_TESTING
+    #include <crtdbg.h>
+#endif
+
 void XMLPlatformUtils::platformInit()
 {
 
-#if 0 && defined(_DEBUG)
-    //  Enable this code for memeory leak testing
-
+#ifdef MEM_LEAK_TESTING
    // Send all reports to STDOUT
    _CrtSetReportMode( _CRT_WARN, _CRTDBG_MODE_FILE );
    _CrtSetReportFile( _CRT_WARN, _CRTDBG_FILE_STDOUT );
