@@ -15,72 +15,10 @@
  */
 
 /*
- * $Log: QName.cpp,v $
- * Revision 1.12  2004/09/08 13:56:22  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.11  2003/10/01 16:32:39  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.10  2003/09/25 22:24:28  peiyongz
- * Using writeString/readString
- *
- * Revision 1.9  2003/09/25 15:22:34  peiyongz
- * Implementation of Serialization
- *
- * Revision 1.8  2003/05/16 06:01:52  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.7  2003/05/15 19:04:35  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.6  2002/11/04 15:22:04  tng
- * C++ Namespace Support.
- *
- * Revision 1.5  2002/10/30 21:52:00  tng
- * [Bug 13641] compiler-generated copy-constructor for QName doesn't do the right thing.
- *
- * Revision 1.4  2002/09/24 19:51:24  tng
- * Performance: use XMLString::equals instead of XMLString::compareString
- *
- * Revision 1.3  2002/09/05 16:06:41  tng
- * [Bug 12232] Make operator to be constant.
- *
- * Revision 1.2  2002/04/02 15:31:48  knoaman
- * Modiy QName comparison (operator=).
- *
- * Revision 1.1.1.1  2002/02/01 22:22:11  peiyongz
- * sane_include
- *
- * Revision 1.8  2001/12/06 17:48:36  tng
- * Performance Enhancement.  Added setNPrefix and setNLocalPart methods that allow code to take advantage of the fact that it knows the length of the prefix and local name, when possible.  That can avoid a copy of the prefix into a null-terminated temporary variable before copying into the fPrefix.
- * Also changed the getRawName method so that it would simply return the local part when there is no prefix, instead of allocating another buffer to copy the local part into the fRawName.
- * When there is a prefix, changed the getRawName to copy the prefix and local part into the fRawName using XMLString::moveChars instead of using XMLString::copyString and XMLString::catString.  The catString method has to loop past the prefix portion of the fRawName, which seems like a waste.
- * By Henry Zongaro.
- *
- * Revision 1.7  2001/07/24 18:31:47  knoaman
- * Added support for <group> + extra constraint checking for complexType
- *
- * Revision 1.6  2001/05/11 13:26:28  tng
- * Copyright update.
- *
- * Revision 1.5  2001/04/19 18:17:08  tng
- * Schema: SchemaValidator update, and use QName in Content Model
- *
- * Revision 1.4  2001/03/21 21:56:11  tng
- * Schema: Add Schema Grammar, Schema Validator, and split the DTDValidator into DTDValidator, DTDScanner, and DTDGrammar.
- *
- * Revision 1.3  2001/02/27 14:48:35  tng
- * Schema: Add CMAny and ContentLeafNameTypeVector, by Pei Yong Zhang
- *
- * Revision 1.2  2001/02/26 21:56:15  tng
- * Schema: QName can also be constructed with rawName.
- *
- * Revision 1.1  2001/02/26 19:44:25  tng
- * Schema: add utility class QName, by Pei Yong Zhang.
- *
+ * $Id: QName.cpp 191682 2005-06-21 16:55:38Z cargilld $
  */
 
+#include <xercesc/util/Janitor.hpp>
 #include <xercesc/util/QName.hpp>
 #include <xercesc/util/OutOfMemoryException.hpp>
 
@@ -89,33 +27,35 @@ XERCES_CPP_NAMESPACE_BEGIN
 // ---------------------------------------------------------------------------
 //  QName: Constructors and Destructor
 // ---------------------------------------------------------------------------
-QName::QName(MemoryManager* const manager) :
-
-    fMemoryManager(manager)
-    , fPrefix(0)
-    , fPrefixBufSz(0)
-    , fLocalPart(0)
-    , fLocalPartBufSz(0)
-    , fRawName(0)
-    , fRawNameBufSz(0)
-    , fURIId(0)
+QName::QName(MemoryManager* const manager)
+:fPrefixBufSz(0)
+,fLocalPartBufSz(0)
+,fRawNameBufSz(0)
+,fURIId(0)
+,fPrefix(0)
+,fLocalPart(0)
+,fRawName(0)
+,fMemoryManager(manager)
 {
 }
 
+typedef JanitorMemFunCall<QName>    CleanupType;
+
 QName::QName( const XMLCh* const   prefix
             , const XMLCh* const   localPart
             , const unsigned int   uriId
-            , MemoryManager* const manager) :
-
-    fMemoryManager(manager)
-    , fPrefix(0)
-    , fPrefixBufSz(0)
-    , fLocalPart(0)
-    , fLocalPartBufSz(0)
-    , fRawName(0)
-    , fRawNameBufSz(0)
-    , fURIId(0)
+            , MemoryManager* const manager)
+:fPrefixBufSz(0)
+,fLocalPartBufSz(0)
+,fRawNameBufSz(0)
+,fURIId(0)
+,fPrefix(0)
+,fLocalPart(0)
+,fRawName(0)
+,fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &QName::cleanUp);
+
     try
     {
         //
@@ -126,27 +66,28 @@ QName::QName( const XMLCh* const   prefix
     }
     catch(const OutOfMemoryException&)
     {
+        cleanup.release();
+
         throw;
     }
-    catch(...)
-    {
-        cleanUp();
-    }
+
+    cleanup.release();
 }
 
 QName::QName( const XMLCh* const rawName
             , const unsigned int uriId
-            , MemoryManager* const manager) :
-
-    fMemoryManager(manager)
-    , fPrefix(0)
-    , fPrefixBufSz(0)
-    , fLocalPart(0)
-    , fLocalPartBufSz(0)
-    , fRawName(0)
-    , fRawNameBufSz(0)
-    , fURIId(0)
+            , MemoryManager* const manager)
+:fPrefixBufSz(0)
+,fLocalPartBufSz(0)
+,fRawNameBufSz(0)
+,fURIId(0)
+,fPrefix(0)
+,fLocalPart(0)
+,fRawName(0)
+,fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &QName::cleanUp);
+
     try
     {
         //
@@ -157,12 +98,12 @@ QName::QName( const XMLCh* const rawName
     }
     catch(const OutOfMemoryException&)
     {
+        cleanup.release();
+
         throw;
     }
-    catch(...)
-    {
-        cleanUp();
-    }
+
+    cleanup.release();
 }
 
 QName::~QName()
@@ -173,16 +114,17 @@ QName::~QName()
 // ---------------------------------------------------------------------------
 //  QName: Copy Constructors
 // ---------------------------------------------------------------------------
-QName::QName(const QName& qname) :
-
-    fMemoryManager(qname.fMemoryManager)
-    , fPrefix(0)
-    , fPrefixBufSz(0)
-    , fLocalPart(0)
-    , fLocalPartBufSz(0)
-    , fRawName(0)
-    , fRawNameBufSz(0)
-    , fURIId(0)
+QName::QName(const QName& qname)
+:XSerializable(qname)
+,XMemory(qname)
+,fPrefixBufSz(0)
+,fLocalPartBufSz(0)
+,fRawNameBufSz(0)
+,fURIId(0)
+,fPrefix(0)
+,fLocalPart(0)
+,fRawName(0)
+,fMemoryManager(qname.fMemoryManager)
 {
     unsigned int newLen;
 
@@ -341,35 +283,36 @@ void QName::setName(const XMLCh* const    rawName
                   , const unsigned int    uriId)
 {
     //set the rawName
-    unsigned int newLen;
-
-    newLen = XMLString::stringLen(rawName);
-    if (!fRawNameBufSz || (newLen > fRawNameBufSz))
-    {
-        fMemoryManager->deallocate(fRawName); //delete [] fRawName;
-        fRawNameBufSz = newLen + 8;
-        fRawName = (XMLCh*) fMemoryManager->allocate
-        (
-            (fRawNameBufSz + 1) * sizeof(XMLCh)
-        ); //new XMLCh[fRawNameBufSz + 1];
-    }
-    XMLString::moveChars(fRawName, rawName, newLen + 1);
-
+    unsigned int newLen = XMLString::stringLen(rawName);
     //find out the prefix and localPart from the rawName
     const int colonInd = XMLString::indexOf(rawName, chColon);
+
     if (colonInd >= 0)
     {
+        if (!fRawNameBufSz || (newLen > fRawNameBufSz))
+        {
+            fMemoryManager->deallocate(fRawName); //delete [] fRawName;
+            fRawNameBufSz = newLen + 8;
+            fRawName = (XMLCh*) fMemoryManager->allocate
+            (
+                (fRawNameBufSz + 1) * sizeof(XMLCh)
+            ); //new XMLCh[fRawNameBufSz + 1];
+        }
+        XMLString::moveChars(fRawName, rawName, newLen + 1);
         setNPrefix(rawName, colonInd);
     }
-     else
+    else
     {
         // No colon, so we just have a name with no prefix
         setPrefix(XMLUni::fgZeroLenString);
+
+        // And clean up any QName and leave it undone until/if asked for again
+        if (fRawName)
+            *fRawName = 0;
     }
 
     setNLocalPart(&rawName[colonInd+1], newLen-colonInd-1);
 
-
     // And finally store the URI id parameter
     fURIId = uriId;
 }
