@@ -14,60 +14,8 @@
  * limitations under the License.
  */
 
-/**
- * $Log: RefHash3KeysIdPool.c,v $
- * Revision 1.13  2004/09/08 13:56:22  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.12  2004/08/30 18:56:21  amassari
- * Change the order of testing to save some CPU cycles
- *
- * Revision 1.11  2004/03/01 15:03:08  peiyongz
- * new getter: getHashModulus
- *
- * Revision 1.10  2004/01/29 11:48:46  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.9  2003/12/17 00:18:35  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.8  2003/11/03 22:00:31  peiyongz
- * RefHashTable-like enumeration accessing added
- *
- * Revision 1.7  2003/10/29 16:18:05  peiyongz
- * size() added and Reset() bug fixed
- *
- * Revision 1.6  2003/06/02 15:18:08  neilg
- * fix for bug #20092; thanks to Berin Lautenbach
- *
- * Revision 1.5  2003/05/21 21:08:04  knoaman
- * gcc 2.95.x is generating an internal error for some template definitions, so
- * we use the default memory manger in such cases.
- *
- * Revision 1.4  2003/05/16 06:01:52  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.3  2003/05/15 19:04:35  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.2  2002/11/04 15:22:04  tng
- * C++ Namespace Support.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:12  peiyongz
- * sane_include
- *
- * Revision 1.4  2001/07/19 18:43:18  peiyongz
- * fix: detect null poiniter in enumerator's ctor.
- *
- * Revision 1.3  2001/06/04 13:45:04  tng
- * The "hash" argument clashes with STL hash.  Fixed by Pei Yong Zhang.
- *
- * Revision 1.2  2001/05/11 13:26:29  tng
- * Copyright update.
- *
- * Revision 1.1  2001/03/21 21:56:12  tng
- * Schema: Add Schema Grammar, Schema Validator, and split the DTDValidator into DTDValidator, DTDScanner, and DTDGrammar.
- *
+/*
+ * $Id: RefHash3KeysIdPool.c 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -79,6 +27,8 @@
 #endif
 
 #include <xercesc/util/NullPointerException.hpp>
+#include <assert.h>
+#include <new>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -165,8 +115,11 @@ RefHash3KeysIdPool<TVal>::RefHash3KeysIdPool( const unsigned int modulus
     initialize(modulus);
 
     // create default hasher
-
+#if defined (XML_GCC_VERSION) && (XML_GCC_VERSION < 29600)
+		 fHash = new HashXMLCh();
+#else
     fHash = new (fMemoryManager) HashXMLCh();
+#endif    
 
     //
     //  Allocate the initial id pointers array. We don't have to zero them
@@ -247,7 +200,10 @@ template <class TVal> void RefHash3KeysIdPool<TVal>::removeAll()
                 delete curElem->fData;
 
             // Then delete the current element and move forward
-            delete curElem;
+            // delete curElem;
+            // destructor is empty...
+            // curElem->~RefHash3KeysTableBucketElem();
+            fMemoryManager->deallocate(curElem);
             curElem = nextElem;
         }
 
@@ -346,7 +302,9 @@ RefHash3KeysIdPool<TVal>::put(void* key1, int key2, int key3, TVal* const valueT
 #if defined (XML_GCC_VERSION) && (XML_GCC_VERSION < 29600)
         newBucket = new RefHash3KeysTableBucketElem<TVal>(key1, key2, key3, valueToAdopt, fBucketList[hashVal]);
 #else
-        newBucket = new (fMemoryManager) RefHash3KeysTableBucketElem<TVal>(key1, key2, key3, valueToAdopt, fBucketList[hashVal]);
+        newBucket =
+            new (fMemoryManager->allocate(sizeof(RefHash3KeysTableBucketElem<TVal>)))
+            RefHash3KeysTableBucketElem<TVal>(key1, key2, key3, valueToAdopt, fBucketList[hashVal]);
 #endif
         fBucketList[hashVal] = newBucket;
     }
@@ -390,8 +348,7 @@ findBucketElem(const void* const key1, const int key2, const int key3, unsigned
 {
     // Hash the key
     hashVal = fHash->getHashVal(key1, fHashModulus, fMemoryManager);
-    if (hashVal > fHashModulus)
-        ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::HshTbl_BadHashFromKey, fMemoryManager);
+    assert(hashVal < fHashModulus);
 
     // Search that bucket for the key
     RefHash3KeysTableBucketElem<TVal>* curElem = fBucketList[hashVal];
@@ -410,8 +367,7 @@ findBucketElem(const void* const key1, const int key2, const int key3, unsigned
 {
     // Hash the key
     hashVal = fHash->getHashVal(key1, fHashModulus);
-    if (hashVal > fHashModulus)
-        ThrowXMLwithMemMgr(RuntimeException, XMLExcepts::HshTbl_BadHashFromKey, fMemoryManager);
+    assert(hashVal < fHashModulus);
 
     // Search that bucket for the key
     const RefHash3KeysTableBucketElem<TVal>* curElem = fBucketList[hashVal];
@@ -450,7 +406,9 @@ template <class TVal> RefHash3KeysIdPoolEnumerator<TVal>::~RefHash3KeysIdPoolEnu
 
 template <class TVal> RefHash3KeysIdPoolEnumerator<TVal>::
 RefHash3KeysIdPoolEnumerator(const RefHash3KeysIdPoolEnumerator<TVal>& toCopy) :
-    fAdoptedElems(toCopy.fAdoptedElems)
+    XMLEnumerator<TVal>(toCopy)
+    , XMemory(toCopy)
+    , fAdoptedElems(toCopy.fAdoptedElems)
     , fCurIndex(toCopy.fCurIndex)
     , fToEnum(toCopy.fToEnum)
     , fCurElem(toCopy.fCurElem)
@@ -557,11 +515,8 @@ template <class TVal> void RefHash3KeysIdPoolEnumerator<TVal>::findNext()
             return;
 
         // Else find the next non-empty bucket
-        while (true)
+        while (fToEnum->fBucketList[fCurHash]==0)
         {
-            if (fToEnum->fBucketList[fCurHash])
-                break;
-
             // Bump to the next hash value. If we max out return
             fCurHash++;
             if (fCurHash == fToEnum->fHashModulus)
