@@ -1,72 +1,31 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: TransService.cpp,v 1.12 2003/05/15 19:07:45 knoaman Exp $
+ * $Id: TransService.cpp 176382 2005-04-21 09:05:57Z cargilld $
  */
 // ---------------------------------------------------------------------------
 //  Includes
 // ---------------------------------------------------------------------------
 #include <xercesc/util/Janitor.hpp>
-#include <xercesc/util/RefHashTableOf.hpp>
-#include <xercesc/util/RefVectorOf.hpp>
 #include <xercesc/util/XML88591Transcoder.hpp>
 #include <xercesc/util/XMLASCIITranscoder.hpp>
 #include <xercesc/util/XMLChTranscoder.hpp>
 #include <xercesc/util/XMLEBCDICTranscoder.hpp>
+#include <xercesc/util/XMLIBM1047Transcoder.hpp>
 #include <xercesc/util/XMLIBM1140Transcoder.hpp>
 #include <xercesc/util/XMLUCS4Transcoder.hpp>
 #include <xercesc/util/XMLUTF8Transcoder.hpp>
@@ -74,43 +33,37 @@
 #include <xercesc/util/XMLWin1252Transcoder.hpp>
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/XMLUni.hpp>
-#include <xercesc/util/TransENameMap.hpp>
 #include <xercesc/util/EncodingValidator.hpp>
 #include <xercesc/util/XMLRegisterCleanup.hpp>
 #include <xercesc/util/PlatformUtils.hpp>
+#include <xercesc/util/TransENameMap.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
 // ---------------------------------------------------------------------------
 //  Local, static data
 //
-//  gMappings
-//      This is a hash table of ENameMap objects. It is created and filled
-//      in when the platform init calls our initTransService() method.
-//
-//  gMappingsRecognizer
-//      This is an array of ENameMap objects, predefined for those
-//      already recognized by XMLRecognizer::Encodings.
-//
 //  gStrictIANAEncoding
 //      A flag to control whether strict IANA encoding names checking should
 //      be done
 //
 // ---------------------------------------------------------------------------
-static RefHashTableOf<ENameMap>*    gMappings = 0;
-static RefVectorOf<ENameMap>*       gMappingsRecognizer = 0;
 static bool gStrictIANAEncoding = false;
+RefHashTableOf<ENameMap>* XMLTransService::gMappings = 0;
+RefVectorOf<ENameMap> * XMLTransService::gMappingsRecognizer = 0;
+static XMLRegisterCleanup mappingsCleanup;
+static XMLRegisterCleanup mappingsRecognizerCleanup;
 
 // -----------------------------------------------------------------------
 //  Notification that lazy data has been deleted
 // -----------------------------------------------------------------------
-static void reinitMappings() {
+void XMLTransService::reinitMappings() {
     delete gMappings;    // The contents of the gMappings hash table are owned by
     gMappings = 0;       //   the it, and so will be deleted by gMapping's destructor.
 }
 
-static void reinitMappingsRecognizer() {
-    delete gMappingsRecognizer;
+void XMLTransService::reinitMappingsRecognizer() {
+    delete XMLTransService::gMappingsRecognizer;
     gMappingsRecognizer = 0;
 }
 
@@ -119,9 +72,6 @@ static void reinitMappingsRecognizer() {
 // ---------------------------------------------------------------------------
 XMLTransService::XMLTransService()
 {
-    static XMLRegisterCleanup mappingsCleanup;
-    static XMLRegisterCleanup mappingsRecognizerCleanup;
-
     if (!gMappings) {
         RefHashTableOf<ENameMap>* t = new RefHashTableOf<ENameMap>(103);
 
@@ -209,7 +159,7 @@ XMLTransService::makeNewTranscoderFor(  const   XMLCh* const            encoding
         resValue = XMLTransService::InternalFailure;
         return 0;
     }
-    XMLString::upperCase(upBuf);
+    XMLString::upperCaseASCII(upBuf);
     ENameMap* ourMapping = gMappings->get(upBuf);
 
     // If we found it, then call the factory method for it
@@ -259,7 +209,7 @@ XMLTransService::makeNewTranscoderFor(  XMLRecognizer::Encodings        encoding
        return temp;
     }
     else {
-        XMLTranscoder* temp =  makeNewXMLTranscoder(XMLRecognizer::nameForEncoding(encodingEnum), resValue, blockSize, manager);
+        XMLTranscoder* temp =  makeNewXMLTranscoder(XMLRecognizer::nameForEncoding(encodingEnum, manager), resValue, blockSize, manager);
 
         // if successful, set resValue to OK
         // if failed, the makeNewXMLTranscoder has already set the proper failing resValue
@@ -465,6 +415,33 @@ void XMLTransService::initTransService()
         )
     );
     gMappings->put
+    (
+		(void*)XMLUni::fgUTF16EncodingString5,
+        new EEndianNameMapFor<XMLUTF16Transcoder>
+        (
+            XMLUni::fgUTF16EncodingString5
+            , false
+        )
+    );
+    gMappings->put
+    (
+		(void*)XMLUni::fgUTF16EncodingString6,
+        new EEndianNameMapFor<XMLUTF16Transcoder>
+        (
+            XMLUni::fgUTF16EncodingString6
+            , false
+        )
+    );
+    gMappings->put
+    (
+		(void*)XMLUni::fgUTF16EncodingString7,
+        new EEndianNameMapFor<XMLUTF16Transcoder>
+        (
+            XMLUni::fgUTF16EncodingString7
+            , false
+        )
+    );
+    gMappings->put
     (
 		(void*)XMLUni::fgUCS4EncodingString,
         new EEndianNameMapFor<XMLUCS4Transcoder>
@@ -500,6 +477,11 @@ void XMLTransService::initTransService()
     gMappings->put((void*)XMLUni::fgIBM037EncodingString, new ENameMapFor<XMLEBCDICTranscoder>(XMLUni::fgIBM037EncodingString));
     gMappings->put((void*)XMLUni::fgIBM037EncodingString2, new ENameMapFor<XMLEBCDICTranscoder>(XMLUni::fgIBM037EncodingString2));
 
+
+    //hhe
+    gMappings->put((void*)XMLUni::fgIBM1047EncodingString, new ENameMapFor<XMLIBM1047Transcoder>(XMLUni::fgIBM1047EncodingString));
+    gMappings->put((void*)XMLUni::fgIBM1047EncodingString2, new ENameMapFor<XMLIBM1047Transcoder>(XMLUni::fgIBM1047EncodingString2));
+
     //
     //  Add in our mappings for IBM037 with Euro update, i.e. IBM1140. It
     //  has alias IBM01140, the one suggested by IANA
@@ -545,8 +527,8 @@ XMLTranscoder::~XMLTranscoder()
 XMLTranscoder::XMLTranscoder(const  XMLCh* const    encodingName
                             , const unsigned int    blockSize
                             , MemoryManager* const  manager) :
-    fEncodingName(0)
-    , fBlockSize(blockSize)
+      fBlockSize(blockSize)
+    , fEncodingName(0)    
     , fMemoryManager(manager)
 {
     fEncodingName = XMLString::replicate(encodingName, fMemoryManager);
@@ -556,7 +538,7 @@ XMLTranscoder::XMLTranscoder(const  XMLCh* const    encodingName
 // ---------------------------------------------------------------------------
 //  XMLTranscoder: Protected helpers
 // ---------------------------------------------------------------------------
-void XMLTranscoder::checkBlockSize(const unsigned int toCheck)
+void XMLTranscoder::checkBlockSize(const unsigned int)
 {
 //    if (toCheck > fBlockSize)
 //        ThrowXML(TranscodingException, XMLExcepts::Trans_BadBlockSize);
