@@ -15,46 +15,7 @@
  */
 
 /*
- * $Log: CygwinTransService.cpp,v $
- * Revision 1.13  2004/09/08 13:56:43  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.12  2004/01/19 16:06:56  amassari
- * WideCharToMultiByte and MultiByteToWideChar return 0 on failure, not -1
- *
- * Revision 1.11  2004/01/13 16:34:22  cargilld
- * Misc memory management changes.
- *
- * Revision 1.10  2003/12/24 15:24:15  cargilld
- * More updates to memory management so that the static memory manager.
- *
- * Revision 1.9  2003/11/08 23:37:00  neilg
- * fix for bug 24287 by Abe Backus.
- *
- * Revision 1.8  2003/05/17 16:32:17  knoaman
- * Memory manager implementation : transcoder update.
- *
- * Revision 1.7  2003/05/16 14:04:46  neilg
- * fix compilation error
- *
- * Revision 1.6  2003/05/16 06:01:57  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.5  2003/05/15 18:47:02  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.4  2003/03/09 17:02:20  peiyongz
- * PanicHandler
- *
- * Revision 1.3  2003/03/07 18:15:57  tng
- * Return a reference instead of void for operator=
- *
- * Revision 1.2  2002/11/04 15:14:32  tng
- * C++ Namespace Support.
- *
- * Revision 1.1  2002/08/19 18:35:56  tng
- * [Bug 6467] Installing Xerces C++ on cygwin environment.
- *
+ * $Id: CygwinTransService.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 // ---------------------------------------------------------------------------
@@ -485,22 +446,23 @@ CygwinTransService::~CygwinTransService()
 // ---------------------------------------------------------------------------
 int CygwinTransService::auxCompareString( const XMLCh* const comp1
                                          , const XMLCh* const comp2
-                                         , signed long maxChars
+                                         , signed long sMaxChars
                                          , const bool ignoreCase)
 {
     const XMLCh* args[2] = { comp1, comp2 };
     XMLCh*       firstBuf = NULL;
-    XMLCh*       secondBuf;
+    XMLCh*       secondBuf = NULL;
     unsigned int len = XMLString::stringLen( comp1);
     unsigned int otherLen = XMLString::stringLen( comp2);
     unsigned int countChar = 0;
+    unsigned int maxChars;
     int          theResult = 0;
 
     // Determine at what string index the comparison stops.
-    if ( maxChars != -1L )
+    if ( sMaxChars != -1L )
     {
-        len = ( len > maxChars ) ? maxChars : len;
-        otherLen = ( otherLen > maxChars ) ? maxChars : otherLen;
+        len = ( len > (unsigned int)sMaxChars ) ? (unsigned int)sMaxChars : len;
+        otherLen = ( otherLen > (unsigned int)sMaxChars ) ? (unsigned int)sMaxChars : otherLen;
         maxChars = ( len > otherLen ) ? otherLen : len;
     }
     else
@@ -608,7 +570,7 @@ const XMLCh* CygwinTransService::getId() const
 
 bool CygwinTransService::isSpace(const XMLCh toCheck) const
 {
-    int theCount = 0;
+    unsigned int theCount = 0;
     while ( theCount < (sizeof(gWhitespace) / sizeof(XMLCh)) )
     {
         if ( toCheck == gWhitespace[theCount] )
@@ -683,7 +645,7 @@ CygwinTransService::makeNewXMLTranscoder(const   XMLCh* const           encoding
     //  Get an upper cased copy of the encoding name, since we use a hash
     //  table and we store them all in upper case.
     //
-    int itsLen = XMLString::stringLen( encodingName) + 1;
+    unsigned int itsLen = XMLString::stringLen( encodingName) + 1;
     memcpy(
         upEncoding
         , encodingName
@@ -976,7 +938,7 @@ CygwinLCPTranscoder::~CygwinLCPTranscoder()
 //  CygwinLCPTranscoder: Implementation of the virtual transcoder interface
 // ---------------------------------------------------------------------------
 unsigned int CygwinLCPTranscoder::calcRequiredSize(const char* const srcText
-                                                   , MemoryManager* const manager)
+                                                   , MemoryManager* const /*manager*/)
 {
     if (!srcText)
         return 0;
@@ -986,7 +948,7 @@ unsigned int CygwinLCPTranscoder::calcRequiredSize(const char* const srcText
 
 
 unsigned int CygwinLCPTranscoder::calcRequiredSize(const XMLCh* const srcText
-                                                   , MemoryManager* const manager)
+                                                   , MemoryManager* const /*manager*/)
 {
     if (!srcText)
         return 0;
@@ -1116,7 +1078,7 @@ XMLCh* CygwinLCPTranscoder::transcode(const char* const toTranscode,
 bool CygwinLCPTranscoder::transcode( const   char* const    toTranscode
                                     ,       XMLCh* const    toFill
                                     , const unsigned int    maxChars
-                                    , MemoryManager* const  manager)
+                                    , MemoryManager* const  /*manager*/)
 {
     // Check for a couple of psycho corner cases
     if (!toTranscode || !maxChars)
@@ -1141,7 +1103,7 @@ bool CygwinLCPTranscoder::transcode( const   char* const    toTranscode
 bool CygwinLCPTranscoder::transcode( const  XMLCh* const    toTranscode
                                     ,       char* const     toFill
                                     , const unsigned int    maxBytes
-                                    , MemoryManager* const  manager)
+                                    , MemoryManager* const  /*manager*/)
 {
     // Watch for a couple of pyscho corner cases
     if (!toTranscode || !maxBytes)
