@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: IconvTransService.cpp,v 1.17 2004/09/08 13:56:44 peiyongz Exp $
+ * $Id: IconvTransService.cpp 176290 2005-01-13 12:36:02Z amassari $
  */
 
 
@@ -28,7 +28,7 @@
 #include <xercesc/framework/MemoryManager.hpp>
 #include <wchar.h>
 
-#if defined (XML_GCC) || defined (XML_PTX) || defined (XML_IBMVAOS2)
+#if defined (XML_GCC) || defined (XML_PTX) || defined (XML_IBMVAOS2) || defined(XML_LINUX) || defined (XML_UNIXWARE)
     #if defined(XML_BEOS)
         wint_t towlower(wint_t wc) {
           return ((wc>'A')&&(wc<'Z') ? wc+'a'-'A' : wc);
