@@ -1,3 +1,7 @@
+#if (__OS400_TGTVRM__>=510)                               /* @01a */
+    #pragma datamodel(P128)                               /* @01a */
+#endif                                                    /* @01a */
+
 /*
  * Copyright 1999-2002,2004 The Apache Software Foundation.
  * 
@@ -16,7 +20,7 @@
 
 /**
  * @02A           V5R2M0    200419   jrhansen : support lowercase function
- * $Id: Iconv400TransService.hpp,v 1.10 2004/09/08 13:56:45 peiyongz Exp $
+ * $Id: Iconv400TransService.hpp 176407 2005-05-18 13:44:44Z cargilld $
  */
 
 #ifndef ICONV400TRANSSERVICE_HPP
@@ -252,3 +256,7 @@ private :
 XERCES_CPP_NAMESPACE_END
 
 #endif
+#if (__OS400_TGTVRM__>=510)                                /* @01a */  
+     #pragma datamodel(pop)                                /* @01a */ 
+#endif                                                     /* @01a */
+
