@@ -1,119 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: IconvFBSDTransService.cpp,v $
- * Revision 1.15  2003/12/24 15:24:15  cargilld
- * More updates to memory management so that the static memory manager.
- *
- * Revision 1.14  2003/05/17 16:32:17  knoaman
- * Memory manager implementation : transcoder update.
- *
- * Revision 1.13  2003/05/16 21:37:00  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.12  2003/05/15 18:47:04  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.11  2003/03/09 17:02:57  peiyongz
- * PanicHandler
- *
- * Revision 1.10  2003/03/07 15:08:57  tng
- * [Bug 17571] fix building IconvFBSD (namespaces) .  Patch from Bjoern A. Zeeb.
- *
- * Revision 1.9  2003/03/07 14:42:45  tng
- * [Bug 17570] IconvFBSD build on alpha,sparc.  Patch from Bjoern A. Zeeb.
- *
- * Revision 1.8  2003/02/25 08:15:42  gareth
- * Patch to fix compile problem in bug #17358. Patch by Michael Cahill.
- *
- * Revision 1.7  2002/12/31 18:42:43  tng
- * [Bug 15608] IconvLCPTranscoder::transcode() is wrong at wcstombs() usage.
- *
- * Revision 1.6  2002/11/04 15:14:34  tng
- * C++ Namespace Support.
- *
- * Revision 1.5  2002/07/04 18:20:18  tng
- * [Bug 10253] Bugfix for the IconvFBSD transcoder.   Patch from Max Gotlib.
- *
- * Revision 1.4  2002/04/11 15:38:05  knoaman
- * String lower case support for FreeBSD by Max Gotlib
- *
- * Revision 1.3  2002/04/09 15:44:00  knoaman
- * Add lower case string support.
- *
- * Revision 1.2  2002/03/18 13:39:11  tng
- * [Bug 7162 ] IconvFreeBSDTransService.cpp needs an #include statement fixed to use xercesc.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:36  peiyongz
- * sane_include
- *
- * Revision 1.4  2002/01/14 19:45:15  tng
- * Support IconvFBSD in multi-threading environment with all the possible combinations of threading and transcoding options.  By Max Gotlib.
- *
- * Revision 1.3  2001/12/12 14:48:16  tng
- * More bug fixes in IconvFBSD Transcoder.  By Max Gotlib.
- *
- * Revision 1.2  2001/12/11 15:10:14  tng
- * More changes to IconvFBSDTransService.  Allow using "old" TransServece implementation (via '-t native' option to runConfigure) or
- * to employ libiconv (it is a part of FreeBSD ports-collection) services.  By Max Gotlib.
- *
- * Revision 1.1  2001/12/03 14:45:11  tng
- * FreeBSD native transcoder (IconvFBSD) added by Max Gotlib.
- *
+ * $Id: IconvFBSDTransService.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 // ---------------------------------------------------------------------------
@@ -1274,8 +1176,6 @@ bool IconvFBSDLCPTranscoder::transcode( const   XMLCh* const    toTranscode
     if (wLent > maxBytes)
         wLent = maxBytes;
 
-    size_t mblen;
-
 #ifndef XML_USE_LIBICONV
 
     wchar_t       tmpWideCharArr[gTempBuffArraySize];
@@ -1295,7 +1195,7 @@ bool IconvFBSDLCPTranscoder::transcode( const   XMLCh* const    toTranscode
     wideCharBuf[wLent] = 0x00;
 
     // Ok, go ahead and try the transcoding. If it fails, then ...
-    mblen = fbsd_wcstombs(toFill, wideCharBuf, maxBytes);
+    size_t mblen = fbsd_wcstombs(toFill, wideCharBuf, maxBytes);
     if (mblen == -1) {
         if (allocatedArray)
             manager->deallocate(allocatedArray);//delete [] allocatedArray;
@@ -1304,6 +1204,8 @@ bool IconvFBSDLCPTranscoder::transcode( const   XMLCh* const    toTranscode
     if (allocatedArray)
         manager->deallocate(allocatedArray);//delete [] allocatedArray;
 
+    // Cap it off just in case
+    toFill[mblen] = 0;
 #else /* XML_USE_LIBICONV */
 
     // Fill the "unicode" string
@@ -1331,8 +1233,8 @@ bool IconvFBSDLCPTranscoder::transcode( const   XMLCh* const    toTranscode
 
     // Ok, go ahead and try the transcoding. If it fails, then ...
     char    *ptr = toFill;
-    mblen = iconvTo(wideCharBuf, &len, &ptr, maxBytes);
-    if (mblen == (size_t)-1) {
+    size_t rc = iconvTo(wideCharBuf, &len, &ptr, maxBytes);
+    if (rc == (size_t)-1) {
         if (wBufPtr)
            manager->deallocate(wBufPtr);//delete [] wBufPtr;
         return false;
@@ -1340,10 +1242,9 @@ bool IconvFBSDLCPTranscoder::transcode( const   XMLCh* const    toTranscode
     if (wBufPtr)
         manager->deallocate(wBufPtr);//delete [] wBufPtr;
 
+    *ptr = 0;
 #endif /* !XML_USE_LIBICONV */
 
-    // Cap it off just in case
-    toFill[mblen] = 0;
     return true;
 }
 
