@@ -1,89 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2002 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2002,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: IconvGNUTransService.cpp,v $
- * Revision 1.9  2003/05/17 16:32:18  knoaman
- * Memory manager implementation : transcoder update.
- *
- * Revision 1.8  2003/05/16 21:37:00  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.7  2003/05/15 18:47:05  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.6  2003/04/07 16:52:13  peiyongz
- * Bug# 18672: IconvGNUTranscoder can't be build when namespaces is on.
- *                       Patch from Bacek@yandex-team.ru (Vasily Tchekalkin)
- *
- * Revision 1.5  2003/03/09 17:03:25  peiyongz
- * PanicHandler
- *
- * Revision 1.4  2002/12/31 18:42:54  tng
- * [Bug 15608] IconvLCPTranscoder::transcode() is wrong at wcstombs() usage.
- *
- * Revision 1.3  2002/11/04 15:14:34  tng
- * C++ Namespace Support.
- *
- * Revision 1.2  2002/09/27 13:33:43  tng
- * [Bug 12547] Xerces C++ 2.1 fails to build on Linux 64 bits arch with -tlinux.  Patch from Guillaume Morin.
- *
- * Revision 1.1  2002/08/19 19:38:18  tng
- * [Bug 11771] Linux specific IconvGNU transcoder.  Patch from Vasily Tchekalkin.
- *
+ * $Id: IconvGNUTransService.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 // ---------------------------------------------------------------------------
@@ -105,6 +37,7 @@
 
 #if !defined(APP_NO_THREADS)
 #include <xercesc/util/Mutexes.hpp>
+#include <xercesc/util/XMLRegisterCleanup.hpp>
 #endif /* !APP_NO_THREADS */
 
 XERCES_CPP_NAMESPACE_BEGIN
@@ -113,6 +46,7 @@ XERCES_CPP_NAMESPACE_BEGIN
 
 // Iconv() access syncronization point
 static XMLMutex    *gIconvMutex = NULL;
+static XMLRegisterCleanup IconvGNUMutexCleanup;
 #  define ICONV_LOCK    XMLMutexLock lockConverter(gIconvMutex);
 
 #else /* APP_NO_THREADS */
@@ -493,6 +427,12 @@ size_t    IconvGNUWrapper::iconvTo ( const char    *fromPtr,
 //  IconvGNUTransService: Constructors and Destructor
 // ---------------------------------------------------------------------------
 
+void reinitIconvGNUMutex()
+{
+    delete gIconvMutex;
+    gIconvMutex = 0;
+}
+
 IconvGNUTransService::IconvGNUTransService()
     : IconvGNUWrapper(), fUnicodeCP(0)
 {
@@ -502,6 +442,7 @@ IconvGNUTransService::IconvGNUTransService()
         gIconvMutex = new XMLMutex;
         if (gIconvMutex == NULL)
             XMLPlatformUtils::panic (PanicHandler::Panic_NoTransService);
+        IconvGNUMutexCleanup.registerCleanup(reinitIconvGNUMutex);
     }
 #endif
 
@@ -729,7 +670,8 @@ void IconvGNUTransService::lowerCase(XMLCh* const toLowerCase) const
 //  IconvGNULCPTranscoder: The virtual transcoder API
 // ---------------------------------------------------------------------------
 unsigned int
-IconvGNULCPTranscoder::calcRequiredSize (const char* const srcText)
+IconvGNULCPTranscoder::calcRequiredSize (const char* const srcText
+                                         , MemoryManager* const manager)
 {
     if (!srcText)
         return 0;
@@ -747,7 +689,7 @@ IconvGNULCPTranscoder::calcRequiredSize (const char* const srcText)
         const char    *ptr = srcText + srcLen - len;
         size_t    rc = iconvFrom(ptr, &len, &pTmpArr, gTempBuffArraySize);
         if (rc == (size_t) -1 && errno != E2BIG) {
-            ThrowXML(TranscodingException, XMLExcepts::Trans_BadSrcSeq);
+            ThrowXMLwithMemMgr(TranscodingException, XMLExcepts::Trans_BadSrcSeq, manager);
             /* return 0; */
         }
         rc = pTmpArr - (char *) tmpWideArr;
@@ -760,7 +702,8 @@ IconvGNULCPTranscoder::calcRequiredSize (const char* const srcText)
 
 
 unsigned int
-IconvGNULCPTranscoder::calcRequiredSize(const XMLCh* const srcText)
+IconvGNULCPTranscoder::calcRequiredSize(const XMLCh* const srcText
+                                        , MemoryManager* const manager)
 {
     if (!srcText)
         return 0;
@@ -774,7 +717,7 @@ IconvGNULCPTranscoder::calcRequiredSize(const XMLCh* const srcText)
     size_t      len = wLent * uChSize();
     if (uChSize() != sizeof(XMLCh) || UBO() != BYTE_ORDER) {
         if (len > gTempBuffArraySize) {
-            wBufPtr = (char*) XMLPlatformUtils::fgMemoryManager->allocate
+            wBufPtr = (char*) manager->allocate
             (
                 len * sizeof(char)
             );//new char[len];
@@ -797,8 +740,8 @@ IconvGNULCPTranscoder::calcRequiredSize(const XMLCh* const srcText)
         size_t    rc = iconvTo(ptr, &len, &pTmpArr, gTempBuffArraySize);
         if (rc == (size_t) -1 && errno != E2BIG) {
             if (wBufPtr)
-                XMLPlatformUtils::fgMemoryManager->deallocate(wBufPtr);//delete [] wBufPtr;
-            ThrowXML(TranscodingException, XMLExcepts::Trans_BadSrcSeq);
+                manager->deallocate(wBufPtr);//delete [] wBufPtr;
+            ThrowXMLwithMemMgr(TranscodingException, XMLExcepts::Trans_BadSrcSeq, manager);
             /* return 0; */
         }
         rc = pTmpArr - tmpBuff;
@@ -807,7 +750,7 @@ IconvGNULCPTranscoder::calcRequiredSize(const XMLCh* const srcText)
             break;
     }
     if (wBufPtr)
-        XMLPlatformUtils::fgMemoryManager->deallocate(wBufPtr);//delete [] wBufPtr;
+        manager->deallocate(wBufPtr);//delete [] wBufPtr;
     return totalLen;
 }
 
@@ -880,7 +823,7 @@ char* IconvGNULCPTranscoder::transcode(const XMLCh* const toTranscode,
         unsigned int  wLent = getWideCharLength(toTranscode);
 
         // Calc needed size.
-        const size_t neededLen = calcRequiredSize (toTranscode);
+        const size_t neededLen = calcRequiredSize (toTranscode, manager);
         if (neededLen == 0)
             return 0;
         // allocate output buffer
@@ -930,7 +873,8 @@ char* IconvGNULCPTranscoder::transcode(const XMLCh* const toTranscode,
 
 bool IconvGNULCPTranscoder::transcode( const   XMLCh* const    toTranscode
                     , char* const        toFill
-                    , const unsigned int    maxBytes)
+                    , const unsigned int    maxBytes
+                    , MemoryManager* const  manager)
 {
     // Watch for a couple of pyscho corner cases
     if (!toTranscode || !maxBytes) {
@@ -954,7 +898,7 @@ bool IconvGNULCPTranscoder::transcode( const   XMLCh* const    toTranscode
 
     if (uChSize() != sizeof(XMLCh) || UBO() != BYTE_ORDER) {
         if (len > gTempBuffArraySize) {
-            wBufPtr = (char*) XMLPlatformUtils::fgMemoryManager->allocate
+            wBufPtr = (char*) manager->allocate
             (
                 len * sizeof(char)
             );//new char[len];
@@ -972,14 +916,14 @@ bool IconvGNULCPTranscoder::transcode( const   XMLCh* const    toTranscode
     size_t    rc = iconvTo(wideCharBuf, &len, &ptr, maxBytes);
     if (rc == (size_t)-1) {
         if (wBufPtr)
-            XMLPlatformUtils::fgMemoryManager->deallocate(wBufPtr);//delete [] wBufPtr;
+            manager->deallocate(wBufPtr);//delete [] wBufPtr;
         return false;
     }
     if (wBufPtr)
-        XMLPlatformUtils::fgMemoryManager->deallocate(wBufPtr);//delete [] wBufPtr;
+        manager->deallocate(wBufPtr);//delete [] wBufPtr;
 
-    // Cap it off just in case
-    toFill[rc] = 0;
+    // Cap it off
+    *ptr = 0;
     return true;
 }
 
@@ -1049,9 +993,9 @@ XMLCh* IconvGNULCPTranscoder::transcode(const char* const toTranscode,
 
     XMLCh* retVal = 0;
     if (*toTranscode) {
-        const unsigned int wLent = calcRequiredSize(toTranscode);
+        const unsigned int wLent = calcRequiredSize(toTranscode, manager);
         if (wLent == 0) {
-            retVal = (XMLCh*) manager->allocate(sizeof(XMLCh));/new XMLCh[1];
+            retVal = (XMLCh*) manager->allocate(sizeof(XMLCh));//new XMLCh[1];
             retVal[0] = 0;
             return retVal;
         }
@@ -1101,7 +1045,8 @@ XMLCh* IconvGNULCPTranscoder::transcode(const char* const toTranscode,
 
 bool IconvGNULCPTranscoder::transcode(const   char* const    toTranscode
                        ,       XMLCh* const    toFill
-                       , const unsigned int    maxChars)
+                       , const unsigned int    maxChars
+                       , MemoryManager* const  manager)
 {
     // Check for a couple of psycho corner cases
     if (!toTranscode || !maxChars)
@@ -1127,7 +1072,7 @@ bool IconvGNULCPTranscoder::transcode(const   char* const    toTranscode
 
     if (uChSize() != sizeof(XMLCh) || UBO() != BYTE_ORDER) {
         if (len > gTempBuffArraySize) {
-            wBufPtr = (char*) XMLPlatformUtils::fgMemoryManager->allocate
+            wBufPtr = (char*) manager->allocate
             (
                 len * sizeof(char)
             );//new char[len];
@@ -1144,14 +1089,14 @@ bool IconvGNULCPTranscoder::transcode(const   char* const    toTranscode
     size_t    rc = iconvFrom(toTranscode, &flen, &ptr, len);
     if (rc == (size_t)-1) {
         if (wBufPtr)
-            XMLPlatformUtils::fgMemoryManager->deallocate(wBufPtr);//delete [] wBufPtr;
+            manager->deallocate(wBufPtr);//delete [] wBufPtr;
         return false;
     }
 
     if (uChSize() != sizeof(XMLCh) || UBO() != BYTE_ORDER)
         mbsToXML (wideCharBuf, wLent, toFill, wLent);
     if (wBufPtr)
-        XMLPlatformUtils::fgMemoryManager->deallocate(wBufPtr);//delete [] wBufPtr;
+        manager->deallocate(wBufPtr);//delete [] wBufPtr;
 
     toFill[wLent] = 0x00;
     return true;
@@ -1186,7 +1131,7 @@ IconvGNUTranscoder::IconvGNUTranscoder (const    XMLCh* const    encodingName
                       ,    iconv_t        cd_to
                       ,    size_t        uchsize
                       ,    unsigned int    ubo
-                      , MemoryManger* const manager
+                      , MemoryManager* const manager
     )
     : XMLTranscoder(encodingName, blockSize, manager)
     , IconvGNUWrapper (cd_from, cd_to, uchsize, ubo)
@@ -1253,7 +1198,7 @@ unsigned int    IconvGNUTranscoder::transcodeFrom
             if (errno != E2BIG || prevSrcLen == srcLen) {
                 if (wBufPtr)
                     getMemoryManager()->deallocate(wBufPtr);//delete [] wBufPtr;
-                ThrowXML(TranscodingException, XMLExcepts::Trans_BadSrcSeq);
+                ThrowXMLwithMemMgr(TranscodingException, XMLExcepts::Trans_BadSrcSeq, getMemoryManager());
             }
         }
         charSizes[cnt] = prevSrcLen - srcLen;
@@ -1305,7 +1250,7 @@ unsigned int    IconvGNUTranscoder::transcodeTo
     if (rc == (size_t)-1 && errno != E2BIG) {
         if (wBufPtr)
             getMemoryManager()->deallocate(wBufPtr);//delete [] wBufPtr;
-        ThrowXML(TranscodingException, XMLExcepts::Trans_BadSrcSeq);
+        ThrowXMLwithMemMgr(TranscodingException, XMLExcepts::Trans_BadSrcSeq, getMemoryManager());
     }
     charsEaten = srcCount - srcLen / uChSize();
     if (wBufPtr)
