@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: Uniconv390TransService.cpp,v 1.8 2004/09/08 13:56:46 peiyongz Exp $
+ * $Id: Uniconv390TransService.cpp 191823 2005-06-22 12:45:35Z cargilld $
  */
 
 
@@ -60,6 +60,7 @@
 #include <xercesc/util/XMLUTF8Transcoder.hpp>
 #include <xercesc/util/XMLUTF16Transcoder.hpp>
 #include <xercesc/util/XMLWin1252Transcoder.hpp>
+#include <unicode/uchar.h>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -164,10 +165,6 @@ DBGPRINTF1("remove converter\n");
 Uniconv390TransService::Uniconv390TransService()
 {
 
-   fCaseConverter = new uniconvcaseconverter;
-   fCaseConverter->ftoupperhand=UNICONV_NOHANDLE;
-   fCaseConverter->ftolowerhand=UNICONV_NOHANDLE;
-
    char * myenviron = getenv("_IXM_FORCE_CONVERSION");
    gForceTranscode = NO_FORCE;
    if ( !strcmp(myenviron,"USE_ICU") )
@@ -176,6 +173,19 @@ Uniconv390TransService::Uniconv390TransService()
       gForceTranscode = MUST_USE_UNICONV;
   DBGPRINTF3("FORCE PARM=%s %d\n",myenviron,gForceTranscode);
 
+// If we are forcing ICU to be used fro transcoding then we also should
+// force it to be used for case conversions.
+if (gForceTranscode == MUST_USE_ICU) {
+   fCaseConverter = new uniconvcaseconverter;
+   fCaseConverter->ftoupperhand=UNICONV_ERROR;
+   fCaseConverter->ftolowerhand=UNICONV_ERROR;
+}
+else {
+   fCaseConverter = new uniconvcaseconverter;
+   fCaseConverter->ftoupperhand=UNICONV_NOHANDLE;
+   fCaseConverter->ftolowerhand=UNICONV_NOHANDLE;
+}
+
    fICUService = new ICUTransService;
 
    gViewTranscoder = false;
@@ -200,7 +210,7 @@ Uniconv390TransService::~Uniconv390TransService()
       fCaseConverter->ftolowerhand=UNICONV_NOHANDLE;
    }
    if (fCaseConverter) {
-      delete [] fCaseConverter;
+      delete fCaseConverter;
       fCaseConverter=0;
    }
    if (fICUService) {
@@ -341,14 +351,14 @@ const XMLCh* Uniconv390TransService::getId() const
 
 bool Uniconv390TransService::isSpace(const XMLCh toCheck) const
 {
-DBGPRINTF2("isspace checking %x\n",toCheck);
-   unsigned short chartype = XMLUniCharacter::getType(toCheck);
-   if ( (chartype == XMLUniCharacter::SPACE_SEPARATOR) ||
-        (chartype == XMLUniCharacter::LINE_SEPARATOR)   ||
-        (chartype == XMLUniCharacter::PARAGRAPH_SEPARATOR) )
-      return true;
-   else
-      return false;
+	/* copied from ICU */
+    if ((toCheck == 0x09)
+    ||  (toCheck == 0x0A)
+    ||  (toCheck == 0x0D))
+    {
+        return true;
+    }
+    return (u_isspace(UChar(toCheck)) != 0);
 }
 
 bool Uniconv390TransService::supportsSrcOfs() const
@@ -689,6 +699,33 @@ void Uniconv390TransService::initTransService()
            )
        );
        gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString5,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString5
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString6,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString6
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString7,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString7
+               , false
+           )
+       );
+       gMappings->put
        (
    		(void*)XMLUni::fgUCS4EncodingString,
            new EEndianNameMapFor<XMLUCS4Transcoder>
@@ -933,6 +970,33 @@ void Uniconv390TransService::initTransService()
            )
        );
        gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString5,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString5
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString6,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString6
+               , false
+           )
+       );
+       gMappings->put
+       (
+   		(void*)XMLUni::fgUTF16EncodingString7,
+           new EEndianNameMapFor<XMLUTF16Transcoder>
+           (
+               XMLUni::fgUTF16EncodingString7
+               , false
+           )
+       );
+       gMappings->put
        (
    		(void*)XMLUni::fgUCS4EncodingString,
            new EEndianNameMapFor<XMLUCS4Transcoder>
