@@ -15,16 +15,7 @@
  */
 
 /*
- * $Log: XMLUTF8Transcoder390.cpp,v $
- * Revision 1.5  2004/09/08 13:56:46  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.4  2004/06/30 19:04:17  peiyongz
- * XML1.0-3rd Edition: UTF_8
- *
- * Revision 1.3  2004/02/06 18:23:55  cargilld
- * Misc 390 changes.
- *
+ * $Id: XMLUTF8Transcoder390.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -226,9 +217,18 @@ XMLUTF8Transcoder390::transcodeFrom(const  XMLByte* const          srcData
         
         if (*srcPtr <= 127)
         {
-            *outPtr++ = XMLCh(*srcPtr++);
-            *sizePtr++ = 1;
-            continue;
+            // Handle ASCII in groups instead of single character at a time.
+            const XMLByte* srcPtr_save = srcPtr;
+            do
+            {
+                *outPtr++ = XMLCh(*srcPtr++);
+            } while (*srcPtr <= 127    &&
+                      srcPtr != srcEnd &&
+                      outPtr != outEnd );
+            memset(sizePtr,1,srcPtr - srcPtr_save);
+            sizePtr += srcPtr - srcPtr_save;
+            if (srcPtr == srcEnd || outPtr == outEnd)
+                break;
         }
         
         // See how many trailing src bytes this sequence is going to require
