@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: Win32TransService.cpp,v 1.21 2004/01/19 16:06:56 amassari Exp $
+ * $Id: Win32TransService.cpp 176273 2005-01-06 21:39:44Z amassari $
  */
 
 
@@ -274,9 +234,9 @@ Win32TransService::Win32TransService()
     //
     const unsigned int nameBufSz = 1024;
     char nameBuf[nameBufSz + 1];
-    unsigned int subIndex = 0;
+    unsigned int subIndex;
     unsigned long theSize;
-    while (true)
+    for (subIndex = 0;;++subIndex)
     {
         // Get the name of the next key
         theSize = nameBufSz;
@@ -301,7 +261,7 @@ Win32TransService::Win32TransService()
             , KEY_READ
             , &encodingKey))
         {
-            XMLPlatformUtils::panic(PanicHandler::Panic_NoTransService);
+            continue;
         }
 
         //
@@ -329,7 +289,8 @@ Win32TransService::Win32TransService()
                 , (unsigned char*)&CPId
                 , &theSize) != ERROR_SUCCESS)
             {
-                XMLPlatformUtils::panic(PanicHandler::Panic_NoTransService);
+                ::RegCloseKey(encodingKey);
+                continue;
             }
 
             //
@@ -348,7 +309,8 @@ Win32TransService::Win32TransService()
                     , (unsigned char*)&IEId
                     , &theSize) != ERROR_SUCCESS)
                 {
-                    XMLPlatformUtils::panic(PanicHandler::Panic_NoTransService);
+                    ::RegCloseKey(encodingKey);
+                    continue;
                 }
 
                 CPMapEntry* newEntry = new CPMapEntry(nameBuf, CPId, IEId);
@@ -356,9 +318,8 @@ Win32TransService::Win32TransService()
             }
         }
 
-        // And now close the subkey handle and bump the subkey index
+        // And close the subkey handle
         ::RegCloseKey(encodingKey);
-        subIndex++;
     }
 
     //
@@ -367,9 +328,8 @@ Win32TransService::Win32TransService()
     //  built and add a new entry with this new name and the same id
     //  values we stored for the original.
     //
-    subIndex = 0;
     char aliasBuf[nameBufSz + 1];
-    while (true)
+    for (subIndex = 0;;++subIndex)
     {
         // Get the name of the next key
         theSize = nameBufSz;
@@ -394,7 +354,7 @@ Win32TransService::Win32TransService()
             , KEY_READ
             , &encodingKey))
         {
-            XMLPlatformUtils::panic(PanicHandler::Panic_NoTransService);
+            continue;
         }
 
         //
@@ -451,9 +411,8 @@ Win32TransService::Win32TransService()
             }
         }
 
-        // And now close the subkey handle and bump the subkey index
+        // And close the subkey handle
         ::RegCloseKey(encodingKey);
-        subIndex++;
     }
 
     // And close the main key handle
@@ -646,7 +605,7 @@ Win32Transcoder::transcodeFrom( const   XMLByte* const      srcData
         //  If we are looking at a leading byte of a multibyte sequence,
         //  then we are going to eat 2 bytes, else 1.
         //
-        const unsigned int toEat = ::IsDBCSLeadByteEx(fWinCP, *inPtr) ?
+        unsigned char toEat = ::IsDBCSLeadByteEx(fWinCP, *inPtr) ?
                                     2 : 1;
 
         // Make sure a whol char is in the source
@@ -786,7 +745,7 @@ bool Win32Transcoder::canTranscodeTo(const unsigned int toCheck) const
     if (toCheck & 0xFFFF0000)
     {
         srcBuf[0] = XMLCh((toCheck >> 10) + 0xD800);
-        srcBuf[1] = XMLCh(toCheck & 0x3FF) + 0xDC00;
+        srcBuf[1] = XMLCh((toCheck & 0x3FF) + 0xDC00);
         srcCount++;
     }
      else
@@ -844,7 +803,7 @@ Win32LCPTranscoder::~Win32LCPTranscoder()
 //  Win32LCPTranscoder: Implementation of the virtual transcoder interface
 // ---------------------------------------------------------------------------
 unsigned int Win32LCPTranscoder::calcRequiredSize(const char* const srcText
-                                                  , MemoryManager* const manager)
+                                                  , MemoryManager* const /*manager*/)
 {
     if (!srcText)
         return 0;
@@ -854,7 +813,7 @@ unsigned int Win32LCPTranscoder::calcRequiredSize(const char* const srcText
 
 
 unsigned int Win32LCPTranscoder::calcRequiredSize(const XMLCh* const srcText
-                                                  , MemoryManager* const manager)
+                                                  , MemoryManager* const /*manager*/)
 {
     if (!srcText)
         return 0;
@@ -988,7 +947,7 @@ XMLCh* Win32LCPTranscoder::transcode(const char* const toTranscode,
 bool Win32LCPTranscoder::transcode( const   char* const     toTranscode
                                     ,       XMLCh* const    toFill
                                     , const unsigned int    maxChars
-                                    , MemoryManager* const  manager)
+                                    , MemoryManager* const  /*manager*/)
 {
     // Check for a couple of psycho corner cases
     if (!toTranscode || !maxChars)
@@ -1013,7 +972,7 @@ bool Win32LCPTranscoder::transcode( const   char* const     toTranscode
 bool Win32LCPTranscoder::transcode( const   XMLCh* const    toTranscode
                                     ,       char* const     toFill
                                     , const unsigned int    maxBytes
-                                    , MemoryManager* const  manager)
+                                    , MemoryManager* const  /*manager*/)
 {
     // Watch for a couple of pyscho corner cases
     if (!toTranscode || !maxBytes)
