@@ -15,104 +15,7 @@
  */
 
 /*
- * $Id: XMLAbstractDoubleFloat.cpp,v 1.29 2004/09/09 20:09:30 peiyongz Exp $
- * $Log: XMLAbstractDoubleFloat.cpp,v $
- * Revision 1.29  2004/09/09 20:09:30  peiyongz
- * getDataOverflowed()
- *
- * Revision 1.28  2004/09/08 13:56:23  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.27  2004/08/23 16:06:49  peiyongz
- * Fix to memory leakage in getCanRep
- *
- * Revision 1.26  2004/01/29 11:48:46  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.25  2004/01/13 19:50:56  peiyongz
- * remove parseContent()
- *
- * Revision 1.24  2004/01/12 16:23:39  neilg
- * remove use of static buffers
- *
- * Revision 1.23  2004/01/03 00:03:18  peiyongz
- * parseContent
- *
- * Revision 1.22  2003/12/23 21:48:14  peiyongz
- * Absorb exception thrown in getCanonicalRepresentation and return 0
- *
- * Revision 1.21  2003/12/20 06:21:34  neilg
- * fix canonical representation production
- *
- * Revision 1.20  2003/12/17 00:18:35  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.19  2003/12/12 04:51:29  peiyongz
- * trailing zeros for double/float w/o decimal point
- *
- * Revision 1.18  2003/12/11 21:38:12  peiyongz
- * support for Canonical Representation for Datatype
- *
- * Revision 1.17  2003/10/15 14:50:01  peiyongz
- * Bugzilla#22821: locale-sensitive function used to validate 'double' type, patch
- * from jsweeney@spss.com (Jeff Sweeney)
- *
- * Revision 1.16  2003/09/25 22:24:28  peiyongz
- * Using writeString/readString
- *
- * Revision 1.15  2003/09/25 15:23:25  peiyongz
- * add sizeof(XMLCh) when allocating memory
- *
- * Revision 1.14  2003/09/23 18:16:07  peiyongz
- * Inplementation for Serialization/Deserialization
- *
- * Revision 1.13  2003/05/16 06:01:52  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.12  2003/05/15 19:07:46  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.11  2003/03/12 20:45:46  peiyongz
- * format string for value converted to Zero.
- *
- * Revision 1.10  2003/03/10 20:55:58  peiyongz
- * Schema Errata E2-40 double/float
- *
- * Revision 1.9  2003/02/02 23:54:43  peiyongz
- * getFormattedString() added to return original and converted value.
- *
- * Revision 1.8  2003/01/30 21:55:22  tng
- * Performance: create getRawData which is similar to toString but return the internal data directly, user is not required to delete the returned memory.
- *
- * Revision 1.7  2002/12/11 00:20:02  peiyongz
- * Doing businesss in value space. Converting out-of-bound value into special values.
- *
- * Revision 1.6  2002/11/04 15:22:05  tng
- * C++ Namespace Support.
- *
- * Revision 1.5  2002/09/24 19:51:24  tng
- * Performance: use XMLString::equals instead of XMLString::compareString
- *
- * Revision 1.4  2002/05/03 16:05:45  peiyongz
- * Bug 7341: Missing newline at end of util and DOM source files,
- * patch from Martin Kalen.
- *
- * Revision 1.3  2002/03/06 19:13:12  peiyongz
- * Patch: more valid lexcial representation for positive/negative zero
- *
- * Revision 1.2  2002/03/01 18:47:37  peiyongz
- * fix: more valid lexcial representation forms for "neural zero"
- *
- * Revision 1.1.1.1  2002/02/01 22:22:14  peiyongz
- * sane_include
- *
- * Revision 1.2  2001/11/22 21:39:00  peiyongz
- * Allow "0.0" to be a valid lexcial representation of ZERO.
- *
- * Revision 1.1  2001/11/19 21:33:42  peiyongz
- * Reorganization: Double/Float
- *
- *
+ * $Id: XMLAbstractDoubleFloat.cpp 191689 2005-06-21 17:15:46Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
@@ -126,6 +29,8 @@
 #include <xercesc/util/Janitor.hpp>
 
 #include <locale.h>
+#include <float.h>
+#include <errno.h>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -168,6 +73,9 @@ void XMLAbstractDoubleFloat::init(const XMLCh* const strValue)
     ArrayJanitor<XMLCh> janTmpName(tmpStrValue, fMemoryManager);
     XMLString::trim(tmpStrValue);
 
+    if (!*tmpStrValue) 
+        ThrowXMLwithMemMgr(NumberFormatException, XMLExcepts::XMLNUM_emptyString, fMemoryManager);
+
     normalizeZero(tmpStrValue);
 
     if (XMLString::equals(tmpStrValue, XMLUni::fgNegINFString) )
@@ -190,7 +98,55 @@ void XMLAbstractDoubleFloat::init(const XMLCh* const strValue)
         // Normal case
         //
     {
-        checkBoundary(tmpStrValue);
+        // Use a stack-based buffer when possible.  Since all
+        // valid doubles or floats will only contain ASCII
+        // digits, a decimal point,  or the exponent character,
+        // they will all be single byte characters, and this will
+        // work.
+        static const unsigned int  maxStackSize = 100;
+
+        const unsigned int  lenTempStrValue =
+            XMLString::stringLen(tmpStrValue);
+
+        if (lenTempStrValue < maxStackSize)
+        {
+            char    buffer[maxStackSize + 1];
+
+            XMLString::transcode(
+                tmpStrValue,
+                buffer,
+                sizeof(buffer) - 1,
+                getMemoryManager());
+
+            // Do this for safety, because we've
+            // no guarantee we didn't overrun the
+            // capacity of the buffer when transcoding
+            // a bogus value.
+            buffer[maxStackSize] = '\0';
+
+            // If they aren't the same length, then some
+            // non-ASCII multibyte character was present.
+            // This will only happen in the case where the
+            // string has a bogus character, and it's long
+            // enough to overrun this buffer, but we need
+            // to check, even if it's unlikely to happen.
+            if (XMLString::stringLen(buffer) != lenTempStrValue)
+            {
+                ThrowXMLwithMemMgr(
+                    NumberFormatException,
+                    XMLExcepts::XMLNUM_Inv_chars,
+                    getMemoryManager());
+            }
+
+            checkBoundary(buffer);
+        }
+        else
+        {
+            char *nptr = XMLString::transcode(tmpStrValue, getMemoryManager());
+            const ArrayJanitor<char> janStr(nptr, fMemoryManager);
+
+            checkBoundary(nptr);
+        }
     }
 
 }
@@ -457,6 +413,58 @@ void XMLAbstractDoubleFloat::normalizeDecimalPoint(char* const toNormal)
     }
 }
 
+
+void
+XMLAbstractDoubleFloat::convert(char* const strValue)
+{
+    normalizeDecimalPoint(strValue);
+
+    char *endptr = 0;
+    errno = 0;
+    fValue = strtod(strValue, &endptr);
+
+    // check if all chars are valid char.  If they are, endptr will
+    // pointer to the null terminator.
+    if (*endptr != '\0')
+    {
+        ThrowXMLwithMemMgr(NumberFormatException, XMLExcepts::XMLNUM_Inv_chars, getMemoryManager());
+    }
+
+    // check if overflow/underflow occurs
+    if (errno == ERANGE)
+    {
+            
+        fDataConverted = true;
+
+        if ( fValue < 0 )
+        {
+            if (fValue > (-1)*DBL_MIN)
+            {
+                fValue = 0;
+            }
+            else
+            {
+                fType = NegINF;
+                fDataOverflowed = true;
+            }
+        }
+        else if ( fValue > 0)
+        {
+            if (fValue < DBL_MIN )
+            {
+                fValue = 0;
+            }
+            else
+            {
+                fType = PosINF;
+                fDataOverflowed = true;
+            }
+        }
+    }
+}
+
+
+
 /***
  * E2-40
  *
@@ -603,10 +611,8 @@ XMLCh* XMLAbstractDoubleFloat::getCanonicalRepresentation(const XMLCh*         c
 
         janRetBuffer.release();
         return retBuffer;
-
-    } //try
-
-    catch (...)
+    }
+    catch (const NumberFormatException&)
     {
         return 0;
     }
@@ -628,6 +634,7 @@ void XMLAbstractDoubleFloat::serialize(XSerializeEngine& serEng)
         serEng << fValue;
         serEng << fType;
         serEng << fDataConverted;
+        serEng << fDataOverflowed;
         serEng << fSign;
 
         serEng.writeString(fRawData);
@@ -644,6 +651,7 @@ void XMLAbstractDoubleFloat::serialize(XSerializeEngine& serEng)
         fType = (LiteralType) type;
 
         serEng >> fDataConverted;
+        serEng >> fDataOverflowed;
         serEng >> fSign;
 
         serEng.readString(fRawData);
