@@ -1,151 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001-2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: XMLDateTime.cpp,v 1.25 2004/01/29 11:48:47 cargilld Exp $
- * $Log: XMLDateTime.cpp,v $
- * Revision 1.25  2004/01/29 11:48:47  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.24  2004/01/25 23:23:26  jberry
- * Step around CodeWarrior compiler warning
- *
- * Revision 1.23  2004/01/13 19:50:56  peiyongz
- * remove parseContent()
- *
- * Revision 1.22  2004/01/13 16:34:20  cargilld
- * Misc memory management changes.
- *
- * Revision 1.21  2004/01/03 00:03:18  peiyongz
- * parseContent
- *
- * Revision 1.20  2003/12/31 02:34:11  neilg
- * enable production of canonical representations for dates with negative years, or years >9999
- *
- * Revision 1.19  2003/12/17 00:18:35  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.18  2003/12/16 22:48:52  peiyongz
- * exception thrown upon invalid number, thanks Gareth Reakes.
- *
- * Revision 1.17  2003/12/11 21:38:12  peiyongz
- * support for Canonical Representation for Datatype
- *
- * Revision 1.16  2003/09/25 22:24:28  peiyongz
- * Using writeString/readString
- *
- * Revision 1.15  2003/09/25 15:22:54  peiyongz
- * Solve HP complier error
- *
- * Revision 1.14  2003/09/23 18:16:07  peiyongz
- * Inplementation for Serialization/Deserialization
- *
- * Revision 1.13  2003/08/14 02:57:27  knoaman
- * Code refactoring to improve performance of validation.
- *
- * Revision 1.12  2003/05/22 02:10:52  knoaman
- * Default the memory manager.
- *
- * Revision 1.11  2003/05/18 14:02:05  knoaman
- * Memory manager implementation: pass per instance manager.
- *
- * Revision 1.10  2003/05/15 19:07:46  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.9  2003/05/15 16:32:19  gareth
- * We did not allow dateTimes with a timezone due to the last seconds fix.
- *
- * Revision 1.8  2003/03/23 22:54:49  peiyongz
- * invalid second values
- *
- * Revision 1.7  2003/02/22 22:49:09  peiyongz
- * Schema Errata E2-45 24:00:00 allowed
- *
- * Revision 1.6  2003/02/02 23:54:43  peiyongz
- * getFormattedString() added to return original and converted value.
- *
- * Revision 1.5  2003/01/30 21:55:22  tng
- * Performance: create getRawData which is similar to toString but return the internal data directly, user is not required to delete the returned memory.
- *
- * Revision 1.4  2002/11/28 20:39:27  peiyongz
- * Schema Errata: E2-23 seconds part shall have at least one digit after the dot
- *                           if it appears.
- *
- * Revision 1.3  2002/11/06 22:22:21  peiyongz
- * Schema-Errata: E2-12: gMonth
- *
- * Revision 1.2  2002/11/04 15:22:05  tng
- * C++ Namespace Support.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:14  peiyongz
- * sane_include
- *
- * Revision 1.4  2001/11/14 22:04:03  peiyongz
- * Patch to apply check on Year and more rigorous on other fields as well.
- *
- * Revision 1.3  2001/11/12 20:36:54  peiyongz
- * SchemaDateTimeException defined
- *
- * Revision 1.2  2001/11/09 20:41:45  peiyongz
- * Fix: compilation error on Solaris and AIX.
- *
- * Revision 1.1  2001/11/07 19:16:03  peiyongz
- * DateTime Port
- *
- *
+ * $Id: XMLDateTime.cpp 225847 2005-07-28 18:54:29Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
@@ -153,6 +23,8 @@
 // ---------------------------------------------------------------------------
 #include <stdlib.h>
 #include <assert.h>
+#include <errno.h>
+
 #include <xercesc/util/XMLDateTime.hpp>
 #include <xercesc/util/XMLString.hpp>
 #include <xercesc/util/XMLUni.hpp>
@@ -357,6 +229,10 @@ void XMLDateTime::addDuration(XMLDateTime*             fNewDate
     int temp = DATETIMES[index][Month] + fDuration->fValue[Month];
     fNewDate->fValue[Month] = modulo(temp, 1, 13);
     int carry = fQuotient(temp, 1, 13);
+    if (fNewDate->fValue[Month] <= 0) {
+        fNewDate->fValue[Month]+= 12;
+        carry--;
+    }
 
     //add years (may be modified additionaly below)
     fNewDate->fValue[CentYear] = DATETIMES[index][CentYear] + fDuration->fValue[CentYear] + carry;
@@ -365,17 +241,29 @@ void XMLDateTime::addDuration(XMLDateTime*             fNewDate
     temp = DATETIMES[index][Second] + fDuration->fValue[Second];
     carry = fQuotient (temp, 60);
     fNewDate->fValue[Second] =  mod(temp, 60, carry);
-		
+    if (fNewDate->fValue[Second] < 0) {
+        fNewDate->fValue[Second]+= 60;
+        carry--;
+    }
+    
     //add minutes
     temp = DATETIMES[index][Minute] + fDuration->fValue[Minute] + carry;
     carry = fQuotient(temp, 60);
     fNewDate->fValue[Minute] = mod(temp, 60, carry);
+    if (fNewDate->fValue[Minute] < 0) {
+        fNewDate->fValue[Minute]+= 60;
+        carry--;
+    }
 
     //add hours
     temp = DATETIMES[index][Hour] + fDuration->fValue[Hour] + carry;
     carry = fQuotient(temp, 24);
     fNewDate->fValue[Hour] = mod(temp, 24, carry);
-		
+    if (fNewDate->fValue[Hour] < 0) {
+        fNewDate->fValue[Hour]+= 24;
+        carry--;
+    }
+    
     fNewDate->fValue[Day] = DATETIMES[index][Day] + fDuration->fValue[Day] + carry;
 
     while ( true )
@@ -398,6 +286,10 @@ void XMLDateTime::addDuration(XMLDateTime*             fNewDate
 
         temp = fNewDate->fValue[Month] + carry;
         fNewDate->fValue[Month] = modulo(temp, 1, 13);
+        if (fNewDate->fValue[Month] <= 0) {
+            fNewDate->fValue[Month]+= 12;
+            fNewDate->fValue[CentYear]--;
+        }
         fNewDate->fValue[CentYear] += fQuotient(temp, 1, 13);
     }
 
@@ -509,6 +401,18 @@ int XMLDateTime::compareOrder(const XMLDateTime* const lValue
         }
     }
 
+    if ( lTemp.fHasTime)
+    {
+        if ( lTemp.fMiliSecond < rTemp.fMiliSecond )
+        {
+            return LESS_THAN;
+        }
+        else if ( lTemp.fMiliSecond > rTemp.fMiliSecond )
+        {
+            return GREATER_THAN;
+        }
+    }
+
     return EQUAL;
 }
 
@@ -525,6 +429,8 @@ XMLDateTime::XMLDateTime(MemoryManager* const manager)
 : fStart(0)
 , fEnd(0)
 , fBufferMaxLen(0)
+, fMiliSecond(0)
+, fHasTime(false)
 , fBuffer(0)
 , fMemoryManager(manager)
 {
@@ -536,6 +442,8 @@ XMLDateTime::XMLDateTime(const XMLCh* const aString,
 : fStart(0)
 , fEnd(0)
 , fBufferMaxLen(0)
+, fMiliSecond(0)
+, fHasTime(false)
 , fBuffer(0)
 , fMemoryManager(manager)
 {
@@ -547,7 +455,8 @@ XMLDateTime::XMLDateTime(const XMLCh* const aString,
 // -----------------------------------------------------------------------
 
 XMLDateTime::XMLDateTime(const XMLDateTime &toCopy)
-: fBufferMaxLen(0)
+: XMLNumber(toCopy)
+, fBufferMaxLen(0)
 , fBuffer(0)
 , fMemoryManager(toCopy.fMemoryManager)
 {
@@ -624,6 +533,7 @@ void XMLDateTime::parseDateTime()
     getTime();
     validateDateTime();
     normalize();
+    fHasTime = true;
 }
 
 //
@@ -651,6 +561,7 @@ void XMLDateTime::parseTime()
 
     validateDateTime();
     normalize();
+    fHasTime = true;
 }
 
 //
@@ -677,9 +588,9 @@ void XMLDateTime::parseDay()
     fValue[Day]      = parseInt(fStart+3, fStart+5);
 
     if ( DAY_SIZE < fEnd )
-    {
-        int sign = findUTCSign(DAY_SIZE);
-        if ( sign < 0 )
+    {        
+        int pos = XMLString::indexOf(UTC_SET, fBuffer[DAY_SIZE]);
+        if (pos == -1 )
         {
             ThrowXMLwithMemMgr1(SchemaDateTimeException
                     , XMLExcepts::DateTime_gDay_invalid
@@ -688,7 +599,8 @@ void XMLDateTime::parseDay()
         }
         else
         {
-            getTimeZone(sign);
+            fValue[utc] = pos+1;
+            getTimeZone(DAY_SIZE);
         }
     }
 
@@ -732,9 +644,9 @@ void XMLDateTime::parseMonth()
     // parse TimeZone if any
     //
     if ( fStart < fEnd )
-    {
-        int sign = findUTCSign(fStart);
-        if ( sign < 0 )
+    {      
+        int pos = XMLString::indexOf(UTC_SET, fBuffer[fStart]);
+        if ( pos == NOT_FOUND )
         {
             ThrowXMLwithMemMgr1(SchemaDateTimeException
                     , XMLExcepts::DateTime_gMth_invalid
@@ -743,7 +655,8 @@ void XMLDateTime::parseMonth()
         }
         else
         {
-            getTimeZone(sign);
+            fValue[utc] = pos+1;
+            getTimeZone(fStart);
         }
     }
 
@@ -806,9 +719,9 @@ void XMLDateTime::parseMonthDay()
     fValue[Day]      = parseInt(5, 7);
 
     if ( MONTHDAY_SIZE < fEnd )
-    {
-        int sign = findUTCSign(MONTHDAY_SIZE);
-        if ( sign<0 )
+    {        
+        int pos = XMLString::indexOf(UTC_SET, fBuffer[MONTHDAY_SIZE]);
+        if ( pos == NOT_FOUND )
         {
             ThrowXMLwithMemMgr1(SchemaDateTimeException
                     , XMLExcepts::DateTime_gMthDay_invalid
@@ -817,7 +730,8 @@ void XMLDateTime::parseMonthDay()
         }
         else
         {
-            getTimeZone(sign);
+            fValue[utc] = pos+1;
+            getTimeZone(MONTHDAY_SIZE);
         }
     }
 
@@ -988,7 +902,7 @@ void XMLDateTime::parseDuration()
                 }
 
                 fValue[Second]     = negate * parseInt(fStart, mlsec);
-                fValue[MiliSecond] = negate * parseInt(mlsec+1, end);
+                fMiliSecond        = negate * parseMiliSecond(mlsec+1, end);
             }
             else
             {
@@ -1124,17 +1038,12 @@ void XMLDateTime::getTime()
 
         if ( sign == NOT_FOUND )
         {
-            fValue[MiliSecond] = parseInt(fStart, fEnd);  //get ms between '.' and fEnd
+            fMiliSecond = parseMiliSecond(fStart, fEnd);  //get ms between '.' and fEnd
             fStart = fEnd;
         }
         else
         {
-            //to do: parseInt would eliminate any leading zeros
-            //       therefore for 12:01:01.0034
-            //       fValue[MiliSecond] would catch 34
-            //       rather than 0034
-            //
-            fValue[MiliSecond] = parseInt(fStart, sign);  //get ms between UTC sign and fEnd
+            fMiliSecond = parseMiliSecond(fStart, sign);  //get ms between UTC sign and fEnd
         }
 	}
     else if(sign == 0 || sign != fStart)
@@ -1205,21 +1114,19 @@ void XMLDateTime::getYearMonth()
 
 void XMLDateTime::parseTimeZone()
 {
-    if ( fStart < fEnd )
-    {
-        int sign = findUTCSign(fStart);
-        if ( sign < 0 )
-        {
+    //fStart points right after the date   	 
+  	if ( fStart < fEnd ) {
+        int pos = XMLString::indexOf(UTC_SET, fBuffer[fStart]);
+    	if (pos == NOT_FOUND) {
             ThrowXMLwithMemMgr1(SchemaDateTimeException
                     , XMLExcepts::DateTime_tz_noUTCsign
                     , fBuffer
                     , fMemoryManager);
-            //("Error in month parsing");
-        }
-        else
-        {
-            getTimeZone(sign);
-        }
+   		}
+   		else { 
+            fValue[utc] = pos+1;
+  	        getTimeZone(fStart);   		
+   		}
     }
 
     return;
@@ -1289,18 +1196,42 @@ void XMLDateTime::normalize()
         return;
 
     int negate = (fValue[utc] == UTC_POS)? -1: 1;
+    int temp;
+    int carry;
+    
+
+    // we normalize a duration so could have 200M...
+    //update months (may be modified additionaly below)
+    temp = fValue[Month];
+    fValue[Month] = modulo(temp, 1, 13);
+    carry = fQuotient(temp, 1, 13);
+    if (fValue[Month] <= 0) {
+        fValue[Month]+= 12;
+        carry--;
+    }
+
+    //add years (may be modified additionaly below)
+    fValue[CentYear] += carry;
 
     // add mins
-    int temp = fValue[Minute] + negate * fTimeZone[mm];
-    int carry = fQuotient(temp, 60);
+    temp = fValue[Minute] + negate * fTimeZone[mm];
+    carry = fQuotient(temp, 60);
     fValue[Minute] = mod(temp, 60, carry);
-
+    if (fValue[Minute] < 0) {
+        fValue[Minute] += 60;
+        carry--;
+    }
+   
     //add hours
     temp = fValue[Hour] + negate * fTimeZone[hh] + carry;
     carry = fQuotient(temp, 24);
     fValue[Hour] = mod(temp, 24, carry);
+    if (fValue[Hour] < 0) {
+        fValue[Hour] += 24;
+        carry--;
+    }
 
-    fValue[Day] += carry;
+    fValue[Day] += carry;   
 
     while (1)
     {
@@ -1322,6 +1253,10 @@ void XMLDateTime::normalize()
 
         temp = fValue[Month] + carry;
         fValue[Month] = modulo(temp, 1, 13);
+        if (fValue[Month] <=0) {
+            fValue[Month]+= 12;
+            fValue[CentYear]--;
+        }
         fValue[CentYear] += fQuotient(temp, 1, 13);
     }
 
@@ -1371,7 +1306,7 @@ void XMLDateTime::validateDateTime() const
         (fValue[Hour] > 24) ||
         ((fValue[Hour] == 24) && ((fValue[Minute] !=0) ||
                                   (fValue[Second] !=0) ||
-                                  (fValue[MiliSecond] !=0))))
+                                  (fMiliSecond    !=0))))
     {
         ThrowXMLwithMemMgr1(SchemaDateTimeException
                 , XMLExcepts::DateTime_hour_invalid
@@ -1474,6 +1409,31 @@ int XMLDateTime::parseInt(const int start, const int end) const
     return (int) retVal;
 }
 
+//
+// Note:
+//    start: pointing to the first digit after the '.'
+//    end:   pointing to one position after the last digit
+//    fStart NOT updated
+//
+double XMLDateTime::parseMiliSecond(const int start, const int end) const
+{
+    double div = 10;
+    double retval = 0;
+    
+    for (int i=start; i < end; i++) {
+
+        if (fBuffer[i] < chDigit_0 || fBuffer[i] > chDigit_9)
+            ThrowXMLwithMemMgr(NumberFormatException, XMLExcepts::XMLNUM_Inv_chars, fMemoryManager);
+
+        retval += (fBuffer[i] == chDigit_0) ? 0 : ((double) (fBuffer[i] - chDigit_0)/div);
+        div *= 10;
+    }
+
+    // we don't check underflow occurs since
+    // nothing we can do about it.
+    return retval;
+}
+
 //
 // [-]CCYY
 //
@@ -1535,15 +1495,16 @@ XMLCh* XMLDateTime::getDateTimeCanonicalRepresentation(MemoryManager* const memM
     XMLCh *miliStartPtr, *miliEndPtr;
     searchMiliSeconds(miliStartPtr, miliEndPtr);
     int miliSecondsLen = miliEndPtr - miliStartPtr;
+    int utcSize = (fValue[utc] == UTC_UNKNOWN) ? 0 : 1;
 
     MemoryManager* toUse = memMgr? memMgr : fMemoryManager;
-    XMLCh* retBuf = (XMLCh*) toUse->allocate( (21 + miliSecondsLen + 2) * sizeof(XMLCh));
+    XMLCh* retBuf = (XMLCh*) toUse->allocate( (21 + miliSecondsLen + utcSize + 1) * sizeof(XMLCh));
     XMLCh* retPtr = retBuf;
 
     // (-?) cc+yy-mm-dd'T'hh:mm:ss'Z'    ('.'s+)?
     //      2+  8       1      8   1
     //
-    int additionalLen = fillYearString(retPtr, CentYear);
+    int additionalLen = fillYearString(retPtr, fValue[CentYear]);
     if(additionalLen != 0)
     {
         // very bad luck; have to resize the buffer...
@@ -1554,21 +1515,21 @@ XMLCh* XMLDateTime::getDateTimeCanonicalRepresentation(MemoryManager* const memM
         retBuf = tmpBuf;
     }
     *retPtr++ = DATE_SEPARATOR;
-    fillString(retPtr, Month, 2);
+    fillString(retPtr, fValue[Month], 2);
     *retPtr++ = DATE_SEPARATOR;
-    fillString(retPtr, Day, 2);
+    fillString(retPtr, fValue[Day], 2);
     *retPtr++ = DATETIME_SEPARATOR;
 
-    fillString(retPtr, Hour, 2);
+    fillString(retPtr, fValue[Hour], 2);
     if (fValue[Hour] == 24)
     {
         *(retPtr - 2) = chDigit_0;
         *(retPtr - 1) = chDigit_0;
     }
     *retPtr++ = TIME_SEPARATOR;
-    fillString(retPtr, Minute, 2);
+    fillString(retPtr, fValue[Minute], 2);
     *retPtr++ = TIME_SEPARATOR;
-    fillString(retPtr, Second, 2);
+    fillString(retPtr, fValue[Second], 2);
 
     if (miliSecondsLen)
     {
@@ -1577,12 +1538,162 @@ XMLCh* XMLDateTime::getDateTimeCanonicalRepresentation(MemoryManager* const memM
         retPtr += miliSecondsLen;
     }
 
-    *retPtr++ = UTC_STD_CHAR;
+    if (utcSize)
+        *retPtr++ = UTC_STD_CHAR;
     *retPtr = chNull;
 
     return retBuf;
 }
 
+/***
+ * E2-41
+ *
+ *  3.2.9.2 Canonical representation
+ * 
+ * Given a member of the date value space, the date 
+ * portion of the canonical representation (the entire 
+ * representation for nontimezoned values, and all but
+ * the timezone representation for timezoned values) 
+ * is always the date portion of the dateTime canonical
+ * representation of the interval midpoint (the 
+ * dateTime representation, truncated on the right
+ * to eliminate 'T' and all following characters). 
+ * For timezoned values, append the canonical 
+ * representation of the recoverable timezone. 
+ *
+ ***/
+XMLCh* XMLDateTime::getDateCanonicalRepresentation(MemoryManager* const memMgr) const
+{    
+    /*
+     * Case Date               Actual Value    Canonical Value
+     *    1 yyyy-mm-dd         yyyy-mm-dd          yyyy-mm-dd
+     *    2 yyyy-mm-ddZ        yyyy-mm-ddT00:00Z   yyyy-mm-ddZ
+     *    3 yyyy-mm-dd+00:00   yyyy-mm-ddT00:00Z   yyyy-mm-ddZ
+     *    4 yyyy-mm-dd+00:01   YYYY-MM-DCT23:59Z   yyyy-mm-dd+00:01              
+     *    5 yyyy-mm-dd+12:00   YYYY-MM-DCT12:00Z   yyyy-mm-dd+12:00    
+     *    6 yyyy-mm-dd+12:01   YYYY-MM-DCT11:59Z   YYYY-MM-DC-11:59 
+     *    7 yyyy-mm-dd+14:00   YYYY-MM-DCT10:00Z   YYYY-MM-DC-10:00 
+     *    8 yyyy-mm-dd-00:00   yyyy-mm-ddT00:00Z   yyyy-mm-ddZ
+     *    9 yyyy-mm-dd-00:01   yyyy-mm-ddT00:01Z   yyyy-mm-dd-00:01 
+     *   11 yyyy-mm-dd-11:59   yyyy-mm-ddT11:59Z   YYYY-MM-DD-11:59
+     *   10 yyyy-mm-dd-12:00   yyyy-mm-ddT12:00Z   YYYY-MM-DD+12:00      
+     *   12 yyyy-mm-dd-14:00   yyyy-mm-ddT14:00Z   YYYY-MM-DD+10:00
+     */
+    int utcSize = (fValue[utc] == UTC_UNKNOWN) ? 0 : 1;
+    // YYYY-MM-DD  + chNull 
+    // 1234567890  + 1
+    int memLength = 10 + 1 + utcSize;
+
+    if (fTimeZone[hh] != 0 || fTimeZone[mm] != 0) {
+        // YYYY-MM-DD+HH:MM  (utcSize will be 1 so drop that)
+        // 1234567890123456
+        memLength += 5; // 6 - 1 for utcSize
+    }
+
+    MemoryManager* toUse = memMgr? memMgr : fMemoryManager;
+    XMLCh* retBuf = (XMLCh*) toUse->allocate( (memLength) * sizeof(XMLCh));
+    XMLCh* retPtr = retBuf;
+
+    if (fValue[Hour] < 12) {
+        
+        int additionalLen = fillYearString(retPtr, fValue[CentYear]);
+        if (additionalLen != 0) {
+            // very bad luck; have to resize the buffer...
+            XMLCh *tmpBuf = (XMLCh*) toUse->allocate( (additionalLen + memLength ) * sizeof(XMLCh));
+            XMLString::moveChars(tmpBuf, retBuf, 4+additionalLen);
+            retPtr = tmpBuf+(retPtr-retBuf);
+            toUse->deallocate(retBuf);
+            retBuf = tmpBuf;
+        }
+        *retPtr++ = DATE_SEPARATOR;
+        fillString(retPtr, fValue[Month], 2);
+        *retPtr++ = DATE_SEPARATOR;
+        fillString(retPtr, fValue[Day], 2);        
+
+        if (utcSize) {
+            if (fTimeZone[hh] != 0 || fTimeZone[mm] != 0) {
+                *retPtr++ = UTC_NEG_CHAR;               
+                fillString(retPtr, fValue[Hour], 2);
+                *retPtr++ = TIME_SEPARATOR;
+                fillString(retPtr, fValue[Minute], 2);
+            }
+            else {
+                *retPtr++ = UTC_STD_CHAR;
+            }
+        }
+        *retPtr = chNull;    
+    }
+    else {
+        /*
+         * Need to reconvert things to get a recoverable time zone between
+         * +12:00 and -11:59
+         */
+        int carry;
+        int minute;
+        int hour;
+        int day;
+        int month;
+        int year;
+        if (fValue[Minute] == 0) {
+            minute = 0;
+            carry = 0;
+        }
+        else {
+            minute = 60 - fValue[Minute];
+            carry = 1;
+        }
+        hour  = 24 - fValue[Hour] - carry;
+        day   = fValue[Day] + 1;
+        month = fValue[Month];
+        year  = fValue[CentYear];
+
+        while (1) {
+            int temp = maxDayInMonthFor(year, month);
+            if (day < 1) {
+                day += maxDayInMonthFor(year, month - 1);
+                carry = -1;
+            }
+            else if (day > temp) {
+                day -= temp;
+                carry = 1;
+            }
+            else {
+                break;
+            }
+
+            temp = month + carry;
+            month = modulo(temp, 1, 13);
+            if (month <= 0) {
+                month+= 12;
+                year--;
+            }
+            year += fQuotient(temp, 1, 13);         
+        }
+
+        int additionalLen = fillYearString(retPtr, year);
+        if (additionalLen != 0) {
+            // very bad luck; have to resize the buffer...
+            XMLCh *tmpBuf = (XMLCh*) toUse->allocate( (additionalLen + memLength ) * sizeof(XMLCh));
+            XMLString::moveChars(tmpBuf, retBuf, 4+additionalLen);
+            retPtr = tmpBuf+(retPtr-retBuf);
+            toUse->deallocate(retBuf);
+            retBuf = tmpBuf;
+        }
+        *retPtr++ = DATE_SEPARATOR;
+        fillString(retPtr, month, 2);
+        *retPtr++ = DATE_SEPARATOR;
+        fillString(retPtr, day, 2);        
+       
+        *retPtr++ = UTC_POS_CHAR;               
+        fillString(retPtr, hour, 2);
+        *retPtr++ = TIME_SEPARATOR;
+        fillString(retPtr, minute, 2);                                
+        *retPtr = chNull;
+    }      
+    return retBuf;
+}
+
+
 /***
  * 3.2.8 time
  *
@@ -1597,25 +1708,26 @@ XMLCh* XMLDateTime::getTimeCanonicalRepresentation(MemoryManager* const memMgr)
     XMLCh *miliStartPtr, *miliEndPtr;
     searchMiliSeconds(miliStartPtr, miliEndPtr);
     int miliSecondsLen = miliEndPtr - miliStartPtr;
-
+    int utcSize = (fValue[utc] == UTC_UNKNOWN) ? 0 : 1;
+    
     MemoryManager* toUse = memMgr? memMgr : fMemoryManager;
-    XMLCh* retBuf = (XMLCh*) toUse->allocate( (10 + miliSecondsLen + 2) * sizeof(XMLCh));
+    XMLCh* retBuf = (XMLCh*) toUse->allocate( (10 + miliSecondsLen + utcSize + 1) * sizeof(XMLCh));
     XMLCh* retPtr = retBuf;
 
     // 'hh:mm:ss'Z'    ('.'s+)?
     //      8    1
     //
 
-    fillString(retPtr, Hour, 2);
+    fillString(retPtr, fValue[Hour], 2);
     if (fValue[Hour] == 24)
     {
         *(retPtr - 2) = chDigit_0;
         *(retPtr - 1) = chDigit_0;
     }
     *retPtr++ = TIME_SEPARATOR;
-    fillString(retPtr, Minute, 2);
+    fillString(retPtr, fValue[Minute], 2);
     *retPtr++ = TIME_SEPARATOR;
-    fillString(retPtr, Second, 2);
+    fillString(retPtr, fValue[Second], 2);
 
     if (miliSecondsLen)
     {
@@ -1624,17 +1736,18 @@ XMLCh* XMLDateTime::getTimeCanonicalRepresentation(MemoryManager* const memMgr)
         retPtr += miliSecondsLen;
     }
 
-    *retPtr++ = UTC_STD_CHAR;
+    if (utcSize)
+        *retPtr++ = UTC_STD_CHAR;
     *retPtr = chNull;
 
     return retBuf;
 }
 
-void XMLDateTime::fillString(XMLCh*& ptr, valueIndex ind, int expLen) const
+void XMLDateTime::fillString(XMLCh*& ptr, int value, int expLen) const
 {
     XMLCh strBuffer[16];
     assert(expLen < 16);
-    XMLString::binToText(fValue[ind], strBuffer, expLen, 10, fMemoryManager);
+    XMLString::binToText(value, strBuffer, expLen, 10, fMemoryManager);
     int   actualLen = XMLString::stringLen(strBuffer);
     int   i;
     //append leading zeros
@@ -1650,11 +1763,11 @@ void XMLDateTime::fillString(XMLCh*& ptr, valueIndex ind, int expLen) const
 
 }
 
-int XMLDateTime::fillYearString(XMLCh*& ptr, valueIndex ind) const
+int XMLDateTime::fillYearString(XMLCh*& ptr, int value) const
 {
     XMLCh strBuffer[16];
     // let's hope we get no years of 15 digits...
-    XMLString::binToText(fValue[ind], strBuffer, 15, 10, fMemoryManager);
+    XMLString::binToText(value, strBuffer, 15, 10, fMemoryManager);
     int   actualLen = XMLString::stringLen(strBuffer);
     // don't forget that years can be negative...
     int negativeYear = 0;
