@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: XMLURL.cpp,v 1.7 2003/05/16 06:01:53 knoaman Exp $
+ * $Id: XMLURL.cpp 231102 2005-08-09 20:19:06Z dbertoni $
  */
 
 
@@ -73,6 +33,8 @@
 #include <xercesc/util/XMLUniDefs.hpp>
 #include <xercesc/util/XMLUni.hpp>
 #include <xercesc/util/XMLUri.hpp>
+#include <xercesc/util/OutOfMemoryException.hpp>
+#include <xercesc/util/XMLChar.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -135,6 +97,12 @@ static ProtoEntry gProtoList[XMLURL::Protocols_Count] =
 // !!! Keep these up to date with list above!
 static const unsigned int gMaxProtoLen = 4;
 
+static const XMLCh gListOne[]    = { chColon, chForwardSlash, chNull };
+static const XMLCh gListTwo[]    = { chAt, chNull };
+static const XMLCh gListThree[]  = { chColon, chNull };
+static const XMLCh gListFour[]   = { chForwardSlash, chNull };
+static const XMLCh gListFive[]   = { chPound, chQuestion, chNull };
+static const XMLCh gListSix[]    = { chPound, chNull };
 
 // ---------------------------------------------------------------------------
 //  Local methods
@@ -170,7 +138,7 @@ XMLURL::Protocols XMLURL::lookupByName(const XMLCh* const protoName)
 {
     for (unsigned int index = 0; index < XMLURL::Protocols_Count; index++)
     {
-        if (!XMLString::compareIString(gProtoList[index].prefix, protoName))
+        if (!XMLString::compareIStringASCII(protoName, gProtoList[index].prefix))
             return gProtoList[index].protocol;
     }
     return XMLURL::Unknown;
@@ -197,6 +165,8 @@ XMLURL::XMLURL(MemoryManager* const manager) :
 {
 }
 
+typedef JanitorMemFunCall<XMLURL>   CleanupType;
+
 XMLURL::XMLURL(const XMLCh* const    baseURL
              , const XMLCh* const    relativeURL
              , MemoryManager* const manager) :
@@ -213,15 +183,20 @@ XMLURL::XMLURL(const XMLCh* const    baseURL
     , fURLText(0)
     , fHasInvalidChar(false)
 {
+    CleanupType cleanup(this, &XMLURL::cleanUp);
+
 	try
-	{
-		setURL(baseURL, relativeURL);
+	{	
+        setURL(baseURL, relativeURL);
 	}
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        cleanup();
+        cleanup.release();
+
         throw;
     }
+
+    cleanup.release();
 }
 
 XMLURL::XMLURL(const XMLCh* const  baseURL
@@ -240,17 +215,22 @@ XMLURL::XMLURL(const XMLCh* const  baseURL
     , fURLText(0)
     , fHasInvalidChar(false)
 {
+    CleanupType cleanup(this, &XMLURL::cleanUp);
+
     XMLCh* tmpRel = XMLString::transcode(relativeURL, fMemoryManager);
     ArrayJanitor<XMLCh> janRel(tmpRel, fMemoryManager);
 	try
 	{
 		setURL(baseURL, tmpRel);
 	}
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        cleanup();
+        cleanup.release();
+
         throw;
     }
+
+    cleanup.release();
 }
 
 XMLURL::XMLURL(const XMLURL&         baseURL
@@ -268,15 +248,20 @@ XMLURL::XMLURL(const XMLURL&         baseURL
     , fURLText(0)
     , fHasInvalidChar(false)
 {
+    CleanupType cleanup(this, &XMLURL::cleanUp);
+
 	try
 	{
 		setURL(baseURL, relativeURL);
 	}
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        cleanup();
+        cleanup.release();
+
         throw;
     }
+
+    cleanup.release();
 }
 
 XMLURL::XMLURL(const  XMLURL&        baseURL
@@ -294,18 +279,22 @@ XMLURL::XMLURL(const  XMLURL&        baseURL
     , fURLText(0)
     , fHasInvalidChar(false)
 {
+    CleanupType cleanup(this, &XMLURL::cleanUp);
+
     XMLCh* tmpRel = XMLString::transcode(relativeURL, fMemoryManager);
     ArrayJanitor<XMLCh> janRel(tmpRel, fMemoryManager);
 	try
 	{
 		setURL(baseURL, tmpRel);
 	}
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        cleanup();
+        cleanup.release();
+
         throw;
     }
 
+    cleanup.release();
 }
 
 XMLURL::XMLURL(const XMLCh* const urlText,
@@ -323,15 +312,20 @@ XMLURL::XMLURL(const XMLCh* const urlText,
     , fURLText(0)
     , fHasInvalidChar(false)
 {
+    CleanupType cleanup(this, &XMLURL::cleanUp);
+
 	try
 	{
 	    setURL(urlText);
 	}
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        cleanup();
+        cleanup.release();
+
         throw;
     }
+
+    cleanup.release();
 }
 
 XMLURL::XMLURL(const char* const urlText,
@@ -349,22 +343,27 @@ XMLURL::XMLURL(const char* const urlText,
     , fURLText(0)
     , fHasInvalidChar(false)
 {
+    CleanupType cleanup(this, &XMLURL::cleanUp);
+
     XMLCh* tmpText = XMLString::transcode(urlText, fMemoryManager);
     ArrayJanitor<XMLCh> janRel(tmpText, fMemoryManager);
 	try
 	{
 	    setURL(tmpText);
 	}
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        cleanup();
+        cleanup.release();
+
         throw;
     }
+
+    cleanup.release();
 }
 
 XMLURL::XMLURL(const XMLURL& toCopy) :
-
-    fMemoryManager(toCopy.fMemoryManager)
+    XMemory(toCopy)
+    , fMemoryManager(toCopy.fMemoryManager)
     , fFragment(0)
     , fHost(0)
     , fPassword(0)
@@ -376,6 +375,8 @@ XMLURL::XMLURL(const XMLURL& toCopy) :
     , fURLText(0)
     , fHasInvalidChar(toCopy.fHasInvalidChar)
 {
+    CleanupType cleanup(this, &XMLURL::cleanUp);
+
     try
     {
         fFragment = XMLString::replicate(toCopy.fFragment, fMemoryManager);
@@ -386,15 +387,19 @@ XMLURL::XMLURL(const XMLURL& toCopy) :
         fUser = XMLString::replicate(toCopy.fUser, fMemoryManager);
         fURLText = XMLString::replicate(toCopy.fURLText, fMemoryManager);
     }
-    catch(...)
+    catch(const OutOfMemoryException&)
     {
-        cleanup();
+        cleanup.release();
+
+        throw;
     }
+
+    cleanup.release();
 }
 
 XMLURL::~XMLURL()
 {
-    cleanup();
+    cleanUp();
 }
 
 
@@ -407,17 +412,20 @@ XMLURL& XMLURL::operator=(const XMLURL& toAssign)
         return *this;
 
     // Clean up our stuff
-    cleanup();
+    cleanUp();
 
     // And copy his stuff
+    fMemoryManager = toAssign.fMemoryManager;
     fFragment = XMLString::replicate(toAssign.fFragment, fMemoryManager);
     fHost = XMLString::replicate(toAssign.fHost, fMemoryManager);
     fPassword = XMLString::replicate(toAssign.fPassword, fMemoryManager);
     fPath = XMLString::replicate(toAssign.fPath, fMemoryManager);
+    fPortNum = toAssign.fPortNum;
     fProtocol = toAssign.fProtocol;
     fQuery = XMLString::replicate(toAssign.fQuery, fMemoryManager);
     fUser = XMLString::replicate(toAssign.fUser, fMemoryManager);
     fURLText = XMLString::replicate(toAssign.fURLText, fMemoryManager);
+    fHasInvalidChar = toAssign.fHasInvalidChar;
 
     return *this;
 }
@@ -460,7 +468,7 @@ const XMLCh* XMLURL::getProtocolName() const
 {
     // Check to see if its ever been set
     if (fProtocol == Unknown)
-        ThrowXML(MalformedURLException, XMLExcepts::URL_NoProtocolPresent);
+        ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_NoProtocolPresent, fMemoryManager);
 
     return gProtoList[fProtocol].prefix;
 }
@@ -474,14 +482,14 @@ void XMLURL::setURL(const XMLCh* const urlText)
     //
     //  Try to parse the URL.
     //
-    cleanup();
+    cleanUp();
     parse(urlText);
 }
 
 void XMLURL::setURL(const XMLCh* const    baseURL
                   , const XMLCh* const    relativeURL)
 {
-    cleanup();
+    cleanUp();
 
     // Parse our URL string
     parse(relativeURL);
@@ -497,17 +505,46 @@ void XMLURL::setURL(const XMLCh* const    baseURL
 			XMLURL basePart(baseURL, fMemoryManager);
 			if (!conglomerateWithBase(basePart, false))
 			{
-				cleanup();
-				ThrowXML(MalformedURLException, XMLExcepts::URL_RelativeBaseURL);
+				cleanUp();
+				ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_RelativeBaseURL, fMemoryManager);
 			}
 		}
 	}
 }
 
+// this version of setURL doesn't throw a malformedurl exception
+// instead it returns false when it failed (or when it would of
+// thrown a malformedurl exception)
+bool XMLURL::setURL(const XMLCh* const    baseURL
+                  , const XMLCh* const    relativeURL
+                  , XMLURL& xmlURL)
+{
+    cleanUp();
+
+    // Parse our URL string
+    if (parse(relativeURL, xmlURL))
+    {
+	    //  If its relative and the base is non-null and non-empty, then
+	    //  parse the base URL string and conglomerate them.
+	    //
+	    if (isRelative() && baseURL && *baseURL)
+	    {		   
+	        XMLURL basePart(fMemoryManager);
+            if (parse(baseURL, basePart)  && conglomerateWithBase(basePart, false))
+            {    
+		        return true;			                    
+		    }
+	    }
+        else
+            return true;
+    }
+    return false;
+}
+
 void XMLURL::setURL(const XMLURL&         baseURL
                   , const XMLCh* const    relativeURL)
 {
-    cleanup();
+    cleanUp();
 
 	// Parse our URL string
     parse(relativeURL);
@@ -552,7 +589,7 @@ BinInputStream* XMLURL::makeNewStream() const
     //
     if (fProtocol == XMLURL::File)
     {
-        if (!fHost || !XMLString::compareIString(fHost, XMLUni::fgLocalHostString))
+        if (!fHost || !XMLString::compareIStringASCII(fHost, XMLUni::fgLocalHostString))
         {
 
             XMLCh* realPath = XMLString::replicate(fPath, fMemoryManager);
@@ -563,7 +600,7 @@ BinInputStream* XMLURL::makeNewStream() const
             // HTTP protocol will be done automatically by the netaccessor
             //
             int end = XMLString::stringLen(realPath);
-            int percentIndex = XMLString::indexOf(realPath, chPercent, 0);
+            int percentIndex = XMLString::indexOf(realPath, chPercent, 0, fMemoryManager);
 
             while (percentIndex != -1) {
 
@@ -574,10 +611,11 @@ BinInputStream* XMLURL::makeNewStream() const
                     XMLCh value1[4];
                     XMLString::moveChars(value1, &(realPath[percentIndex]), 3);
                     value1[3] = chNull;
-                    ThrowXML2(MalformedURLException
+                    ThrowXMLwithMemMgr2(MalformedURLException
                             , XMLExcepts::XMLNUM_URI_Component_Invalid_EscapeSequence
                             , realPath
-                            , value1);
+                            , value1
+                            , fMemoryManager);
                 }
 
                 unsigned int value = (xlatHexDigit(realPath[percentIndex+1]) * 16) + xlatHexDigit(realPath[percentIndex+2]);
@@ -590,11 +628,11 @@ BinInputStream* XMLURL::makeNewStream() const
                 realPath[i] = chNull;
                 end = i;
 
-                percentIndex = XMLString::indexOf(realPath, chPercent, percentIndex);
+                percentIndex = XMLString::indexOf(realPath, chPercent, percentIndex, fMemoryManager);
             }
 
 
-            BinFileInputStream* retStrm = new (fMemoryManager) BinFileInputStream(realPath);
+            BinFileInputStream* retStrm = new (fMemoryManager) BinFileInputStream(realPath, fMemoryManager);
             if (!retStrm->getIsOpen())
             {
                 delete retStrm;
@@ -609,7 +647,7 @@ BinInputStream* XMLURL::makeNewStream() const
     //  have to just throw here.
     //
     if (!XMLPlatformUtils::fgNetAccessor)
-        ThrowXML(MalformedURLException, XMLExcepts::URL_UnsupportedProto);
+        ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_UnsupportedProto, fMemoryManager);
 
     // Else ask the net accessor to create the stream
     return XMLPlatformUtils::fgNetAccessor->makeNew(*this);
@@ -700,8 +738,8 @@ void XMLURL::buildFullText()
         {
             *outPtr++ = chColon;
 
-            XMLCh tmpBuf[16];
-            XMLString::binToText(fPortNum, tmpBuf, 16, 10);
+            XMLCh tmpBuf[17];
+            XMLString::binToText(fPortNum, tmpBuf, 16, 10, fMemoryManager);
             XMLString::copyString(outPtr, tmpBuf);
             outPtr += XMLString::stringLen(tmpBuf);
         }
@@ -736,7 +774,7 @@ void XMLURL::buildFullText()
 //  Just a central place to handle cleanup, since its done from a number
 //  of different spots.
 //
-void XMLURL::cleanup()
+void XMLURL::cleanUp()
 {
     fMemoryManager->deallocate(fFragment);//delete [] fFragment;
     fMemoryManager->deallocate(fHost);//delete [] fHost;
@@ -756,6 +794,7 @@ void XMLURL::cleanup()
 
     fProtocol = Unknown;
     fPortNum = 0;
+    fHasInvalidChar = false;
 }
 
 
@@ -769,7 +808,7 @@ bool XMLURL::conglomerateWithBase(const XMLURL& baseURL, bool useExceptions)
     if (baseURL.isRelative())
     {
         if (useExceptions)
-			ThrowXML(MalformedURLException, XMLExcepts::URL_RelativeBaseURL);
+			ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_RelativeBaseURL, fMemoryManager);
         else
             return false;
     }
@@ -848,7 +887,7 @@ bool XMLURL::conglomerateWithBase(const XMLURL& baseURL, bool useExceptions)
 
     // Its a relative path, so weave them together.
     if (baseURL.fPath) {
-        XMLCh* temp = XMLPlatformUtils::weavePaths(baseURL.fPath, fPath);
+        XMLCh* temp = XMLPlatformUtils::weavePaths(baseURL.fPath, fPath ,fMemoryManager);
         fMemoryManager->deallocate(fPath);//delete [] fPath;
         fPath = temp;
     }
@@ -873,7 +912,7 @@ void XMLURL::parse(const XMLCh* const urlText)
 {
     // Simplify things by checking for the psycho scenarios first
     if (!*urlText)
-        ThrowXML(MalformedURLException, XMLExcepts::URL_NoProtocolPresent);
+        ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_NoProtocolPresent, fMemoryManager);
 
     // Before we start, check if this urlText contains valid uri characters
     if (!XMLUri::isURIString(urlText))
@@ -883,8 +922,8 @@ void XMLURL::parse(const XMLCh* const urlText)
 
     //
     //  The first thing we will do is to check for a file name, so that
-    //  we don't waste time thinking its a URL. If its in the form x:\
-    //  or x:/ and x is an ASCII letter, then assume that's the deal.
+    //  we don't waste time thinking its a URL. If its in the form x:\ or x:/
+    //  and x is an ASCII letter, then assume that's the deal.
     //
     if (((*urlText >= chLatin_A) && (*urlText <= chLatin_Z))
     ||  ((*urlText >= chLatin_a) && (*urlText <= chLatin_z)))
@@ -894,7 +933,7 @@ void XMLURL::parse(const XMLCh* const urlText)
             if ((*(urlText + 2) == chForwardSlash)
             ||  (*(urlText + 2) == chBackSlash))
             {
-                ThrowXML(MalformedURLException, XMLExcepts::URL_NoProtocolPresent);
+                ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_NoProtocolPresent, fMemoryManager);
             }
         }
     }
@@ -912,27 +951,21 @@ void XMLURL::parse(const XMLCh* const urlText)
     // Run up past any spaces
     while (*srcPtr)
     {
-        if (!XMLPlatformUtils::fgTransService->isSpace(*srcPtr))
+        if (!XMLChar1_0::isWhitespace(*srcPtr))
             break;
         srcPtr++;
     }
 
     // Make sure it wasn't all space
     if (!*srcPtr)
-        ThrowXML(MalformedURLException, XMLExcepts::URL_NoProtocolPresent);
+        ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_NoProtocolPresent, fMemoryManager);
 
     //
     //  Ok, the next thing we have to do is to find either a / or : character.
     //  If the : is first, we assume we have a protocol. If the / is first,
     //  then we skip to the host processing.
     //
-    static const XMLCh listOne[]    = { chColon, chForwardSlash, chNull };
-    static const XMLCh listTwo[]    = { chAt, chNull };
-    static const XMLCh listThree[]  = { chColon, chNull };
-    static const XMLCh listFour[]   = { chForwardSlash, chNull };
-    static const XMLCh listFive[]   = { chPound, chQuestion, chNull };
-    static const XMLCh listSix[]    = { chPound, chNull };
-    XMLCh* ptr1 = XMLString::findAny(srcPtr, listOne);
+    XMLCh* ptr1 = XMLString::findAny(srcPtr, gListOne);
     XMLCh* ptr2;
 
     // If we found a protocol, then deal with it
@@ -948,11 +981,12 @@ void XMLURL::parse(const XMLCh* const urlText)
 
             if (fProtocol == Unknown)
             {
-                ThrowXML1
+                ThrowXMLwithMemMgr1
                 (
                     MalformedURLException
                     , XMLExcepts::URL_UnsupportedProto1
                     , srcPtr
+                    , fMemoryManager
                 );
             }
 
@@ -978,7 +1012,7 @@ void XMLURL::parse(const XMLCh* const urlText)
         if (*srcPtr)
         {
             // Search from here for a / character
-            ptr1 = XMLString::findAny(srcPtr, listFour);
+            ptr1 = XMLString::findAny(srcPtr, gListFour);
 
             //
             //  If we found something, then the host is between where
@@ -992,7 +1026,7 @@ void XMLURL::parse(const XMLCh* const urlText)
                     fMemoryManager->deallocate(fHost);//delete [] fHost;
                     fHost = (XMLCh*) fMemoryManager->allocate
                     (
-                        (ptr1 - srcPtr + 1) * sizeof(XMLCh)
+                        ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
                     );//new XMLCh[(ptr1 - srcPtr) + 1];
                     ptr2 = fHost;
                     while (srcPtr < ptr1)
@@ -1017,10 +1051,11 @@ void XMLURL::parse(const XMLCh* const urlText)
         // we didn't get them, so throw an exception
         //
         if (fProtocol == HTTP) {
-            ThrowXML
+            ThrowXMLwithMemMgr
                 (
                     MalformedURLException
                     , XMLExcepts::URL_ExpectingTwoSlashes
+                    , fMemoryManager
                 );
         }
     }
@@ -1036,7 +1071,7 @@ void XMLURL::parse(const XMLCh* const urlText)
         //  find one, then everything between the start of the host data
         //  and the character is the user name.
         //
-        ptr1 = XMLString::findAny(fHost, listTwo);
+        ptr1 = XMLString::findAny(fHost, gListTwo);
         if (ptr1)
         {
             // Get this info out as the user name
@@ -1049,7 +1084,7 @@ void XMLURL::parse(const XMLCh* const urlText)
             XMLString::cut(fHost, ptr1 - fHost);
 
             // Is there a password inside the user string?
-            ptr2 = XMLString::findAny(fUser, listThree);
+            ptr2 = XMLString::findAny(fUser, gListThree);
             if (ptr2)
             {
                 // Remove it from the user name string
@@ -1067,7 +1102,7 @@ void XMLURL::parse(const XMLCh* const urlText)
         //  not at the end of the host data, then lets see if we have a
         //  port trailing the
         //
-        ptr1 = XMLString::findAny(fHost, listThree);
+        ptr1 = XMLString::findAny(fHost, gListThree);
         if (ptr1)
         {
             // Remove it from the host name
@@ -1075,14 +1110,14 @@ void XMLURL::parse(const XMLCh* const urlText)
 
             // Try to convert it to a numeric port value and store it
             ptr1++;
-            if (!XMLString::textToBin(ptr1, fPortNum))
-                ThrowXML(MalformedURLException, XMLExcepts::URL_BadPortField);
+            if (!XMLString::textToBin(ptr1, fPortNum, fMemoryManager))
+                ThrowXMLwithMemMgr(MalformedURLException, XMLExcepts::URL_BadPortField, fMemoryManager);
         }
 
         // If the host ended up empty, then toss is
         if (!*fHost)
         {
-            delete[] fHost;
+            fMemoryManager->deallocate(fHost);//delete[] fHost;
             fHost = 0;
         }
     }
@@ -1098,7 +1133,7 @@ void XMLURL::parse(const XMLCh* const urlText)
     //  forward slash character, or relative. Its basically everything up
     //  to the end of the string or to any trailing query or fragment.
     //
-    ptr1 = XMLString::findAny(srcPtr, listFive);
+    ptr1 = XMLString::findAny(srcPtr, gListFive);
     if (!ptr1)
     {
         fMemoryManager->deallocate(fPath);//delete [] fPath;
@@ -1112,7 +1147,7 @@ void XMLURL::parse(const XMLCh* const urlText)
         fMemoryManager->deallocate(fPath);//delete [] fPath;
         fPath = (XMLCh*) fMemoryManager->allocate
         (
-            (ptr1 - srcPtr + 1) * sizeof(XMLCh)
+            ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
         );//new XMLCh[(ptr1 - srcPtr) + 1];
         ptr2 = fPath;
         while (srcPtr < ptr1)
@@ -1137,7 +1172,7 @@ void XMLURL::parse(const XMLCh* const urlText)
     //  separator.
     //
     srcPtr++;
-    ptr1 = XMLString::findAny(srcPtr, listSix);
+    ptr1 = XMLString::findAny(srcPtr, gListSix);
     fMemoryManager->deallocate(fQuery);//delete [] fQuery;
     if (!ptr1)
     {
@@ -1148,7 +1183,7 @@ void XMLURL::parse(const XMLCh* const urlText)
     {
         fQuery = (XMLCh*) fMemoryManager->allocate
         (
-            (ptr1 - srcPtr + 1) * sizeof(XMLCh)
+            ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
         );//new XMLCh[(ptr1 - srcPtr) + 1];
         ptr2 = fQuery;
         while (srcPtr < ptr1)
@@ -1165,6 +1200,277 @@ void XMLURL::parse(const XMLCh* const urlText)
     }
 }
 
+bool XMLURL::parse(const XMLCh* const urlText, XMLURL& xmlURL)
+{
+    // Simplify things by checking for the psycho scenarios first
+    if (!*urlText)
+        return false;
+
+    // Before we start, check if this urlText contains valid uri characters
+    if (!XMLUri::isURIString(urlText))
+        xmlURL.fHasInvalidChar = true;
+    else
+        xmlURL.fHasInvalidChar = false;
+
+    //
+    //  The first thing we will do is to check for a file name, so that
+    //  we don't waste time thinking its a URL. If its in the form x:\ or x:/ 
+    //  and x is an ASCII letter, then assume that's the deal.
+    //
+    if (((*urlText >= chLatin_A) && (*urlText <= chLatin_Z))
+    ||  ((*urlText >= chLatin_a) && (*urlText <= chLatin_z)))
+    {
+        if (*(urlText + 1) == chColon)
+        {
+            if ((*(urlText + 2) == chForwardSlash)
+            ||  (*(urlText + 2) == chBackSlash))
+            {
+                return false;
+            }
+        }
+    }
+
+    // Get a copy of the URL that we can modify
+    XMLCh* srcCpy = XMLString::replicate(urlText, xmlURL.fMemoryManager);
+    ArrayJanitor<XMLCh> janSrcCopy(srcCpy, xmlURL.fMemoryManager);
+
+    //
+    //  Get a pointer now that we can run up thrown the source as we parse
+    //  bits and pieces out of it.
+    //
+    XMLCh* srcPtr = srcCpy;
+
+    // Run up past any spaces
+    while (*srcPtr)
+    {
+        if (!XMLChar1_0::isWhitespace(*srcPtr))
+            break;
+        srcPtr++;
+    }
+
+    // Make sure it wasn't all space
+    if (!*srcPtr)
+        return false;
+
+    //
+    //  Ok, the next thing we have to do is to find either a / or : character.
+    //  If the : is first, we assume we have a protocol. If the / is first,
+    //  then we skip to the host processing.
+    //
+    XMLCh* ptr1 = XMLString::findAny(srcPtr, gListOne);
+    XMLCh* ptr2;
+
+    // If we found a protocol, then deal with it
+    if (ptr1)
+    {
+        if (*ptr1 == chColon)
+        {
+            // Cap the string at the colon
+            *ptr1 = 0;
+
+            // And try to find it in our list of protocols
+            xmlURL.fProtocol = lookupByName(srcPtr);
+
+            if (xmlURL.fProtocol == Unknown)
+                return false;
+
+            // And move our source pointer up past what we've processed
+            srcPtr = (ptr1 + 1);
+        }
+    }
+
+    //
+    //  Ok, next we need to see if we have any host part. If the next
+    //  two characters are //, then we need to check, else move on.
+    //
+    if ((*srcPtr == chForwardSlash) && (*(srcPtr + 1) == chForwardSlash))
+    {
+        // Move up past the slashes
+        srcPtr += 2;
+
+        //
+        //  If we aren't at the end of the string, then there has to be a
+        //  host part at this point. we will just look for the next / char
+        //  or end of string and make all of that the host for now.
+        //
+        if (*srcPtr)
+        {
+            // Search from here for a / character
+            ptr1 = XMLString::findAny(srcPtr, gListFour);
+
+            //
+            //  If we found something, then the host is between where
+            //  we are and what we found. Else the host is the rest of
+            //  the content and we are done. If its empty, leave it null.
+            //
+            if (ptr1)
+            {
+                if (ptr1 != srcPtr)
+                {
+                    xmlURL.fHost = (XMLCh*) xmlURL.fMemoryManager->allocate
+                    (
+                        ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
+                    );//new XMLCh[(ptr1 - srcPtr) + 1];
+                    ptr2 = xmlURL.fHost;
+                    while (srcPtr < ptr1)
+                        *ptr2++ = *srcPtr++;
+                    *ptr2 = 0;
+                }
+            }
+             else
+            {
+                xmlURL.fHost = XMLString::replicate(srcPtr, xmlURL.fMemoryManager);
+
+                // Update source pointer to the end
+                srcPtr += XMLString::stringLen(xmlURL.fHost);
+            }
+        }
+    }
+    else
+    {
+        //
+        // http protocol requires two forward slashes
+        // we didn't get them, so throw an exception
+        //
+        if (xmlURL.fProtocol == HTTP)
+            return false;
+    }
+
+    //
+    //  If there was a host part, then we have to grovel through it for
+    //  all the bits and pieces it can hold.
+    //
+    if (xmlURL.fHost)
+    {
+        //
+        //  Look for a '@' character, which indicates a user name. If we
+        //  find one, then everything between the start of the host data
+        //  and the character is the user name.
+        //
+        ptr1 = XMLString::findAny(xmlURL.fHost, gListTwo);
+        if (ptr1)
+        {
+            // Get this info out as the user name
+            *ptr1 = 0;
+            xmlURL.fUser = XMLString::replicate(xmlURL.fHost, xmlURL.fMemoryManager);
+            ptr1++;
+
+            // And now cut these chars from the host string
+            XMLString::cut(xmlURL.fHost, ptr1 - xmlURL.fHost);
+
+            // Is there a password inside the user string?
+            ptr2 = XMLString::findAny(xmlURL.fUser, gListThree);
+            if (ptr2)
+            {
+                // Remove it from the user name string
+                *ptr2 = 0;
+
+                // And copy out the remainder to the password field
+                ptr2++;
+                xmlURL.fPassword = XMLString::replicate(ptr2, xmlURL.fMemoryManager);
+            }
+        }
+
+        //
+        //  Ok, so now we are at the actual host name, if any. If we are
+        //  not at the end of the host data, then lets see if we have a
+        //  port trailing the
+        //
+        ptr1 = XMLString::findAny(xmlURL.fHost, gListThree);
+        if (ptr1)
+        {
+            // Remove it from the host name
+            *ptr1 = 0;
+
+            // Try to convert it to a numeric port value and store it
+            ptr1++;
+            if (!XMLString::textToBin(ptr1, xmlURL.fPortNum, xmlURL.fMemoryManager))
+                return false;
+        }
+
+        // If the host ended up empty, then toss is
+        if (!*(xmlURL.fHost))
+        {
+            xmlURL.fMemoryManager->deallocate(xmlURL.fHost);//delete[] fHost;
+            xmlURL.fHost = 0;
+        }
+    }
+
+    // If we are at the end, then we are done now
+    if (!*srcPtr)
+	{
+        return true;
+	}
+
+    //
+    //  Next is the path part. It can be absolute, i.e. starting with a
+    //  forward slash character, or relative. Its basically everything up
+    //  to the end of the string or to any trailing query or fragment.
+    //
+    ptr1 = XMLString::findAny(srcPtr, gListFive);
+    if (!ptr1)
+    {
+        xmlURL.fPath = XMLString::replicate(srcPtr, xmlURL.fMemoryManager);
+        return true;
+    }
+
+    // Everything from where we are to what we found is the path
+    if (ptr1 > srcPtr)
+    {
+        xmlURL.fPath = (XMLCh*) xmlURL.fMemoryManager->allocate
+        (
+            ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
+        );//new XMLCh[(ptr1 - srcPtr) + 1];
+        ptr2 = xmlURL.fPath;
+        while (srcPtr < ptr1)
+            *ptr2++ = *srcPtr++;
+        *ptr2 = 0;
+    }
+
+    //
+    //  If we found a fragment, then it is the rest of the string and we
+    //  are done.
+    //
+    if (*srcPtr == chPound)
+    {
+        srcPtr++;
+        xmlURL.fFragment = XMLString::replicate(srcPtr, xmlURL.fMemoryManager);
+        return true;
+    }
+
+    //
+    //  The query is either the rest of the string, or up to the fragment
+    //  separator.
+    //
+    srcPtr++;
+    ptr1 = XMLString::findAny(srcPtr, gListSix);
+    if (!ptr1)
+    {
+        xmlURL.fQuery = XMLString::replicate(srcPtr, xmlURL.fMemoryManager);
+        return true;
+    }
+     else
+    {
+        xmlURL.fQuery = (XMLCh*) xmlURL.fMemoryManager->allocate
+        (
+            ((ptr1 - srcPtr) + 1) * sizeof(XMLCh)
+        );//new XMLCh[(ptr1 - srcPtr) + 1];
+        ptr2 = xmlURL.fQuery;
+        while (srcPtr < ptr1)
+            *ptr2++ = *srcPtr++;
+        *ptr2 = 0;
+    }
+
+    // If we are not at the end now, then everything else is the fragment
+    if (*srcPtr == chPound)
+    {
+        srcPtr++;
+        xmlURL.fFragment = XMLString::replicate(srcPtr, xmlURL.fMemoryManager);
+    }
+
+    return true;
+}
 
 XERCES_CPP_NAMESPACE_END
 
+
