@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: XMLUni.cpp,v 1.38 2003/11/25 03:46:26 neilg Exp $
+ * $Id: XMLUni.cpp 176382 2005-04-21 09:05:57Z cargilld $
  */
 
 
@@ -70,6 +30,7 @@ XERCES_CPP_NAMESPACE_BEGIN
 // ---------------------------------------------------------------------------
 //  XMLUni: Static data
 // ---------------------------------------------------------------------------
+
 const XMLCh XMLUni::fgAnyString[] =
 {
     chLatin_A, chLatin_N, chLatin_Y, chNull
@@ -469,6 +430,17 @@ const XMLCh XMLUni::fgUTF16EncodingString5[] =
     chLatin_U, chLatin_T, chLatin_F, chDigit_1, chDigit_6, chNull
 };
 
+const XMLCh XMLUni::fgUTF16EncodingString6[] =
+{
+    chLatin_U, chLatin_C, chLatin_S, chDash, chDigit_2, chNull
+};
+
+const XMLCh XMLUni::fgUTF16EncodingString7[] =
+{
+    chLatin_I, chLatin_S, chLatin_O, chDash, chDigit_1, chDigit_0, chDigit_6, chDigit_4
+    , chDigit_6, chDash, chLatin_U, chLatin_C, chLatin_S, chDash, chDigit_2, chNull
+};
+
 const XMLCh XMLUni::fgUTF16BEncodingString[] =
 {
     chLatin_U, chLatin_T, chLatin_F, chDash, chDigit_1, chDigit_6, chSpace, chOpenParen, chLatin_B, chLatin_E, chCloseParen, chNull
@@ -652,6 +624,15 @@ const XMLCh XMLUni::fgXMLURIName[] =
     ,   chLatin_e, chLatin_s, chLatin_p, chLatin_a, chLatin_c, chLatin_e, chNull
 };
 
+const XMLCh XMLUni::fgInfosetURIName[] = 
+{
+        chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash
+    ,   chForwardSlash, chLatin_w, chLatin_w, chLatin_w, chPeriod, chLatin_w
+    ,   chDigit_3, chPeriod, chLatin_o, chLatin_r, chLatin_g, chForwardSlash
+    ,   chLatin_T, chLatin_R, chForwardSlash, chLatin_R, chLatin_E, chLatin_C
+    ,   chDash, chLatin_x, chLatin_m, chLatin_l, chNull
+};
+
 const XMLCh XMLUni::fgYesString[] =
 {
         chLatin_y, chLatin_e, chLatin_s, chNull
@@ -713,6 +694,13 @@ const XMLCh XMLUni::fgDGXMLScanner[] =
     ,   chLatin_c, chLatin_a, chLatin_n, chLatin_n, chLatin_e, chLatin_r, chNull
 };
 
+const XMLCh XMLUni::fgXSAXMLScanner[] =
+{
+        chLatin_X, chLatin_S, chLatin_A
+    ,   chLatin_X, chLatin_M, chLatin_L, chLatin_S
+    ,   chLatin_c, chLatin_a, chLatin_n, chLatin_n, chLatin_e, chLatin_r, chNull
+};
+
 const XMLCh XMLUni::fgCDataStart[] =
 {
         chOpenAngle, chBang, chOpenSquare, chLatin_C, chLatin_D
@@ -1024,6 +1012,23 @@ const XMLCh XMLUni::fgXercesSchemaFullChecking[] =
     ,   chLatin_e, chLatin_c, chLatin_k, chLatin_i, chLatin_n, chLatin_g, chNull
 };
 
+//Xerces: http://apache.org/xml/features/validation/identity-constraint-checking
+const XMLCh XMLUni::fgXercesIdentityConstraintChecking[] =
+{
+        chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash
+    ,   chForwardSlash, chLatin_a, chLatin_p, chLatin_a, chLatin_c, chLatin_h
+    ,   chLatin_e, chPeriod, chLatin_o, chLatin_r, chLatin_g, chForwardSlash
+    ,   chLatin_x, chLatin_m, chLatin_l, chForwardSlash, chLatin_f, chLatin_e
+    ,   chLatin_a, chLatin_t, chLatin_u, chLatin_r, chLatin_e, chLatin_s
+    ,   chForwardSlash, chLatin_v, chLatin_a, chLatin_l, chLatin_i, chLatin_d
+    ,   chLatin_a, chLatin_t, chLatin_i, chLatin_o, chLatin_n, chForwardSlash
+    ,   chLatin_i, chLatin_d, chLatin_e, chLatin_n, chLatin_t, chLatin_i 
+    ,   chLatin_t, chLatin_y, chDash   , chLatin_c, chLatin_o, chLatin_n, chLatin_s
+    ,   chLatin_t, chLatin_r, chLatin_a, chLatin_i, chLatin_n, chLatin_t
+    ,   chDash,    chLatin_c, chLatin_h, chLatin_e, chLatin_c, chLatin_k, chLatin_i
+    ,   chLatin_n, chLatin_g, chNull
+};
+
 //Xerces: http://apache.org/xml/features/nonvalidating/load-external-dtd
 const XMLCh XMLUni::fgXercesLoadExternalDTD[] =
 {
@@ -1095,6 +1100,47 @@ const XMLCh XMLUni::fgXercesStandardUriConformant[] =
     ,   chLatin_m, chLatin_a, chLatin_n, chLatin_t, chNull
 };
 
+//Xerces: http://apache.org/xml/features/dom-has-psvi-info
+const XMLCh XMLUni::fgXercesDOMHasPSVIInfo[] =
+{
+        chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash
+    ,   chForwardSlash, chLatin_a, chLatin_p, chLatin_a, chLatin_c, chLatin_h
+    ,   chLatin_e, chPeriod, chLatin_o, chLatin_r, chLatin_g, chForwardSlash
+    ,   chLatin_x, chLatin_m, chLatin_l, chForwardSlash, chLatin_f, chLatin_e
+    ,   chLatin_a, chLatin_t, chLatin_u, chLatin_r, chLatin_e, chLatin_s
+    ,   chForwardSlash, chLatin_d, chLatin_o, chLatin_m, chDash, chLatin_h
+    ,   chLatin_a, chLatin_s, chDash, chLatin_p, chLatin_s, chLatin_v, chLatin_i
+    ,   chDash, chLatin_i, chLatin_n, chLatin_f, chLatin_o, chNull
+};
+
+//Xerces: http://apache.org/xml/features/generate-synthetic-annotations
+const XMLCh XMLUni::fgXercesGenerateSyntheticAnnotations[] = 
+{
+        chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash
+    ,   chForwardSlash, chLatin_a, chLatin_p, chLatin_a, chLatin_c, chLatin_h
+    ,   chLatin_e, chPeriod, chLatin_o, chLatin_r, chLatin_g, chForwardSlash
+    ,   chLatin_x, chLatin_m, chLatin_l, chForwardSlash, chLatin_f, chLatin_e
+    ,   chLatin_a, chLatin_t, chLatin_u, chLatin_r, chLatin_e, chLatin_s
+    ,   chForwardSlash, chLatin_g, chLatin_e, chLatin_n, chLatin_e, chLatin_r
+    ,   chLatin_a, chLatin_t, chLatin_e, chDash, chLatin_s, chLatin_y, chLatin_n
+    ,   chLatin_t, chLatin_h, chLatin_e, chLatin_t, chLatin_i, chLatin_c, chDash 
+    ,   chLatin_a, chLatin_n, chLatin_n, chLatin_o, chLatin_t, chLatin_a, chLatin_t
+    ,   chLatin_i, chLatin_o, chLatin_n, chLatin_s, chNull
+};
+
+const XMLCh XMLUni::fgXercesValidateAnnotations[] =
+//Xerces: http://apache.org/xml/features/validate-annotations
+{
+        chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash
+    ,   chForwardSlash, chLatin_a, chLatin_p, chLatin_a, chLatin_c, chLatin_h
+    ,   chLatin_e, chPeriod, chLatin_o, chLatin_r, chLatin_g, chForwardSlash
+    ,   chLatin_x, chLatin_m, chLatin_l, chForwardSlash, chLatin_f, chLatin_e
+    ,   chLatin_a, chLatin_t, chLatin_u, chLatin_r, chLatin_e, chLatin_s
+    ,   chForwardSlash, chLatin_v, chLatin_a, chLatin_l, chLatin_i, chLatin_d
+    ,   chLatin_a, chLatin_t, chLatin_e, chDash
+    ,   chLatin_a, chLatin_n, chLatin_n, chLatin_o, chLatin_t, chLatin_a, chLatin_t
+    ,   chLatin_i, chLatin_o, chLatin_n, chLatin_s, chNull
+};
 
 //Property
 //Xerces: http://apache.org/xml/properties/schema/external-schemaLocation
@@ -1219,10 +1265,72 @@ const XMLCh XMLUni::fgXercesUseCachedGrammarInParse[] =
     ,   chLatin_a, chLatin_t, chLatin_i, chLatin_o, chLatin_n, chForwardSlash
     ,   chLatin_u, chLatin_s, chLatin_e, chDash, chLatin_c, chLatin_a, chLatin_c
     ,   chLatin_h, chLatin_e, chLatin_d, chLatin_G, chLatin_r, chLatin_a, chLatin_m
-    ,   chLatin_m, chLatin_a, chLatin_r, chLatin_I, chLatin_n, chLatin_P, chLatin_r
-    ,   chLatin_s, chLatin_e, chNull
+    ,   chLatin_m, chLatin_a, chLatin_r, chLatin_I, chLatin_n, chLatin_P, chLatin_a
+    ,   chLatin_r, chLatin_s, chLatin_e, chNull
 };
 
+//Xerces: http://apache.org/xml/features/validation/ignoreCachedDTD
+const XMLCh XMLUni::fgXercesIgnoreCachedDTD[] =
+{
+        chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash
+    ,   chForwardSlash, chLatin_a, chLatin_p, chLatin_a, chLatin_c, chLatin_h
+    ,   chLatin_e, chPeriod, chLatin_o, chLatin_r, chLatin_g, chForwardSlash
+    ,   chLatin_x, chLatin_m, chLatin_l, chForwardSlash, chLatin_f, chLatin_e
+    ,   chLatin_a, chLatin_t, chLatin_u, chLatin_r, chLatin_e, chLatin_s
+    ,   chForwardSlash, chLatin_v, chLatin_a, chLatin_l, chLatin_i, chLatin_d
+    ,   chLatin_a, chLatin_t, chLatin_i, chLatin_o, chLatin_n, chForwardSlash
+    ,   chLatin_i, chLatin_g, chLatin_n, chLatin_o, chLatin_r, chLatin_e
+    ,   chLatin_C, chLatin_a, chLatin_c, chLatin_h, chLatin_e, chLatin_d
+    ,   chLatin_D, chLatin_T, chLatin_D, chNull
+};
+
+//Xerces: http://apache.org/xml/features/schema/ignore-annotations
+const XMLCh XMLUni::fgXercesIgnoreAnnotations[] =
+{
+        chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash
+    ,   chForwardSlash, chLatin_a, chLatin_p, chLatin_a, chLatin_c, chLatin_h
+    ,   chLatin_e, chPeriod, chLatin_o, chLatin_r, chLatin_g, chForwardSlash
+    ,   chLatin_x, chLatin_m, chLatin_l, chForwardSlash, chLatin_f, chLatin_e
+    ,   chLatin_a, chLatin_t, chLatin_u, chLatin_r, chLatin_e, chLatin_s
+    ,   chForwardSlash, chLatin_s, chLatin_c, chLatin_h, chLatin_e, chLatin_m
+    ,   chLatin_a, chForwardSlash, chLatin_i, chLatin_g, chLatin_n, chLatin_o
+    ,   chLatin_r, chLatin_e, chDash
+    ,   chLatin_a, chLatin_n, chLatin_n, chLatin_o, chLatin_t, chLatin_a, chLatin_t
+    ,   chLatin_i, chLatin_o, chLatin_n, chLatin_s, chNull
+};
+
+//Xerces: http://apache.org/xml/features/disable-default-entity-resolution
+const XMLCh XMLUni::fgXercesDisableDefaultEntityResolution[] =
+{
+        chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash
+    ,   chForwardSlash, chLatin_a, chLatin_p, chLatin_a, chLatin_c, chLatin_h
+    ,   chLatin_e, chPeriod, chLatin_o, chLatin_r, chLatin_g, chForwardSlash
+    ,   chLatin_x, chLatin_m, chLatin_l, chForwardSlash, chLatin_f, chLatin_e
+    ,   chLatin_a, chLatin_t, chLatin_u, chLatin_r, chLatin_e, chLatin_s
+    ,   chForwardSlash, chLatin_d, chLatin_i, chLatin_s, chLatin_a, chLatin_b
+    ,   chLatin_l, chLatin_e, chDash, chLatin_d, chLatin_e, chLatin_f
+    ,   chLatin_a, chLatin_u, chLatin_l, chLatin_t, chDash, chLatin_e
+    ,   chLatin_n, chLatin_t, chLatin_i, chLatin_t, chLatin_y, chDash
+    ,   chLatin_r, chLatin_e, chLatin_s, chLatin_o, chLatin_l, chLatin_u
+    ,   chLatin_t, chLatin_i, chLatin_o, chLatin_n, chNull
+};
+
+//Xerces: http://apache.org/xml/features/validation/schema/skip-dtd-validation
+const XMLCh XMLUni::fgXercesSkipDTDValidation[] =
+{
+        chLatin_h, chLatin_t, chLatin_t, chLatin_p, chColon, chForwardSlash
+    ,   chForwardSlash, chLatin_a, chLatin_p, chLatin_a, chLatin_c, chLatin_h
+    ,   chLatin_e, chPeriod, chLatin_o, chLatin_r, chLatin_g, chForwardSlash
+    ,   chLatin_x, chLatin_m, chLatin_l, chForwardSlash, chLatin_f, chLatin_e
+    ,   chLatin_a, chLatin_t, chLatin_u, chLatin_r, chLatin_e, chLatin_s
+    ,   chForwardSlash, chLatin_v, chLatin_a, chLatin_l, chLatin_i, chLatin_d
+    ,   chLatin_a, chLatin_t, chLatin_i, chLatin_o, chLatin_n, chForwardSlash
+    ,   chLatin_s, chLatin_c, chLatin_h, chLatin_e, chLatin_m, chLatin_a
+    ,   chForwardSlash, chLatin_s, chLatin_k, chLatin_i, chLatin_p, chDash
+    ,   chLatin_d, chLatin_t, chLatin_d, chDash, chLatin_v, chLatin_a
+    ,   chLatin_l, chLatin_i, chLatin_d, chLatin_a, chLatin_t, chLatin_i 
+    ,   chLatin_o, chLatin_n, chNull
+};
 
 //Introduced in DOM Level 3
 const XMLCh XMLUni::fgDOMCanonicalForm[] =
@@ -1407,6 +1515,20 @@ const XMLCh XMLUni::fgDOMXMLDeclaration[] =
     chLatin_n, chNull 
 };
 
+const XMLCh XMLUni::fgXercescInterfacePSVITypeInfo[] =
+{
+    chLatin_D, chLatin_O, chLatin_M, chLatin_P, chLatin_S, chLatin_V, chLatin_I,
+    chLatin_T, chLatin_y, chLatin_p, chLatin_e, chLatin_I, chLatin_n, chLatin_f,
+    chLatin_o, chNull
+};
+
+const XMLCh XMLUni::fgXercescInterfaceDOMDocumentTypeImpl[] =
+{
+    chLatin_D, chLatin_O, chLatin_M, chLatin_D, chLatin_o, chLatin_c, chLatin_u,
+    chLatin_m, chLatin_e, chLatin_n, chLatin_t, chLatin_T, chLatin_y, chLatin_p,
+    chLatin_e, chLatin_I, chLatin_m, chLatin_p, chLatin_l, chNull
+};
+
 // en_US
 const char XMLUni::fgXercescDefaultLocale[] = "en_US";
 
@@ -1423,7 +1545,124 @@ const XMLCh XMLUni::fgXMLDOMMsgDomain[] =
     ,   chNull
 };
 
+// default exception string
+const XMLCh XMLUni::fgDefErrMsg[] =
+{
+        chLatin_C, chLatin_o, chLatin_u, chLatin_l, chLatin_d
+    ,   chSpace, chLatin_n, chLatin_o, chLatin_t, chSpace
+    ,   chLatin_l, chLatin_o, chLatin_a, chLatin_d, chSpace
+    ,   chLatin_m, chLatin_e, chLatin_s, chLatin_s, chLatin_a
+    ,   chLatin_g, chLatin_e, chNull
+};
 
+// Datatype 
+const XMLCh XMLUni::fgValueZero[] =
+{
+    chDigit_0, chNull
+};
+
+const XMLCh XMLUni::fgNegOne[] =
+{
+    chDash, chDigit_1, chNull
+};
+
+const XMLCh XMLUni::fgValueOne[] =
+{
+    chDigit_1, chNull
+};
+
+//"9223372036854775807"
+const XMLCh XMLUni::fgLongMaxInc[] =
+{
+    chDigit_9, chDigit_2, chDigit_2, chDigit_3, chDigit_3, chDigit_7, chDigit_2,
+    chDigit_0, chDigit_3, chDigit_6, chDigit_8, chDigit_5, chDigit_4, chDigit_7,
+    chDigit_7, chDigit_5, chDigit_8, chDigit_0, chDigit_7, chNull
+};
+
+//"-9223372036854775808"
+const XMLCh XMLUni::fgLongMinInc[] =
+{
+    chDash, chDigit_9, chDigit_2, chDigit_2, chDigit_3, chDigit_3, chDigit_7,
+    chDigit_2, chDigit_0, chDigit_3, chDigit_6, chDigit_8, chDigit_5, chDigit_4,
+    chDigit_7, chDigit_7, chDigit_5, chDigit_8, chDigit_0, chDigit_8,  chNull
+};
+
+const XMLCh XMLUni::fgIntMaxInc[] =
+{
+    chDigit_2, chDigit_1, chDigit_4, chDigit_7, chDigit_4, chDigit_8,
+    chDigit_3, chDigit_6, chDigit_4, chDigit_7, chNull
+};
+
+const XMLCh XMLUni::fgIntMinInc[] =
+{
+    chDash, chDigit_2, chDigit_1, chDigit_4, chDigit_7, chDigit_4,
+    chDigit_8, chDigit_3, chDigit_6, chDigit_4, chDigit_8, chNull
+};
+
+const XMLCh XMLUni::fgShortMaxInc[] =
+{
+    chDigit_3, chDigit_2, chDigit_7, chDigit_6, chDigit_7, chNull
+};
+
+const XMLCh XMLUni::fgShortMinInc[] =
+{
+    chDash, chDigit_3, chDigit_2, chDigit_7, chDigit_6, chDigit_8, chNull
+};
+
+const XMLCh XMLUni::fgByteMaxInc[] =
+{
+    chDigit_1, chDigit_2, chDigit_7, chNull
+};
+
+const XMLCh XMLUni::fgByteMinInc[] =
+{
+    chDash, chDigit_1, chDigit_2, chDigit_8, chNull
+};
+
+const XMLCh XMLUni::fgULongMaxInc[] =
+{
+    chDigit_1, chDigit_8, chDigit_4, chDigit_4, chDigit_6, chDigit_7, chDigit_4,
+    chDigit_4, chDigit_0, chDigit_7, chDigit_3, chDigit_7, chDigit_0, chDigit_9,
+    chDigit_5, chDigit_5, chDigit_1, chDigit_6, chDigit_1, chDigit_5, chNull
+};
+
+const XMLCh XMLUni::fgUIntMaxInc[] =
+{
+    chDigit_4, chDigit_2, chDigit_9, chDigit_4, chDigit_9, chDigit_6,
+    chDigit_7, chDigit_2, chDigit_9, chDigit_5, chNull
+};
+
+const XMLCh XMLUni::fgUShortMaxInc[] =
+{
+    chDigit_6, chDigit_5, chDigit_5, chDigit_3, chDigit_5, chNull
+};
+
+const XMLCh XMLUni::fgUByteMaxInc[] =
+{
+    chDigit_2, chDigit_5, chDigit_5, chNull
+};
+
+// http://www.w3.org/2001/05/xmlschema-errata#Errata2
+// E2-25
+//"([a-zA-Z]{1,8})(-[a-zA-Z0-9]{1,8})*"
+const XMLCh XMLUni::fgLangPattern[] =
+{
+    chOpenParen,   chOpenSquare,  chLatin_a, chDash, chLatin_z, chLatin_A, chDash, chLatin_Z,
+    chCloseSquare, chOpenCurly, chDigit_1, chComma, chDigit_8, chCloseCurly, chCloseParen,
+    chOpenParen,   chDash, chOpenSquare, chLatin_a, chDash, chLatin_z, chLatin_A, chDash, chLatin_Z,
+	chDigit_0,     chDash, chDigit_9, chCloseSquare, chOpenCurly, chDigit_1, chComma, chDigit_8,
+    chCloseCurly,  chCloseParen, chAsterisk, chNull
+};
+
+const XMLCh XMLUni::fgBooleanValueSpace[][32] =
+{
+    { chLatin_f, chLatin_a, chLatin_l, chLatin_s, chLatin_e, chNull },
+    { chLatin_t, chLatin_r, chLatin_u, chLatin_e, chNull },
+    { chDigit_0, chNull },
+    { chDigit_1, chNull }
+};
+
+const unsigned int XMLUni::fgBooleanValueSpaceArraySize = sizeof XMLUni::fgBooleanValueSpace / sizeof (XMLCh*);
 
 XERCES_CPP_NAMESPACE_END
 
