@@ -1,61 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001-2004 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001-2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: XMLUri.cpp,v 1.24 2004/02/04 13:14:15 amassari Exp $
+ * $Id: XMLUri.cpp 240230 2005-08-26 13:02:42Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
@@ -276,12 +236,15 @@ static const XMLCh PATH_SEPARATORS[] =
 //  XMLUri: Constructors and Helper methods
 // ---------------------------------------------------------------------------
 // ctor# 2
+
+typedef JanitorMemFunCall<XMLUri>   CleanupType;
+
 XMLUri::XMLUri(const XMLCh* const uriSpec,
                MemoryManager* const manager)
-: fScheme(0)
+: fPort(-1)
+, fScheme(0)
 , fUserInfo(0)
 , fHost(0)
-, fPort(-1)
 , fRegAuth(0)
 , fPath(0)
 , fQueryString(0)
@@ -289,28 +252,29 @@ XMLUri::XMLUri(const XMLCh* const uriSpec,
 , fURIText(0)
 , fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &XMLUri::cleanUp);
+
     try {
         initialize((XMLUri *)0, uriSpec);
     }
     catch(const OutOfMemoryException&)
     {
+        cleanup.release();
+
         throw;
     }
-    catch (...)
-    {
-        cleanUp();
-        throw;
-    }
+
+    cleanup.release();
 }
 
 // ctor# 7 relative ctor
 XMLUri::XMLUri(const XMLUri* const      baseURI
               , const XMLCh* const   uriSpec
               , MemoryManager* const manager)
-: fScheme(0)
+: fPort(-1)
+, fScheme(0)
 , fUserInfo(0)
 , fHost(0)
-, fPort(-1)
 , fRegAuth(0)
 , fPath(0)
 , fQueryString(0)
@@ -318,26 +282,29 @@ XMLUri::XMLUri(const XMLUri* const      baseURI
 , fURIText(0)
 , fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &XMLUri::cleanUp);
+
     try {
         initialize(baseURI, uriSpec);
     }
     catch(const OutOfMemoryException&)
     {
+        cleanup.release();
+
         throw;
     }
-    catch (...)
-    {
-        cleanUp();
-        throw;
-    }
+
+    cleanup.release();
 }
 
 //Copy constructor
 XMLUri::XMLUri(const XMLUri& toCopy)
-: fScheme(0)
+: XSerializable(toCopy)
+, XMemory(toCopy)
+, fPort(-1)
+, fScheme(0)
 , fUserInfo(0)
 , fHost(0)
-, fPort(-1)
 , fRegAuth(0)
 , fPath(0)
 , fQueryString(0)
@@ -345,35 +312,39 @@ XMLUri::XMLUri(const XMLUri& toCopy)
 , fURIText(0)
 , fMemoryManager(toCopy.fMemoryManager)
 {
+    CleanupType cleanup(this, &XMLUri::cleanUp);
+
     try {
         initialize(toCopy);
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch (...)
-    {
-        cleanUp();
+        cleanup.release();
+
         throw;
     }
 
+    cleanup.release();
 }
 
 XMLUri& XMLUri::operator=(const XMLUri& toAssign)
 {
+    cleanUp();
+
+    CleanupType cleanup(this, &XMLUri::cleanUp);
+
     try {
         initialize(toAssign);
     }
     catch(const OutOfMemoryException&)
     {
+        cleanup.release();
+
         throw;
     }
-    catch (...)
-    {
-        cleanUp();
-        throw;
-    }
+
+    cleanup.release();
+
     return *this;
 }
 
@@ -385,27 +356,27 @@ XMLUri::~XMLUri()
 void XMLUri::cleanUp()
 {
     if (fScheme)
-        fMemoryManager->deallocate(fScheme);//delete[] fScheme;
+        XMLString::release((void**)&fScheme, fMemoryManager);//delete[] fScheme;
 
     if (fUserInfo)
-        fMemoryManager->deallocate(fUserInfo);//delete[] fUserInfo;
+        XMLString::release((void**)&fUserInfo, fMemoryManager);//delete[] fUserInfo;
 
     if (fHost)
-        fMemoryManager->deallocate(fHost);//delete[] fHost;
+        XMLString::release((void**)&fHost, fMemoryManager);//delete[] fHost;
         
     if (fRegAuth)
-        fMemoryManager->deallocate(fRegAuth);//delete[] fRegAuth;
+        XMLString::release((void**)&fRegAuth, fMemoryManager);//delete[] fRegAuth;
 
     if (fPath)
-        fMemoryManager->deallocate(fPath);//delete[] fPath;
+        XMLString::release((void**)&fPath, fMemoryManager);//delete[] fPath;
 
     if (fQueryString)
-        fMemoryManager->deallocate(fQueryString);//delete[] fQueryString;
+        XMLString::release((void**)&fQueryString, fMemoryManager);//delete[] fQueryString;
 
     if (fFragment)
-        fMemoryManager->deallocate(fFragment);//delete[] fFragment;
+        XMLString::release((void**)&fFragment, fMemoryManager);//delete[] fFragment;
 
-    fMemoryManager->deallocate(fURIText);//delete[] fURIText;
+    XMLString::release((void**)&fURIText, fMemoryManager);//delete[] fURIText;
 }
 
 void XMLUri::initialize(const XMLUri& toCopy)
@@ -456,15 +427,13 @@ void XMLUri::initialize(const XMLUri* const baseURI
 	int index = 0;
 	bool foundScheme = false;
 
-	// Check for scheme, which must be before `/', '?' or '#'. 
-	// Also handle names with DOS drive letters ('D:'), 
-	// so 1-character schemes are not allowed.
+	// Check for scheme, which must be before `/', '?' or '#'. 	
         int colonIdx = XMLString::indexOf(trimmedUriSpec, chColon);
         int slashIdx = XMLString::indexOf(trimmedUriSpec, chForwardSlash);
         int queryIdx = XMLString::indexOf(trimmedUriSpec, chQuestion);
         int fragmentIdx = XMLString::indexOf(trimmedUriSpec, chPound);
 
-        if ((colonIdx < 2) ||
+        if ((colonIdx <= 0) ||
             (colonIdx > slashIdx && slashIdx != -1) ||
             (colonIdx > queryIdx && queryIdx != -1) ||
             (colonIdx > fragmentIdx && fragmentIdx != -1))
@@ -825,18 +794,7 @@ void XMLUri::initializeAuthority(const XMLCh* const uriSpec)
 
         if (portStr && *portStr)
         {
-            try
-            {
-                port = XMLString::parseInt(portStr, fMemoryManager);
-            }
-            catch(const OutOfMemoryException&)
-            {
-                throw;
-            }
-            catch (...)
-            {
-                throw;
-            }
+            port = XMLString::parseInt(portStr, fMemoryManager);
         }
     } // if > 0
 
@@ -894,7 +852,7 @@ void XMLUri::initializePath(const XMLCh* const uriSpec)
     int index = 0;
     int start = 0;
     int end = XMLString::stringLen(uriSpec);
-    XMLCh testChar;
+    XMLCh testChar = 0;
 
     // path - everything up to query string or fragment
     if (start < end)
@@ -1181,18 +1139,7 @@ void XMLUri::setUserInfo(const XMLCh* const newUserInfo)
                 , fMemoryManager);
     }
 
-    try
-    {
-        isConformantUserInfo(newUserInfo, fMemoryManager);
-    }
-    catch(const OutOfMemoryException&)
-    {
-        throw;
-    }
-    catch (...)
-    {
-        throw;
-    }
+    isConformantUserInfo(newUserInfo, fMemoryManager);
 
     if (getUserInfo())
     {
@@ -1645,6 +1592,7 @@ bool XMLUri::isURIString(const XMLCh* const uricString)
         return false;
 
     const XMLCh* tmpStr = uricString;
+
     while (*tmpStr)
     {
         if (isReservedOrUnreservedCharacter(*tmpStr))            
@@ -2098,15 +2046,13 @@ bool XMLUri::isValidURI(const XMLUri* const baseURI
     int index = 0;
     bool foundScheme = false;
 
-    // Check for scheme, which must be before `/', '?' or '#'. 
-    // Also handle names with DOS drive letters ('D:'), 
-    // so 1-character schemes are not allowed.
+    // Check for scheme, which must be before `/', '?' or '#'.     
     int colonIdx = XMLString::indexOf(trimmedUriSpec, chColon);
     int slashIdx = XMLString::indexOf(trimmedUriSpec, chForwardSlash);
     int queryIdx = XMLString::indexOf(trimmedUriSpec, chQuestion);
     int fragmentIdx = XMLString::indexOf(trimmedUriSpec, chPound);
 
-    if ((colonIdx < 2) ||
+    if ((colonIdx <= 0) ||
         (colonIdx > slashIdx && slashIdx != -1) ||
         (colonIdx > queryIdx && queryIdx != -1) ||
         (colonIdx > fragmentIdx && fragmentIdx != -1))
@@ -2194,23 +2140,19 @@ bool XMLUri::isValidURI(bool haveBaseURI, const XMLCh* const uriStr)
     {
         if (!haveBaseURI)
             return false;
-        else
-            return true;
         return true;
     }
 
     int index = 0;
     bool foundScheme = false;
 
-    // Check for scheme, which must be before `/', '?' or '#'. 
-    // Also handle names with DOS drive letters ('D:'), 
-    // so 1-character schemes are not allowed.
+    // Check for scheme, which must be before `/', '?' or '#'.     
     int colonIdx = XMLString::indexOf(trimmedUriSpec, chColon);
     int slashIdx = XMLString::indexOf(trimmedUriSpec, chForwardSlash);
     int queryIdx = XMLString::indexOf(trimmedUriSpec, chQuestion);
     int fragmentIdx = XMLString::indexOf(trimmedUriSpec, chPound);
 
-    if ((colonIdx < 2) ||
+    if ((colonIdx <= 0) ||
         (colonIdx > slashIdx && slashIdx != -1) ||
         (colonIdx > queryIdx && queryIdx != -1) ||
         (colonIdx > fragmentIdx && fragmentIdx != -1))
@@ -2543,6 +2485,37 @@ bool XMLUri::processPath(const XMLCh* const pathStr,
     return true;
 }
 
+/***
+ * [Bug7698]: filenames with embedded spaces in schemaLocation strings not handled properly
+ *
+ * This method is called when Scanner/TraverseSchema knows that the URI reference is
+ * for local file.
+ *
+ ***/ 
+void XMLUri::normalizeURI(const XMLCh*     const systemURI,
+                                XMLBuffer&       normalizedURI)
+{
+    const XMLCh* pszSrc = systemURI;
+
+    normalizedURI.reset();
+
+    while (*pszSrc) {
+
+        if ((*(pszSrc) == chPercent)
+        &&  (*(pszSrc+1) == chDigit_2)
+        &&  (*(pszSrc+2) == chDigit_0))
+        {
+            pszSrc += 3;
+            normalizedURI.append(chSpace);
+        }
+        else 
+        {
+            normalizedURI.append(*pszSrc);
+            pszSrc++;
+        }
+    }
+}
+
 /***
  * Support for Serialization/De-serialization
  ***/
@@ -2554,13 +2527,10 @@ void XMLUri::serialize(XSerializeEngine& serEng)
 
     if (serEng.isStoring())
     {
-
+        serEng<<fPort;
         serEng.writeString(fScheme);
         serEng.writeString(fUserInfo);
         serEng.writeString(fHost);
-
-        serEng<<fPort;
-
         serEng.writeString(fRegAuth);
         serEng.writeString(fPath);
         serEng.writeString(fQueryString);
@@ -2569,12 +2539,10 @@ void XMLUri::serialize(XSerializeEngine& serEng)
     }
     else
     {
+        serEng>>fPort;
         serEng.readString(fScheme);
         serEng.readString(fUserInfo);
         serEng.readString(fHost);
-
-        serEng>>fPort;
-
         serEng.readString(fRegAuth);
         serEng.readString(fPath);
         serEng.readString(fQueryString);
@@ -2585,10 +2553,10 @@ void XMLUri::serialize(XSerializeEngine& serEng)
 }
 
 XMLUri::XMLUri(MemoryManager* const manager)
-: fScheme(0)
+: fPort(-1)
+, fScheme(0)
 , fUserInfo(0)
 , fHost(0)
-, fPort(-1)
 , fRegAuth(0)
 , fPath(0)
 , fQueryString(0)
@@ -2599,4 +2567,3 @@ XMLUri::XMLUri(MemoryManager* const manager)
 }
 
 XERCES_CPP_NAMESPACE_END
-
