@@ -15,28 +15,7 @@
  */
 
 /*
- * $Log: BMPattern.cpp,v $
- * Revision 1.5  2004/09/08 13:56:47  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.4  2003/10/01 16:32:40  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.3  2003/05/15 18:42:54  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.2  2002/11/04 15:17:00  tng
- * C++ Namespace Support.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:28  peiyongz
- * sane_include
- *
- * Revision 1.2  2001/05/11 13:26:40  tng
- * Copyright update.
- *
- * Revision 1.1  2001/03/02 19:22:31  knoaman
- * Schema: Regular expression handling part I
- *
+ * $Id: BMPattern.cpp 191691 2005-06-21 17:28:38Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
@@ -53,6 +32,9 @@ XERCES_CPP_NAMESPACE_BEGIN
 // ---------------------------------------------------------------------------
 //  BMPattern: Constructors
 // ---------------------------------------------------------------------------
+
+typedef JanitorMemFunCall<BMPattern>    CleanupType;
+
 BMPattern::BMPattern( const XMLCh*         const pattern
                     ,       bool                 ignoreCase
                     ,       MemoryManager* const manager) :
@@ -64,19 +46,20 @@ BMPattern::BMPattern( const XMLCh*         const pattern
     , fUppercasePattern(0)
     , fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &BMPattern::cleanUp);
+
 	try {
         fPattern = XMLString::replicate(pattern, fMemoryManager);
 		initialize();
 	}
     catch(const OutOfMemoryException&)
     {
+        cleanup.release();
+
         throw;
     }
-    catch(...) {
 
-		cleanUp();
-		throw;
-	}
+    cleanup.release();
 }
 
 BMPattern::BMPattern( const XMLCh*         const pattern
@@ -91,19 +74,20 @@ BMPattern::BMPattern( const XMLCh*         const pattern
     , fUppercasePattern(0)
     , fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &BMPattern::cleanUp);
+
 	try {
         fPattern = XMLString::replicate(pattern, fMemoryManager);
 		initialize();
 	}
     catch(const OutOfMemoryException&)
     {
+        cleanup.release();
+
         throw;
     }
-    catch(...) {
 
-		cleanUp();
-		throw;
-	}
+    cleanup.release();
 }
 
 BMPattern::~BMPattern() {
@@ -137,7 +121,7 @@ int BMPattern::matches(const XMLCh* const content, int start, int limit) {
 
 		int patternIndex = patternLen;
 		int nIndex = index + 1;
-		XMLCh ch;
+		XMLCh ch = 0;
 
 		while (patternIndex > 0) {
 
