@@ -15,28 +15,7 @@
  */
 
 /*
- * $Log: Match.cpp,v $
- * Revision 1.5  2004/09/08 13:56:47  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.4  2003/05/16 00:03:10  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.3  2002/12/18 13:01:02  gareth
- * New functionality - tokenize and replace. Fixed REVISIT for case insensitive match. Patch by Jennifer Schachter.
- *
- * Revision 1.2  2002/11/04 15:17:00  tng
- * C++ Namespace Support.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:29  peiyongz
- * sane_include
- *
- * Revision 1.2  2001/05/11 13:26:42  tng
- * Copyright update.
- *
- * Revision 1.1  2001/03/02 19:22:40  knoaman
- * Schema: Regular expression handling part I
- *
+ * $Id: Match.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 // ---------------------------------------------------------------------------
@@ -61,7 +40,8 @@ Match::Match(MemoryManager* const manager) :
 }
 
 Match::Match(const Match& toCopy) :
-    fNoGroups(0)
+    XMemory(toCopy) 
+    , fNoGroups(0)
     , fPositionsSize(0)
     , fStartPositions(0)
     , fEndPositions(0)
@@ -70,7 +50,7 @@ Match::Match(const Match& toCopy) :
   initialize(toCopy);
 }
 
-Match& Match::operator=(const Match& toAssign){
+Match& Match::operator=(const Match& toAssign) {
   
   initialize(toAssign);
   return *this;
