@@ -15,65 +15,7 @@
  */
 
 /*
- * $Log: ParserForXMLSchema.cpp,v $
- * Revision 1.9  2004/09/08 13:56:47  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.8  2004/01/29 11:51:21  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.7  2003/12/17 00:18:37  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.6  2003/05/15 18:42:54  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.5  2003/03/18 19:38:28  knoaman
- * Schema Errata E2-18 + misc. regex fixes.
- *
- * Revision 1.4  2003/01/13 19:02:23  knoaman
- * [Bug 14390] C++ Indentifier collision with Python.
- *
- * Revision 1.3  2002/11/04 15:17:00  tng
- * C++ Namespace Support.
- *
- * Revision 1.2  2002/03/18 19:29:53  knoaman
- * Change constant names to eliminate possible conflict with user defined ones.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:29  peiyongz
- * sane_include
- *
- * Revision 1.6  2001/09/20 13:11:42  knoaman
- * Regx  + misc. fixes
- *
- * Revision 1.5  2001/06/01 14:15:37  knoaman
- * Add a return value to satisfy compilers that complain about
- * no return value, although that code will not be executed.
- *
- * Revision 1.4  2001/05/11 21:50:56  knoaman
- * Schema updates and fixes.
- *
- * Revision 1.3  2001/05/11 13:26:44  tng
- * Copyright update.
- *
- * Revision 1.2  2001/05/03 18:17:30  knoaman
- * Some design changes:
- * o Changed the TokenFactory from a single static instance, to a
- *    normal class. Each RegularExpression object will have its own
- *    instance of TokenFactory, and that instance will be passed to
- *    other classes that need to use a TokenFactory to create Token
- *    objects (with the exception of RangeTokenMap).
- * o Added a new class RangeTokenMap to map a the different ranges
- *    in a given category to a specific RangeFactory object. In the old
- *    design RangeFactory had dual functionality (act as a Map, and as
- *    a factory for creating RangeToken(s)). The RangeTokenMap will
- *    have its own copy of the TokenFactory. There will be only one
- *    instance of the RangeTokenMap class, and that instance will be
- *    lazily deleted when XPlatformUtils::Terminate is called.
- *
- * Revision 1.1  2001/03/02 19:26:43  knoaman
- * Schema: Regular expression handling part II
- *
+ * $Id: ParserForXMLSchema.cpp 232854 2005-08-15 18:58:08Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
@@ -178,9 +120,12 @@ RangeToken* ParserForXMLSchema::parseCharacterClass(const bool) {
 
     int type;
     bool firstLoop = true;
+    bool wasDecoded;
 
     while ( (type = getState()) != REGX_T_EOF) {
 
+        wasDecoded = false;
+
         // single range | from-to-range | subtraction
         if (type == REGX_T_CHAR && getCharData() == chCloseSquare && !firstLoop) {
 
@@ -233,6 +178,9 @@ RangeToken* ParserForXMLSchema::parseCharacterClass(const bool) {
                     end = true;
                 }
                 break;
+            case chDash:
+                wasDecoded = true;
+                // fall thru to default.
             default:
                 ch = decodeEscaped();
             }
@@ -261,11 +209,16 @@ RangeToken* ParserForXMLSchema::parseCharacterClass(const bool) {
             if (type == REGX_T_CHAR
                 && (ch == chOpenSquare
                     || ch == chCloseSquare
-                    || ch == chDash)) {
+                    || (ch == chDash && getCharData() == chCloseSquare && firstLoop))) {
+                // if regex = [-] then invalid...
                 // '[', ']', '-' not allowed and should be esacaped
                 XMLCh chStr[] = { ch, chNull };
                 ThrowXMLwithMemMgr2(ParseException,XMLExcepts::Parser_CC6, chStr, chStr, getMemoryManager());
             }
+            if (ch == chDash && getCharData() == chDash && getState() != REGX_T_BACKSOLIDUS && !wasDecoded) {
+                XMLCh chStr[] = { ch, chNull };
+                ThrowXMLwithMemMgr2(ParseException,XMLExcepts::Parser_CC6, chStr, chStr, getMemoryManager());
+            }
 
             if (getState() != REGX_T_CHAR || getCharData() != chDash) {
                 tok->addRange(ch, ch);
@@ -276,8 +229,11 @@ RangeToken* ParserForXMLSchema::parseCharacterClass(const bool) {
                 if ((type = getState()) == REGX_T_EOF)
                     ThrowXMLwithMemMgr(ParseException,XMLExcepts::Parser_CC2, getMemoryManager());
 
-                if ((type == REGX_T_CHAR && getCharData() == chCloseSquare)
-                    || type == REGX_T_XMLSCHEMA_CC_SUBTRACTION) {
+                if (type == REGX_T_CHAR && getCharData() == chCloseSquare) {
+                    tok->addRange(ch, ch);
+                    tok->addRange(chDash, chDash);
+                }
+                else if (type == REGX_T_XMLSCHEMA_CC_SUBTRACTION) {
 
                     static const XMLCh dashStr[] = { chDash, chNull};
                     ThrowXMLwithMemMgr2(ParseException, XMLExcepts::Parser_CC6, dashStr, dashStr, getMemoryManager());
