@@ -15,70 +15,24 @@
  */
 
 /*
- * $Log: RangeToken.cpp,v $
- * Revision 1.10  2004/09/08 13:56:47  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.9  2003/12/17 00:18:37  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.8  2003/05/16 21:37:00  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.7  2003/05/15 21:46:47  knoaman
- * Add missing include.
- *
- * Revision 1.6  2002/11/04 15:17:00  tng
- * C++ Namespace Support.
- *
- * Revision 1.5  2002/10/15 18:15:02  knoaman
- * [Bug 13490]: - new[]/delete mismatch in RangeToken.cpp
- *
- * Revision 1.4  2002/05/27 11:46:53  tng
- * Fix compilation error.  The definition should match declaration.
- *
- * Revision 1.3  2002/05/24 16:42:20  knoaman
- * Performance fixes: eliminate mulitple calls to addRange and sort.
- *
- * Revision 1.2  2002/03/18 19:29:53  knoaman
- * Change constant names to eliminate possible conflict with user defined ones.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:30  peiyongz
- * sane_include
- *
- * Revision 1.4  2001/05/29 19:39:33  knoaman
- * Typo fix
- *
- * Revision 1.3  2001/05/11 13:26:45  tng
- * Copyright update.
- *
- * Revision 1.2  2001/05/03 18:17:37  knoaman
- * Some design changes:
- * o Changed the TokenFactory from a single static instance, to a
- *    normal class. Each RegularExpression object will have its own
- *    instance of TokenFactory, and that instance will be passed to
- *    other classes that need to use a TokenFactory to create Token
- *    objects (with the exception of RangeTokenMap).
- * o Added a new class RangeTokenMap to map a the different ranges
- *    in a given category to a specific RangeFactory object. In the old
- *    design RangeFactory had dual functionality (act as a Map, and as
- *    a factory for creating RangeToken(s)). The RangeTokenMap will
- *    have its own copy of the TokenFactory. There will be only one
- *    instance of the RangeTokenMap class, and that instance will be
- *    lazily deleted when XPlatformUtils::Terminate is called.
- *
- * Revision 1.1  2001/03/02 19:26:46  knoaman
- * Schema: Regular expression handling part II
- *
+ * $Id: RangeToken.cpp 225535 2005-07-27 15:08:56Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
 //  Includes
 // ---------------------------------------------------------------------------
+#include <assert.h>
+
 #include <xercesc/util/regx/RangeToken.hpp>
 #include <xercesc/util/regx/TokenFactory.hpp>
 #include <xercesc/util/IllegalArgumentException.hpp>
 
+#if defined(XML_USE_ICU_TRANSCODER) || defined (XML_USE_UNICONV390_TRANSCODER)
+#include <unicode/uchar.h>
+#else
+#include <xercesc/util/XMLUniDefs.hpp>
+#endif
+
 XERCES_CPP_NAMESPACE_BEGIN
 
 // ---------------------------------------------------------------------------
@@ -118,15 +72,55 @@ RangeToken::~RangeToken() {
 // ---------------------------------------------------------------------------
 RangeToken* RangeToken::getCaseInsensitiveToken(TokenFactory* const tokFactory) {
 
-    // REVIST
-    // We will not build a token with case insenstive ranges
-    // For now we will return a copy of ourselves.
     if (fCaseIToken == 0 && tokFactory) {
 
         bool isNRange = (getTokenType() == T_NRANGE) ? true : false;
         RangeToken* lwrToken = tokFactory->createRange(isNRange);
 
+        for (unsigned int i = 0;  i < fElemCount - 1;  i += 2) {
+            for (XMLInt32 ch = fRanges[i];  ch <= fRanges[i + 1];  ++ch) {
+#if defined(XML_USE_ICU_TRANSCODER) || defined (XML_USE_UNICONV390_TRANSCODER)
+                const XMLInt32  upperCh = u_toupper(ch);
+
+                if (upperCh != ch)
+                {
+                    lwrToken->addRange(upperCh, upperCh);
+                }
+
+                const XMLInt32  lowerCh = u_tolower(ch);
+
+                if (lowerCh != ch)
+                {
+                    lwrToken->addRange(lowerCh, lowerCh);
+                }
+
+                const XMLInt32  titleCh = u_totitle(ch);
+
+                if (titleCh != ch && titleCh != upperCh)
+                {
+                    lwrToken->addRange(titleCh, titleCh);
+                }
+#else
+                if (ch >= chLatin_A && ch <= chLatin_Z)
+                {
+                    ch += chLatin_a - chLatin_A;
+
+                    lwrToken->addRange(ch, ch);
+                }
+                else if (ch >= chLatin_a && ch <= chLatin_z)
+                {
+                    ch -= chLatin_a - chLatin_A;
+
+                    lwrToken->addRange(ch, ch);
+                }
+#endif
+            }
+        }
+
         lwrToken->mergeRanges(this);
+        lwrToken->compactRanges();
+        lwrToken->createMap();
+
         fCaseIToken = lwrToken;
     }
 
@@ -311,6 +305,7 @@ void RangeToken::mergeRanges(const Token *const tok) {
         }
 
         fElemCount = rangeTok->fElemCount;
+        fSorted = true;
         return;
     }
 
@@ -572,8 +567,7 @@ Token* RangeToken::complementRanges(RangeToken* const tok,
 // ---------------------------------------------------------------------------
 bool RangeToken::match(const XMLInt32 ch) {
 
-    if (fMap == 0)
-        createMap();
+    createMap();
 
     bool ret;
 
@@ -631,7 +625,9 @@ void RangeToken::expand(const unsigned int length) {
     fMaxCount = newMax;
 }
 
-void RangeToken::createMap() {
+void RangeToken::doCreateMap() {
+
+    assert(!fMap);
 
     int asize = MAPSIZE/32;
     fMap = (int*) fMemoryManager->allocate(asize * sizeof(int));//new int[asize];
