@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: RangeTokenMap.hpp,v 1.6 2004/09/08 13:56:47 peiyongz Exp $
+ * $Id: RangeTokenMap.hpp 180016 2005-06-04 19:49:30Z jberry $
  */
 
 #if !defined(RANGETOKENMAP_HPP)
@@ -107,7 +107,7 @@ protected:
     // -----------------------------------------------------------------------
     //  Constructor and destructors
     // -----------------------------------------------------------------------
-    RangeTokenMap();
+    RangeTokenMap(MemoryManager* manager);
     ~RangeTokenMap();
 
     // -----------------------------------------------------------------------
@@ -138,8 +138,10 @@ private:
      *  Initializes the registry with a set of commonly used RangeToken
      *  objects.
      */
-     void initializeRegistry();
-	 friend class TokenFactory;
+    void initializeRegistry();
+    void buildTokenRanges();
+    void cleanUp();
+	friend class TokenFactory;
 
     // -----------------------------------------------------------------------
     //  Private data members
@@ -161,14 +163,15 @@ private:
     //
     //  fMutex
     //      A mutex object for synchronization
-    // -----------------------------------------------------------------------
-    bool                               fRegistryInitialized;	
+    // -----------------------------------------------------------------------	
     RefHashTableOf<RangeTokenElemMap>* fTokenRegistry;
     RefHashTableOf<RangeFactory>*      fRangeMap;
 	XMLStringPool*                     fCategories;
     TokenFactory*                      fTokenFactory;
     XMLMutex                           fMutex;
     static RangeTokenMap*              fInstance;
+
+    friend class XMLInitializer;
 };
 
 // ---------------------------------------------------------------------------
