@@ -15,97 +15,7 @@
  */
 
 /*
- * $Log: RegularExpression.cpp,v $
- * Revision 1.23  2004/09/08 13:56:47  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.22  2004/01/13 20:05:00  peiyongz
- * revert code back to previous version
- *
- * Revision 1.19  2003/12/24 15:24:15  cargilld
- * More updates to memory management so that the static memory manager.
- *
- * Revision 1.18  2003/12/17 05:16:59  neilg
- * ensure all uses of ArrayJanitor use a memory manager
- *
- * Revision 1.17  2003/12/17 00:18:37  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.16  2003/12/16 12:25:48  cargilld
- * Change a conditional expression to an if-else to avoid a compiler problem.
- *
- * Revision 1.15  2003/10/01 16:32:40  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.14  2003/08/14 02:57:27  knoaman
- * Code refactoring to improve performance of validation.
- *
- * Revision 1.13  2003/05/25 21:42:41  knoaman
- * Allocate/Deallocate Context::xxx only when necessary.
- *
- * Revision 1.12  2003/05/18 14:02:06  knoaman
- * Memory manager implementation: pass per instance manager.
- *
- * Revision 1.11  2003/05/16 21:37:00  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.10  2003/05/16 06:01:57  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.9  2003/05/16 00:03:10  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.8  2003/05/15 18:42:54  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.7  2003/05/12 10:08:22  gareth
- * The correct file this time.
- *
- * Revision 1.5  2002/12/18 13:01:02  gareth
- * New functionality - tokenize and replace. Fixed REVISIT for case insensitive match. Patch by Jennifer Schachter.
- *
- * Revision 1.4  2002/11/04 15:17:00  tng
- * C++ Namespace Support.
- *
- * Revision 1.3  2002/10/15 18:56:02  knoaman
- * [Bug 13604] while loop never terminates.
- *
- * Revision 1.2  2002/03/18 19:29:53  knoaman
- * Change constant names to eliminate possible conflict with user defined ones.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:30  peiyongz
- * sane_include
- *
- * Revision 1.6  2002/01/02 20:09:11  knoaman
- * Fix for regular expression patterns that begin with ".".
- *
- * Revision 1.5  2001/10/09 12:20:25  tng
- * Leak fix: Need to delete fMatch if adopted.
- *
- * Revision 1.4  2001/05/11 21:50:58  knoaman
- * Schema updates and fixes.
- *
- * Revision 1.3  2001/05/11 13:26:46  tng
- * Copyright update.
- *
- * Revision 1.2  2001/05/03 18:17:42  knoaman
- * Some design changes:
- * o Changed the TokenFactory from a single static instance, to a
- *    normal class. Each RegularExpression object will have its own
- *    instance of TokenFactory, and that instance will be passed to
- *    other classes that need to use a TokenFactory to create Token
- *    objects (with the exception of RangeTokenMap).
- * o Added a new class RangeTokenMap to map a the different ranges
- *    in a given category to a specific RangeFactory object. In the old
- *    design RangeFactory had dual functionality (act as a Map, and as
- *    a factory for creating RangeToken(s)). The RangeTokenMap will
- *    have its own copy of the TokenFactory. There will be only one
- *    instance of the RangeTokenMap class, and that instance will be
- *    lazily deleted when XPlatformUtils::Terminate is called.
- *
- * Revision 1.1  2001/03/02 19:22:52  knoaman
- * Schema: Regular expression handling part I
- *
+ * $Id: RegularExpression.cpp 225473 2005-07-27 07:09:16Z dbertoni $
  */
 
 // ---------------------------------------------------------------------------
@@ -113,7 +23,6 @@
 // ---------------------------------------------------------------------------
 #include <xercesc/util/regx/RegularExpression.hpp>
 #include <xercesc/util/PlatformUtils.hpp>
-#include <xercesc/util/regx/RegxUtil.hpp>
 #include <xercesc/util/regx/Match.hpp>
 #include <xercesc/util/regx/RangeToken.hpp>
 #include <xercesc/util/regx/RegxDefs.hpp>
@@ -124,6 +33,9 @@
 #include <xercesc/util/IllegalArgumentException.hpp>
 #include <xercesc/framework/XMLBuffer.hpp>
 #include <xercesc/util/OutOfMemoryException.hpp>
+#include <xercesc/util/XMLInitializer.hpp>
+#include <xercesc/util/XMLRegisterCleanup.hpp>
+#include <xercesc/util/XMLUniDefs.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -146,6 +58,66 @@ const unsigned short RegularExpression::WT_LETTER = 1;
 const unsigned short RegularExpression::WT_OTHER = 2;
 RangeToken*          RegularExpression::fWordRange = 0;
 
+
+static void
+localCleanup()
+{
+    RegularExpression::staticCleanup();
+}
+
+static XMLRegisterCleanup WordRangeCleanup;
+
+
+
+bool RegularExpression::matchIgnoreCase(const XMLInt32 ch1,
+                                                 const XMLInt32 ch2)
+{
+    if (ch1 >= 0x10000)
+    {
+        XMLCh string1[2];
+        XMLCh string2[2];
+
+        RegxUtil::decomposeToSurrogates(ch1, string1[0], string1[1]);
+
+        if (ch2 >= 0x10000)
+        {
+            RegxUtil::decomposeToSurrogates(ch2, string2[0], string2[1]);
+        }
+        else
+        {
+            // XMLString::compareNIString is broken, because it assume the
+            // two strings must be of the same length.  Note that two strings
+            // of different length could compare as equal, because there is no
+            // guarantee that a Unicode code point that is encoded in UTF-16 as
+            // a surrogate pair does not have a case mapping to a code point
+            // that is not in the surrogate range.  Just to be safe, we pad the
+            // shorter string with a space, which cannot hvae a case mapping.
+            string2[0] = (XMLCh)ch2;
+            string2[1] = chSpace;
+        }
+
+        return (0==XMLString::compareNIString(string1, string2, 2));
+    }
+    else if (ch2 >= 0x10000)
+    {
+        const XMLCh string1[2] = { (XMLCh)ch1, chSpace };
+        XMLCh string2[2];
+
+        RegxUtil::decomposeToSurrogates(ch2, string2[0], string2[1]);
+
+        return (0==XMLString::compareNIString(string1, string2, 2));
+    }
+    else
+    {
+        const XMLCh  char1 = (XMLCh)ch1;
+        const XMLCh  char2 = (XMLCh)ch2;
+
+        return (0==XMLString::compareNIString(&char1, &char2, 1));
+    }
+  }
+
+
+
 // ---------------------------------------------------------------------------
 //  RegularExpression::Context: Constructors and Destructor
 // ---------------------------------------------------------------------------
@@ -165,11 +137,9 @@ RegularExpression::Context::Context(MemoryManager* const manager) :
 
 RegularExpression::Context::~Context()
 {
-	if (fOffsets)
+    if (fOffsets)
         fMemoryManager->deallocate(fOffsets);//delete [] fOffsets;
 
-    fMemoryManager->deallocate(fString);//delete [] fString;
-
 	if (fAdoptMatch)
 		delete fMatch;
 }
@@ -183,19 +153,8 @@ void RegularExpression::Context::reset(const XMLCh* const string
                                        , const int limit
                                        , const int noClosures)
 {
-    if (stringLen > fStringMaxLen || !fString) {
-
-        fStringMaxLen = stringLen;
-
-        if (fString)
-            fMemoryManager->deallocate(fString);
-
-        fString = XMLString::replicate(string, fMemoryManager);
-    }
-    else {
-        memcpy(fString, string, (stringLen + 1) * sizeof(XMLCh));
-    }
-
+    fString = string;
+    fStringMaxLen = stringLen;
 	fStart = start;
 	fLimit = limit;
 	fLength = fLimit - fStart;	
@@ -247,6 +206,9 @@ bool RegularExpression::Context::nextCh(XMLInt32& ch, int& offset,
 // ---------------------------------------------------------------------------
 //  RegularExpression: Constructors and Destructors
 // ---------------------------------------------------------------------------
+
+typedef JanitorMemFunCall<RegularExpression>    CleanupType;
+
 RegularExpression::RegularExpression(const char* const pattern,
                                      MemoryManager* const manager)
 	:fHasBackReferences(false),
@@ -265,6 +227,8 @@ RegularExpression::RegularExpression(const char* const pattern,
      fTokenFactory(0),
      fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &RegularExpression::cleanUp);
+
 	try {
 
 		XMLCh* tmpBuf = XMLString::transcode(pattern, fMemoryManager);
@@ -273,13 +237,12 @@ RegularExpression::RegularExpression(const char* const pattern,
 	}
     catch(const OutOfMemoryException&)
     {
+        cleanup.release();
+
         throw;
     }
-    catch (...) {
 
-		cleanUp();
-		throw;
-	}
+    cleanup.release();
 }
 
 RegularExpression::RegularExpression(const char* const pattern,
@@ -301,6 +264,8 @@ RegularExpression::RegularExpression(const char* const pattern,
      fTokenFactory(0),
      fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &RegularExpression::cleanUp);
+
 	try {
 
 		XMLCh* tmpBuf = XMLString::transcode(pattern, fMemoryManager);
@@ -311,13 +276,12 @@ RegularExpression::RegularExpression(const char* const pattern,
 	}
     catch(const OutOfMemoryException&)
     {
+        cleanup.release();
+
         throw;
     }
-    catch (...) {
 
-		cleanUp();
-		throw;
-	}
+    cleanup.release();
 }
 
 
@@ -339,19 +303,20 @@ RegularExpression::RegularExpression(const XMLCh* const pattern,
      fTokenFactory(0),
      fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &RegularExpression::cleanUp);
+
 	try {
 
 		setPattern(pattern);
 	}
     catch(const OutOfMemoryException&)
     {
+        cleanup.release();
+
         throw;
     }
-    catch (...) {
 
-		cleanUp();
-		throw;
-	}
+    cleanup.release();
 }
 
 RegularExpression::RegularExpression(const XMLCh* const pattern,
@@ -373,19 +338,20 @@ RegularExpression::RegularExpression(const XMLCh* const pattern,
      fTokenFactory(0),
      fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &RegularExpression::cleanUp);
+
 	try {
 
 		setPattern(pattern, options);
 	}
     catch(const OutOfMemoryException&)
     {
+        cleanup.release();
+
         throw;
     }
-    catch (...) {
 
-		cleanUp();
-		throw;
-	}
+    cleanup.release();
 }
 
 RegularExpression::~RegularExpression() {
@@ -425,6 +391,8 @@ void RegularExpression::setPattern(const XMLCh* const pattern,
 	fTokenTree = regxParser->parse(fPattern, fOptions);
 	fNoGroups = regxParser->getNoParen();
 	fHasBackReferences = regxParser->hasBackReferences();
+
+    prepare();
 }
 
 // ---------------------------------------------------------------------------
@@ -492,9 +460,6 @@ bool RegularExpression::matches(const XMLCh* const expression, const int start,
                                 const int end, Match* const pMatch
                                 , MemoryManager* const manager)	{
 		
-	if (fOperations == 0)
-		prepare();
-
 	Context context(manager);
 	int		 strLength = XMLString::stringLen(expression);
 
@@ -624,11 +589,6 @@ bool RegularExpression::matches(const XMLCh* const expression, const int start,
 
 				if (!range->match(ch)) {
 
-					if (!ignoreCase)
-						continue;
-
-					// Perform case insensitive match
-					// REVISIT
 					continue;
 				}
 
@@ -698,9 +658,6 @@ RefArrayVectorOf<XMLCh>* RegularExpression::tokenize(const XMLCh* const expressi
                                                      const int start, const int end,
                                                      RefVectorOf<Match> *subEx){
   
-  if (fOperations == 0)
-	  prepare();
-
   RefArrayVectorOf<XMLCh>* tokenStack = new (fMemoryManager) RefArrayVectorOf<XMLCh>(16, true, fMemoryManager);
 
   Context context(fMemoryManager);
@@ -895,6 +852,31 @@ XMLCh* RegularExpression::replace(const XMLCh* const matchString,
     
 }
 
+
+// -----------------------------------------------------------------------
+//  Static initialize and cleanup methods
+// -----------------------------------------------------------------------
+void
+XMLInitializer::initializeRegularExpression()
+{
+    RegularExpression::staticInitialize(XMLPlatformUtils::fgMemoryManager);
+}
+
+
+
+void
+RegularExpression::staticInitialize(MemoryManager*  memoryManager)
+{
+    fWordRange = TokenFactory::staticGetRange(fgUniIsWord, false);
+
+	if (fWordRange == 0)
+		ThrowXMLwithMemMgr1(RuntimeException, XMLExcepts::Regex_RangeTokenGetError, fgUniIsWord, memoryManager);
+
+    WordRangeCleanup.registerCleanup(localCleanup);
+}
+
+
+
 // ---------------------------------------------------------------------------
 //  RegularExpression: Helpers methods
 // ---------------------------------------------------------------------------
@@ -1160,21 +1142,10 @@ bool RegularExpression::matchRange(Context* const context, const Op* const op,
 	bool match = false;
 
 	if (ignoreCase) {
-
-		//REVISIT we should match ignoring case, but for now
-		//we will do a normal match
-		//tok = tok->getCaseInsensitiveToken();
-		//if (!token->match(strCh)) {
-
-		//	if (strCh > 0x10000)
-		//		return -1;
-			// Do case insensitive matching - uppercase match
-			// or lowercase match
-		//}
-		match = tok->match(strCh);
+		tok = tok->getCaseInsensitiveToken(fTokenFactory);
 	}
-	else
-		match = tok->match(strCh);
+
+    match = tok->match(strCh);
 
 	if (!match)
 		return false;
@@ -1538,12 +1509,10 @@ const XMLCh* RegularExpression::subInExp(const XMLCh* const repString,
 
 
 /*
- * Prepares for matching. This method is called just before starting matching
+ * Prepares for matching. This method is called during construction.
  */
 void RegularExpression::prepare() {
 
-	XMLMutexLock lockInit(&fMutex);
-
 	compile(fTokenTree);
 
 	fMinLength = fTokenTree->getMinLength();
@@ -1560,7 +1529,14 @@ void RegularExpression::prepare() {
 			rangeTok->compactRanges();
 			fFirstChar = rangeTok;
 		}
-	}
+
+        rangeTok->createMap();
+
+    	if (isSet(fOptions, IGNORE_CASE))
+        {
+            rangeTok->getCaseInsensitiveToken(fTokenFactory);
+        }
+    }
 
 	if (fOperations != 0 && fOperations->getNextOp() == 0 &&
 		(fOperations->getOpType() == Op::O_STRING ||
@@ -1613,7 +1589,7 @@ void RegularExpression::prepare() {
 		if (fFixedString != 0) {
 
 			fBMPattern = new (fMemoryManager) BMPattern(fFixedString, 256,
-									   isSet(fixedOpts, IGNORE_CASE));
+									   isSet(fixedOpts, IGNORE_CASE), fMemoryManager);
 		}
 	}
 }
