@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: RegularExpression.hpp,v 1.19 2004/09/08 13:56:47 peiyongz Exp $
+ * $Id: RegularExpression.hpp 225473 2005-07-27 07:09:16Z dbertoni $
  */
 
 #if !defined(REGULAREXPRESSION_HPP)
@@ -27,13 +27,13 @@
 #include <xercesc/util/RefArrayVectorOf.hpp>
 #include <xercesc/util/XMLString.hpp>
 #include <xercesc/util/Janitor.hpp>
-#include <xercesc/util/Mutexes.hpp>
 #include <xercesc/util/regx/Op.hpp>
 #include <xercesc/util/regx/TokenFactory.hpp>
 #include <xercesc/util/regx/BMPattern.hpp>
 #include <xercesc/util/regx/ModifierToken.hpp>
 #include <xercesc/util/regx/ConditionToken.hpp>
 #include <xercesc/util/regx/OpFactory.hpp>
+#include <xercesc/util/regx/RegxUtil.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -139,6 +139,17 @@ public:
     XMLCh *replace(const XMLCh* const matchString, const XMLCh* const replaceString,
                    const int start, const int end);
 
+    // -----------------------------------------------------------------------
+    //  Static initialize and cleanup methods
+    // -----------------------------------------------------------------------
+    static void
+    staticInitialize(MemoryManager*  memoryManager);
+
+    static void
+    staticCleanup();
+
+    static bool isSet(const int options, const int flag);
+
 private:
     // -----------------------------------------------------------------------
     //  Private data types
@@ -154,18 +165,16 @@ private:
                        const int start, const int limit, const int noClosures);
             bool nextCh(XMLInt32& ch, int& offset, const short direction);
             
-            bool      fAdoptMatch;
-            int       fStart;
-            int       fLimit;
-            int       fLength;    // fLimit - fStart
-            int       fSize;
-            int       fStringMaxLen;
-            int*      fOffsets;
-            Match*    fMatch;
-            XMLCh*    fString;
+            bool           fAdoptMatch;
+            int            fStart;
+            int            fLimit;
+            int            fLength;    // fLimit - fStart
+            int            fSize;
+            int            fStringMaxLen;
+            int*           fOffsets;
+            Match*         fMatch;
+            const XMLCh*   fString;
             MemoryManager* fMemoryManager;
-
-            friend class Janitor<Context>;
     };
 
     // -----------------------------------------------------------------------
@@ -189,7 +198,6 @@ private:
     // -----------------------------------------------------------------------
     void prepare();
     int parseOptions(const XMLCh* const options);
-    bool isSet(const int options, const int flag);
     unsigned short getWordType(const XMLCh* const target, const int begin,
                                const int end, const int offset);
     unsigned short getCharType(const XMLCh ch);
@@ -290,12 +298,20 @@ private:
     RangeToken*        fFirstChar;
     static RangeToken* fWordRange;
     OpFactory          fOpFactory;
-    XMLMutex           fMutex;
     TokenFactory*      fTokenFactory;
     MemoryManager*     fMemoryManager;
 };
 
 
+
+  // -----------------------------------------------------------------------
+  //  RegularExpression: Static initialize and cleanup methods
+  // -----------------------------------------------------------------------
+  inline void RegularExpression::staticCleanup()
+  {
+      fWordRange = 0;
+  }
+
   // ---------------------------------------------------------------------------
   //  RegularExpression: Cleanup methods
   // ---------------------------------------------------------------------------
@@ -543,7 +559,7 @@ private:
 
           ret = match(context, op->elementAt(i), offset, direction);
 
-          if (ret == context->fLimit)
+          if (ret >= 0 && ret <= context->fLimit)
               return ret;
       }
 
@@ -591,14 +607,6 @@ private:
       return ret;
   }
 
-  inline bool RegularExpression::matchIgnoreCase(const XMLInt32 ch1,
-                                                 const XMLInt32 ch2)
-  {
-
-      return (0==XMLString::compareNIString((const XMLCh*)&ch1,(const XMLCh*)&ch2, 1));
-  }
-
-
 XERCES_CPP_NAMESPACE_END
 
 #endif
