@@ -1,136 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2003 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2003,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: RegxParser.cpp,v $
- * Revision 1.11  2004/01/29 11:51:21  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.10  2003/12/17 00:18:37  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.9  2003/05/18 14:02:06  knoaman
- * Memory manager implementation: pass per instance manager.
- *
- * Revision 1.8  2003/05/16 00:03:10  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.7  2003/05/15 18:42:55  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.6  2003/03/18 19:38:28  knoaman
- * Schema Errata E2-18 + misc. regex fixes.
- *
- * Revision 1.5  2003/03/04 16:36:17  knoaman
- * RegEx: fix for character category escape
- *
- * Revision 1.4  2003/01/13 19:02:23  knoaman
- * [Bug 14390] C++ Indentifier collision with Python.
- *
- * Revision 1.3  2002/11/04 15:17:00  tng
- * C++ Namespace Support.
- *
- * Revision 1.2  2002/03/18 19:29:53  knoaman
- * Change constant names to eliminate possible conflict with user defined ones.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:30  peiyongz
- * sane_include
- *
- * Revision 1.10  2001/11/20 20:48:10  knoaman
- * Fix for invalid repeating quantifier check.
- *
- * Revision 1.9  2001/11/16 15:56:37  knoaman
- * Add check for invalid repeating quantifier.
- *
- * Revision 1.8  2001/09/20 13:11:42  knoaman
- * Regx  + misc. fixes
- *
- * Revision 1.7  2001/08/31 16:53:41  knoaman
- * Misc. fixes.
- *
- * Revision 1.6  2001/07/26 12:46:48  knoaman
- * Fix for bug 2815.
- *
- * Revision 1.5  2001/06/06 13:49:27  jberry
- * Fix two improper NULL tests
- *
- * Revision 1.4  2001/05/11 21:51:01  knoaman
- * Schema updates and fixes.
- *
- * Revision 1.3  2001/05/11 13:26:48  tng
- * Copyright update.
- *
- * Revision 1.2  2001/05/03 18:17:45  knoaman
- * Some design changes:
- * o Changed the TokenFactory from a single static instance, to a
- *    normal class. Each RegularExpression object will have its own
- *    instance of TokenFactory, and that instance will be passed to
- *    other classes that need to use a TokenFactory to create Token
- *    objects (with the exception of RangeTokenMap).
- * o Added a new class RangeTokenMap to map a the different ranges
- *    in a given category to a specific RangeFactory object. In the old
- *    design RangeFactory had dual functionality (act as a Map, and as
- *    a factory for creating RangeToken(s)). The RangeTokenMap will
- *    have its own copy of the TokenFactory. There will be only one
- *    instance of the RangeTokenMap class, and that instance will be
- *    lazily deleted when XPlatformUtils::Terminate is called.
- *
- * Revision 1.1  2001/03/02 19:22:54  knoaman
- * Schema: Regular expression handling part I
- *
+ * $Id: RegxParser.cpp 225473 2005-07-27 07:09:16Z dbertoni $
  */
 
 // ---------------------------------------------------------------------------
@@ -201,8 +86,6 @@ Token* RegxParser::parse(const XMLCh* const regxStr, const int options) {
         return 0;
     }
 
-	XMLMutexLock lockInit(&fMutex);
-
 	fOptions = options;
 	fOffset = 0;
 	fNoGroups = 1;
@@ -225,7 +108,9 @@ Token* RegxParser::parse(const XMLCh* const regxStr, const int options) {
     Token* retTok = parseRegx();
 
 	if (fOffset != fStringLen) {
-        ThrowXMLwithMemMgr(ParseException,XMLExcepts::Parser_Parse1, fMemoryManager);
+        XMLCh value1[65];
+        XMLString::binToText(fOffset, value1, 64, 10, fMemoryManager);
+        ThrowXMLwithMemMgr2(ParseException,XMLExcepts::Parser_Parse1, value1, fString, fMemoryManager);
     }
 
     if (fReferences != 0) {
@@ -1290,6 +1175,15 @@ RangeToken* RegxParser::parseCharacterClass(const bool useNRange) {
 
     tok->sortRanges();
     tok->compactRanges();
+
+    // If the case-insensitive option is enabled, we need to
+    // have the new RangeToken instance build its internal
+    // case-insensitive RangeToken.
+    if (RegularExpression::isSet(fOptions, RegularExpression::IGNORE_CASE))
+    {
+        tok->getCaseInsensitiveToken(fTokenFactory);
+    }
+
     setParseContext(S_NORMAL);
     processNext();
 
