@@ -15,46 +15,7 @@
  */
 
 /*
- * $Log: UnicodeRangeFactory.cpp,v $
- * Revision 1.5  2004/09/08 13:56:47  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.4  2003/12/17 00:18:37  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.3  2002/11/04 15:17:01  tng
- * C++ Namespace Support.
- *
- * Revision 1.2  2002/02/05 13:20:06  tng
- * [Bug 5716] Can't parse with Validation more than one file.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:34  peiyongz
- * sane_include
- *
- * Revision 1.4  2001/10/15 18:30:40  knoaman
- * Add support for 'Pi' and 'Pf'.
- *
- * Revision 1.3  2001/05/11 13:26:51  tng
- * Copyright update.
- *
- * Revision 1.2  2001/05/03 18:17:56  knoaman
- * Some design changes:
- * o Changed the TokenFactory from a single static instance, to a
- *    normal class. Each RegularExpression object will have its own
- *    instance of TokenFactory, and that instance will be passed to
- *    other classes that need to use a TokenFactory to create Token
- *    objects (with the exception of RangeTokenMap).
- * o Added a new class RangeTokenMap to map a the different ranges
- *    in a given category to a specific RangeFactory object. In the old
- *    design RangeFactory had dual functionality (act as a Map, and as
- *    a factory for creating RangeToken(s)). The RangeTokenMap will
- *    have its own copy of the TokenFactory. There will be only one
- *    instance of the RangeTokenMap class, and that instance will be
- *    lazily deleted when XPlatformUtils::Terminate is called.
- *
- * Revision 1.1  2001/03/02 19:26:48  knoaman
- * Schema: Regular expression handling part II
- *
+ * $Id: UnicodeRangeFactory.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 // ---------------------------------------------------------------------------
@@ -125,9 +86,7 @@ const XMLCh uniCategNames[][UNICATEGSIZE] =
 // ---------------------------------------------------------------------------
 //  UnicodeRangeFactory: Constructors and Destructor
 // ---------------------------------------------------------------------------
-UnicodeRangeFactory::UnicodeRangeFactory() :
-   fRangesCreated(false)
- , fKeywordsInitialized(false)
+UnicodeRangeFactory::UnicodeRangeFactory()
 {
 }
 
@@ -138,18 +97,18 @@ UnicodeRangeFactory::~UnicodeRangeFactory() {
 // ---------------------------------------------------------------------------
 //  UnicodeRangeFactory: Range creation methods
 // ---------------------------------------------------------------------------
-void UnicodeRangeFactory::buildRanges() {
+void UnicodeRangeFactory::buildRanges(RangeTokenMap *rangeTokMap) {
 
     if (fRangesCreated)
         return;
 
     if (!fKeywordsInitialized) {
-        initializeKeywordMap();
+        initializeKeywordMap(rangeTokMap);
     }
 
-    RangeTokenMap* rangeTokMap = RangeTokenMap::instance();
     TokenFactory* tokFactory = rangeTokMap->getTokenFactory();
 	RangeToken* ranges[UNICATEGSIZE];
+    RangeToken* tok;
 
     for (int i=0; i < UNICATEGSIZE; i++) {
         ranges[i] = tokFactory->createRange();
@@ -159,45 +118,85 @@ void UnicodeRangeFactory::buildRanges() {
 
         unsigned short charType = XMLUniCharacter::getType(j);
 
-		ranges[charType]->addRange(j, j);
-		charType = getUniCategory(charType);
-		ranges[charType]->addRange(j, j);
+        ranges[charType]->addRange(j, j);
+        charType = getUniCategory(charType);
+        ranges[charType]->addRange(j, j);
     }
 
-	ranges[XMLUniCharacter::UNASSIGNED]->addRange(0x10000, Token::UTF16_MAX);
+    ranges[XMLUniCharacter::UNASSIGNED]->addRange(0x10000, Token::UTF16_MAX);
 
-	for (int k=0; k < UNICATEGSIZE; k++) {
+    for (int k=0; k < UNICATEGSIZE; k++) {
+        tok = (RangeToken*) RangeToken::complementRanges(ranges[k], tokFactory);
+        // build the internal map.
+        tok->createMap();
         rangeTokMap->setRangeToken(uniCategNames[k], ranges[k]);
+        rangeTokMap->setRangeToken(uniCategNames[k], tok , true);
     }
 
     // Create all range
-	RangeToken* tok = tokFactory->createRange();
-	tok->addRange(0, Token::UTF16_MAX);
-	rangeTokMap->setRangeToken(fgUniAll, tok);
+    tok = tokFactory->createRange();
+    tok->addRange(0, Token::UTF16_MAX);
+    // build the internal map.
+    tok->createMap();
+    rangeTokMap->setRangeToken(fgUniAll, tok);
 
     // Create alpha range
     tok = tokFactory->createRange();
     tok->mergeRanges(ranges[XMLUniCharacter::UPPERCASE_LETTER]);
     tok->mergeRanges(ranges[XMLUniCharacter::LOWERCASE_LETTER]);
     tok->mergeRanges(ranges[XMLUniCharacter::OTHER_LETTER]);
+    // build the internal map.
+    tok->createMap();
     rangeTokMap->setRangeToken(fgUniIsAlpha, tok);
 
     // Create alpha-num range
     RangeToken* alnumTok = tokFactory->createRange();
     alnumTok->mergeRanges(tok);
     alnumTok->mergeRanges(ranges[XMLUniCharacter::DECIMAL_DIGIT_NUMBER]);
+    // build the internal map.
+    alnumTok->createMap();
     rangeTokMap->setRangeToken(fgUniIsAlnum, alnumTok);
 
     // Create word range
     tok = tokFactory->createRange();
     tok->mergeRanges(alnumTok);
     tok->addRange(chUnderscore, chUnderscore);
+    // build the internal map.
+    tok->createMap();
     rangeTokMap->setRangeToken(fgUniIsWord, tok);
 
+    tok = (RangeToken*) RangeToken::complementRanges(tok, tokFactory);
+    // build the internal map.
+    tok->createMap();
+    rangeTokMap->setRangeToken(fgUniIsWord, tok , true);
+
     // Create assigned range
-    tok = ranges[XMLUniCharacter::UNASSIGNED];
-    rangeTokMap->setRangeToken(fgUniAssigned,(RangeToken*)RangeToken::complementRanges(tok,
-		          tokFactory, tokFactory->getMemoryManager()));
+    tok = (RangeToken*)RangeToken::complementRanges(
+                ranges[XMLUniCharacter::UNASSIGNED],
+		        tokFactory,
+                tokFactory->getMemoryManager());
+    // build the internal map.
+    tok->createMap();
+    rangeTokMap->setRangeToken(fgUniAssigned,tok);
+
+    // Create space range
+    tok = tokFactory->createRange();
+    tok->mergeRanges(ranges[XMLUniCharacter::SPACE_SEPARATOR]);
+    tok->mergeRanges(ranges[XMLUniCharacter::LINE_SEPARATOR]);
+    //tok->mergeRanges(ranges[XMLUniCharacter::PARAGRAPH_SEPARATOR]);
+    // build the internal map.
+    tok->createMap();
+    rangeTokMap->setRangeToken(fgUniIsSpace, tok);
+
+    tok = (RangeToken*) RangeToken::complementRanges(tok, tokFactory);
+    // build the internal map.
+    tok->createMap();
+    rangeTokMap->setRangeToken(fgUniIsSpace, tok , true);
+
+    // build the internal maps.
+    for (int l=0; l < UNICATEGSIZE; l++) {
+        ranges[l]->createMap();
+    }
 
     fRangesCreated = true;
 }
@@ -205,22 +204,21 @@ void UnicodeRangeFactory::buildRanges() {
 // ---------------------------------------------------------------------------
 //  UnicodeRangeFactory: Initialization methods
 // ---------------------------------------------------------------------------
-void UnicodeRangeFactory::initializeKeywordMap() {
+void UnicodeRangeFactory::initializeKeywordMap(RangeTokenMap *rangeTokMap) {
 
     if (fKeywordsInitialized)
         return;
 
-    RangeTokenMap* rangeTokMap = RangeTokenMap::instance();
-
 	for (int k=0; k < UNICATEGSIZE; k++) {
         rangeTokMap->addKeywordMap(uniCategNames[k], fgUnicodeCategory);
     }
 
-	rangeTokMap->addKeywordMap(fgUniAll, fgUnicodeCategory);
+    rangeTokMap->addKeywordMap(fgUniAll, fgUnicodeCategory);
     rangeTokMap->addKeywordMap(fgUniIsAlpha, fgUnicodeCategory);
     rangeTokMap->addKeywordMap(fgUniIsAlnum, fgUnicodeCategory);
     rangeTokMap->addKeywordMap(fgUniIsWord, fgUnicodeCategory);
     rangeTokMap->addKeywordMap(fgUniAssigned, fgUnicodeCategory);
+    rangeTokMap->addKeywordMap(fgUniIsSpace, fgUnicodeCategory);
 
     fKeywordsInitialized = true;
 }
@@ -230,7 +228,6 @@ void UnicodeRangeFactory::initializeKeywordMap() {
 // ---------------------------------------------------------------------------
 unsigned short UnicodeRangeFactory::getUniCategory(const unsigned short type)
 {
-
     switch(type) {
     case XMLUniCharacter::UPPERCASE_LETTER:
     case XMLUniCharacter::LOWERCASE_LETTER:
@@ -245,17 +242,17 @@ unsigned short UnicodeRangeFactory::getUniCategory(const unsigned short type)
     case XMLUniCharacter::DECIMAL_DIGIT_NUMBER:
     case XMLUniCharacter::LETTER_NUMBER:
     case XMLUniCharacter::OTHER_NUMBER:
-		return CHAR_NUMBER;
+        return CHAR_NUMBER;
     case XMLUniCharacter::SPACE_SEPARATOR:
     case XMLUniCharacter::LINE_SEPARATOR:
     case XMLUniCharacter::PARAGRAPH_SEPARATOR:
-		return CHAR_SEPARATOR;
+        return CHAR_SEPARATOR;
     case XMLUniCharacter::CONTROL:
     case XMLUniCharacter::FORMAT:
     case XMLUniCharacter::SURROGATE:
     case XMLUniCharacter::PRIVATE_USE:
     case XMLUniCharacter::UNASSIGNED:
-		return CHAR_OTHER;
+        return CHAR_OTHER;
     case XMLUniCharacter::CONNECTOR_PUNCTUATION:
     case XMLUniCharacter::DASH_PUNCTUATION:
     case XMLUniCharacter::START_PUNCTUATION:
@@ -263,12 +260,12 @@ unsigned short UnicodeRangeFactory::getUniCategory(const unsigned short type)
     case XMLUniCharacter::OTHER_PUNCTUATION:
     case XMLUniCharacter::INITIAL_PUNCTUATION:
     case XMLUniCharacter::FINAL_PUNCTUATION:
-		return CHAR_PUNCTUATION;
+        return CHAR_PUNCTUATION;
     case XMLUniCharacter::MATH_SYMBOL:
     case XMLUniCharacter::CURRENCY_SYMBOL:
     case XMLUniCharacter::MODIFIER_SYMBOL:
     case XMLUniCharacter::OTHER_SYMBOL:
-		return CHAR_SYMBOL;
+        return CHAR_SYMBOL;
     }
 
     return 0;
