@@ -15,7 +15,16 @@
  */
 
 /*
- * $Log: GrammarResolver.cpp,v $
+ * $Log$
+ * Revision 1.32  2005/04/29 20:21:02  dbertoni
+ * Patch for Jira issue XERCESC-1407.
+ *
+ * Revision 1.31  2005/03/20 14:53:35  knoaman
+ * [jira 1381] Memory leak in GrammarResolver - patch by Christian Will.
+ *
+ * Revision 1.30  2004/12/03 17:00:13  amassari
+ * Avoid throwing an exception when orphaning a cached grammar that has not been used yet
+ *
  * Revision 1.29  2004/09/29 19:27:07  cargilld
  * Fix for Jira-1217: fixing problems with getXSModel.
  *
@@ -428,8 +437,7 @@ void GrammarResolver::cacheGrammars()
 void GrammarResolver::cacheGrammarFromParse(const bool aValue)
 {
     reset();
-    fCacheGrammar = aValue;    
-    fGrammarBucket->setAdoptElements(!fCacheGrammar);
+    fCacheGrammar = aValue;
 }
 
 Grammar* GrammarResolver::orphanGrammar(const XMLCh* const nameSpaceKey)
@@ -439,12 +447,18 @@ Grammar* GrammarResolver::orphanGrammar(const XMLCh* const nameSpaceKey)
         Grammar* grammar = fGrammarPool->orphanGrammar(nameSpaceKey);
         if (grammar)
         {
-            fGrammarFromPool->removeKey(nameSpaceKey);
-            return grammar;
-        }       
-        // It failed to remove it from the grammar pool either because it
-        // didn't exist or because it is locked.
-        return 0;
+            if (fGrammarFromPool->containsKey(nameSpaceKey))
+                fGrammarFromPool->removeKey(nameSpaceKey);
+        }
+        // Check to see if it's in fGrammarBucket, since
+        // we put it there if the grammar pool refused to
+        // cache it.
+        else if (fGrammarBucket->containsKey(nameSpaceKey))
+        {
+            grammar = fGrammarBucket->orphanKey(nameSpaceKey);
+        }
+
+        return grammar;
     }
     else
     {
@@ -455,7 +469,7 @@ Grammar* GrammarResolver::orphanGrammar(const XMLCh* const nameSpaceKey)
 XSModel *GrammarResolver::getXSModel()
 {
     XSModel* xsModel;
-    if (fCacheGrammar)
+    if (fCacheGrammar || fUseCachedGrammar)
     {
         // We know if the grammarpool changed thru caching, orphaning and erasing
         // but NOT by other mechanisms such as lockPool() or unlockPool() so it
