@@ -1,152 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: MixedContentModel.cpp,v $
- * Revision 1.10  2004/01/29 11:51:21  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.9  2003/12/17 00:18:38  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.8  2003/11/20 18:12:20  knoaman
- * Use a bitwise operation to check the node type.
- *
- * Revision 1.7  2003/11/07 17:08:11  knoaman
- * For PSVI support, distinguish wildcard elements with namespace lists.
- *
- * Revision 1.6  2003/05/18 14:02:06  knoaman
- * Memory manager implementation: pass per instance manager.
- *
- * Revision 1.5  2003/05/16 21:43:20  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.4  2003/05/15 18:48:27  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.3  2002/11/04 14:54:58  tng
- * C++ Namespace Support.
- *
- * Revision 1.2  2002/09/24 19:48:39  tng
- * Performance: use XMLString::equals instead of XMLString::compareString
- *
- * Revision 1.1.1.1  2002/02/01 22:22:39  peiyongz
- * sane_include
- *
- * Revision 1.13  2001/08/24 12:48:48  tng
- * Schema: AllContentModel
- *
- * Revision 1.12  2001/08/21 16:06:11  tng
- * Schema: Unique Particle Attribution Constraint Checking.
- *
- * Revision 1.11  2001/07/09 15:22:37  knoaman
- * complete <any> declaration.
- *
- * Revision 1.10  2001/06/12 22:13:33  peiyongz
- * validateContentSpecial() : apply SubstitutionGroupComparator.isEquivalentTo()
- *
- * Revision 1.9  2001/05/11 13:27:19  tng
- * Copyright update.
- *
- * Revision 1.8  2001/05/03 21:02:30  tng
- * Schema: Add SubstitutionGroupComparator and update exception messages.  By Pei Yong Zhang.
- *
- * Revision 1.7  2001/04/19 18:17:32  tng
- * Schema: SchemaValidator update, and use QName in Content Model
- *
- * Revision 1.6  2001/03/21 21:56:28  tng
- * Schema: Add Schema Grammar, Schema Validator, and split the DTDValidator into DTDValidator, DTDScanner, and DTDGrammar.
- *
- * Revision 1.5  2001/03/21 19:29:57  tng
- * Schema: Content Model Updates, by Pei Yong Zhang.
- *
- * Revision 1.4  2001/02/27 18:32:32  tng
- * Schema: Use XMLElementDecl instead of DTDElementDecl in Content Model.
- *
- * Revision 1.3  2001/02/27 14:48:54  tng
- * Schema: Add CMAny and ContentLeafNameTypeVector, by Pei Yong Zhang
- *
- * Revision 1.2  2001/02/16 14:58:57  tng
- * Schema: Update Makefile, configure files, project files, and include path in
- * certain cpp files because of the move of the common Content Model files.  By Pei Yong Zhang.
- *
- * Revision 1.1  2001/02/16 14:17:29  tng
- * Schema: Move the common Content Model files that are shared by DTD
- * and schema from 'DTD' folder to 'common' folder.  By Pei Yong Zhang.
- *
- * Revision 1.5  2000/05/15 22:31:32  andyh
- * Replace #include<memory.h> with <string.h> everywhere.
- *
- * Revision 1.4  2000/03/18 00:00:05  roddey
- * Initial updates for two way transcoding support
- *
- * Revision 1.3  2000/03/02 19:55:39  roddey
- * This checkin includes many changes done while waiting for the
- * 1.1.0 code to be finished. I can't list them all here, but a list is
- * available elsewhere.
- *
- * Revision 1.2  2000/02/09 21:42:39  abagchi
- * Copyright swatswat
- *
- * Revision 1.1.1.1  1999/11/09 01:03:43  twl
- * Initial checkin
- *
- * Revision 1.3  1999/11/08 20:45:43  rahul
- * Swat for adding in Product name and CVS comment log variable.
- *
+ * $Id: MixedContentModel.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -210,13 +79,16 @@ MixedContentModel::MixedContentModel(const bool             dtd
         fCount * sizeof(ContentSpecNode::NodeTypes)
     ); //new ContentSpecNode::NodeTypes[fCount];
     for (unsigned int index = 0; index < fCount; index++) {
-        fChildren[index] = children.elementAt(index);
+        fChildren[index] = new (fMemoryManager) QName(*children.elementAt(index));
         fChildTypes[index] = childTypes.elementAt(index);
     }
 }
 
 MixedContentModel::~MixedContentModel()
 {
+    for (unsigned int index = 0; index < fCount; index++) {
+        delete fChildren[index];
+    }
     fMemoryManager->deallocate(fChildren); //delete [] fChildren;
     fMemoryManager->deallocate(fChildTypes); //delete [] fChildTypes;
 }
