@@ -1,135 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Id: AbstractNumericFacetValidator.cpp,v 1.18 2004/01/29 11:51:22 cargilld Exp $
- * $Log: AbstractNumericFacetValidator.cpp,v $
- * Revision 1.18  2004/01/29 11:51:22  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.17  2003/12/17 00:18:38  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.16  2003/11/12 20:32:03  peiyongz
- * Statless Grammar: ValidationContext
- *
- * Revision 1.15  2003/10/17 21:13:43  peiyongz
- * using XTemplateSerializer
- *
- * Revision 1.14  2003/10/07 19:39:37  peiyongz
- * Use of Template_Class Object Serialization/Deserialization API
- *
- * Revision 1.13  2003/10/02 19:21:06  peiyongz
- * Implementation of Serialization/Deserialization
- *
- * Revision 1.12  2003/05/15 18:53:26  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.11  2003/02/03 16:34:35  peiyongz
- * fix to misplaced derived and base value in error message.
- *
- * Revision 1.10  2003/02/02 23:55:40  peiyongz
- * getFormattedString() added to return original and converted value.
- *
- * Revision 1.9  2003/01/30 21:56:22  tng
- * Performance: call getRawData instead of toString
- *
- * Revision 1.8  2003/01/25 16:33:25  peiyongz
- * wrong error code.
- *
- * Revision 1.7  2002/12/18 14:17:55  gareth
- * Fix to bug #13438. When you eant a vector that calls delete[] on its members you should use RefArrayVectorOf.
- *
- * Revision 1.6  2002/11/26 22:19:15  peiyongz
- * Schema Errata E2-16 maxExclusive
- *
- * Revision 1.5  2002/11/04 14:53:27  tng
- * C++ Namespace Support.
- *
- * Revision 1.4  2002/09/24 19:44:40  tng
- * Performance: use XMLString::equals instead of XMLString::compareString
- *
- * Revision 1.3  2002/04/01 20:17:46  peiyongz
- * Bug#7551: Exceptions are caught by value, rather than by reference
- *
- * Revision 1.2  2002/02/14 15:17:31  peiyongz
- * getEnumString()
- *
- * Revision 1.1.1.1  2002/02/01 22:22:39  peiyongz
- * sane_include
- *
- * Revision 1.6  2001/12/13 16:48:29  peiyongz
- * Avoid dangling pointer
- *
- * Revision 1.5  2001/12/10 22:13:21  peiyongz
- * swap checking to avoid "dangling pointer" reported by BoundsChecker
- *
- * Revision 1.4  2001/11/12 20:37:57  peiyongz
- * SchemaDateTimeException defined
- *
- * Revision 1.3  2001/10/16 16:29:34  tng
- * Schema: Fix Typo
- *
- * Revision 1.2  2001/10/09 21:17:41  peiyongz
- * . macro to simplify code
- * .save get***() to temp vars.
- *
- * Revision 1.1  2001/10/01 16:13:56  peiyongz
- * DTV Reorganization:new classes: AbstractNumericFactValidator/ AbstractNumericValidator
- *
+ * $Id: AbstractNumericFacetValidator.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 // ---------------------------------------------------------------------------
@@ -258,7 +144,6 @@ void AbstractNumericFacetValidator::assignFacet(MemoryManager* const manager)
         return;
 
     XMLCh* key;
-    XMLCh* value;
 
     RefHashTableOfEnumerator<KVStringPair> e(facets, false, manager);
 
@@ -266,7 +151,7 @@ void AbstractNumericFacetValidator::assignFacet(MemoryManager* const manager)
     {
         KVStringPair pair = e.nextElement();
         key = pair.getKey();
-        value = pair.getValue();
+        XMLCh* value = pair.getValue();
 
         if (XMLString::equals(key, SchemaSymbols::fgELT_PATTERN))
         {
@@ -974,18 +859,14 @@ void AbstractNumericFacetValidator::serialize(XSerializeEngine& serEng)
          ***/
         DatatypeValidator::serialize(serEng);
 
-        serEng<<fMaxInclusiveInherited;
-        serEng<<fMaxExclusiveInherited;
-        serEng<<fMinInclusiveInherited;
-        serEng<<fMinExclusiveInherited;
-        serEng<<fEnumerationInherited;
- 
         // need not write type info for the XMLNumber since
-        // the derivative class has done that
-        serEng<<fMaxInclusive;
-        serEng<<fMaxExclusive;
-        serEng<<fMinInclusive;
-        serEng<<fMinExclusive;
+        // the derivative class has done that       
+        storeClusive(serEng, fMaxInclusiveInherited, fMaxInclusive);
+        storeClusive(serEng, fMaxExclusiveInherited, fMaxExclusive);
+        storeClusive(serEng, fMinInclusiveInherited, fMinInclusive);
+        storeClusive(serEng, fMinExclusiveInherited, fMinExclusive);
+
+        serEng<<fEnumerationInherited;
 
         /***
          * Serialize RefArrayVectorOf<XMLCh>
@@ -1005,16 +886,12 @@ void AbstractNumericFacetValidator::serialize(XSerializeEngine& serEng)
 
         DatatypeValidator::serialize(serEng);
 
-        serEng>>fMaxInclusiveInherited;
-        serEng>>fMaxExclusiveInherited;
-        serEng>>fMinInclusiveInherited;
-        serEng>>fMinExclusiveInherited;
-        serEng>>fEnumerationInherited;
+        loadClusive(serEng, fMaxInclusiveInherited, fMaxInclusive, numType, 1);
+        loadClusive(serEng, fMaxExclusiveInherited, fMaxExclusive, numType, 2);
+        loadClusive(serEng, fMinInclusiveInherited, fMinInclusive, numType, 3);
+        loadClusive(serEng, fMinExclusiveInherited, fMinExclusive, numType, 4);
 
-        fMaxInclusive=XMLNumber::loadNumber(numType, serEng);
-        fMaxExclusive=XMLNumber::loadNumber(numType, serEng);
-        fMinInclusive=XMLNumber::loadNumber(numType, serEng);
-        fMinExclusive=XMLNumber::loadNumber(numType, serEng);
+        serEng>>fEnumerationInherited;
 
         /***
          *  Deserialize RefArrayVectorOf<XMLCh>         
@@ -1027,6 +904,66 @@ void AbstractNumericFacetValidator::serialize(XSerializeEngine& serEng)
 
 }
 
+//
+// A user defined dv may inherit any of the Max/Min/Inc/Exc from a
+// built dv, which will create its own Max/Min/Inc/Exc during the
+// loading. Therefore if the user defined store and load this 
+// facet, and does not own it, that will cause leakage.
+//
+// To avoid checking if the facet belongs to a builtIn dv or not, we
+// do this way, for any inherited *clusive, we will not store it, and later 
+// on during loading, we get it from the base dv.
+//
+void AbstractNumericFacetValidator::storeClusive(XSerializeEngine&       serEng
+                                               , bool                    inherited
+                                               , XMLNumber*              data)
+{
+    serEng<<inherited;
+
+    //store only if own it
+    if (!inherited)
+        serEng<<data;
+
+}
+
+// it is guranteed that the base dv is loaded before this dv
+//
+void AbstractNumericFacetValidator::loadClusive(XSerializeEngine&       serEng
+                                              , bool&                   inherited
+                                              , XMLNumber*&             data
+                                              , XMLNumber::NumberType   numType
+                                              , int                     flag)
+{
+    serEng>>inherited;
+
+    if (!inherited)
+        data = XMLNumber::loadNumber(numType, serEng);
+    else
+    {
+        AbstractNumericFacetValidator* basedv = (AbstractNumericFacetValidator*) getBaseValidator();
+
+        switch(flag)
+        {
+        case 1: 
+            data = basedv->getMaxInclusive();
+            break;
+        case 2:
+            data = basedv->getMaxExclusive();
+            break;
+        case 3:
+            data = basedv->getMinInclusive();
+            break;
+        case 4:
+            data = basedv->getMinExclusive();
+            break;
+        default:
+            break;
+        }
+
+    }
+
+}
+
 XERCES_CPP_NAMESPACE_END
 
 /**
