@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: DatatypeValidatorFactory.hpp,v 1.17 2004/09/13 21:38:34 peiyongz Exp $
+ * $Id: DatatypeValidatorFactory.hpp 176148 2004-10-20 15:19:07Z knoaman $
  */
 
 #if !defined(DATATYPEVALIDATORFACTORY_HPP)
@@ -278,8 +278,11 @@ DatatypeValidatorFactory::getBuiltInRegistry() {
 // ---------------------------------------------------------------------------
 inline void DatatypeValidatorFactory::cleanUp() {
 
-	delete fUserDefinedRegistry;
-	fUserDefinedRegistry = 0;
+    if (fUserDefinedRegistry)
+    {
+	    delete fUserDefinedRegistry;
+	    fUserDefinedRegistry = 0;
+    }
 }
 
 XERCES_CPP_NAMESPACE_END
