@@ -15,38 +15,7 @@
  */
 
 /*
- * $Id: DateDatatypeValidator.hpp,v 1.9 2004/09/08 13:56:52 peiyongz Exp $
- * $Log: DateDatatypeValidator.hpp,v $
- * Revision 1.9  2004/09/08 13:56:52  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.8  2004/01/29 11:51:22  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.7  2003/12/17 00:18:38  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.6  2003/10/02 19:21:06  peiyongz
- * Implementation of Serialization/Deserialization
- *
- * Revision 1.5  2003/08/14 03:00:11  knoaman
- * Code refactoring to improve performance of validation.
- *
- * Revision 1.4  2003/05/15 18:53:26  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.3  2002/12/18 14:17:55  gareth
- * Fix to bug #13438. When you eant a vector that calls delete[] on its members you should use RefArrayVectorOf.
- *
- * Revision 1.2  2002/11/04 14:53:28  tng
- * C++ Namespace Support.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:40  peiyongz
- * sane_include
- *
- * Revision 1.1  2001/11/07 19:18:52  peiyongz
- * DateTime Port
- *
+ * $Id: DateDatatypeValidator.hpp 225120 2005-07-25 13:41:26Z cargilld $
  */
 
 #if !defined(DATE_DATATYPE_VALIDATOR_HPP)
@@ -94,6 +63,12 @@ public:
         , MemoryManager* const manager = XMLPlatformUtils::fgMemoryManager
     );
 
+    virtual const XMLCh* getCanonicalRepresentation
+                        (
+                          const XMLCh*         const rawData
+                        ,       MemoryManager* const memMgr = 0
+                        ,       bool                 toValidate = false
+                        ) const;
     /***
      * Support for Serialization/De-serialization
      ***/
