@@ -1,221 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: ComplexTypeInfo.cpp,v $
- * Revision 1.26  2004/01/29 11:52:31  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.25  2004/01/13 16:17:09  knoaman
- * Fo sanity, use class name to qualify method
- *
- * Revision 1.24  2004/01/09 22:41:58  knoaman
- * Use a global static mutex for locking when creating local static mutexes instead of compareAndSwap
- *
- * Revision 1.23  2003/12/24 17:42:03  knoaman
- * Misc. PSVI updates
- *
- * Revision 1.22  2003/12/17 00:18:40  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.21  2003/12/16 17:18:50  peiyongz
- * don't expand ContextSpecNode when deserilized
- *
- * Revision 1.20  2003/11/20 18:05:16  knoaman
- * PSVI: Use a copy of the content spec node when creating the content model.
- *
- * Revision 1.19  2003/11/13 23:20:47  peiyongz
- * initSize
- *
- * Revision 1.18  2003/11/10 21:54:51  neilg
- * implementation for new stateless means of traversing attribute definition lists
- *
- * Revision 1.17  2003/11/07 17:08:12  knoaman
- * For PSVI support, distinguish wildcard elements with namespace lists.
- *
- * Revision 1.16  2003/10/29 16:22:58  peiyongz
- * allow proper recreation of ContentModel from deserialization
- *
- * Revision 1.15  2003/10/21 10:23:53  amassari
- * When creating a new list of attributes, use the assigned memory manager
- *
- * Revision 1.14  2003/10/17 21:17:12  peiyongz
- * using XTemplateSerializer
- *
- * Revision 1.13  2003/10/14 15:22:28  peiyongz
- * Implementation of Serialization/Deserialization
- *
- * Revision 1.12  2003/10/10 16:25:40  peiyongz
- * Implementation of Serialization/Deserialization
- *
- * Revision 1.11  2003/10/08 21:33:48  peiyongz
- * Synchronize ContentSpec/ContentModel/FormattedModel
- *
- * Revision 1.10  2003/09/26 18:31:05  peiyongz
- * Synchronize ContentSpecNode and formattedModel
- *
- * Revision 1.9  2003/05/18 14:02:07  knoaman
- * Memory manager implementation: pass per instance manager.
- *
- * Revision 1.8  2003/05/16 21:43:21  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.7  2003/05/15 18:57:27  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.6  2003/01/29 19:57:30  gareth
- * API to retrive local and uri part of the type name
- *
- * Revision 1.5  2002/12/19 14:04:05  gareth
- * get/set methods to see if the represented type is anonymous. Patch by Peter Volchek.
- *
- * Revision 1.4  2002/11/04 14:49:41  tng
- * C++ Namespace Support.
- *
- * Revision 1.3  2002/03/21 15:34:40  knoaman
- * Add support for reporting line/column numbers of schema errors.
- *
- * Revision 1.2  2002/02/06 22:29:24  knoaman
- * Remove unnecessary data/methods.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:45  peiyongz
- * sane_include
- *
- * Revision 1.27  2002/01/15 19:09:16  knoaman
- * Fix for bug 5807.
- *
- * Revision 1.26  2002/01/02 15:20:22  tng
- * Schema Fix: should not store a temp value as the key in the element pool and the attribute pool.
- *
- * Revision 1.25  2001/12/17 21:38:59  tng
- * Fix dangling pointer.
- *
- * Revision 1.24  2001/11/21 14:30:13  knoaman
- * Fix for UPA checking.
- *
- * Revision 1.23  2001/11/15 17:10:19  knoaman
- * Particle derivation checking support.
- *
- * Revision 1.22  2001/11/07 21:50:28  tng
- * Fix comment log that lead to error.
- *
- * Revision 1.21  2001/11/07 21:12:15  tng
- * Performance: Create QName in ContentSpecNode only if it is a leaf/Any/PCDataNode.
- *
- * Revision 1.20  2001/10/12 18:08:57  tng
- * make sure the second node exists before calling getType
- *
- * Revision 1.19  2001/10/04 15:08:56  knoaman
- * Add support for circular import.
- *
- * Revision 1.18  2001/09/05 20:49:11  knoaman
- * Fix for complexTypes with mixed content model.
- *
- * Revision 1.17  2001/08/29 21:27:07  knoaman
- * no message
- *
- * Revision 1.16  2001/08/28 20:43:52  knoaman
- * Fix for content spec node adoption.
- *
- * Revision 1.15  2001/08/27 23:04:02  knoaman
- * Handle deletion of spec node tree created during UPA checking.
- *
- * Revision 1.14  2001/08/27 20:48:45  knoaman
- * Make the UPA rename before the content model expansion.
- *
- * Revision 1.13  2001/08/27 20:14:42  knoaman
- * Validate attributes in <all>, <redefine>, <group> and <attributeGroup> declarations.
- * Misc. fixes.
- *
- * Revision 1.12  2001/08/24 12:48:48  tng
- * Schema: AllContentModel
- *
- * Revision 1.11  2001/08/23 11:54:26  tng
- * Add newline at the end and various typo fixes.
- *
- * Revision 1.10  2001/08/21 18:14:55  knoaman
- * Defer creation of spec node.
- *
- * Revision 1.9  2001/08/21 16:06:11  tng
- * Schema: Unique Particle Attribution Constraint Checking.
- *
- * Revision 1.8  2001/08/09 15:23:16  knoaman
- * add support for <anyAttribute> declaration.
- *
- * Revision 1.7  2001/07/24 18:33:46  knoaman
- * Added support for <group> + extra constraint checking for complexType
- *
- * Revision 1.6  2001/06/05 13:59:53  knoaman
- * Fixes to include and import.
- *
- * Revision 1.5  2001/05/11 13:27:32  tng
- * Copyright update.
- *
- * Revision 1.4  2001/05/10 17:49:40  tng
- * Schema: SchemaValidator fixes
- *
- * Revision 1.3  2001/05/10 16:33:12  knoaman
- * Traverse Schema Part III + error messages.
- *
- * Revision 1.2  2001/05/03 20:34:41  tng
- * Schema: SchemaValidator update
- *
- * Revision 1.1  2001/04/19 17:43:14  knoaman
- * More schema implementation classes.
- *
+ * $Id: ComplexTypeInfo.cpp 191219 2005-06-17 21:51:35Z dbertoni $
  */
 
 // ---------------------------------------------------------------------------
@@ -232,6 +32,7 @@
 #include <xercesc/validators/schema/XSDLocator.hpp>
 #include <xercesc/internal/XTemplateSerializer.hpp>
 #include <xercesc/util/XMLRegisterCleanup.hpp>
+#include <xercesc/util/XMLInitializer.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
@@ -263,6 +64,11 @@ void ComplexTypeInfo::reinitAnyType() {
     sAnyTypeMutexRegistered = false;
 }
 
+void XMLInitializer::initializeAnyType()
+{
+    ComplexTypeInfo::getAnyType(1);
+}
+
 ComplexTypeInfo* ComplexTypeInfo::getAnyType(unsigned int emptyNSId)
 {
     if (!sAnyTypeMutexRegistered)
@@ -271,7 +77,7 @@ ComplexTypeInfo* ComplexTypeInfo::getAnyType(unsigned int emptyNSId)
         {
             XMLMutexLock lock(XMLPlatformUtils::fgAtomicMutex);
             if (!sAnyTypeMutex)
-                sAnyTypeMutex = new XMLMutex;
+                sAnyTypeMutex = new XMLMutex(XMLPlatformUtils::fgMemoryManager);
         }
 
         // Use a faux scope to synchronize while we do this
@@ -356,8 +162,10 @@ ComplexTypeInfo::ComplexTypeInfo(MemoryManager* const manager)
     , fBlockSet(0)
     , fFinalSet(0)
     , fScopeDefined(Grammar::TOP_LEVEL_SCOPE)
-    , fElementId(XMLElementDecl::fgInvalidElemId)
     , fContentType(SchemaElementDecl::Empty)
+    , fElementId(XMLElementDecl::fgInvalidElemId)
+    , fUniqueURI(0)
+    , fContentSpecOrgURISize(16)
     , fTypeName(0)
     , fTypeLocalName(0)
     , fTypeUri(0)
@@ -367,18 +175,16 @@ ComplexTypeInfo::ComplexTypeInfo(MemoryManager* const manager)
     , fContentSpec(0)
     , fAttWildCard(0)    
     , fAttList(0)
-    , fElements(0)
-    , fSpecNodesToDelete(0)
+    , fElements(0)    
     , fAttDefs(0)
     , fContentModel(0)
     , fFormattedModel(0)
     , fContentSpecOrgURI(0)
-    , fUniqueURI(0)
-    , fContentSpecOrgURISize(16)    
     , fLocator(0)
     , fMemoryManager(manager)
 {
-
+    fAttDefs = new (fMemoryManager) RefHash2KeysTableOf<SchemaAttDef>(29, true, fMemoryManager);
+    fAttList = new (fMemoryManager) SchemaAttDefList(fAttDefs,fMemoryManager);
 }
 
 
@@ -395,8 +201,7 @@ ComplexTypeInfo::~ComplexTypeInfo()
     delete fAttWildCard;
     delete fAttDefs;
     delete fAttList;
-    delete fElements;
-    delete fSpecNodesToDelete;
+    delete fElements;    
     delete fLocator;
 
     delete fContentModel;
@@ -410,18 +215,12 @@ ComplexTypeInfo::~ComplexTypeInfo()
 // ---------------------------------------------------------------------------
 void ComplexTypeInfo::addAttDef(SchemaAttDef* const toAdd) {
 
-    // Fault in the att list if required
-    if (!fAttDefs)
-        faultInAttDefList();
-
     // Tell this guy the element id of its parent (us)
     toAdd->setElemId(getElementId());
 
     fAttDefs->put((void*)(toAdd->getAttName()->getLocalPart()),
                           toAdd->getAttName()->getURI(), toAdd);
     // update and/or create fAttList
-    if(!fAttList)
-        ((ComplexTypeInfo*)this)->fAttList = new (fMemoryManager) SchemaAttDefList(fAttDefs,fMemoryManager);
     fAttList->addAttDef(toAdd);
 }
 
@@ -450,17 +249,11 @@ void ComplexTypeInfo::setLocator(XSDLocator* const aLocator) {
 // ---------------------------------------------------------------------------
 XMLAttDefList& ComplexTypeInfo::getAttDefList() const
 {
-    if (!fAttList)
-    {
-        // If the att def list is not made yet, then fault it in too
-        if (!fAttDefs)
-            faultInAttDefList();
-
-        ((ComplexTypeInfo*)this)->fAttList = new (fMemoryManager) SchemaAttDefList(fAttDefs, fMemoryManager);
-    }
-
-    // Reset it before we return it
-    fAttList->Reset();
+    // NOTE: if users plan on using nextElement() to access attributes
+    //       they need to call Reset() explicitly (i.e attList.Reset()).
+    //       It's better to get the attribute count and use an index to
+    //       access attributes (especially if same grammar is used in
+    //       multiple threads).
     return *fAttList;
 }
 
@@ -491,19 +284,11 @@ XMLAttDef* ComplexTypeInfo::findAttr(const XMLCh* const
                                      , const XMLElementDecl::LookupOpts   options
                                      , bool&              wasAdded) const
 {
-    SchemaAttDef* retVal = 0;
-
-    // If no att list faulted in yet, then it cannot exist
-    if (fAttDefs)
-        retVal = fAttDefs->get(baseName, uriId);
+    SchemaAttDef* retVal = fAttDefs->get(baseName, uriId);
 
     // Fault it in if not found and ask to add it
     if (!retVal && (options == XMLElementDecl::AddIfNotFound))
     {
-        // Fault in the list itself if not already
-        if (!fAttDefs)
-            faultInAttDefList();
-
         // And add a default attribute for this name
         retVal = new (fMemoryManager) SchemaAttDef
         (
@@ -517,9 +302,7 @@ XMLAttDef* ComplexTypeInfo::findAttr(const XMLCh* const
         retVal->setElemId(getElementId());
         fAttDefs->put((void*)retVal->getAttName()->getLocalPart(), uriId, retVal);
 
-        // update and/or create fAttList
-        if(!fAttList)
-            ((ComplexTypeInfo*)this)->fAttList = new (fMemoryManager) SchemaAttDefList(fAttDefs,fMemoryManager);
+        // update fAttList
         fAttList->addAttDef(retVal);
         wasAdded = true;
     }
@@ -532,15 +315,9 @@ XMLAttDef* ComplexTypeInfo::findAttr(const XMLCh* const
 
 bool ComplexTypeInfo::resetDefs() {
 
-    // If the collection hasn't been faulted in, then no att defs
-    if (!fAttDefs)
-        return false;
-
-    //
     //  Ok, run through them and clear the 'provided' flag on each of them.
     //  This lets the scanner use them to track which has been provided and
     //  which have not.
-    //
     RefHash2KeysTableOfEnumerator<SchemaAttDef> enumDefs(fAttDefs, false, fMemoryManager);
     while (enumDefs.hasMoreElements())
         enumDefs.nextElement().setProvided(false);
@@ -554,16 +331,12 @@ void ComplexTypeInfo::checkUniqueParticleAttribution (SchemaGrammar*    const pG
                                                       XMLStringPool*    const pStringPool,
                                                       XMLValidator*     const pValidator)
 {
-    if (fContentSpec) {
-        ContentSpecNode* specNode = new (fMemoryManager) ContentSpecNode(*fContentSpec);
-        XMLContentModel* cm = makeContentModel(true, specNode);
-
-        if (cm) {
-            cm->checkUniqueParticleAttribution(pGrammar, pGrammarResolver, pStringPool, pValidator, fContentSpecOrgURI);
-            delete cm;
+    if (fContentSpec && !fContentModel)
+    {
+        fContentModel = makeContentModel(true);
+        if (fContentModel) {
+            fContentModel->checkUniqueParticleAttribution(pGrammar, pGrammarResolver, pStringPool, pValidator, fContentSpecOrgURI, fTypeLocalName);
         }
-
-        fSpecNodesToDelete->removeAllElements();
     }
 }
 
@@ -611,33 +384,22 @@ XMLCh* ComplexTypeInfo::formatContentModel() const
     return newValue;
 }
 
-XMLContentModel* ComplexTypeInfo::makeContentModel(const bool checkUPA, ContentSpecNode* const specNode)
+XMLContentModel* ComplexTypeInfo::makeContentModel(const bool checkUPA)
 {
-    if ((specNode || fContentSpec) && !fSpecNodesToDelete) {
-        fSpecNodesToDelete = new (fMemoryManager) RefVectorOf<ContentSpecNode>(8, true, fMemoryManager);
-    }
-
-    // expand the content spec first
-    ContentSpecNode* aSpecNode = specNode;
+    ContentSpecNode* aSpecNode = new (fMemoryManager) ContentSpecNode(*fContentSpec);
     XMLContentModel* retModel = 0;
-    if (aSpecNode) {
 
+    if (checkUPA) {
         fContentSpecOrgURI = (unsigned int*) fMemoryManager->allocate
         (
             fContentSpecOrgURISize * sizeof(unsigned int)
         ); //new unsigned int[fContentSpecOrgURISize];
-        aSpecNode = convertContentSpecTree(aSpecNode, checkUPA);
-        retModel = buildContentModel(aSpecNode);
-        fSpecNodesToDelete->addElement(aSpecNode);
-    }
-    else {
-        // building content model for the complex type
-        aSpecNode = new (fMemoryManager) ContentSpecNode(*fContentSpec);
-        aSpecNode = convertContentSpecTree(aSpecNode, checkUPA);
-        retModel = buildContentModel(aSpecNode);
-        delete aSpecNode;
     }
 
+    aSpecNode = convertContentSpecTree(aSpecNode, checkUPA);
+    retModel = buildContentModel(aSpecNode);
+
+    delete aSpecNode;
     return retModel;
 }
 
@@ -803,12 +565,14 @@ ComplexTypeInfo::convertContentSpecTree(ContentSpecNode* const curNode,
     // When checking Unique Particle Attribution, rename leaf elements
     if (checkUPA) {
         if (curNode->getElement()) {
+            if (fUniqueURI == fContentSpecOrgURISize) {
+                resizeContentSpecOrgURI();
+            }
+
             fContentSpecOrgURI[fUniqueURI] = curNode->getElement()->getURI();
             curNode->getElement()->setURI(fUniqueURI);
             fUniqueURI++;
         }
-        if (fUniqueURI == fContentSpecOrgURISize)
-            resizeContentSpecOrgURI();
     }
 
     // Get the spec type of the passed node
@@ -1073,9 +837,10 @@ void ComplexTypeInfo::serialize(XSerializeEngine& serEng)
         serEng<<fBlockSet;
         serEng<<fFinalSet;
         serEng<<fScopeDefined;
-        serEng<<fElementId;
         serEng<<fContentType;
 
+        serEng<<fElementId;
+
         serEng.writeString(fTypeName);
         serEng.writeString(fTypeLocalName);
         serEng.writeString(fTypeUri);
@@ -1101,8 +866,7 @@ void ComplexTypeInfo::serialize(XSerializeEngine& serEng)
           *
           *   fContentModel;
           *   fFormattedModel;
-          *   fLocator;
-          *   fSpecNodesToDelete
+          *   fLocator;          
           * 
           *   fContentSpecOrgURI:     start of the array
           *   fContentSpecOrgURISize: size of the array
@@ -1120,9 +884,10 @@ void ComplexTypeInfo::serialize(XSerializeEngine& serEng)
         serEng>>fBlockSet;
         serEng>>fFinalSet;
         serEng>>fScopeDefined;
-        serEng>>fElementId;
         serEng>>fContentType;
 
+        serEng>>fElementId;
+
         serEng.readString(fTypeName);
         serEng.readString(fTypeLocalName);
         serEng.readString(fTypeUri);
@@ -1133,6 +898,7 @@ void ComplexTypeInfo::serialize(XSerializeEngine& serEng)
         serEng>>fBaseComplexTypeInfo;
         serEng>>fContentSpec;
         serEng>>fAttWildCard;
+        delete fAttList; // will recreate it next...
         serEng>>fAttList;
 
         /***
@@ -1141,14 +907,14 @@ void ComplexTypeInfo::serialize(XSerializeEngine& serEng)
          * Deserialize RefHash2KeysTableOf<SchemaAttDef>* fAttDefs;
          ***/
         XTemplateSerializer::loadObject(&fElements, 8, false, serEng);
+        delete fAttDefs; // will recreate it next...
         XTemplateSerializer::loadObject(&fAttDefs, 29, true, serEng);
 
          /***
           *   Don't deserialize 
           *
           *   fFormattedModel;
-          *   fLocator;
-          *   fSpecNodesToDelete
+          *   fLocator;          
           * 
           *   fContentSpecOrgURI:     start of the array
           *   fContentSpecOrgURISize: size of the array
@@ -1156,11 +922,18 @@ void ComplexTypeInfo::serialize(XSerializeEngine& serEng)
           ***/
 
          fFormattedModel = 0;
-         fLocator = 0;
-         fSpecNodesToDelete = 0;
+         fLocator = 0;         
          fContentSpecOrgURI = 0;
          fContentSpecOrgURISize = 0;
          fUniqueURI = 0;
+
+         // Create the content model by calling getContentModel().  This
+         // will ensure the grammar can be used concurrently by multiple
+         // parsers.
+         // Don't bother to do check unique particle attribution, since
+         // this will already have been done when the grammar was first
+         // created (if full schema checking was enabled).
+         getContentModel(false);
     }
 }
 
