@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: ComplexTypeInfo.hpp,v 1.23 2004/09/23 00:37:24 cargilld Exp $
+ * $Id: ComplexTypeInfo.hpp 176334 2005-03-07 20:10:21Z knoaman $
  */
 
 #if !defined(COMPLEXTYPEINFO_HPP)
@@ -203,8 +203,12 @@ private:
     int                                fBlockSet;
     int                                fFinalSet;
     int                                fScopeDefined;
-    unsigned int                       fElementId;
     int                                fContentType;
+
+    unsigned int                       fElementId;
+    unsigned int                       fUniqueURI;
+    unsigned int                       fContentSpecOrgURISize;
+
     XMLCh*                             fTypeName;
     XMLCh*                             fTypeLocalName;
     XMLCh*                             fTypeUri;
@@ -219,8 +223,6 @@ private:
     XMLContentModel*                   fContentModel;
     XMLCh*                             fFormattedModel;
     unsigned int*                      fContentSpecOrgURI;
-    unsigned int                       fUniqueURI;
-    unsigned int                       fContentSpecOrgURISize;
     XSDLocator*                        fLocator;
     MemoryManager*                     fMemoryManager;
 
@@ -326,20 +328,12 @@ inline SchemaAttDef* ComplexTypeInfo::getAttWildCard() {
 inline const SchemaAttDef* ComplexTypeInfo::getAttDef(const XMLCh* const baseName,
                                                       const int uriId) const {
 
-    // If no list, then return a null
-    if (!fAttDefs)
-        return 0;
-
     return fAttDefs->get(baseName, uriId);
 }
 
 inline SchemaAttDef* ComplexTypeInfo::getAttDef(const XMLCh* const baseName,
                                                 const int uriId)
 {
-    // If no list, then return a null
-    if (!fAttDefs)
-        return 0;
-
     return fAttDefs->get(baseName, uriId);
 }
 
@@ -538,19 +532,11 @@ inline void ComplexTypeInfo::setAnonymous() {
 // ---------------------------------------------------------------------------
 inline bool ComplexTypeInfo::hasAttDefs() const
 {
-    // If the collection hasn't been faulted in, then no att defs
-    if (!fAttDefs)
-        return false;
-
     return !fAttDefs->isEmpty();
 }
 
 inline bool ComplexTypeInfo::contains(const XMLCh* const attName) {
 
-    if (!fAttDefs) {
-        return false;
-    }
-
     RefHash2KeysTableOfEnumerator<SchemaAttDef> enumDefs(fAttDefs, false, fMemoryManager);
 
     while (enumDefs.hasMoreElements()) {
