@@ -15,7 +15,16 @@
  */
 
 /*
- * $Log: GeneralAttributeCheck.cpp,v $
+ * $Log$
+ * Revision 1.27  2005/03/17 08:22:29  amassari
+ * Fully qualify enum (jira# 1383)
+ *
+ * Revision 1.26  2004/11/18 16:20:06  cargilld
+ * Changes for linker problems with linux build using xlc.
+ *
+ * Revision 1.25  2004/10/20 15:19:07  knoaman
+ * Allow option of initializing static data in XMLPlatformUtils::Initialize
+ *
  * Revision 1.24  2004/09/30 13:14:28  amassari
  * Fix jira#1280 - Borland leaks memory if break or continue are used inside a catch block
  *
@@ -155,6 +164,7 @@
 #include <xercesc/validators/schema/TraverseSchema.hpp>
 #include <xercesc/util/PlatformUtils.hpp>
 #include <xercesc/util/XMLRegisterCleanup.hpp>
+#include <xercesc/util/XMLInitializer.hpp>
 #include <xercesc/validators/datatype/DatatypeValidatorFactory.hpp>
 #include <xercesc/util/OutOfMemoryException.hpp>
 
@@ -163,28 +173,28 @@ XERCES_CPP_NAMESPACE_BEGIN
 // ---------------------------------------------------------------------------
 //  Local const data
 // ---------------------------------------------------------------------------
-const XMLCh fgValueZero[] =
+static const XMLCh fgValueZero[] =
 {
     chDigit_0, chNull
 };
 
-const XMLCh fgValueOne[] =
+static const XMLCh fgValueOne[] =
 {
     chDigit_1, chNull
 };
 
-const XMLCh fgUnbounded[] =
+static const XMLCh fgUnbounded[] =
 {
     chLatin_u, chLatin_n, chLatin_b, chLatin_o, chLatin_u, chLatin_n, chLatin_d,
     chLatin_e, chLatin_d, chNull
 };
 
-const XMLCh fgLocal[] =
+static const XMLCh fgLocal[] =
 {
     chLatin_l, chLatin_o, chLatin_c, chLatin_a, chLatin_l, chNull
 };
 
-const XMLCh fgGlobal[] =
+static const XMLCh fgGlobal[] =
 {
     chLatin_g, chLatin_l, chLatin_o, chLatin_b, chLatin_a, chLatin_l, chNull
 };
@@ -207,6 +217,12 @@ DatatypeValidator*                GeneralAttributeCheck::fNonNegIntDV = 0;
 DatatypeValidator*                GeneralAttributeCheck::fBooleanDV = 0;
 DatatypeValidator*                GeneralAttributeCheck::fAnyURIDV = 0;
 
+void XMLInitializer::initializeGeneralAttrCheckMap()
+{
+    GeneralAttributeCheck *obj = new GeneralAttributeCheck();
+    delete obj;
+}
+
 
 // ---------------------------------------------------------------------------
 //  GeneralAttributeCheck: Constructors and Destructor
@@ -248,7 +264,7 @@ void GeneralAttributeCheck::mapElements()
             XMLMutexLock lock(XMLPlatformUtils::fgAtomicMutex);
 
             if (!sGeneralAttCheckMutex)
-                sGeneralAttCheckMutex = new XMLMutex;
+                sGeneralAttCheckMutex = new XMLMutex(XMLPlatformUtils::fgMemoryManager);
         }
 
         // Use a faux scope to synchronize while we do this
@@ -595,7 +611,7 @@ void GeneralAttributeCheck::initCharFlagTable()
     //  Write it out to a temp file to be read back into this source later.
     //
     FILE* outFl = fopen("ea_table.out", "wt+");
-    fprintf(outFl, "unsigned short GeneralAttributeCheck::fgElemAttTable[E_Count][A_Count] =\n{\n    {");
+    fprintf(outFl, "unsigned short GeneralAttributeCheck::fgElemAttTable[GeneralAttributeCheck::E_Count][GeneralAttributeCheck::A_Count] =\n{\n    {");
 
     //"all"
     attList[E_All][A_ID] = Att_Optional | DV_ID;
@@ -930,7 +946,7 @@ unsigned short GeneralAttributeCheck::fgElemAttTable[GeneralAttributeCheck::E_Co
   { 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 0, 34, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 4098, 0, 0}
 };
 
-const XMLCh* GeneralAttributeCheck::fAttNames[A_Count] =
+const XMLCh* GeneralAttributeCheck::fAttNames[GeneralAttributeCheck::A_Count] =
 {
     SchemaSymbols::fgATT_ABSTRACT,
     SchemaSymbols::fgATT_ATTRIBUTEFORMDEFAULT,
