@@ -1,114 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 2001, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: SchemaAttDef.cpp,v $
- * Revision 1.13  2004/01/29 11:52:31  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.12  2003/12/24 17:42:03  knoaman
- * Misc. PSVI updates
- *
- * Revision 1.11  2003/12/17 20:50:35  knoaman
- * PSVI: fix for annotation of attributes in attributeGroup/derived types
- *
- * Revision 1.10  2003/11/25 18:15:00  knoaman
- * Serialize enclosing complex type. Thanks to David Cargill.
- *
- * Revision 1.9  2003/11/21 22:34:46  neilg
- * More schema component model implementation, thanks to David Cargill.
- * In particular, this cleans up and completes the XSModel, XSNamespaceItem,
- * XSAttributeDeclaration and XSAttributeGroup implementations.
- *
- * Revision 1.8  2003/10/17 21:17:12  peiyongz
- * using XTemplateSerializer
- *
- * Revision 1.7  2003/10/10 16:25:40  peiyongz
- * Implementation of Serialization/Deserialization
- *
- * Revision 1.6  2003/05/18 14:02:07  knoaman
- * Memory manager implementation: pass per instance manager.
- *
- * Revision 1.5  2003/05/16 21:43:21  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.4  2003/02/06 13:51:55  gareth
- * fixed bug with multiple attributes being validated by the same union type.
- *
- * Revision 1.3  2003/01/29 19:47:16  gareth
- * added DOMTypeInfo and some PSVI methods
- *
- * Revision 1.2  2002/11/04 14:49:41  tng
- * C++ Namespace Support.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:45  peiyongz
- * sane_include
- *
- * Revision 1.4  2001/08/09 15:23:16  knoaman
- * add support for <anyAttribute> declaration.
- *
- * Revision 1.3  2001/07/31 15:26:54  knoaman
- * Added support for <attributeGroup>.
- *
- * Revision 1.2  2001/05/11 13:27:33  tng
- * Copyright update.
- *
- * Revision 1.1  2001/02/27 18:48:22  tng
- * Schema: Add SchemaAttDef, SchemaElementDecl, SchemaAttDefList.
- *
+ * $Id: SchemaAttDef.cpp 191054 2005-06-17 02:56:35Z jberry $
  */
 
 
@@ -136,14 +43,14 @@ const XMLCh* SchemaAttDef::getFullName() const
 SchemaAttDef::SchemaAttDef(MemoryManager* const manager) :
     XMLAttDef(XMLAttDef::CData, XMLAttDef::Implied, manager)
     , fElemId(XMLElementDecl::fgInvalidElemId)
+    , fValidity(PSVIDefs::UNKNOWN)
+    , fValidation(PSVIDefs::NONE)
+    , fPSVIScope(PSVIDefs::SCP_ABSENT)    
     , fAttName(0)
     , fDatatypeValidator(0)
     , fAnyDatatypeValidator(0)
     , fMemberTypeValidator(0)
     , fNamespaceList(0)
-    , fValidity(PSVIDefs::UNKNOWN)
-    , fValidation(PSVIDefs::NONE)
-    , fPSVIScope(PSVIDefs::SCP_ABSENT)    
     , fBaseAttDecl(0)
 {
 }
@@ -156,13 +63,13 @@ SchemaAttDef::SchemaAttDef( const XMLCh* const           prefix
                           , MemoryManager* const         manager) :
     XMLAttDef(type, defType, manager)
     , fElemId(XMLElementDecl::fgInvalidElemId)
+    , fValidity(PSVIDefs::UNKNOWN)
+    , fValidation(PSVIDefs::NONE)
+    , fPSVIScope(PSVIDefs::SCP_ABSENT)
     , fDatatypeValidator(0)
     , fAnyDatatypeValidator(0)
     , fMemberTypeValidator(0)    
     , fNamespaceList(0)
-    , fValidity(PSVIDefs::UNKNOWN)
-    , fValidation(PSVIDefs::NONE)
-    , fPSVIScope(PSVIDefs::SCP_ABSENT)
     , fBaseAttDecl(0)
 {
     fAttName = new (manager) QName(prefix, localPart, uriId, manager);
@@ -179,13 +86,13 @@ SchemaAttDef::SchemaAttDef( const XMLCh* const           prefix
 
     XMLAttDef(attValue, type, defType, enumValues, manager)
     , fElemId(XMLElementDecl::fgInvalidElemId)
+    , fValidity(PSVIDefs::UNKNOWN)
+    , fValidation(PSVIDefs::NONE)
+    , fPSVIScope(PSVIDefs::SCP_ABSENT)
     , fDatatypeValidator(0)
     , fAnyDatatypeValidator(0)
     , fMemberTypeValidator(0)
     , fNamespaceList(0)
-    , fValidity(PSVIDefs::UNKNOWN)
-    , fValidation(PSVIDefs::NONE)
-    , fPSVIScope(PSVIDefs::SCP_ABSENT)
     , fBaseAttDecl(0)
 {
     fAttName = new (manager) QName(prefix, localPart, uriId, manager);
@@ -197,14 +104,14 @@ SchemaAttDef::SchemaAttDef(const SchemaAttDef* other) :
               other->getDefaultType(), other->getEnumeration(),
               other->getMemoryManager())
     , fElemId(XMLElementDecl::fgInvalidElemId)
+    , fValidity(other->fValidity)
+    , fValidation(other->fValidation)
+    , fPSVIScope(other->fPSVIScope)
     , fAttName(0)
     , fDatatypeValidator(other->fDatatypeValidator)
     , fAnyDatatypeValidator(other->fAnyDatatypeValidator)
     , fMemberTypeValidator(other->fMemberTypeValidator)
     , fNamespaceList(0)
-    , fValidity(other->fValidity)
-    , fValidation(other->fValidation)
-    , fPSVIScope(other->fPSVIScope)
     , fBaseAttDecl(other->fBaseAttDecl)
 {
     QName* otherName = other->getAttName();
@@ -248,7 +155,12 @@ void SchemaAttDef::serialize(XSerializeEngine& serEng)
     if (serEng.isStoring())
     {
         serEng<<fElemId;
+        serEng<<(int)fValidity;
+        serEng<<(int)fValidation;
+        serEng<<(int)fPSVIScope;
+
         serEng<<fAttName;
+
         DatatypeValidator::storeDV(serEng, fDatatypeValidator);
         DatatypeValidator::storeDV(serEng, fAnyDatatypeValidator);
         DatatypeValidator::storeDV(serEng, (DatatypeValidator*)fMemberTypeValidator);
@@ -258,15 +170,24 @@ void SchemaAttDef::serialize(XSerializeEngine& serEng)
          ***/
         XTemplateSerializer::storeObject(fNamespaceList, serEng);
 
-        serEng<<(int)fValidity;
-        serEng<<(int)fValidation;
         serEng<<fBaseAttDecl;
     }
     else
     {
 
         serEng>>fElemId;
+        int i;
+        serEng>>i;
+        fValidity = (PSVIDefs::Validity)i;
+
+        serEng>>i;
+        fValidation = (PSVIDefs::Validation)i;
+        
+        serEng>>i;
+        fPSVIScope = (PSVIDefs::PSVIScope)i;
+
         serEng>>fAttName;
+
         fDatatypeValidator    = DatatypeValidator::loadDV(serEng);
         fAnyDatatypeValidator = DatatypeValidator::loadDV(serEng);
         fMemberTypeValidator  = DatatypeValidator::loadDV(serEng);
@@ -275,14 +196,7 @@ void SchemaAttDef::serialize(XSerializeEngine& serEng)
          * Deserialize ValueVectorOf<unsigned int>
          ***/
         XTemplateSerializer::loadObject(&fNamespaceList, 8, false, serEng);
-
-        int i;
-        serEng>>i;
-        fValidity = (PSVIDefs::Validity)i;
-
-        serEng>>i;
-        fValidation = (PSVIDefs::Validation)i;
-
+       
         serEng>>fBaseAttDecl;
     }
 }
