@@ -15,7 +15,7 @@
  */
 
 /**
-  * $Id: XSDDOMParser.cpp,v 1.14 2004/09/08 13:56:57 peiyongz Exp $
+  * $Id: XSDDOMParser.cpp 219096 2005-07-14 20:51:00Z amassari $
   */
 
 
@@ -245,6 +245,8 @@ void XSDDOMParser::startElement( const XMLElementDecl&       elemDecl
     else
     {
         startAnnotationElement(elemDecl, attrList, attrCount);
+        if(isEmpty)
+            endElement(elemDecl, urlId, isRoot, elemPrefix);
         // avoid falling through; don't call startElement in this case
         return;
     }
@@ -314,9 +316,9 @@ void XSDDOMParser::startElement( const XMLElementDecl&       elemDecl
         XMLAttDef* attr = 0;
         DOMAttrImpl * insertAttr = 0;
 
-        while (defAttrs->hasMoreElements())
+        for (unsigned int i=0; i<defAttrs->getAttDefCount(); i++)
         {
-            attr = &defAttrs->nextElement();
+            attr = &defAttrs->getAttDef(i);
 
             const XMLAttDef::DefAttTypes defType = attr->getDefaultType();
             if ((defType == XMLAttDef::Default)
