@@ -15,44 +15,20 @@
  */
 
 /*
- * $Log: FieldValueMap.cpp,v $
- * Revision 1.8  2004/09/08 13:56:59  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.7  2003/10/01 16:32:42  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.6  2003/05/22 02:10:52  knoaman
- * Default the memory manager.
- *
- * Revision 1.5  2003/05/18 14:02:09  knoaman
- * Memory manager implementation: pass per instance manager.
- *
- * Revision 1.4  2003/05/15 18:59:34  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.3  2002/12/18 14:17:59  gareth
- * Fix to bug #13438. When you eant a vector that calls delete[] on its members you should use RefArrayVectorOf.
- *
- * Revision 1.2  2002/11/04 14:47:41  tng
- * C++ Namespace Support.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:50  peiyongz
- * sane_include
- *
- * Revision 1.1  2001/11/02 14:08:40  knoaman
- * Add support for identity constraints.
- *
+ * $Id: FieldValueMap.cpp 191701 2005-06-21 18:16:34Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
 //  Includes
 // ---------------------------------------------------------------------------
 #include <xercesc/validators/schema/identity/FieldValueMap.hpp>
+#include <xercesc/util/Janitor.hpp>
 #include <xercesc/util/OutOfMemoryException.hpp>
 
 XERCES_CPP_NAMESPACE_BEGIN
 
+typedef JanitorMemFunCall<FieldValueMap>    CleanupType;
+
 // ---------------------------------------------------------------------------
 //  FieldValueMap: Constructors and Destructor
 // ---------------------------------------------------------------------------
@@ -65,39 +41,47 @@ FieldValueMap::FieldValueMap(MemoryManager* const manager)
 }
 
 FieldValueMap::FieldValueMap(const FieldValueMap& other)
-    : fFields(0)
+    : XMemory(other)
+    , fFields(0)
     , fValidators(0)
     , fValues(0)
     , fMemoryManager(other.fMemoryManager)
 {
-    try {
-        if (other.fFields) {
+    if (other.fFields) {
+        CleanupType cleanup(this, &FieldValueMap::cleanUp);
 
-            unsigned int valuesSize = other.fValues->size();
+        try {
 
-            fFields = new (fMemoryManager) ValueVectorOf<IC_Field*>(*(other.fFields));
-            fValidators = new (fMemoryManager) ValueVectorOf<DatatypeValidator*>(*(other.fValidators));
-            fValues = new (fMemoryManager) RefArrayVectorOf<XMLCh>(other.fFields->curCapacity(), true, fMemoryManager);
+                unsigned int valuesSize = other.fValues->size();
 
-            for (unsigned int i=0; i<valuesSize; i++) {
-                fValues->addElement(XMLString::replicate(other.fValues->elementAt(i), fMemoryManager));
-            }
+                fFields = new (fMemoryManager) ValueVectorOf<IC_Field*>(*(other.fFields));
+                fValidators = new (fMemoryManager) ValueVectorOf<DatatypeValidator*>(*(other.fValidators));
+                fValues = new (fMemoryManager) RefArrayVectorOf<XMLCh>(other.fFields->curCapacity(), true, fMemoryManager);
+
+                for (unsigned int i=0; i<valuesSize; i++) {
+                    fValues->addElement(XMLString::replicate(other.fValues->elementAt(i), fMemoryManager));
+                }
         }
-    }
-    catch(const OutOfMemoryException&)
-    {
-        throw;
-    }
-    catch(...) {
+        catch(const OutOfMemoryException&)
+        {
+            cleanup.release();
 
-        delete fFields;
-        delete fValidators;
-        delete fValues;
-        throw;
+            throw;
+        }
+
+        cleanup.release();
     }
 }
 
 FieldValueMap::~FieldValueMap()
+{
+    cleanUp();
+}
+
+// ---------------------------------------------------------------------------
+//  FieldValueMap: Private helper methods.
+// ---------------------------------------------------------------------------
+void FieldValueMap::cleanUp()
 {
     delete fFields;
     delete fValidators;
