@@ -15,46 +15,7 @@
  */
 
 /*
- * $Log: IdentityConstraint.cpp,v $
- * Revision 1.11  2004/09/08 13:56:59  peiyongz
- * Apache License Version 2.0
- *
- * Revision 1.10  2004/01/29 11:52:32  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.9  2003/11/14 22:35:09  neilg
- * changes in support of second phase of XSModel implementation; thanks to David Cargill
- *
- * Revision 1.8  2003/11/13 23:21:41  peiyongz
- * initSize
- *
- * Revision 1.7  2003/10/17 21:18:04  peiyongz
- * using XTemplateSerializer
- *
- * Revision 1.6  2003/10/14 15:24:23  peiyongz
- * Implementation of Serialization/Deserialization
- *
- * Revision 1.5  2003/10/01 16:32:42  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.4  2003/05/15 18:59:34  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.3  2002/11/04 14:47:41  tng
- * C++ Namespace Support.
- *
- * Revision 1.2  2002/09/24 19:57:20  tng
- * Performance: use XMLString::equals instead of XMLString::compareString
- *
- * Revision 1.1.1.1  2002/02/01 22:22:50  peiyongz
- * sane_include
- *
- * Revision 1.2  2001/11/15 17:10:19  knoaman
- * Particle derivation checking support.
- *
- * Revision 1.1  2001/11/02 14:08:40  knoaman
- * Add support for identity constraints.
- *
+ * $Id: IdentityConstraint.cpp 191701 2005-06-21 18:16:34Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
@@ -77,6 +38,8 @@
 
 XERCES_CPP_NAMESPACE_BEGIN
 
+typedef JanitorMemFunCall<IdentityConstraint>   CleanupType;
+
 // ---------------------------------------------------------------------------
 //  IdentityConstraint: Constructors and Destructor
 // ---------------------------------------------------------------------------
@@ -90,19 +53,20 @@ IdentityConstraint::IdentityConstraint(const XMLCh* const identityConstraintName
     , fMemoryManager(manager)
     , fNamespaceURI(-1)
 {
+    CleanupType cleanup(this, &IdentityConstraint::cleanUp);
+
     try {
         fIdentityConstraintName = XMLString::replicate(identityConstraintName, fMemoryManager);
         fElemName = XMLString::replicate(elemName, fMemoryManager);
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch(...) {
+        cleanup.release();
 
-        cleanUp();
         throw;
     }
+
+    cleanup.release();
 }
 
 
