@@ -1,109 +1,21 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 2001-2005 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 /*
- * $Log: XercesXPath.cpp,v $
- * Revision 1.13  2004/01/29 11:52:32  cargilld
- * Code cleanup changes to get rid of various compiler diagnostic messages.
- *
- * Revision 1.12  2003/12/17 00:18:41  cargilld
- * Update to memory management so that the static memory manager (one used to call Initialize) is only for static data.
- *
- * Revision 1.11  2003/10/17 21:18:04  peiyongz
- * using XTemplateSerializer
- *
- * Revision 1.10  2003/10/14 15:24:23  peiyongz
- * Implementation of Serialization/Deserialization
- *
- * Revision 1.9  2003/10/01 16:32:42  neilg
- * improve handling of out of memory conditions, bug #23415.  Thanks to David Cargill.
- *
- * Revision 1.8  2003/05/18 14:02:09  knoaman
- * Memory manager implementation: pass per instance manager.
- *
- * Revision 1.7  2003/05/16 21:43:22  knoaman
- * Memory manager implementation: Modify constructors to pass in the memory manager.
- *
- * Revision 1.6  2003/05/15 18:59:34  knoaman
- * Partial implementation of the configurable memory manager.
- *
- * Revision 1.5  2002/12/20 22:10:48  tng
- * XML 1.1
- *
- * Revision 1.4  2002/12/04 18:21:23  knoaman
- * Identity constraint fix.
- *
- * Revision 1.3  2002/11/04 14:47:42  tng
- * C++ Namespace Support.
- *
- * Revision 1.2  2002/10/30 21:52:01  tng
- * [Bug 13641] compiler-generated copy-constructor for QName doesn't do the right thing.
- *
- * Revision 1.1.1.1  2002/02/01 22:22:51  peiyongz
- * sane_include
- *
- * Revision 1.3  2001/11/15 17:10:19  knoaman
- * Particle derivation checking support.
- *
- * Revision 1.2  2001/11/07 14:25:36  knoaman
- * Fix compliation error on Unix.
- *
- * Revision 1.1  2001/11/02 14:08:40  knoaman
- * Add support for identity constraints.
- *
+ * $Id: XercesXPath.cpp 191701 2005-06-21 18:16:34Z cargilld $
  */
 
 // ---------------------------------------------------------------------------
@@ -168,8 +80,10 @@ XercesNodeTest::XercesNodeTest(const XMLCh* const prefix,
 }
 
 XercesNodeTest::XercesNodeTest(const XercesNodeTest& other)
-    : fType(other.fType)
-    , fName(new ((other.fName)->getMemoryManager())QName(*other.fName))
+    : XSerializable(other)
+    , XMemory(other)
+    , fType(other.fType)
+    , fName(new ((other.fName)->getMemoryManager()) QName(*other.fName))
 {
 }
 
@@ -240,7 +154,9 @@ XercesStep::XercesStep(const unsigned short axisType, XercesNodeTest* const node
 }
 
 XercesStep::XercesStep(const XercesStep& other)
-    : fAxisType(other.fAxisType)
+    : XSerializable(other)
+    , XMemory(other)
+    , fAxisType(other.fAxisType)
     , fNodeTest(0)
 {
     fNodeTest = new (other.fNodeTest->getName()->getMemoryManager()) XercesNodeTest(*(other.fNodeTest));
@@ -291,12 +207,15 @@ void XercesStep::serialize(XSerializeEngine& serEng)
 {
     if (serEng.isStoring())
     {
-        serEng<<fAxisType;
+        serEng<<(int)fAxisType;
         serEng<<fNodeTest;
     }
     else
     {
-        serEng>>fAxisType;
+        int i;
+        serEng>>i;
+        fAxisType = (unsigned short) i;
+
         serEng>>fNodeTest;
     }
 }
@@ -367,6 +286,8 @@ XercesLocationPath::XercesLocationPath(MemoryManager* const)
 {
 }
 
+typedef JanitorMemFunCall<XercesXPath>  CleanupType;
+
 // ---------------------------------------------------------------------------
 //  XercesPath: Constructors and Destructor
 // ---------------------------------------------------------------------------
@@ -381,6 +302,8 @@ XercesXPath::XercesXPath(const XMLCh* const xpathExpr,
     , fLocationPaths(0)
     , fMemoryManager(manager)
 {
+    CleanupType cleanup(this, &XercesXPath::cleanUp);
+
     try
     {
         fExpression = XMLString::replicate(xpathExpr, fMemoryManager);
@@ -392,13 +315,12 @@ XercesXPath::XercesXPath(const XMLCh* const xpathExpr,
     }
     catch(const OutOfMemoryException&)
     {
-        throw;
-    }
-    catch(...) {
+        cleanup.release();
 
-        cleanUp();
         throw;
     }
+
+    cleanup.release();
 }
 
 XercesXPath::~XercesXPath() {
@@ -1380,7 +1302,7 @@ int XPathScanner::scanNCName(const XMLCh* const data,
 
     XMLCh ch = data[currentOffset];
 
-    if (!XMLChar1_0::isXMLLetter(ch) && ch != chUnderscore) {
+    if (!XMLChar1_0::isFirstNCNameChar(ch)) {
         return currentOffset;
     }
 
@@ -1388,7 +1310,7 @@ int XPathScanner::scanNCName(const XMLCh* const data,
 
         ch = data[currentOffset];
 
-        if (ch == chColon || !XMLChar1_0::isNameChar(ch)) {
+        if (!XMLChar1_0::isNCNameChar(ch)) {
             break;
         }
     }
