@@ -15,7 +15,7 @@
  */
 
 /*
- * $Id: ThreadTest.cpp,v 1.35 2004/09/08 13:57:05 peiyongz Exp $
+ * $Id: ThreadTest.cpp 240234 2005-08-26 13:06:50Z cargilld $
  *
  * @author Andy Heninger, IBM
  */
@@ -88,7 +88,7 @@ void ThreadFuncs::startThread(ThreadFunc func, void *param)
 }
 
 
-#elif defined (AIX) || defined(SOLARIS) || defined(LINUX) || defined(HPUX) || defined (OS390) || defined(MACOSX) || defined(FREEBSD) || defined(__CYGWIN__) || defined(__QNXNTO__)
+#elif defined (AIX) || defined(SOLARIS) || defined(LINUX) || defined(HPUX) || defined (OS390) || defined(MACOSX) || defined(FREEBSD) || defined(__CYGWIN__) || defined(__QNXNTO__) || defined(INTERIX) || defined(IRIX)
 #include <pthread.h>
 #include <unistd.h>
 #include <errno.h>
@@ -354,22 +354,22 @@ public:
     void resetDocument() {
     };
 
-    void warning(const SAXParseException& exception)     {
+    void warning(const SAXParseException& exc)     {
         fprintf(stderr, "*** Warning ");
         fflush(stderr);
-        throw exception;
+        throw exc;
     };
 
-    void error(const SAXParseException& exception)       {
+    void error(const SAXParseException& exc)       {
         fprintf(stderr, "*** Error ");
         fflush(stderr);
-        throw exception;
+        throw exc;
     };
 
-    void fatalError(const SAXParseException& exception)  {
+    void fatalError(const SAXParseException& exc)  {
         fprintf(stderr, "***** Fatal error ");
         fflush(stderr);
-        throw exception;
+        throw exc;
     };
 
     // Create a nested class that can inherit from HandlerBase
