@@ -1,129 +1,22 @@
 /*
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2000 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution,
- *    if any, must include the following acknowledgment:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowledgment may appear in the software itself,
- *    if and wherever such third-party acknowledgments normally appear.
- *
- * 4. The names "Xerces" and "Apache Software Foundation" must
- *    not be used to endorse or promote products derived from this
- *    software without prior written permission. For written
- *    permission, please contact apache\@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache",
- *    nor may "Apache" appear in their name, without prior written
- *    permission of the Apache Software Foundation.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation, and was
- * originally based on software copyright (c) 1999, International
- * Business Machines, Inc., http://www.ibm.com .  For more information
- * on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
+ * Copyright 1999-2000,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 
 /*
- * $Log: Xlat.cpp,v $
- * Revision 1.18  2003/05/14 19:11:34  gareth
- * Added code creation for new method that returns error serverity the DOM way.
- *
- * Revision 1.17  2003/04/14 08:41:00  gareth
- * Xlat now works under linux - Big thanks to Neil Graham (I no longer have to find a windows box). Still slight problems working with glibc before 2.2.4 (If you mess up the parameters it seg faults due to handling of wprintf)
- *
- * Revision 1.16  2002/12/12 23:40:39  peiyongz
- * normlize locale string.
- *
- * Revision 1.15  2002/11/12 17:24:58  tng
- * DOM Message: add new domain for DOM Messages.
- *
- * Revision 1.14  2002/11/04 15:24:50  tng
- * C++ Namespace Support.
- *
- * Revision 1.13  2002/09/30 22:09:58  peiyongz
- * To generate icu resource file (in text) for error message.
- *
- * Revision 1.12  2002/07/04 17:40:07  tng
- * Use new DOM in Xlat.
- *
- * Revision 1.11  2002/03/01 16:18:38  tng
- * Nest entire code in an inner block so that reference counting should recover
- * all document and DOMString storage when this block exits.
- *
- * Revision 1.10  2002/02/07 16:19:40  knoaman
- * sane_include update.
- *
- * Revision 1.9  2002/02/01 23:48:37  peiyongz
- * sane_include
- *
- * Revision 1.8  2001/05/03 19:09:36  knoaman
- * Support Warning/Error/FatalError messaging.
- * Validity constraints errors are treated as errors, with the ability by user to set
- * validity constraints as fatal errors.
- *
- * Revision 1.7  2000/03/18 00:00:58  roddey
- * Improved error reporting
- *
- * Revision 1.6  2000/03/03 01:29:36  roddey
- * Added a scanReset()/parseReset() method to the scanner and
- * parsers, to allow for reset after early exit from a progressive parse.
- * Added calls to new Terminate() call to all of the samples. Improved
- * documentation in SAX and DOM parsers.
- *
- * Revision 1.5  2000/03/02 19:55:52  roddey
- * This checkin includes many changes done while waiting for the
- * 1.1.0 code to be finished. I can't list them all here, but a list is
- * available elsewhere.
- *
- * Revision 1.4  2000/02/14 19:25:44  roddey
- * Fixed some small bugs in how it used strings returned from DOM calls.
- *
- * Revision 1.3  2000/02/06 07:48:41  rahulj
- * Year 2K copyright swat.
- *
- * Revision 1.2  2000/01/05 20:24:58  roddey
- * Some changes to simplify life for the Messge Catalog message loader. The formatter
- * for the message loader now spits out a simple header of ids that allows the loader to
- * be independent of hard coded set numbers.
- *
- * Revision 1.1.1.1  1999/11/09 01:01:12  twl
- * Initial checkin
- *
- * Revision 1.5  1999/11/08 20:42:04  rahul
- * Swat for adding in Product name and CVS comment log variable.
- *
+ * $Id: Xlat.cpp 226336 2005-07-29 07:54:39Z amassari $
  */
 
 
@@ -412,6 +305,13 @@ enumMessages(   const   DOMElement*             srcElem
         //  Write out an entry to the target header file. These are enums, so
         //  we use the id as the enum name.
         //
+
+        if (XMLString::stringLen(msgText) > 128) {
+            wprintf(L"Message text %s is too long, 128 character limit\n\n", xmlStrToPrintable(msgText));            
+            throw ErrReturn_SrcFmtError;
+        }
+
+
         fwprintf(headerFl, L"      , %-32s   = %d\n", xmlStrToPrintable(msgId), count);
         releasePrintableStr
 
@@ -466,18 +366,22 @@ int main (int argC, char** argV) {
         wprintf(L"Parser init error.\n  ERROR: %s\n\n", toCatch.getMessage());
         return ErrReturn_ParserInit;
     }
-    	
+    
+    int i;
     XMLCh** newArgV = new XMLCh*[argC];
-    for(int i=0;i<argC; i++) 
+    for(i=0;i<argC; i++) 
     {
         newArgV[i] = XMLString::transcode(argV[i]);
     }
     int toReturn = (Xlat_main(argC,newArgV));
-    for (int i=0; i<argC; i++) 
+    for (i=0; i<argC; i++) 
     {
-        delete [] newArgV[i];
+        XMLString::release(&newArgV[i]);
     }
     delete [] newArgV;
+
+    XMLPlatformUtils::Terminate();
+
     return toReturn;
 }
 
@@ -534,7 +438,7 @@ int Xlat_main(int argC, XMLCh** argV)
             {
                 parseError(toCatch);
             }
-            XMLString::release(&tmpFileBuf);
+            delete tmpFileBuf;
 
             //
             //  Use the output format parm to create the correct kind of output
@@ -699,7 +603,7 @@ int Xlat_main(int argC, XMLCh** argV)
                     XMLString::release(&errNameSpace);
                     throw ErrReturn_OutFileOpenFailed;
                 }
-                XMLString::release(&tmpFileBuf);                
+                delete tmpFileBuf;
 
                 //
                 //  Write out the opening of the class they are nested within, and
@@ -707,6 +611,7 @@ int Xlat_main(int argC, XMLCh** argV)
                 //                
                 fwprintf(outHeader, L"// This file is generated, don't edit it!!\n\n");
                 fwprintf(outHeader, L"#if !defined(ERRHEADER_%s)\n", xmlStrToPrintable(errNameSpace) );
+                releasePrintableStr                
                 fwprintf(outHeader, L"#define ERRHEADER_%s\n\n", xmlStrToPrintable(errNameSpace) );
                 releasePrintableStr
 
@@ -918,6 +823,14 @@ int Xlat_main(int argC, XMLCh** argV)
 
                 }
 
+                // the private default ctor
+                fwprintf(outHeader, L"\n");
+                fwprintf(outHeader, L"private:\n");
+                fwprintf(outHeader, L"    // -----------------------------------------------------------------------\n");
+                fwprintf(outHeader, L"    //  Unimplemented constructors and operators\n");
+                fwprintf(outHeader, L"    // -----------------------------------------------------------------------\n");
+                fwprintf(outHeader, L"    %s();\n", xmlStrToPrintable(errNameSpace));
+                releasePrintableStr
 
                 // And close out the class declaration, the namespace declaration and the header file
                 fwprintf(outHeader, L"};\n\n");
@@ -949,7 +862,6 @@ int Xlat_main(int argC, XMLCh** argV)
 
     // And call the termination method
     release_Globals();
-    XMLPlatformUtils::Terminate();
 
     // Went ok, so return success
     return ErrReturn_Success;
